
/*
 * Colors variations
 */

@textColor: #333;

@magenta: #6e3671;
@teal: #568a89;
@pink: #ac5287;
@pinkDark: #a8829f;
@yellow: #d4c737;
@yellowLight: #fff03d;
@orange: #c79121;
@orangeLight: #ee9000;
@orangeDark: #a57225;
@purple: #65596B;
@teal: #568a89;
@blueDark: #4c4f53;
@blue: #60747c;
@blueLight: #ccdadf;
@red: #931313;
@redLight: #a65858;
@greenDark: #496949;
@green: #356e35;
@greenLight: #71843f;

@white: #ffffff;
@black: #000000;
@darken: #404040;
@lighten: #d5e7ec;
@grayDark: #525252;
@silver: #b4b4b4;
@silverLight: #d0d0d0;


.txt-color-blue {
	color: @blue !important;
}
.txt-color-blueLight {
	color: @blueLight !important;
}
.txt-color-blueDark {
	color: @blueDark !important;
}
.txt-color-green {
	color: @green !important;
}
.txt-color-greenLight {
	color: @greenLight !important;
}
.txt-color-greenDark {
	color: @greenDark !important;
}
.txt-color-red {
	color: @red !important;
}
.txt-color-yellow {
	color: @yellow !important;
}
.txt-color-yellowLight {
	color: @yellowLight !important;
}
.txt-color-orange {
	color: @orange !important;
}
.txt-color-orangeLight {
	color: @orangeLight !important;
}
.txt-color-orangeDark {
	color: @orangeDark !important;
}
.txt-color-pink {
	color: @pink !important;
}
.txt-color-pinkDark {
	color: @pinkDark !important;
}
.txt-color-purple {
	color: @purple !important;
}
.txt-color-darken {
	color: @darken !important;
}
.txt-color-silver {
	color: @silver !important;
}
.txt-color-lighten {
	color: @lighten !important;
}
.txt-color-white {
	color: @white !important;
}
.txt-color-grayDark {
	color: @grayDark !important;
}
.txt-color-magenta {
	color: @magenta !important;
}
.txt-color-teal {
	color: @teal !important;
}
.txt-color-redLight {
	color: @redLight !important;
}
.bg-color-blue {
	background-color: @blue !important;
}
.bg-color-blueLight {
	background-color: @blueLight !important;
}
.bg-color-blueDark {
	background-color: @blueDark !important;
}
.bg-color-green {
	background-color: @green !important;
}
.bg-color-greenLight {
	background-color: @greenLight !important;
}
.bg-color-greenDark {
	background-color: @greenDark !important;
}
.bg-color-red {
	background-color: @red !important;
}
.bg-color-yellow {
	background-color: @yellow !important;
}
.bg-color-yellowLight {
	background-color: @yellowLight !important;
}
.bg-color-orange {
	background-color: @orange !important;
}
.bg-color-orangeLight {
	background-color: @orangeLight !important;
}
.bg-color-orangeDark {
	background-color: @orangeDark !important;
}
.bg-color-pink {
	background-color: @pink !important;
}
.bg-color-pinkDark {
	background-color: @pinkDark !important;
}
.bg-color-purple {
	background-color: @purple !important;
}
.bg-color-darken {
	background-color: @darken !important;
}
.bg-color-silver {
	background-color: @silver !important;
}
.bg-color-lighten {
	background-color: @lighten !important;
}
.bg-color-white {
	background-color: @white !important;
}
.bg-color-grayDark {
	background-color: @grayDark !important;
}
.bg-color-magenta {
	background-color: @magenta !important;
}
.bg-color-teal {
	background-color: @teal !important;
}
.bg-color-redLight {
	background-color: @redLight !important;
}
