/*
 * Buttons
 */

.customfile-button {
	padding: 6px 12px;
	margin-bottom: 0;
	font-size: 14px;
	font-weight: 400;
	line-height: 1.428571429;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	cursor: pointer;
	border: 1px solid #ccc;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	-o-user-select: none;
	user-select: none;
}

.btn,
a:link,
button {
	-webkit-tap-highlight-color: rgba(169, 3, 41, .5);
}

.btns {
	margin:0;
	padding:0;
	list-style:none;

	>li {
		display:inline-block;
		margin-bottom:7px;
	}
}

.btn {
	padding: 6px 12px;
	border-radius: 2px;
	box-shadow: inset 0 -2px 0 rgba(0, 0, 0, .05);
	-webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, .05);

	&:active {
		position: relative;
		top: 1px;
		left: 1px;
	}
	&.btn-ribbon {
		background-color: #5b6771;
		color: #fff;
		padding: 1px 5px;
		line-height: 20px;
		vertical-align: middle;
		height: 21px;
		display: block;
		border: 0;
		float: left;
		margin: 0 8px 0 0;
		cursor: pointer;
	}
	&.btn-ribbon>i {
		font-size: 111%;
	}
}

.btn-xs {
	padding: 1px 5px;
	line-height: 1.3em;
}
.btn-sm {
	padding: 3px 10px;
}
.btn-lg {
	padding: 9px 15px;
}
.btn-xl {
	padding: 11px 15px;
}

.btn-circle {
	width: 30px;
	height: 30px;
	text-align: center;
	padding: 7px 0 5px;
	font-size: 12px;
	line-height: 18px;
	border-radius: 50%;

	&.btn-lg {
		width: 50px;
		height: 50px;
		padding: 9px 15px 7px;
		font-size: 18px;
		line-height: 30px;
		border-radius: 50%;
	}
	&.btn-xl {
		width: 70px;
		height: 70px;
		padding: 11px 15px 9px;
		font-size: 24px;
		line-height: 50px;
		border-radius: 50%;
	}
}

.btn-metro {
	margin: 0 0 20px;
	padding-top: 15px;
	padding-bottom: 15px;

	>span {
		display: block;
		vertical-align: bottom;
		margin-top: 10px;
		text-transform: uppercase;

		>span.label {
			position: absolute;
			top: 0;
			right: 0;
		}
	}
}

/*.btn-primary {
	background-color: #627685;
	border-color: #46545e;

	&:hover,
	&:focus,
	&:active,
	&.active,
	.open .dropdown-toggle& {
		background-color: rgba(91, 103, 113, 0.8);
		border-color: #46545e;
	}
}*/

.btn-label {
	position: relative;
	left: -12px;
	display: inline-block;
	padding: 7px 12px 5px;
	background: rgba(0, 0, 0, .15);
	border-radius: 3px 0 0 3px;
}

.btn-labeled {
	padding-top: 0;
	padding-bottom: 0;
}

.btn-select-tick {
	i {
		display: none;
	}
	.btn:hover i {
		opacity: .3;
		display: block;
	}
	.active i {
		display: block;
		opacity: 1!important;
	}
}

.btn-header {
	&.pull-right {
		margin-left: 6px;
	}
	a {
		@media (min-width:768px) and (max-width:979px) {
			margin-top: 9px!important;
			/*width: 40px!important;*/
		}
		@media (min-width:768px) and (max-width:880px) {
			margin-top: 9px!important;
			/*width: 40px!important;*/
			/*height: 39px!important;*/
			line-height: 26px!important;
		}
		@media (max-width:767px) {
			margin-top: 5px!important;
			width: 40px!important;
			height: 39px!important;
			line-height: 34px!important;
		}
		@media only screen and (min-width:0) and (max-width:679px) {
			margin-top: 5px!important;
			width: 40px!important;
			height: 39px!important;
			line-height: 34px!important;
		}
		@media only screen and (min-width:320px) and (max-width:479px) {
			margin-top: 5px!important;
			width: 40px!important;
			height: 39px!important;
			line-height: 34px!important;
		}
		>span {
			font-size: 13px;
			font-weight: 400;
			line-height: 30px;
			height: 30px;
			display: inline-block;
		}
	}
	&.transparent {
		@media (min-width:768px) and (max-width:880px) {
			a {
				border: 0!important;
				background: 0 0;
				margin-left: 0;
				width: 25px!important;
				-webkit-box-shadow: none!important;
				box-shadow: none!important;

				&:hover {
					color: #a90329;
				}
			}
		}
		@media (max-width:767px) {
			a:hover {
				color: #a90329;
			}
		}
		@media only screen and (min-width:0) and (max-width:679px) {
			a {
				border: 0!important;
				background: 0 0;
				margin-left: 0;
				width: 25px!important;
				-webkit-box-shadow: none!important;
				box-shadow: none!important;

				&:hover {
					color: #a90329;
				}
			}
		}
		@media only screen and (min-width:320px) and (max-width:479px) {
			a {
				border: 0!important;
				background: 0 0;
				margin-left: 0;
				width: 25px!important;
				-webkit-box-shadow: none!important;
				box-shadow: none!important;

				&:hover {
					color: #a90329;
				}
			}
		}
	}
	>:first-child >a {
		border-radius: 2px;
		cursor: default!important;
		display: inline-block;
		font-weight: 700;
		height: 30px;
		min-width: 30px;
		padding: 3px;
		text-align: center;
		text-decoration: none!important;
		-moz-user-select: none;
		-webkit-user-select: none;
		background-color: #f8f8f8;
		background-image: -webkit-gradient(linear, left top, left bottom, from(#f8f8f8), to(#f1f1f1));
		background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
		background-image: -webkit-gradient(linear, top left, bottom left, from(#f8f8f8), to(#f1f1f1));
		background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
		background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
		border: 1px solid #bfbfbf;
		color: #6D6A69;
		font-size: 17px;
		margin: 10px 0 0;

		&:hover {
			border: 1px solid #bfbfbf;
			color: #222;
			-webkit-transition: all 0s;
			transition: all 0s;
			cursor: pointer;
			-webkit-box-shadow: inset 0 0 4px 1px rgba(0, 0, 0, .08);
			box-shadow: inset 0 0 4px 1px rgba(0, 0, 0, .08);
		}
		&:active {
			background-color: #e8e8e8;
			background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #e8e8e8), color-stop(100%, #ededed));
			background-image: -webkit-linear-gradient(top, #e8e8e8 0, #ededed 100%);
			background-image: -webkit-gradient(linear, top left, bottom left, from(#e8e8e8), to(#ededed));
			background-image: -webkit-linear-gradient(top, #e8e8e8 0, #ededed 100%);
			background-image: linear-gradient(to bottom, #e8e8e8 0, #ededed 100%);
			filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#e8e8e8',  endColorstr='#ededed',  GradientType=0);
			-webkit-box-shadow: inset 0 0 3px 1px rgba(0, 0, 0, .15);
			box-shadow: inset 0 0 3px 1px rgba(0, 0, 0, .15);
		}
	}
}

.ribbon-button-alignment {
	padding-top: 10px;
	display: inline-block;

	&.pull-right >.btn.btn-ribbon {
		margin: 0 0 0 8px;
	}
}

.header-btn {
	margin-top: 5px;
}
