/*
 * Pricing-style component
 */

.pricing-big {
	border: 0!important;

	.panel-heading {
		border-radius: 5px 5px 0 0;
	}

	.panel-title {
		text-transform: capitalize;
		font-size: 18px;
		padding: 20px 0;
		text-align: center;
		border-radius: 5px 5px 0 0;
		margin: 0;
		font-weight: 700;
	}

	.the-price {
		padding: 20px 0;
		background: #333;
		text-align: center;
		font-size: 24px;
		font-weight: 700;
		color: #FFF;
		-webkit-box-shadow: none!important;
		box-shadow: none!important;
	}

	.subscript {
		font-size: 18px;
		color: #999;
		margin-left: 5px;
	}

	.panel-footer {
		border-radius: 0 0 5px 5px;
		background-color: #F2F2F2!important;

		>div {
			padding: 15px 0 10px;
			display: block;
			font-size: 13px;
		}

		.btn {
			padding: 15px 0;
			border-radius: 3px;
			font-weight: 700;
			font-size: 14px;

			span {
				font-weight: 400;
				font-style: italic;
			}
		}
	}

	table {
		background: #FAFAFA;
		padding: 20px 15px;
		height: 230px;
		text-align: left;
	}
}

.price-features {
	background: #FAFAFA;
	padding: 20px 15px;
	min-height: 230px;
	font-size: 13.5px;

	.price-features li+li {
		margin-top: 10px;
	}
}
