/*
 * Forms styles
 */

.form {
	hr {
		margin-left: -13px;
		margin-right: -13px;
		border-color: rgba(0, 0, 0, .1);
		margin-top: 20px;
		margin-bottom: 20px;
	}
	fieldset {
		display: block;
		border: 0;
		background: rgba(255, 255, 255, .9);
		position: relative;
	}
	header,
	legend {
		display: block;
		padding: 8px 0;
		border-bottom: 1px dashed rgba(0, 0, 0, .2);
		background: #fff;
		font-size: 16px;
		font-weight: 300;
		color: #222;
		margin: 25px 0 20px;
	}
	.no-padding & header {
		margin: 25px 14px 0;
	}
	header:first-child {
		margin-top: 10px;
	}
	.form-group:last-child,
	.form-group:last-child .note,
	fieldset .form-group:last-child,
	fieldset .form-group:last-child .note {
		margin-bottom: 0;
	}
}

fieldset {
	position: relative;
}

legend {
	font-weight: 400;
	margin-top: 0;
	background: 0 0;
}

i.hint {
	vertical-align: super;
	opacity: 0.5;

	&:hover {
		opacity: 0.9;
	}
	.nohints & {
		display: none;
	}
}

.input-group-addon {
	padding: 6px 10px 5px;
	border-radius: 0;
	transition: background-color .3s;
	-webkit-transition: background-color .3s;

	.fa {
		font-size: 14px;
	}
	.fa-2x,
	.fa-lg {
		font-size: 2em;
	}
	.fa-3x,
	.fa-4x,
	.fa-5x {
		font-size: 30px;
	}
	.checkbox,
	.radio {
		min-height: 0;
		margin-right: 0!important;
		padding-top: 0;
	}
	label input[type=checkbox].checkbox + span,
	label input[type=checkbox].checkbox + span:before,
	label input[type=radio].radiobox + span,
	label input[type=radio].radiobox+span:before {
		margin-right: 0;
	}
	.onoffswitch,
	.onoffswitch-label {
		margin: 0;
	}
	input[type=text]:focus + & {
		border-color: #0091d9;
		background-color: #72a0ce;
		color: #fff;
	}
	.has-warning input[type=text]:focus + & {
		border-color: #7f6a1e;
		background-color: #cead35;
		color: #fff;
	}
	.has-error input[type=text]:focus + & {
		border-color: #c46a69;
		background-color: #c46a69;
		color: #fff;
	}
	.has-success input[type=text]:focus + & {
		border-color: #446b46;
		background-color: #588a5a;
		color: #fff;
	}
}

.input-icon-left {
	>i {
		right: auto;
		left: 24px;
	}
	.form-control {
		padding-left: 29px;
	}
}

.input-icon-right {
	position: relative;

	.form-control {
		padding-right: 27px;
	}
}

.input-icon-left,
.input-icon-right {
	>i {
		position: absolute;
		right: 10px;
		top: 30%;
		font-size: 16px;
		color: #bfbfbf;
	}
}

.form-actions {
	display: block;
	padding: 13px 14px 15px;
	border-top: 1px solid rgba(0, 0, 0, .1);
	background: rgba(249, 249, 249, .9);
	margin-top: 25px;
	margin-left: -13px;
	margin-right: -13px;
	margin-bottom: -13px;
	text-align: right;

	.well & {
		margin-left: -19px;
		margin-right: -19px;
		margin-bottom: -19px;
	}
	.well.well-lg & {
		margin-left: -24px;
		margin-right: -24px;
		margin-bottom: -24px;
	}
	.well.well-sm & {
		margin-left: -9px;
		margin-right: -9px;
		margin-bottom: -9px;
	}
	.popover-content & {
		margin: 0 -14px -9px;
		border-radius: 0 0 3px 3px;
		padding: 9px 14px;
	}
	.no-padding .form & {
		margin: 0;
		display: block;
		padding: 13px 14px 15px;
		border-top: 1px solid rgba(0, 0, 0, .1);
		background: rgba(248, 248, 248, .9);
		text-align: right;
		margin-top: 25px;
	}
}

:focus {
	outline: 0!important;
}

.filter_column input {
	padding: 0px 3px;
}
.filter_column input,
.filter_column select {
	width: 100%;
	color: rgba(0, 0, 0, 0.5);
	border: 1px solid #CCC;
	border-radius: 0;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	   -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
			box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.uneditable-input:focus,
input[type=color]:focus,
input[type=date]:focus,
input[type=datetime-local]:focus,
input[type=datetime]:focus,
input[type=email]:focus,
input[type=month]:focus,
input[type=number]:focus,
input[type=password]:focus,
input[type=search]:focus,
input[type=tel]:focus,
input[type=text]:focus,
input[type=time]:focus,
input[type=url]:focus,
input[type=week]:focus,
.filter_column input:focus,
.filter_column select:focus,
select:focus,
textarea:focus {
	border-color: rgba(82, 168, 236, 0.8);
	outline: 0;
	outline: thin dotted 9;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.6);
	   -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.6);
			box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.6);
}

.form-control {
	padding: 7px 12px 5px;
}

.form-control,
.input-lg,
.input-sm,
.input-xs {
	border-radius: 0 !important;
}

.input-xs {
	height: 24px;
	padding: 3px 10px 1px;
	font-size: 11px;
	line-height: 1.5;
}

.fileinput {
	padding-top: 3px;
}


input[type=checkbox].checkbox,
input[type=radio].radiobox {
	visibility: hidden;
	position: absolute;
	z-index: 20;
	width: 18px;
	height: 18px;

	.checkbox &+span,
	.checkbox-inline &+span,
	.radio &+span,
	.radiobox-inline &+span {
		margin-left: -20px;

		.form-inline & {
			margin-left: 0;
		}
	}
	&+span,
	label &+span {
		vertical-align: middle;
		line-height: 20px;
	}
	&+span,
	&+span:after,
	&:before {
		box-sizing: content-box!important;
		-webkit-box-sizing: content-box!important;
		-moz-box-sizing: content-box!important;
	}
	label &+span {
		position: relative;
		z-index: 19;
		display: inline-block;
		margin: 0;
		line-height: 17px;
		min-height: 14px;
		min-width: 14px;
		margin-right: 5px;

		&:hover {
			cursor: pointer;
		}
		&:before {
			font-family: FontAwesome;
			font-size: 12px;
			border-radius: 0;
			content: "\a0";
			display: inline-block;
			text-align: center;
			vertical-align: middle;
			padding: 1px;
			height: 12px;
			line-height: 12px;
			min-width: 12px;
			margin-right: 5px;
			border: 1px solid #bfbfbf;
			background-color: #f4f4f4;
			font-weight: 400;
			margin-top: -1px;
		}
	}
}

input[type=checkbox] {
	label & {
		&.checkbox {
			+span:before {
				content: "\a0";
			}
			&:checked+span {
				font-weight: 700;

				&:before {
					content: "\f00c";
					color: #2E7BCC;
				}
			}
			&.style-1 {
				&+span:before {
					color: #333;
					background: #fff;
					text-shadow: none;
					-webkit-box-shadow: none!important;
					box-shadow: none!important;
					border-width: 1px;
					height: 12px;
					line-height: 13px;
					min-width: 12px;
				}
				&:checked+span {
					font-weight: 400;

					&:before {
						color: #333;
						border-color: #333;
					}
				}
			}
			&.style-2+span:before {
				background: 0 0;
				border-color: #c1c1c1;
				-webkit-box-shadow: none;
				box-shadow: none;
			}
			&.style-2:checked+span {
				font-weight: 400;

				&:before {
					content: "\f00c";
					color: #66665e;
					border-color: #4d90fe;
					background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6MUQ0MEM4RUFEQUE4MTFFMkEwMjM5NzlCRjAxM0UwRjciIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6MUQ0MEM4RUJEQUE4MTFFMkEwMjM5NzlCRjAxM0UwRjciPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDoxRDQwQzhFOERBQTgxMUUyQTAyMzk3OUJGMDEzRTBGNyIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDoxRDQwQzhFOURBQTgxMUUyQTAyMzk3OUJGMDEzRTBGNyIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/PsD/PVAAAAAQSURBVHjaYv7//78vQIABAAlYA05NMPppAAAAAElFTkSuQmCC) #fff;
				}
			}
			&.style-3:checked+span:before {
				color: #fff;
				border-color: #a90329;
				background: #a90329;
			}
		}
	}
	label:active & {
		&.checkbox {
			+span:before {
				-webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
				box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
			}
		}
	}
	label:hover & {
		&.checkbox {
			+span:before {
				color: #2E7BCC;
				border-color: #2E7BCC;
			}
			&.style-1+span:before {
				border-color: #333;
			}
			&.style-2 {
				+span:before {
					-webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .1), 0 1px 0 0 rgba(255, 255, 255, .2);
					box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .1), 0 1px 0 0 rgba(255, 255, 255, .2);
				}
				&:checked+span:before {
					-webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
					box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
				}
			}
			&.style-3+span:before {
				color: #fff;
				border-color: #A90327;
			}
		}
	}
	label:active & {
		&.checkbox {
			&:checked+span:before {
				color: #fff;
				background: #2E7BCC;
				border-color: #2E7BCC;
			}
			&.style-1:checked+span:before {
				color: #fff;
				background: #333;
				border-color: #333;
			}
			&.style-2+span:before,
			&.style-2:checked+span:before {
				color: #66665e;
				background: 0 0;
				border-color: #c1c1c1;
				-webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
				box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
			}
			&.style-3:checked+span:before {
				color: #a90329;
				background: #fff;
				border-color: #a90329;
			}
		}
	}
	label &[disabled] {
		&.checkbox {
			+span,
			&:checked+span {
				color: #A7A7A7;
				cursor: not-allowed;
			}
			&:checked+span:before {
				content: "\f00c";
			}
			&.style-2:checked+span:before {
				content: "\f00c";
			}
			+span:before,
			&:checked+span:before,
			&:checked+span:before {
				background: #eee!important;
				border-color: #CCC!important;
				-webkit-box-shadow: none;
				color: #A7A7A7;
				box-shadow: none!important;
			}
		}
	}
	label:hover &[disabled] {
		&.checkbox {
			&:checked+span:before {
				color: #A7A7A7;
				cursor: not-allowed;
			}
			&:checked+span:before {
				background: #eee!important;
				border-color: #CCC!important;
				-webkit-box-shadow: none;
				color: #A7A7A7;
				box-shadow: none!important;
			}
		}
	}
}

input[type=radio] {
	&.radiobox {
		label & {
			+span:before {
				content: "\a0";
				border-radius: 50%;
				-webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .1), 0 1px 0 0 rgba(255, 255, 255, .2);
				box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .1), 0 1px 0 0 rgba(255, 255, 255, .2);
			}
			&:checked+span {
				font-weight: 700;

				&:before {
					content: "\f111";
					color: #2E7BCC;
				}
			}
			&.style-1 {
				+span:before {
					font-size: 9px;
					background: #fff;
					text-shadow: none;
					-webkit-box-shadow: none!important;
					box-shadow: none!important;
					border-width: 1px;
					height: 13px;
					line-height: 13px;
					min-width: 13px;
				}
				&:checked+span:before {
					font-size: 10px;
					color: #333;
					border-color: #333;
					background: #fff;
				}
				&:checked+span {
					font-weight: 400;
				}
			}
			&.style-2 {
				&:checked+span {
					font-weight: 400;

					&:before {
						color: #66665e;
						border-color: #4d90fe;
						font-size: 9px;
					}
				}
			}
			&.style-3 {
				&:checked+span:before {
					color: #a90329;
					border-color: #a90329;
				}
			}
		}
		label:hover & {
			+span:before,
			&:checked+span:before {
				color: #2E7BCC;
				border-color: #2E7BCC;
			}
			&.style-1 {
				&+span:before,
				&:checked+span:before {
					color: #333;
					border-color: #333;
					background: #fff;
				}
			}
			&.style-2 {
				&:checked+span:before {
					color: #66665e;
					border-color: #4d90fe;
				}
			}
			&.style-3 {
				&+span:before,
				&:checked+span:before {
					color: #a90329;
					border-color: #a90329;
				}
			}
		}
		label:active & {
			+span:before {
				-webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
				box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, .3), 0 1px 0 0 rgba(255, 255, 255, .4);
			}
		}
	}
	label &[disabled] {
		&.radiobox {
			+span,
			&:checked+span,
			&:checked+span:before {
				color: #A7A7A7;
				cursor: not-allowed;
			}
			&:checked+span:before {
				content: "\f111";
			}
			+span:before,
			&:checked+span:before {
				background: #eee!important;
				border-color: #CCC!important;
				-webkit-box-shadow: none;
				box-shadow: none;
				color: #A7A7A7;
			}
		}
	}
	label:active &,
	label:hover & {
		&[disabled].radiobox:checked+span:before {
			background: #eee!important;
			border-color: #CCC!important;
			-webkit-box-shadow: none;
			box-shadow: none;
			color: #A7A7A7;
		}
	}
}


textarea {
	&.clone {
		position: absolute;
		visibility: hidden;
	}
}

.textarea-div {
	background-color: #FFF;
	border: 1px solid #CCC;
	border-bottom: 0;
	margin: 10px 0 0;
}
.textarea-controls {
	box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	padding: 5px;
	display: block;
	background-color: #FFF;
	border: 1px solid #CCC;
	border-top: 0;
	height: 43px;
	line-height: 33px;
	overflow: hidden;

	>label {
		margin: 3px 10px 0;
	}
	.ams-form .checkbox {
		padding-left: 22px!important;
	}
}

.typearea {
	cursor: text;
	overflow-x: hidden;
	overflow-y: auto;
	max-height: 90px;
	padding: 5px 25px 5px 5px;
	position: relative;
	border-bottom: 1px solid #EEE;

	textarea {
		width: 100%;
		border-color: transparent!important;
		box-sizing: border-box;
		box-shadow: none;
		-moz-box-sizing: border-box;
		-webkit-box-sizing: border-box;
		-webkit-box-shadow: none;
		overflow: hidden;
		padding: 0;
		margin: 0;
		-webkit-transition: height .2s;
		transition: height .2s;
		outline: 0;
		resize: none;
		min-height: 61px;
	}
}


.error-box {
	max-width: 900px;
	margin: 0 auto;
}

.error-text {
	font-weight: 400;
	color: #fff;
	letter-spacing: -4px;
	font-size: 700%;
	margin-bottom: 30px;
	text-shadow: 0 1px 0 #ccc, 0 2px 0 #bfbfbf, 0 3px 0 #bbb, 0 4px 0 #b9b9b9, 0 5px 0 #aaa, 0 6px 1px rgba(0, 0, 0, .1), 0 0 5px rgba(0, 0, 0, .1), 0 1px 3px rgba(0, 0, 0, .3), 0 3px 5px rgba(0, 0, 0, .2), 0 5px 10px rgba(0, 0, 0, .25), 0 10px 10px rgba(0, 0, 0, .2), 0 20px 20px rgba(0, 0, 0, .15);
}

.error-search {
	width: 300px;
	margin: 0 auto 20px;
}

.error-icon-shadow {
	text-shadow: 0 1px 0 #803838, 0 2px 0 #a85d5d, 0 3px 0 #b86565, 0 4px 0 #d86f6f, 0 5px 0 #b3a5a5, 0 6px 1px rgba(131, 51, 51, .1), 0 0 5px rgba(102, 30, 30, .1), 0 1px 3px rgba(95, 15, 15, .3), 0 3px 5px rgba(100, 23, 23, .2), 0 5px 10px rgba(114, 30, 30, .25), 0 10px 10px rgba(94, 15, 15, .2), 0 20px 20px rgba(121, 38, 38, .15);
}

.form-inline {
	.checkbox,
	.radiobox {
		padding-left: 0;
	}
}


.ams-form {
	position: relative;
	margin: 0;
	outline: 0;
	color: #333;

	*,
	:after,
	:before {
		margin: 0;
		padding: 0;
		-webkit-box-sizing: content-box;
		   -moz-box-sizing: content-box;
				box-sizing: content-box;
	}
	header {
		display: block;
		padding: 8px 0;
		border-bottom: 1px dashed rgba(0, 0, 0, .2);
		background: #fff;
		font-size: 16px;
		font-weight: 300;
		color: #232323;
		margin: 10px 14px 0;
	}
	fieldset {
		display: block;
		position: relative;
		padding: 10px 15px 5px;
		border: 0;
		background: rgba(255, 255, 255, .9);

		&[disabled] {
			>section,
			>article,
			>div {
				opacity: 0.5;
			}
		}
		&.switched {
			>section,
			>article,
			>div {
				display: none;
			}
			legend {
				border-bottom: 0;
			}
		}
		&.bordered {
			margin: 10px;
			border: 1px solid rgba(192, 192, 192, 0.8);
			-webkit-border-radius: 3px;
			   -moz-border-radius: 3px;
					border-radius: 3px;

			&.switched {
				border: 1px solid transparent;
			}
			legend {
				width: auto;
				padding: 3px 10px 1px;
				border: 1px solid rgba(192, 192, 192, 0.8);
				-webkit-border-radius: 3px;
				   -moz-border-radius: 3px;
						border-radius: 3px;
			}
		}
	}
	fieldset+fieldset {
		border-top: 1px solid rgba(0, 0, 0, .1);
	}
	legend {
		padding-top: 10px;

		&.inner,
		.inner {
			font-weight: 300;
			font-size: 14.5px!important;
		}
		&.switcher {
			font-weight: 300;
			font-size: 16.5px;
			border: 0;
			padding-bottom: 0;
			cursor: pointer;
		}
		.fa {
			color: rgb(50, 118, 177);
			font-size: 75%;
		}
		.hint {
			vertical-align: top;
			font-size: 1em;
		}
		label.checkbox {
			display: inline-block;
			margin-bottom: 0px;
			min-height: 18px;

			i {
				position: absolute;
				left: 3px;
				top: -1px;
			}
		}
	}
	>.modal-viewport >fieldset >legend {
		padding-top: 0;
	}
	section {
		margin-bottom: 10px;
		position: relative;
	}
	.form-group {
		padding: 5px 10px;
	}
	label {
		&.checkbox,
		&.radio {
			padding-top: 0;
		}
	}
	input {
		&.input-lg {
			height: 44px;
			padding: 10px 16px;
			font-size: 17px;
			line-height: 1.33;
		}
		&.input-sm {
			height: 30px;
			padding: 5px 10px;
			font-size: 12px;
			line-height: 1.5;
		}
		&.input-xs {
			height: 24px;
			padding: 2px 10px;
			font-size: 11px;
			line-height: 1.5;
		}
	}
	select {
		&.input-sm {
			height: 30px;
			line-height: 15px;
			font-size: 12px;
		}
		&.input-sm+i {
			height: 10px;
		}
		&.input-lg {
			height: 44px;
			line-height: 22px;
			font-size: 17px;
		}
		&.input-lg+i {
			height: 11px;
			top: 17px;
		}
	}
	.row {
		margin: 0 -15px;

		&:after {
			display: table;
			content: '';
			clear: both;
		}
	}
	.col-1 {
		width: 8.33%;
	}
	.col-2 {
		width: 16.66%;
	}
	.col-3 {
		width: 25%;
	}
	.col-4 {
		width: 33.33%;
	}
	.col-5 {
		width: 41.66%;
	}
	.col-6 {
		width: 50%;
	}
	.col-8 {
		width: 66.67%;
	}
	.col-9 {
		width: 75%;
	}
	.col-10 {
		width: 83.33%;
	}
	.col {
		float: left;
		min-height: 1px;
		padding-right: 15px;
		padding-left: 15px;
		-webkit-box-sizing: border-box;
		box-sizing: border-box;
		-moz-box-sizing: border-box;

		@media screen and (max-width:600px) {
			float: none;
			width: 100%;
		}
		.label {
			@media screen and (max-width: 600px) {
				text-align: left;
				padding-left: 20px;
			}
		}
	}
	footer {
		display: block;
		padding: 7px 25px 15px;
		border-top: 1px solid rgba(0, 0, 0, .1);
		background: rgba(248, 248, 248, .9);

		&:after {
			display: table;
			clear: both;
			content: '';
		}
		.btn {
			float: right;
			height: 31px;
			margin: 10px 0 0 5px;
			padding: 0 22px;
			font: 300 15px/29px Ubuntu, Helvetica, Arial, sans-serif;
			cursor: pointer;

			&.btn-info {
				float: left;
			}
		}
		.submit-message {
			display: inline-block;
		}
	}
	.message {
		display: none;
		color: #6fb679;

		i {
			display: block;
			margin: 0 auto 20px;
			width: 81px;
			height: 81px;
			border: 1px solid #6fb679;
			border-radius: 50%;
			font-size: 30px;
			line-height: 81px;
		}
	}
	&.submitted {
		fieldset,
		footer {
			display: none;
		}
		.message {
			display: block;
			padding: 25px 30px;
			background: rgba(255, 255, 255, .9);
			font: 300 18px/27px Ubuntu, Helvetica, Arial, sans-serif;
			text-align: center;
		}
	}
	.note {
		margin-top: 6px;
		padding: 0 1px;
		font-size: 11px;
		line-height: 15px;
		color: #999;

		a {
			font-size: 13px;
		}
	}
	.note-success {
		color: #6fb679;
	}
	.control-label {
		display: block;
		margin-top: 4px;
		margin-bottom: 6px;
		padding-top: 0;
		line-height: 19px;
		font-weight: 400;
		font-size: 13px;
		color: #666;
		text-align: right;

		@media screen and (max-width: 992px) {
			text-align: left;
			margin-bottom: 0;
		}
		&.col {
			text-align: right;

			@media screen and (max-width: 600px) {
				text-align: left;
				padding-left: 20px;
			}
		}
		span {
			margin-right: 10px;

			&::after {
				content: " *";
				color: transparent;
			}
			>.hint {
				margin-top: -2px;
			}
		}
		.col {
			margin: 0;
			padding-top: 7px;
		}
	}
	label.input span.textline-field {
		display: block;
		margin-top: 4px;
		margin-bottom: 6px;
		padding-top: 0;
		line-height: 19px;
		font-size: 13px;
	}
	.required-field {
		.control-label {
			span::after {
				color: red;
			}
		}
	}
	.tooltip {
		position: absolute;
		z-index: 99999;
		left: -9999px;
		padding: 2px 8px 3px;
		font-size: 11px;
		line-height: 16px;
		font-weight: 400;
		background: rgba(0, 0, 0, .9);
		color: #fff;
		opacity: 0;
		transition: margin .3s, opacity .3s;
		-webkit-transition: margin .3s, opacity .3s;

		&:after {
			position: absolute;
			content: '';
		}
	}
	.tooltip-top-right {
		bottom: 100%;
		margin-bottom: 15px;

		&:after {
			top: 100%;
			right: 11px;
			border-top: 4px solid rgba(0, 0, 0, .9);
			border-right: 4px solid transparent;
			border-left: 4px solid transparent;
		}
	}
	.input input:focus+.tooltip-top-right,
	.textarea textarea:focus+.tooltip-top-right {
		right: 0;
		left: auto;
		margin-bottom: 5px;
	}
	.tooltip-top-left {
		bottom: 100%;
		margin-bottom: 15px;

		&:after {
			top: 100%;
			left: 11px;
			border-top: 4px solid rgba(0, 0, 0, .9);
			border-right: 4px solid transparent;
			border-left: 4px solid transparent;
		}
	}
	.input input:focus+.tooltip-top-left,
	.textarea textarea:focus+.tooltip-top-left {
		right: auto;
		left: 0;
		margin-bottom: 5px;
	}
	.tooltip-right {
		top: 4px;
		white-space: nowrap;
		margin-left: 15px;

		&:after {
			top: 6px;
			right: 100%;
			border-top: 4px solid transparent;
			border-right: 4px solid rgba(0, 0, 0, .9);
			border-bottom: 4px solid transparent;
		}
	}
	.input input:focus + .tooltip-right,
	.textarea textarea:focus+.tooltip-right {
		left: 100%;
		margin-left: 5px;
	}
	.tooltip-left {
		top: 4px;
		white-space: nowrap;
		margin-right: 15px;

		&:after {
			top: 6px;
			left: 100%;
			border-top: 4px solid transparent;
			border-bottom: 4px solid transparent;
			border-left: 4px solid rgba(0, 0, 0, .9);
		}
	}
	.input input:focus + .tooltip-left,
	.textarea textarea:focus + .tooltip-left {
		right: 100%;
		left: auto;
		margin-right: 5px;
	}
	.tooltip-bottom-right {
		top: 100%;
		margin-top: 15px;

		&:after {
			bottom: 100%;
			right: 11px;
			border-right: 4px solid transparent;
			border-bottom: 4px solid rgba(0, 0, 0, .9);
			border-left: 4px solid transparent;
		}
	}
	.input input:focus + .tooltip-bottom-right,
	.textarea textarea:focus + .tooltip-bottom-right {
		right: 0;
		left: auto;
		margin-top: 5px;
	}
	.tooltip-bottom-left {
		top: 100%;
		margin-top: 15px;

		&:after {
			bottom: 100%;
			left: 11px;
			border-right: 4px solid transparent;
			border-bottom: 4px solid rgba(0, 0, 0, .9);
			border-left: 4px solid transparent;
		}
	}
	.input input:focus + .tooltip-bottom-left,
	.textarea textarea:focus + .tooltip-bottom-left {
		right: auto;
		left: 0;
		margin-top: 5px;
	}
	.inline-group {
		margin: 0 -30px -4px 0;

		&:after {
			content: '';
			display: table;
			clear: both;
		}
		.checkbox,
		.radio {
			float: left;
			margin-right: 30px;

			&:last-child {
				margin-bottom: 4px;
			}
		}
	}
	.btn {
		-webkit-box-sizing: border-box;
		   -moz-box-sizing: border-box;
				box-sizing: border-box;
	}
	.button {
		float: right;
		height: 31px;
		overflow: hidden;
		margin: 10px 0 0 5px;
		padding: 0 25px;
		outline: 0;
		border: 0;
		font: 300 15px/31px Ubuntu, Helvetica, Arial, sans-serif;
		text-decoration: none;
		color: #fff;
		cursor: pointer;
		background-color: #3276B1;
		opacity: .8;
		transition: opacity .2s;
		-webkit-transition: opacity .2s;

		&:hover {
			opacity: 1;
		}
		&.button-secondary {
			background-color: #b3b3b3;
		}
	}
	.button,
	.checkbox,
	.input,
	.radio,
	.select,
	.textarea,
	.toggle {
		display: block;
		position: relative;
		font-weight: 400;
	}
	.input input,
	.select select,
	.textarea textarea {
		display: block;
		-webkit-box-sizing: border-box;
		   -moz-box-sizing: border-box;
				box-sizing: border-box;
		width: 100%;
		height: 28px;
		padding: 6px 8px;
		outline: 0;
		border-width: 1px;
		border-style: solid;
		border-radius: 0;
		background: #fff;
		font: 13px/16px Ubuntu, Helvetica, Arial, sans-serif;
		color: #404040;
		appearance: normal;
		-moz-appearance: none;
		-webkit-appearance: none;

		&.display-mode {
			border: none;
			padding: 0;
			margin-top: 2px;
			margin-bottom: 3px;
			height: 14px;
			line-height: 1em;
		}
	}
	.input input:focus + .tooltip,
	.textarea textarea:focus + .tooltip {
		opacity: 1;
	}
	.input .icon-prepend + input,
	.textarea .icon-prepend + textarea {
		padding-left: 37px;
	}
	.input .icon-append + input,
	.textarea .icon-append + textarea {
		padding-right: 37px;
	}
	.input .icon-prepend + .icon-append + input,
	.textarea .icon-prepend + .icon-append + textarea {
		padding-left: 37px;
	}
	.input-file {
		.button {
			position: absolute;
			top: 3px;
			right: 3px;
			float: none;
			height: 22px;
			margin: 0;
			padding: 0 14px;
			font-size: 13px;
			line-height: 22px;

			&:hover {
				-webkit-box-shadow: none;
				box-shadow: none;
			}
			input {
				position: absolute;
				top: 0;
				right: 0;
				padding: 0;
				font-size: 30px;
				cursor: pointer;
				opacity: 0;
			}
		}
	}
	.select {
		select {
			padding: 5px;
		}
		i {
			position: absolute;
			top: 9px;
			right: 11px;
			width: 5px;
			height: 11px;
			background: #fff;

			&:before,
			&:after {
				content: '';
				position: absolute;
				right: 0;
				border-right: 4px solid transparent;
				border-left: 4px solid transparent;
			}
			&:before {
				top: 0;
				border-bottom: 4px solid #404040;
			}
			&:after {
				bottom: 0;
				border-top: 4px solid #404040;
			}
		}
	}
	.select-multiple select {
		height: auto;
	}
	.textarea textarea {
		height: auto;
		resize: none;
	}
	.textarea-resizable textarea {
		resize: vertical;
	}
	.textarea-expandable textarea {
		height: 31px;

		&:focus {
			height: auto;
		}
	}
	.checkbox,
	.radio {
		margin-bottom: 4px;
		padding-left: 25px;
		line-height: 25px;
		color: #404040;
		cursor: pointer;
		font-size: 13px;

		&:last-child {
			margin-bottom: 0;
		}
		i {
			display: block;
			position: absolute;
			top: 3px;
			left: 0;
			width: 17px;
			height: 17px;
			outline: 0;
			border-width: 1px;
			border-style: solid;
			background: #FFF;
		}
		input {
			position: absolute;
			left: -9999px;

			&+i:after {
				position: absolute;
				opacity: 0;
				transition: opacity .1s;
				-webkit-transition: opacity .1s;
			}
			&:checked+i:after {
				opacity: 1;
			}
		}
	}
	.radio input+i:after {
		background-color: #3276B1;
	}
	.checkbox input {
		&+i:after {
			content: '\f00c';
			top: -1px;
			left: 1px;
			width: 15px;
			height: 15px;
			font: 400 16px/19px FontAwesome;
			text-align: center;
		}
		&+i:after {
			color: #3276B1;
		}
		&:checked:hover+i:after {
			content: '\f00d';
		}
		&:checked:disabled:hover+i:after {
			content: '\f00c';
		}
	}
	.radio input + i:after {
		content: '';
		top: 4px;
		left: 4px;
		width: 9px;
		height: 9px;
		border-radius: 50%;
	}
	.checkbox + .checkbox,
	.radio + .radio {
		margin-top: 0;
	}
	&.table td .checkbox i,
	&.table td .radio i,
	&.table th .checkbox i,
	&.table th .radio i {
		top: 0!important;
	}
	.inner {
		.checkbox {
			min-height: 13px;

			i {
				width: 13px;
				height: 13px;
			}
			input +i:after {
				width: 11px;
				height: 11px;
				font: 300 12px/16px FontAwesome;
			}
		}
	}
	.toggle {
		margin-bottom: 4px;
		padding-right: 61px;
		font-size: 15px;
		line-height: 25px;
		color: #404040;
		cursor: pointer;

		&:last-child {
			margin-bottom: 0;
		}
		&.state-error input:checked+i {
			background: #fff0f0;
		}
		&.state-success input:checked+i {
			background: #f0fff0;
		}
		input {
			position: absolute;
			left: -9999px;

			&:checked+i:before {
				right: 36px;
			}
			&:checked+i:after {
				content: attr(data-swchon-text);
				text-align: right;
			}
		}
		i {
			display: block;
			position: absolute;
			content: '';
			top: 4px;
			right: 0;
			width: 49px;
			height: 17px;
			border-width: 1px;
			border-style: solid;
			border-radius: 12px;
			background: #fff;

			&:before {
				display: block;
				position: absolute;
				content: '';
				z-index: 1;
				top: 4px;
				right: 4px;
				width: 9px;
				height: 9px;
				border-radius: 50%;
				opacity: 1;
				transition: right .2s;
				-webkit-transition: right .2s;
				background-color: #3276B1;
			}
			&:after {
				position: absolute;
				content: attr(data-swchoff-text);
				top: 2px;
				right: 8px;
				left: 8px;
				font-style: normal;
				font-size: 9px;
				line-height: 17px;
				font-weight: 700;
				text-align: left;
				color: #5f5f5f;
			}
		}
	}
	.checkbox:hover i,
	.radio:hover i,
	.toggle:hover i {
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
	}
	.checkbox:active i,
	.radio:active i,
	.toggle:active i {
		background: #F0F0F0;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
	}
	.checkbox input:checked+i,
	.radio input:checked+i,
	.toggle input:checked+i {
		border-color: #3276B1;
	}
	.rating {
		margin-bottom: 4px;
		font-size: 13px;
		line-height: 25px;
		color: #404040;

		&:last-child {
			margin-bottom: 0;
		}
		&.state-error+em {
			margin-top: -4px;
			margin-bottom: 4px;
		}
		input {
			position: absolute;
			left: -9999px;

			&+label:hover,
			&+label:hover~label {
				color: #3276B1;
			}
			&:checked~label {
				color: #3276B1;
			}
		}
		label {
			display: block;
			float: right;
			height: 17px;
			margin-top: 5px;
			padding: 0 2px;
			font-size: 17px;
			line-height: 17px;
			cursor: pointer;
			color: #ccc;
			transition: color .3s;
			-webkit-transition: color .3s;
		}
	}
	.icon-append,
	.icon-prepend {
		position: absolute;
		top: 4px;
		width: 20px;
		height: 20px;
		font-size: 14px;
		line-height: 20px;
		text-align: center;
		 color: #A2A2A2;
	}
	.icon-append {
		right: 4px;
		padding-left: 2px;
		border-left-width: 1px;
		border-left-style: solid;
	}
	.icon-append-2 {
		right: 31px;
	}
	.icon-prepend {
		left: 4px;
		padding-right: 2px;
		border-right-width: 1px;
		border-right-style: solid;
	}
	.icon-prepend-2 {
		left: 31px;
	}
	.checkbox i,
	.icon-append,
	.icon-prepend,
	.input input,
	.radio i,
	.select select,
	.textarea textarea,
	.toggle i {
		border-color: #BDBDBD;
		transition: border-color .3s;
		-webkit-transition: border-color .3s;
	}
	.input.bordered:hover,
	.checkbox:hover i,
	.input:hover input,
	.radio:hover i,
	.select:hover select,
	.textarea:hover textarea,
	.toggle:hover i {
		border-color: rgba(82, 168, 236, 0.7);
	}
	.checkbox input:focus+i,
	.input input:focus,
	.radio input:focus+i,
	.select select:focus,
	.textarea textarea:focus,
	.toggle input:focus+i {
		border-color: rgba(82, 168, 236, 0.7);
		outline: 0;
		outline: thin dotted 9;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.7);
		   -moz-box-shadow: inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(82,168,236,0.7);
				box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.7);
	}
	.checkbox.state-error i,
	.radio.state-error i,
	.state-error input,
	.state-error select,
	.state-error textarea,
	.toggle.state-error i {
		background: #fff0f0;
		border-color: rgba(255, 60, 60, 0.8) !important;

		&:focus {
			-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(255, 60, 60, 0.6) !important;
			   -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(255, 60, 60, 0.6) !important;
					box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(255, 60, 60, 0.6) !important;
		}
	}
	.state-error .select2-container .select2-choice,
	.state-error .select2-container .select2-choices {
		border-color: rgba(255, 60, 60, 0.8) !important;

		&:focus {
			-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(255, 60, 60, 0.6) !important;
			   -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(255, 60, 60, 0.6) !important;
					box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(255, 60, 60, 0.6) !important;
		}
	}
	.checkbox.state-success i,
	.radio.state-success i,
	.state-success input,
	.state-success select,
	.state-success textarea,
	.toggle.state-success i {
		background: #f0fff0;
		border-color: #7DC27D;
	}
	.button.state-disabled,
	.checkbox.state-disabled,
	.input.state-disabled input,
	.radio.state-disabled,
	.select.state-disabled,
	.textarea.state-disabled,
	.toggle.state-disabled {
		cursor: default!important;
		opacity: .6!important;
	}
	.checkbox.state-disabled:hover i,
	.input.state-disabled:hover input,
	.radio.state-disabled:hover i,
	.select.state-disabled:hover select,
	.textarea.state-disabled:hover textarea,
	.toggle.state-disabled:hover i {
		border-color: #e5e5e5!important;
	}
	.state-disabled.checkbox input+i:after,
	.state-disabled.checkbox input:checked+i,
	.state-disabled.radio input+i:after,
	.state-disabled.radio input:checked+i,
	.state-disabled.toggle input:checked+i {
		border-color: #e5e5e5!important;
		color: #333!important;
	}
	.ui-widget-content .ui-spinner-input {
		margin: 0;
		border: 0;
		-webkit-box-shadow: none!important;
		box-shadow: none!important;
		height: 29px;
	}
	.state-error {
		color: #D56161;

		select+i {
			background: #FFF0F0;
			-webkit-box-shadow: 0 0 0 9px #FFF0F0;
			box-shadow: 0 0 0 9px #FFF0F0;
		}
		&+em {
			display: block;
			margin-top: 6px;
			padding: 0 1px;
			font-style: normal;
			font-size: 11px;
			line-height: 15px;
			color: #D56161;
		}
	}
	.state-success {
		select+i {
			background: #f0fff0;
			-webkit-box-shadow: 0 0 0 9px #f0fff0;
			box-shadow: 0 0 0 9px #f0fff0;
		}
	}
	.state-disabled {
		&.radio input+i:after {
			background-color: #333;
		}
	}
	.form-tiny {
		.form-group {
			padding: 0px 10px;
		}
		.control-label {
			margin-top: 2px;
			margin-bottom: 3px;
			line-height: 14px;
		}
		label.input {
			span.textline-field {
				margin-top: 2px;
				margin-bottom: 3px;
				line-height: 14px;
			}
		}
	}
	.form-nomargin,
	&.form-nomargin{
		.control-label {
			margin-top: 0;
			margin-bottom: 0;
		}
		label.input {
			span.textline-field {
				margin-top: 0;
				margin-bottom: 0;
			}
		}
	}
	.form-nopadding,
	&.form-nopadding {
		.form-group {
			padding: 0 10px 1px;
		}
	}
}

.ams-form-modal {
	position: fixed;
	z-index: 1;
	display: none;
	width: 400px;
}

.ams-form-modal-overlay {
	position: fixed;
	top: 0;
	left: 0;
	display: none;
	width: 100%;
	height: 100%;
	background: rgba(0, 0, 0, .7);
}

.state-error .icon-append,
.state-error .icon-prepend {
	color: #ed1c24;
}


/*
 * X-editable - v1.5.0
 */

.editableform {
	margin-bottom: 0;

	.control-group {
		margin-bottom: 0;
		white-space: nowrap;
	}
	.editable-date {
		padding: 0;
		margin: 0;
		float: left;
	}
}

.editableform-loading {
	background: url(../img/loading.gif) center center no-repeat;
	height: 25px;
	width: auto;
	min-width: 25px;
}

.editable-buttons {
	display: inline-block;
	vertical-align: top;
	margin-left: 7px;
	zoom: 1;
	*display: inline;

	&.editable-buttons-bottom {
		display: block;
		margin-top: 7px;
		margin-left: 0;
	}
	.editable-cancel {
		margin-left: 7px;
	}
	button.ui-button-icon-only {
		height: 24px;
		width: 30px;
	}
}

.editable-inline {
	.add-on .icon-th {
		margin-top: 3px;
		margin-left: 1px;
	}
	.editableform-loading {
		background-position: left 5px;
	}
}

.editable-input {
	vertical-align: top;
	display: inline-block;
	width: auto;
	white-space: normal;
	zoom: 1;
	*display: inline;

	.datepicker {
		top: 0;
		left: 0;
		padding: 4px;

		&:before {
			content: '';
			display: inline-block;
			border-left: 7px solid transparent;
			border-right: 7px solid transparent;
			border-bottom: 7px solid #ccc;
			border-bottom-color: rgba(0, 0, 0, .2);
			position: absolute;
			top: -7px;
			left: 6px;
		}
		&:after {
			content: '';
			display: inline-block;
			border-left: 6px solid transparent;
			border-right: 6px solid transparent;
			border-bottom: 6px solid #fff;
			position: absolute;
			top: -6px;
			left: 7px;
		}
		>div {
			display: none;
		}
		table {
			width: 100%;
			min-width: 214px;
			margin: 0;
		}
		thead tr:first-child th {
			cursor: pointer;

			&:hover {
				background: #eee;
			}
		}
		td,
		th {
			text-align: center;
			width: 24px;
			height: 20px;
		}
		th {
			&.switch {
				width: 145px;
			}
			&.next,
			&.prev {
				font-size: 19.5px;
			}
		}
		td {
			span {
				display: block;
				width: 47px;
				height: 54px;
				line-height: 54px;
				float: left;
				margin: 2px;
				cursor: pointer;

				&:hover {
					background: #eee;
				}
				&.active {
					background: #3276b1;
					color: #fff;
					text-shadow: 0 -1px 0 rgba(0, 0, 0, .25);
					border-radius: 3px;
				}
				&.old {
					color: #555;
				}
			}
		}
		td.day:hover {
			background: #eee;
			cursor: pointer;
		}
		td.day.disabled,
		td.new,
		td.old {
			color: #555;
		}
		td.active,
		td.active:hover {
			background: #3276b1;
			color: #fff;
			text-shadow: 0 -1px 0 rgba(0, 0, 0, .25);
			border-radius: 3px;
		}
		&.prev i,
		&.next i {
			display: inline-block;
			font-family: FontAwesome;
			font-style: normal;
			font-weight: 400;
			line-height: 1;
			-webkit-font-smoothing: antialiased;
			-moz-osx-font-smoothing: grayscale;
			font-size: 14px;
		}
		&.prev i:before {
			content: "\f060";
		}
		&.next i:before {
			content: "\f061";
		}
	}
}

.editable-checklist label {
	white-space: nowrap;

	input[type=checkbox],
	span {
		vertical-align: middle;
		margin: 0;
	}
}

.editable-wysihtml5 {
	width: 566px;
	height: 250px;
}

.editable-pre-wrapped {
	white-space: pre-wrap;
}

.editable-container {
	&.editable-popup {
		max-width: none!important;
	}
	&.popover {
		width: auto;
	}
	&.editable-inline {
		display: inline-block;
		vertical-align: middle;
		width: auto;
		zoom: 1;
		*display: inline;
	}
	&.ui-widget {
		font-size: inherit;
		z-index: 9990;
	}
}

.editable-click,
a.editable-click,
a.editable-click:hover {
	text-decoration: none;
	border-bottom: dashed 1px #08c;
}

.editable-click.editable-disabled,
a.editable-click.editable-disabled,
a.editable-click.editable-disabled:hover {
	color: #585858;
	cursor: default;
	border-bottom: 0;
}

.editable-empty,
.editable-empty:focus,
.editable-empty:hover {
	font-style: italic;
	color: #D14;
	text-decoration: none;
}

.editable-unsaved {
	font-weight: 700;
}

.editable-bg-transition {
	-webkit-transition: background-color 1400ms ease-out;
	transition: background-color 1400ms ease-out;
}

.form-horizontal .editable {
	padding-top: 5px;
	display: inline-block;
}

.editable-address {
	display: block;
	margin-bottom: 5px;
}

.editable-address span {
	width: 70px;
	display: inline-block;
}

.editable-clear {
	clear: both;
	font-size: .9em;
	text-decoration: none;
	text-align: right;
}

.editable-clear-x {
	background: url(../img/clear.png) center center no-repeat;
	display: block;
	width: 13px;
	height: 13px;
	position: absolute;
	opacity: .6;
	z-index: 100;
	top: 50%;
	right: 6px;
	margin-top: -6px;

	&:hover {
		opacity: 1;
	}
}

.editable-error-block {
	max-width: 300px;
	margin: 5px 0 0;
	width: auto;
	white-space: normal;

	&.ui-state-error {
		padding: 3px;
	}
}

.editable-error {
	color: red;
}

.input-append.date .add-on i,
.input-prepend.date .add-on i {
	display: block;
	cursor: pointer;
	width: 16px;
	height: 16px;
}


/*
 * JQuery-UI widgets
 */

.ui-timepicker-div {
	.ui-widget-header {
		margin-bottom: 8px;
	}
	dl {
		text-align: left;

		dt {
			float: left;
			clear: left;
			padding: 0 0 0 5px;
		}
		dd {
			margin: 17px 10px 12px 40%;
		}
	}
	td {
		font-size: 90%;
	}
}


.ui-tpicker-grid-label {
	background: 0 0;
	border: 0;
	margin: 0;
	padding: 0;
}


.ui-timepicker-rtl {
	direction: rtl;

	dl {
		text-align: right;
		padding: 0 5px 0 0;

		dt {
			float: right;
			clear: right;
		}
		dd {
			margin: 0 40% 10px 10px;
		}
	}
}


#login {
	background: #fff;
	overflow: visible;

	.container {
		border: 0;
	}
	#header {
		margin: 0;
		height: 71px;
		border-bottom: 1px solid #eee!important;
		overflow: hidden;
		padding: 0 30px;
		-webkit-background-clip: padding-box;
		border-width: 0;
		min-height: 28px;
		background: #f4f4f4!important;
		margin-bottom: 20px;

		@media (min-width:768px) and (max-width:880px) {
			padding: 0 5px!important;
		}
		@media only screen and (min-width:0) and (max-width:679px) {
			padding: 0 5px!important;
		}
		#logo {
			margin-top: 22px;
			margin-left: 0;

			@media only screen and (min-width:0) and (max-width:679px) {
				margin-top: 22px;
			}
			img {
				width: 137px;

				@media only screen and (min-width:0) and (max-width:679px) {
					width: 135px;
				}
			}
		}
	}
	&-header-space {
		float: right;
		text-align: right;
		display: block;
		vertical-align: middle;
		line-height: 71px;

		>:first-child {
			font-size: 13px;
			margin-right: 14px;
			vertical-align: -3px;
			font-weight: 400;
		}
		>* {
			display: inline-block;
		}
		.btn {
			font-weight: 700;
			text-transform: uppercase;
		}
	}
	#main {
		background: #fff;
		margin: 0;
	}
	.hero {
		background-image: url(../img/gradient/login.png);
		background-repeat: no-repeat;
		background-position: 0 137px;
		height: 360px;
		width: 100%;
		float: left;
	}
	h4.paragraph-header {
		color: #565656;
		font-size: 15px;
		font-weight: 400;
		line-height: 22px;
		margin-top: 15px;
		width: 270px;
	}
	h5.about-heading {
		color: #565656;
		font-size: 15px;
		font-weight: 700;
		line-height: 24px;
		margin: 0 0 5px;
	}
	.login-header-big {
		font-weight: 400;
	}
	.login-desc-box-l {
		min-height: 350px;
		width: 50%;
	}
	.login-app-icons {
		vertical-align: top;
		margin-top: 90px;
		width: 300px;
	}
}

.bootstrapWizard {
	display: block;
	list-style: none;
	padding: 0;
	position: relative;
	width: 100%;

	a:active,
	a:focus,
	a:hover {
		text-decoration: none;
	}
	li {
		display: block;
		float: left;
		width: 25%;
		text-align: center;
		padding-left: 0;

		&:before {
			border-top: 3px solid #55606E;
			content: "";
			display: block;
			font-size: 0;
			overflow: hidden;
			position: relative;
			top: 11px;
			right: 1px;
			width: 100%;
			z-index: 1;
		}
		&:first-child:before {
			left: 50%;
			max-width: 50%;
		}
		&:last-child:before {
			max-width: 50%;
			width: 50%;
		}
		.step {
			background: #B2B5B9;
			color: #fff;
			display: inline;
			font-size: 15px;
			font-weight: 700;
			padding: 7px 13px;
			border: 3px solid transparent;
			border-radius: 50%;
			line-height: normal;
			position: relative;
			text-align: center;
			z-index: 2;
			-webkit-transition: all .1s linear 0s;
			transition: all .1s linear 0s;

			i {
				font-size: 10px;
				font-weight: 400;
				position: relative;
				top: -1.5px;
			}
		}
		&.complete .step {
			background: #0aa66e;
			padding: 1px 6px;
			border: 3px solid #55606E;
		}
		&.active .step,
		&.active.complete .step {
			background: #0091d9;
			color: #fff;
			font-weight: 700;
			padding: 7px 13px;
			font-size: 15px;
			border-radius: 50%;
			border: 3px solid #55606E;
		}
		.title {
			color: #bfbfbf;
			display: block;
			font-size: 13px;
			line-height: 15px;
			max-width: 100%;
			position: relative;
			table-layout: fixed;
			text-align: center;
			top: 20px;
			word-wrap: break-word;
			z-index: 104;
		}
		&.active .title,
		&.complete .title {
			color: #2B3D53;
		}
	}
}
.wizard-actions {
	display: block;
	list-style: none;
	padding: 0;
	position: relative;
	width: 100%;

	li {
		display: inline;
	}
}

.fuelux {
	.wizard {
		position: relative;
		overflow: hidden;
		background-color: #f9f9f9;
		border: 1px solid #d4d4d4;
		border-radius: 4px;
		*zoom: 1;
		-webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, .065);
		box-shadow: 0 1px 4px rgba(0, 0, 0, .065);

		&:after,
		&:before {
			display: table;
			line-height: 0;
			content: "";
		}
		&:after {
			clear: both;
		}
		ul {
			width: 4000px;
			padding: 0;
			margin: 0;
			list-style: none outside none;

			&.previous-disabled li.complete {
				cursor: default;

				&:hover {
					color: #356e35;
					cursor: default;
					background: #f3f4f5;

					.chevron:before {
						border-left-color: #f3f4f5;
					}
				}
			}
			li {
				position: relative;
				float: left;
				height: 46px;
				padding: 0 20px 0 30px;
				margin: 0;
				font-size: 16px;
				line-height: 46px;
				color: #999;
				cursor: default;
				background: #ededed;

				&:first-child {
					padding-left: 20px;
					border-radius: 4px 0 0 4px;
				}
				&.complete {
					color: #296829;
					background: #f3f4f5;

					&:hover {
						cursor: pointer;
						background: #e7eff8;

						.chevron:before {
							border-left: 14px solid #e7eff8;
						}
					}
					.chevron:before {
						border-left: 14px solid #f3f4f5;
					}
				}
				&.active {
					color: #3a87ad;
					background: #f1f6fc;

					.chevron:before {
						border-left: 14px solid #f1f6fc;
					}
				}
				.chevron {
					position: absolute;
					top: 0;
					right: -14px;
					z-index: 1;
					display: block;
					border: 24px solid transparent;
					border-right: 0;
					border-left: 14px solid #d4d4d4;

					&:before {
						position: absolute;
						top: -24px;
						right: 1px;
						display: block;
						border: 24px solid transparent;
						border-right: 0;
						border-left: 14px solid #ededed;
						content: "";
					}
				}
				.badge {
					margin-right: 8px;
				}
			}
		}
		.actions {
			position: absolute;
			right: 0;
			z-index: 2;
			float: right;
			padding-right: 15px;
			padding-left: 15px;
			line-height: 46px;
			vertical-align: middle;
			background-color: #eee;
			border-left: 1px solid #d4d4d4;

			a {
				margin-right: 8px;
				font-size: 12px;
				line-height: 45px;
			}
			.btn-prev i {
				margin-right: 5px;
			}
			.btn-next i {
				margin-left: 5px;
			}
		}
	}
	.fuelux .step-content {
		.step-pane {
			display: none;
		}
		.active {
			display: block;

			.btn-group .active {
				display: inline-block;
			}
		}
	}
}

.ams-metro-tile {
	float: left;
	display: block;
	background-color: #fff;
	width: 100px;
	height: 70px;
	cursor: pointer;
	-webkit-box-shadow: inset 0 0 1px #FFC;
	box-shadow: inset 0 0 1px #FFC;
	border: 1px dotted #C5C5C5;
	text-decoration: none;
	color: #fff;
	font-weight: 300;
	font-smooth: always;
	margin: 0 10px 20px 0;
	padding: 5px;
	position: relative;

	&:hover {
		z-index: 10;
		-webkit-transform: scale(1.07);
		-moz-transform: scale(1.07);
	}
	&.big-cubes {
		width: 120px;
		height: 120px;
	}
	&.double {
		width: 249px;
	}
	&:active {
		top: 1px;
		left: 1px;
	}
	.iconbox {
		text-align: center;

		i {
			display: block;
			margin: 15px auto 0;
			height: 75px;
		}
		span {
			display: block;
			text-align: left;
			line-height: 1em;

			>span {
				position: absolute;
				right: -5px;
				bottom: -10px;
				border-radius: 50%;
				padding: 6px 4px 3px;
				border: 1px solid #fff;
			}
		}
	}
}

.client-form header {
	padding: 15px 13px;
	margin: 0;
	border-bottom-style: solid;
	border-bottom-color: rgba(0, 0, 0, .1);
	background: rgba(248, 248, 248, .9);
}
