/**
 * UI modal dialog
 */

.modal-overflow {
	.modal-body {
		overflow: hidden;
	}
}

.ui-dialog {
	position: absolute;
	top: 0;
	left: 0;
	padding: 0;
	width: 300px;
	overflow: hidden;
	-webkit-background-clip: padding-box;
	background-clip: padding-box;
	background-color: #fff;
	border-radius: 6px;
	-webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, .5);
			box-shadow: 0 5px 15px rgba(0, 0, 0, .5);
	border: 1px solid rgba(0, 0, 0, .2);
	outline: medium none;
	z-index: 1050;

	.ui-dialog-titlebar {
		position: relative;
		padding: 0 10px;
		background: #fff;
		border-color: #fff;
		font-size: 18px;
		text-decoration: none;
		border: 0 0 0 1px solid;
		border-bottom-right-radius: 0;
		border-bottom-left-radius: 0;
		border-bottom: 1px solid #ccc;
		border-bottom-color: #eee;
	}
	.ui-dialog-title {
		float: left;
		margin: 0;
		color: #404040;
		font-weight: 700;
		padding: 5px;
		text-overflow: ellipsis;
		overflow: hidden;
	}
	.ui-dialog-titlebar-close {
		position: absolute;
		right: .3em;
		top: 50%;
		width: 19px;
		margin: -16px 4px 0 0;
		padding: 1px;
		height: 18px;
		font-size: 20px;
		font-weight: 700;
		line-height: 13.5px;
		text-shadow: 0 1px 0 #fff;
		filter: alpha(opacity=25);
		-khtml-opacity: .25;
		  -moz-opacity: .25;
			   opacity: .25;
		background: 0 0;
		border: 0;
		-webkit-box-shadow: none;
				box-shadow: none;

		&:before {
			content: "\f00d";
			font-family: FontAwesome;
			font-style: normal;
			font-weight: 400;
			line-height: 1;
			-webkit-font-smoothing: antialiased;
			-moz-osx-font-smoothing: grayscale;
			font-size: 13px;
		}
		&:focus,
		&:hover {
			padding: 1px;
			filter: alpha(opacity=90);
			-moz-opacity: .9;
			opacity: .9;
		}
		span {
			display: block;
			margin: 1px;
			text-indent: 9999px;
		}
	}
	.ui-dialog-content {
		position: relative;
		border: 0;
		padding: .5em 1em;
		background: 0 0;
		overflow: auto;
	}
	.ui-dialog-buttonpane {
		margin: 13px 0 0;
		padding: 19px 15px 20px;
		border-top: 1px solid #eee;
		border-width: 1px 0 0;
		border-radius: 0 0 6px 6px;
		background-image: none;
		background-color: #fff;
		-webkit-box-shadow: inset 0 1px 0 #fff;
				box-shadow: inset 0 1px 0 #fff;
		text-align: right;

		.ui-dialog-buttonset {
			float: right;
		}
		button {
			margin: 0 .4em 0 0;
			cursor: pointer;
		}
	}
	.ui-resizable-se {
		width: 14px;
		height: 14px;
		right: 3px;
		bottom: 3px;
	}
	.ui-draggable &-titlebar {
		cursor: move;
	}
	&-buttonpane &-buttonset .ui-button {
		color: #fff;
		background-color: #428bca;
		border-color: #357ebd;

		&.ui-state-hover {
			color: #fff;
			background-color: #3276b1;
			border-color: #285e8e;
		}
	}
	&-buttonset {
		.ui-button:not(:first-child) {
			cursor: pointer;
			display: inline-block;
			color: #333;
			background-color: #fff;
			border: 1px solid #ccc;
			-webkit-transition: .1s linear all;
			transition: .1s linear all;
			overflow: visible;
		}
		.ui-button:not(:first-child) .ui-state-hover {
			color: #333;
			background-color: #ebebeb;
			border-color: #adadad;
			text-decoration: none;
		}
		.ui-button.ui-button-info {
			color: #fff;
			background-color: #5bc0de;
			border-color: #46b8da;

			&.ui-state-hover {
				color: #fff;
				background-color: #39b3d7;
				border-color: #269abc;
			}
		}
		.ui-button.ui-button-success {
			color: #fff;
			background-color: #5cb85c;
			border-color: #4cae4c;

			&.ui-state-hover {
				color: #fff;
				background-color: #47a447;
				border-color: #398439;
			}
		}
		.ui-button.ui-button-warning {
			color: #fff;
			background-color: #f0ad4e;
			border-color: #eea236;

			&.ui-state-hover {
				color: #fff;
				background-color: #ed9c28;
				border-color: #d58512;
			}
		}
		.ui-button.ui-button-danger {
			color: #fff;
			background-color: #d9534f;
			border-color: #d43f3a;

			&.ui-state-hover {
				color: #fff;
				background-color: #d2322d;
				border-color: #ac2925;
			}
		}
		.ui-button.ui-button-inverse {
			color: #fff;
			background-color: #222;
			border-color: #080808;

			&.ui-state-hover {
				color: #fff;
				background-color: #363636;
				border-color: #000;
			}
		}
	}
}

.modal-overflow {
	position: relative;

	.scrollmarker {
		position: absolute;
		width: 100%;
		height: 20px;

		&.top {
			background: -moz-linear-gradient(top,  rgba(50, 118, 177, 1) 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%); /* FF3.6+ */
			background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(50, 118, 177, 1)), color-stop(17%,rgba(50, 118, 177, 0.83)), color-stop(100%,rgba(50, 118, 177,0))); /* Chrome,Safari4+ */
			background: -webkit-linear-gradient(top,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* Chrome10+,Safari5.1+ */
			background: -o-linear-gradient(top,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* Opera 11.10+ */
			background: -ms-linear-gradient(top,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* IE10+ */
			background: linear-gradient(to bottom,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* W3C */
		}
		&.bottom {
			background: -moz-linear-gradient(bottom,  rgba(50, 118, 177, 1) 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%); /* FF3.6+ */
			background: -webkit-gradient(linear, left bottom, left top, color-stop(0%,rgba(50, 118, 177, 1)), color-stop(17%,rgba(50, 118, 177, 0.83)), color-stop(100%,rgba(50, 118, 177,0))); /* Chrome,Safari4+ */
			background: -webkit-linear-gradient(bottom,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* Chrome10+,Safari5.1+ */
			background: -o-linear-gradient(bottom,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* Opera 11.10+ */
			background: -ms-linear-gradient(bottom,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* IE10+ */
			background: linear-gradient(to top,  rgba(50, 118, 177,1) 0%,rgba(50, 118, 177, 0.83) 17%,rgba(50, 118, 177, 0) 100%); /* W3C */
		}
	}
}
