/*
 * Tables and datatables
 */

.table-full {
	width: 100%;
}

.table-wrap {
	overflow: auto;
}

.table.has-tickbox {
	thead tr th:first-child {
		width: 18px;
	}
	&.ams-form tbody tr td:first-child .checkbox,
	&.ams-form tbody tr td:first-child .radio,
	&.ams-form thead tr th:first-child .checkbox,
	&.ams-form thead tr th:first-child .radio {
		padding: 0!important;
	}
}

.table-tight {
	td,
	th {
		padding: 4px 8px!important;
	}
}
.table-mini {
	td,
	th {
		padding: 1px 8px!important;
	}
}

.table-bordered {
	>thead >tr >td,
	>thead >tr >th {
		border-width: 1px;
	}
	.no-padding {
		& >.table-bordered {
			border: 0!important;

			tbody tr td:first-child,
			thead tr td:first-child,
			thead tr th:first-child {
				border-left-width: 0!important;
			}
			tbody tr td:last-child,
			thead tr th:last-child {
				border-right-width: 0!important;
			}
			tbody tr:last-child td {
				border-bottom-width: 0!important;
			}
		}
	}
	.no-padding .note-editable & {
		border: 1px solid #ddd!important;
	}
}

tr.bordered-bottom {
	th,
	td {
		border-bottom: 1px solid #ddd;
	}
}

.dt-row {
	padding: 4px 10px;
}

.dt-top-row {
	height: 0;
	line-height: 0;
	position: relative;
}

.dt-bottom-row {
	background: #fafafa;
	font-size: 11px;
	overflow: hidden;
	padding: 5px 10px;
	border-top: 1px solid #ccc;
	-webkit-box-shadow: inset 0 1px #fff;
	-ms-box-shadow: inset 0 1px #fff;
	box-shadow: inset 0 1px #fff;
}

.dataTables_length {
	position: absolute;
	right: 13px;
	top: -35px;

	select {
		width: 60px;
		padding: 3px;
		font-size: 13px;
		border: 1px solid #bbb;
	}
}

.dataTables_filter {
	position: absolute;
	left: 10px;
	top: -35px;

	input {
		padding: 3px 8px 1px;
		font-size: 13px;
	}
	.form-control {
		height: 28px;
	}
	.input-group {
		width: 180px!important;
	}
	input select {
		border: 1px solid #bbb;
	}
}

.dataTables_paginate {
	margin: 4px 0 0;

	.pagination {
		margin: 0;
	}
}

.dt-wrapper {
	overflow: hidden;
}

.dataTables_wrapper {
	position: relative;

	table.table {
		clear: both;
		max-width: inherit;
		margin-bottom: 0;

		thead {
			th {
				white-space: nowrap;
				text-overflow: ellipsis;
				-ms-text-overflow: ellipsis;
			}

			.sorting,
			.sorting_asc,
			.sorting_asc_disabled,
			.sorting_desc,
			.sorting_desc_disabled {
				cursor: pointer;
				padding-right: 20px;
			}

			.sorting {
				background: url(../img/datatable/sort_both.png) no-repeat center right;
			}

			.sorting_asc {
				background: url(../img/datatable/sort_asc.png) no-repeat center right;
			}

			.sorting_desc {
				background: url(../img/datatable/sort_desc.png) no-repeat center right;
			}

			.sorting_asc_disabled {
				background: url(../img/datatable/sort_asc_disabled.png) no-repeat center right;
			}

			.sorting_desc_disabled {
				background: url(../img/datatable/sort_desc_disabled.png) no-repeat center right;
			}
		}

		tbody tr.active {
			th,
			td {
				background-color: #08C;
				color: #fff;
			}

			&:hover td,
			&:hover th {
				background-color: #0075b0!important;
			}
		}
	}

	table.dataTable th:active {
		outline: 0;
	}

	.table-striped tbody tr.active:nth-child(odd) td,
	.table-striped tbody tr.active:nth-child(odd) th {
		background-color: #017ebc;
	}

	select {
		min-height: inherit;
	}

	table+.row {
		margin-bottom: 0;
		margin-top: 10px;
	}

	.dt_actions {
		float: left;
		margin-right: 20px;
	}

	.bottom,
	.top {
		background-color: #f5f5f5;
		border: 1px solid #CCC;
		padding: 15px;
	}

	div.DTTT .btn:hover {
		text-decoration: none!important;
	}

	ul.DTTT_dropdown.dropdown-menu {
		a {
			color: #333!important;
		}

		li:hover a {
			background-color: #08c;
			color: #fff!important;
		}
	}

	div.DTTT_print_info {
		&.modal {
			height: 150px;
			margin-top: -75px;
			text-align: center;
		}

		h6 {
			font-weight: 400;
			font-size: 28px;
			line-height: 28px;
			margin: 1em;
		}

		p {
			font-size: 14px;
			line-height: 20px;
		}
	}

	div.DTFC_LeftFootWrapper table,
	div.DTFC_LeftHeadWrapper table,
	table.DTFC_Cloned tr.even {
		background-color: #fff;
	}

	div.DTFC_LeftHeadWrapper table {
		margin-bottom: 0!important;
		border-top-right-radius: 0!important;
		border-bottom-left-radius: 0!important;
		border-bottom-right-radius: 0!important;
	}
}

.dataTables_scrollBody {
	-webkit-overflow-scrolling: touch;
}

.dataTables_info {
	.top & {
		float: none;
	}

	div.dt-bottom-row & {
		float: left;
		padding-top: 10px;
		font-size: 12px;
	}
}

.dataTables_full {
	width: 100%!important;
}

.dataTables_empty {
	text-align: center!important;
	font-size: 15px;
	background: #fff!important;
	padding: 20px 0!important;
	cursor: default;
}

.dataTables_scroll {
	clear: both;
}

.dataTables_scrollHeadInner table.table-bordered {
	border-radius: 4px 4px 0 0;

	&,
	& thead {
		border-bottom: 0;
	}
}

.dataTables_scrollBody table {
	border-top: 0;
}

.dataTables_processing {
	position: absolute;
	top: 50%;
	margin-top: -24px;
	z-index: 100;
	left: 50%;
	width: 250px;
	margin-left: -125px;
	border: 1px solid #ddd;
	text-align: center;
	color: #000;
	background: #fff;
	font-size: 15px!important;
	-webkit-box-shadow: 0 0 4px rgba(0, 0, 0, .2);
	-ms-box-shadow: 0 0 4px rgba(0, 0, 0, .2);
	box-shadow: 0 0 4px rgba(0, 0, 0, .2);
	padding: 10px 0;
}

.dataTables_wrapper {
	.center {
		text-align: center;
	}

	.details,
	.details:hover {
		background: #ddd!important;
	}

	.details table td {
		background: #fff!important;
	}
}

.dataTables_scrollHeadInner table.table,
.dataTables_wrapper .details table.table {
	margin: 0!important;
}

.dataTables_scrollHead table {
	margin-bottom: 0!important;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;

	thead tr:last-child th:first-child {
		border-bottom-left-radius: 0!important;
		border-bottom-right-radius: 0!important;
	}
}

.DTFC_LeftHeadWrapper table thead tr:last-child td:first-child,
.DTFC_LeftHeadWrapper table thead tr:last-child th:first-child {
	border-bottom-left-radius: 0!important;
	border-bottom-right-radius: 0!important;
}

.DTFC_LeftBodyWrapper table,
.dataTables_scrollBody table {
	border-top: 0;
	margin-bottom: 0!important;
}
.DTFC_LeftBodyWrapper tbody tr:first-child td,
.DTFC_LeftBodyWrapper tbody tr:first-child th,
div.DTFC_LeftFootWrapper table,
div.dataTables_scrollBody tbody tr:first-child th,
div.dataTables_scrollFoot table {
	border-top: 0;
}


/*
 * Datatables ColVis plug-in
 */

.ColVis {
	position: absolute;
	right: 83px;
	top: -35px;
}

.ColVis_collection {
	position: relative;
	width: 180px;
	background-color: #fff;
	border: 1px solid rgba(0, 0, 0, .2);
	-webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
	box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
	z-index: 1102;
	padding-top: 3px;
	padding-left: 10px;
	list-style-type: none;
	list-style-position: outside;

	.ColVis_Button {
		position: relative;
		margin-right: 3px;
		height: 30px;
		background-color: #fff;
		border: 1px solid #d0d0d0;
		cursor: hand;
		padding: 3px 5px;
	}

	button.ColVis_Button {
		padding: 4px 12px;
		height: 26px;
		background-color: #fff;
		border: 0;
		width: 100%;
		float: none;
		font-size: 12px;

		&+button.ColVis_Button {
			border-top: 1px solid #e1e1e1;
		}

		button.ColVis_Button input {
			margin: 0;
		}
	}
}

button.ColVis_Button {
	padding: 4px 5px;
	text-align: left;

	&::-moz-focus-inner {
		border: 0!important;
		padding: 0;
	}
}

.ColVis_collectionBackground {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background-color: #000;
	z-index: 1100;
}

div.ColVis_catcher {
	position: absolute;
	z-index: 1101;
}

span.ColVis_radio {
	display: inline-block;
	width: 20px;
	vertical-align: -2px;
}

.ColVis_text_hover,
div.ColVis_collection button.ColVis_Button:hover {
	background: #F2F2F2;
	color: #222;
}


/*
 * Datatables columns reorder plug-in
 */

table.DTCR_clonedTable {
	background-color: #fff;
	z-index: 202;
}

div.DTCR_pointer {
	width: 1px;
	background-color: #0259C4;
	z-index: 201;
}

ul.DTTT_dropdown.dropdown-menu li {
	position: relative;

	&:hover a {
		background-color: #f2f2f2;
		color: #333!important;
	}
}

.table_tools_group {
	position: absolute;
	right: 83px;
	top: -37px;
}

.DTTT.btn-group {
	position: absolute;
	top: -38px;
	right: 83px;
}

.DTTT_dropdown {
	z-index: 2002;
}

.DTFC_LeftHeadWrapper {
	border-bottom: 1px solid #ddd;
}

div.DTTT_container {
	position: relative;
	float: right;
	margin-bottom: 1em;
}

a.DTTT_button,
button.DTTT_button,
div.DTTT_button {
	position: relative;
	float: left;
	margin-right: 3px;
	padding: 5px 8px;
	border: 1px solid #999;
	cursor: pointer;
	*cursor: hand;
	font-size: .88em;
	color: #000!important;
	-o-border-radius: 2px;
	border-radius: 2px;
	-webkit-box-shadow: 1px 1px 3px #ccc;
	-ms-box-shadow: 1px 1px 3px #ccc;
	-o-box-shadow: 1px 1px 3px #ccc;
	box-shadow: 1px 1px 3px #ccc;
	background: #fff;
	background: -webkit-linear-gradient(top, #fff 0, #f3f3f3 89%, #f9f9f9 100%);
	background: -webkit-gradient(linear, top left, bottom left, from(#fff), color-stop(89%, #f3f3f3), to(#f9f9f9));
	background: -webkit-linear-gradient(top, #fff 0, #f3f3f3 89%, #f9f9f9 100%);
	background: linear-gradient(top, #fff 0, #f3f3f3 89%, #f9f9f9 100%);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff',  endColorstr='#f9f9f9',  GradientType=0);

	&:hover {
		border: 1px solid #666;
		text-decoration: none!important;
		-webkit-box-shadow: 1px 1px 3px #999;
		-ms-box-shadow: 1px 1px 3px #999;
		-o-box-shadow: 1px 1px 3px #999;
		box-shadow: 1px 1px 3px #999;
		background: #f3f3f3;
		background: -webkit-linear-gradient(top, #f3f3f3 0, #e2e2e2 89%, #f4f4f4 100%);
		background: -webkit-gradient(linear, top left, bottom left, from(#f3f3f3), color-stop(89%, #e2e2e2), to(#f4f4f4));
		background: -webkit-linear-gradient(top, #f3f3f3 0, #e2e2e2 89%, #f4f4f4 100%);
		background: linear-gradient(top, #f3f3f3 0, #e2e2e2 89%, #f4f4f4 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f3f3f3',  endColorstr='#f4f4f4',  GradientType=0);
	}
}

button.DTTT_button {
	height: 30px;
	padding: 3px 8px;
}

.DTTT_button embed {
	outline: 0;
}

a.DTTT_disabled,
button.DTTT_disabled,
div.DTTT_disabled {
	color: #999;
	border: 1px solid #d0d0d0;
	background: #fff;
	background: -webkit-linear-gradient(top, #fff 0, #f9f9f9 89%, #fafafa 100%);
	background: -webkit-gradient(linear, top left, bottom left, from(#fff), color-stop(89%, #f9f9f9), to(#fafafa));
	background: -webkit-linear-gradient(top, #fff 0, #f9f9f9 89%, #fafafa 100%);
	background: linear-gradient(top, #fff 0, #f9f9f9 89%, #fafafa 100%);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff',  endColorstr='#fafafa',  GradientType=0);
}

table.DTTT_selectable tbody tr {
	cursor: pointer;
	*cursor: hand;
}
table.dataTable tr.DTTT_selected {
	&.odd {
		td.sorting_1,
		td.sorting_2,
		td.sorting_3 {
			background-color: #9FAFD1;
		}
	}

	&.even {
		td.sorting_1,
		td.sorting_2,
		td.sorting_3 {
			background-color: #B0BED9;
		}
	}
}

div.DTTT_collection {
	width: 150px;
	padding: 8px 8px 4px;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, .4);
	background-color: #f3f3f3;
	background-color: rgba(255, 255, 255, .3);
	overflow: hidden;
	z-index: 2002;
	-o-border-radius: 5px;
	border-radius: 5px;
	-webkit-box-shadow: 3px 3px 5px rgba(0, 0, 0, .3);
	-ms-box-shadow: 3px 3px 5px rgba(0, 0, 0, .3);
	-o-box-shadow: 3px 3px 5px rgba(0, 0, 0, .3);
	box-shadow: 3px 3px 5px rgba(0, 0, 0, .3);

	a.DTTT_button,
	button.DTTT_button,
	div.DTTT_button {
		position: relative;
		left: 0;
		right: 0;
		display: block;
		float: none;
		margin-bottom: 4px;
		-webkit-box-shadow: 1px 1px 3px #999;
		-ms-box-shadow: 1px 1px 3px #999;
		-o-box-shadow: 1px 1px 3px #999;
		box-shadow: 1px 1px 3px #999;
	}
}

div.DTTT_collection_background {
	z-index: 2001;
}

.DTTT_print_info {
	position: fixed;
	top: 50%;
	left: 50%;
	width: 400px;
	height: 150px;
	margin-left: -200px;
	margin-top: -75px;
	text-align: center;
	color: #333;
	padding: 10px 30px;
	background: #fff;
	background: -webkit-linear-gradient(top, #fff 0, #f3f3f3 89%, #f9f9f9 100%);
	background: -webkit-gradient(linear, top left, bottom left, from(#fff), color-stop(89%, #f3f3f3), to(#f9f9f9));
	background: -webkit-linear-gradient(top, #fff 0, #f3f3f3 89%, #f9f9f9 100%);
	background: linear-gradient(top, #fff 0, #f3f3f3 89%, #f9f9f9 100%);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff',  endColorstr='#f9f9f9',  GradientType=0);
	opacity: .95;
	border: 1px solid #000;
	border: 1px solid rgba(0, 0, 0, .5);
	-o-border-radius: 6px;
	border-radius: 6px;
	-webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, .5);
	-ms-box-shadow: 0 3px 7px rgba(0, 0, 0, .5);
	-o-box-shadow: 0 3px 7px rgba(0, 0, 0, .5);
	box-shadow: 0 3px 7px rgba(0, 0, 0, .5);

	h6 {
		font-weight: 400;
		font-size: 28px;
		line-height: 28px;
		margin: 1em;
	}

	p {
		font-size: 14px;
		line-height: 20px;
	}
}
