/*
 * Icons styles
 */

.square {
	display: block;
	float: left;
	margin-right: 10px;
	height: 20px;
	width: 20px;
}

.icon-color-good {
	color: #40ac2b;
}
.icon-color-bad {
	color: #ed1c24;
}

.percent-sign:after {
	content: " %";
	line-height: normal;
}
.degree-sign:after {
	content: " Â°F";
	line-height: normal;
}

.ui-icon {
	.ui-state-default &[class*=" icon-"] {
		background: 0 0;
		margin-left: -12px;
	}
	&-carat-1-n {
		background-position: 0 0;
	}
	&-carat-1-ne {
		background-position: -16px 0;
	}
	&-carat-1-e {
		background-position: -32px 0;

		&:before {
			content: "\f105";
			font-family: FontAwesome;
			font-size: 14px;
			display: inline;
		}
	}
	&-carat-1-se {
		background-position: -48px 0;
	}
	&-carat-1-s {
		background-position: -64px 0;
	}
	&-carat-1-sw {
		background-position: -80px 0;
	}
	&-carat-1-w {
		background-position: -96px 0;
	}
	&-carat-1-nw {
		background-position: -112px 0;
	}
	&-carat-2-n-s {
		background-position: -128px 0;
	}
	&-carat-2-e-w {
		background-position: -144px 0;
	}
	&-triangle-1-n {
		background-position: 0 -16px;
	}
	&-triangle-1-ne {
		background-position: -16px -16px;
	}
	&-triangle-1-e {
		background-position: -32px -16px;
	}
	&-triangle-1-se {
		background-position: -48px -16px;
	}
	&-triangle-1-s {
		background-position: -64px -16px;
	}
	&-triangle-1-sw {
		background-position: -80px -16px;
	}
	&-triangle-1-w {
		background-position: -96px -16px;
	}
	&-triangle-1-nw {
		background-position: -112px -16px;
	}
	&-triangle-2-n-s {
		background-position: -128px -16px;
	}
	&-triangle-2-e-w {
		background-position: -144px -16px;
	}
	&-arrow-1-n {
		background-position: 0 -32px;
	}
	&-arrow-1-ne {
		background-position: -16px -32px;
	}
	&-arrow-1-e {
		background-position: -32px -32px;
	}
	&-arrow-1-se {
		background-position: -48px -32px;
	}
	&-arrow-1-s {
		background-position: -64px -32px;
	}
	&-arrow-1-sw {
		background-position: -80px -32px;
	}
	&-arrow-1-w {
		background-position: -96px -32px;
	}
	&-arrow-1-nw {
		background-position: -112px -32px;
	}
	&-arrow-2-n-s {
		background-position: -128px -32px;
	}
	&-arrow-2-ne-sw {
		background-position: -144px -32px;
	}
	&-arrow-2-e-w {
		background-position: -160px -32px;
	}
	&-arrow-2-se-nw {
		background-position: -176px -32px;
	}
	&-arrowstop-1-n {
		background-position: -192px -32px;
	}
	&-arrowstop-1-e {
		background-position: -208px -32px;
	}
	&-arrowstop-1-s {
		background-position: -224px -32px;
	}
	&-arrowstop-1-w {
		background-position: -240px -32px;
	}
	&-arrowthick-1-n {
		background-position: 0 -48px;
	}
	&-arrowthick-1-ne {
		background-position: -16px -48px;
	}
	&-arrowthick-1-e {
		background-position: -32px -48px;
	}
	&-arrowthick-1-se {
		background-position: -48px -48px;
	}
	&-arrowthick-1-s {
		background-position: -64px -48px;
	}
	&-arrowthick-1-sw {
		background-position: -80px -48px;
	}
	&-arrowthick-1-w {
		background-position: -96px -48px;
	}
	&-arrowthick-1-nw {
		background-position: -112px -48px;
	}
	&-arrowthick-2-n-s {
		background-position: -128px -48px;
	}
	&-arrowthick-2-ne-sw {
		background-position: -144px -48px;
	}
	&-arrowthick-2-e-w {
		background-position: -160px -48px;
	}
	&-arrowthick-2-se-nw {
		background-position: -176px -48px;
	}
	&-arrowthickstop-1-n {
		background-position: -192px -48px;
	}
	&-arrowthickstop-1-e {
		background-position: -208px -48px;
	}
	&-arrowthickstop-1-s {
		background-position: -224px -48px;
	}
	&-arrowthickstop-1-w {
		background-position: -240px -48px;
	}
	&-arrowreturnthick-1-w {
		background-position: 0 -64px;
	}
	&-arrowreturnthick-1-n {
		background-position: -16px -64px;
	}
	&-arrowreturnthick-1-e {
		background-position: -32px -64px;
	}
	&-arrowreturnthick-1-s {
		background-position: -48px -64px;
	}
	&-arrowreturn-1-w {
		background-position: -64px -64px;
	}
	&-arrowreturn-1-n {
		background-position: -80px -64px;
	}
	&-arrowreturn-1-e {
		background-position: -96px -64px;
	}
	&-arrowreturn-1-s {
		background-position: -112px -64px;
	}
	&-arrowrefresh-1-w {
		background-position: -128px -64px;
	}
	&-arrowrefresh-1-n {
		background-position: -144px -64px;
	}
	&-arrowrefresh-1-e {
		background-position: -160px -64px;
	}
	&-arrowrefresh-1-s {
		background-position: -176px -64px;
	}
	&-arrow-4 {
		background-position: 0 -80px;
	}
	&-arrow-4-diag {
		background-position: -16px -80px;
	}
	&-extlink {
		background-position: -32px -80px;
	}
	&-newwin {
		background-position: -48px -80px;
	}
	&-refresh {
		background-position: -64px -80px;
	}
	&-shuffle {
		background-position: -80px -80px;
	}
	&-transfer-e-w {
		background-position: -96px -80px;
	}
	&-transferthick-e-w {
		background-position: -112px -80px;
	}
	&-folder-collapsed {
		background-position: 0 -96px;
	}
	&-folder-open {
		background-position: -16px -96px;
	}
	&-document {
		background-position: -32px -96px;
	}
	&-document-b {
		background-position: -48px -96px;
	}
	&-note {
		background-position: -64px -96px;
	}
	&-mail-closed {
		background-position: -80px -96px;
	}
	&-mail-open {
		background-position: -96px -96px;
	}
	&-suitcase {
		background-position: -112px -96px;
	}
	&-comment {
		background-position: -128px -96px;
	}
	&-person {
		background-position: -144px -96px;
	}
	&-print {
		background-position: -160px -96px;
	}
	&-trash {
		background-position: -176px -96px;
	}
	&-locked {
		background-position: -192px -96px;
	}
	&-unlocked {
		background-position: -208px -96px;
	}
	&-bookmark {
		background-position: -224px -96px;
	}
	&-tag {
		background-position: -240px -96px;
	}
	&-home {
		background-position: 0 -112px;
	}
	&-flag {
		background-position: -16px -112px;
	}
	&-calendar {
		background-position: -32px -112px;
	}
	&-cart {
		background-position: -48px -112px;
	}
	&-pencil {
		background-position: -64px -112px;
	}
	&-clock {
		background-position: -80px -112px;
	}
	&-disk {
		background-position: -96px -112px;
	}
	&-calculator {
		background-position: -112px -112px;
	}
	&-zoomin {
		background-position: -128px -112px;
	}
	&-zoomout {
		background-position: -144px -112px;
	}
	&-search {
		background-position: -160px -112px;
	}
	&-wrench {
		background-position: -176px -112px;
	}
	&-gear {
		background-position: -192px -112px;
	}
	&-heart {
		background-position: -208px -112px;
	}
	&-star {
		background-position: -224px -112px;
	}
	&-link {
		background-position: -240px -112px;
	}
	&-cancel {
		background-position: 0 -128px;
	}
	&-plus {
		background-position: -16px -128px;
	}
	&-plusthick {
		background-position: -32px -128px;
	}
	&-minus {
		background-position: -48px -128px;
	}
	&-minusthick {
		background-position: -64px -128px;
	}
	&-close {
		background-position: -80px -128px;
	}
	&-closethick {
		background-position: -96px -128px;
	}
	&-key {
		background-position: -112px -128px;
	}
	&-lightbulb {
		background-position: -128px -128px;
	}
	&-scissors {
		background-position: -144px -128px;
	}
	&-clipboard {
		background-position: -160px -128px;
	}
	&-copy {
		background-position: -176px -128px;
	}
	&-contact {
		background-position: -192px -128px;
	}
	&-image {
		background-position: -208px -128px;
	}
	&-video {
		background-position: -224px -128px;
	}
	&-script {
		background-position: -240px -128px;
	}
	&-alert {
		background-position: 0 -144px;
	}
	&-info {
		background-position: -16px -144px;
	}
	&-notice {
		background-position: -32px -144px;
	}
	&-help {
		background-position: -48px -144px;
	}
	&-check {
		background-position: -64px -144px;
	}
	&-bullet {
		background-position: -80px -144px;
	}
	&-radio-on {
		background-position: -96px -144px;
	}
	&-radio-off {
		background-position: -112px -144px;
	}
	&-pin-w {
		background-position: -128px -144px;
	}
	&-pin-s {
		background-position: -144px -144px;
	}
	&-play {
		background-position: 0 -160px;
	}
	&-pause {
		background-position: -16px -160px;
	}
	&-seek-next {
		background-position: -32px -160px;
	}
	&-seek-prev {
		background-position: -48px -160px;
	}
	&-seek-end {
		background-position: -64px -160px;
	}
	&-seek-first, &-seek-start {
		background-position: -80px -160px;
	}
	&-stop {
		background-position: -96px -160px;
	}
	&-eject {
		background-position: -112px -160px;
	}
	&-volume-off {
		background-position: -128px -160px;
	}
	&-volume-on {
		background-position: -144px -160px;
	}
	&-power {
		background-position: 0 -176px;
	}
	&-signal-diag {
		background-position: -16px -176px;
	}
	&-signal {
		background-position: -32px -176px;
	}
	&-battery-0 {
		background-position: -48px -176px;
	}
	&-battery-1 {
		background-position: -64px -176px;
	}
	&-battery-2 {
		background-position: -80px -176px;
	}
	&-battery-3 {
		background-position: -96px -176px;
	}
	&-circle-plus {
		background-position: 0 -192px;
	}
	&-circle-minus {
		background-position: -16px -192px;
	}
	&-circle-close {
		background-position: -32px -192px;
	}
	&-circle-triangle-e {
		background-position: -48px -192px;
	}
	&-circle-triangle-s {
		background-position: -64px -192px;
	}
	&-circle-triangle-w {
		background-position: -80px -192px;
	}
	&-circle-triangle-n {
		background-position: -96px -192px;
	}
	&-circle-arrow-e {
		background-position: -112px -192px;
	}
	&-circle-arrow-s {
		background-position: -128px -192px;
	}
	&-circle-arrow-w {
		background-position: -144px -192px;
	}
	&-circle-arrow-n {
		background-position: -160px -192px;
	}
	&-circle-zoomin {
		background-position: -176px -192px;
	}
	&-circle-zoomout {
		background-position: -192px -192px;
	}
	&-circle-check {
		background-position: -208px -192px;
	}
	&-circlesmall-plus {
		background-position: 0 -208px;
	}
	&-circlesmall-minus {
		background-position: -16px -208px;
	}
	&-circlesmall-close {
		background-position: -32px -208px;
	}
	&-squaresmall-plus {
		background-position: -48px -208px;
	}
	&-squaresmall-minus {
		background-position: -64px -208px;
	}
	&-squaresmall-close {
		background-position: -80px -208px;
	}
	&-grip-dotted-vertical {
		background-position: 0 -224px;
	}
	&-grip-dotted-horizontal {
		background-position: -16px -224px;
	}
	&-grip-solid-vertical {
		background-position: -32px -224px;
	}
	&-grip-solid-horizontal {
		background-position: -48px -224px;
	}
	&-gripsmall-diagonal-se {
		background-position: -64px -224px;
	}
	&-grip-diagonal-se {
		background-position: -80px -224px;
	}
}


.ui-button-icon {
	&-primary.ui-icon[class*=" icon-"]:before,
	&-primary.ui-icon[class^=icon-]:before,
	&-secondary.ui-icon[class*=" icon-"]:before,
	&-secondary.ui-icon[class^=icon-]:before {
		font-size: inherit;
		margin-left: 7px!important;
		margin-left: 5px;
		display: inline;
		text-decoration: inherit;
		color: inherit;
	}
}
