/*
 * Bootstrap tags input
 */

.bootstrap-tagsinput {
	display: block;
	width: 100%;
	min-height: 32px;
	padding: 1px 3px;
	font-size: 13px;
	line-height: 1.428571429;
	color: #555;
	vertical-align: middle;
	background-color: #FFF;
	border: 1px solid #CCC;
	border-radius: 0;

	>span {
		border-radius: 0!important;
		font-weight: 400;
		padding: 3px 28px 4px 8px;
		font-size: 13px;
		border: 1px solid #285E8E;
		background: #3276B1;
	}

	input {
		border: 0;
		-webkit-box-shadow: none;
		box-shadow: none;
		outline: 0;
		background-color: transparent;
		padding: 0;
		margin: 0;
		width: auto!important;
		max-width: inherit;

		&:focus {
			border: 0;
			-webkit-box-shadow: none;
			box-shadow: none;
		}
	}

	.tag {
		color: #FFF;
		position: relative;
		margin: 3px 0 3px 2px;
		display: inline-block;

		[data-role=remove] {
			display: block;
			top: -1px;
			right: 0;
			padding: 3px 4px 3px 5px;
			width: 23px;
			height: 22px;
			position: absolute;
			cursor: pointer;

			&:after {
				content: "\f057";
				font-family: fontAwesome;
				padding: 2px 1px;
				line-height: 17px;
				font-size: 15px;
				text-align: center;
			}

			&:hover {
				background: rgba(0, 0, 0, .3);
				-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, .2), 0 1px 2px rgba(0, 0, 0, .05);
				box-shadow: inset 0 1px 0 rgba(255, 255, 255, .2), 0 1px 2px rgba(0, 0, 0, .05);

				&:active {
					-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
					box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
				}
			}
		}
	}
}
