/*
 * MyAMS
 * « My Application Management Skin »
 *
 * $Tag: 0.1.2 $
 * A bootstrap based application/administration skin
 *
 * Custom administration and application skin tools
 * Released under Zope Public License ZPL 1.1
 * ©2014 Thierry Florac <tflorac@ulthar.net>
 */

@import "colors.less";
@import "anims.less";
@import "icons.less";
@import "typo.less";

@import "layout.less";
@import "messages.less";

@import "menus.less";
@import "tabs.less";
@import "content.less";
@import "tables.less";
@import "forms.less";
@import "buttons.less";
@import "widgets.less";
@import "ui.less";
@import "modal.less";

@import "pricing.less";
@import "superbox.less";
@import "tags.less";
@import "slider.less";
@import "graphs.less";

@import "apps/chat.less";
@import "apps/mail.less";
@import "apps/todo.less";
