/*
 * MyAMS
 * « My Application Management Skin »
 *
 * $Tag: 0.1.2 $
 * A bootstrap based application/administration skin
 *
 * Custom administration and application skin tools
 * Released under Zope Public License ZPL 1.1
 * ©2014 Thierry Florac <tflorac@ulthar.net>
 */
/*
 * Colors variations
 */
.txt-color-blue {
  color: #60747c !important;
}
.txt-color-blueLight {
  color: #ccdadf !important;
}
.txt-color-blueDark {
  color: #4c4f53 !important;
}
.txt-color-green {
  color: #356e35 !important;
}
.txt-color-greenLight {
  color: #71843f !important;
}
.txt-color-greenDark {
  color: #496949 !important;
}
.txt-color-red {
  color: #931313 !important;
}
.txt-color-yellow {
  color: #d4c737 !important;
}
.txt-color-yellowLight {
  color: #fff03d !important;
}
.txt-color-orange {
  color: #c79121 !important;
}
.txt-color-orangeLight {
  color: #ee9000 !important;
}
.txt-color-orangeDark {
  color: #a57225 !important;
}
.txt-color-pink {
  color: #ac5287 !important;
}
.txt-color-pinkDark {
  color: #a8829f !important;
}
.txt-color-purple {
  color: #65596b !important;
}
.txt-color-darken {
  color: #404040 !important;
}
.txt-color-silver {
  color: #b4b4b4 !important;
}
.txt-color-lighten {
  color: #d5e7ec !important;
}
.txt-color-white {
  color: #ffffff !important;
}
.txt-color-grayDark {
  color: #525252 !important;
}
.txt-color-magenta {
  color: #6e3671 !important;
}
.txt-color-teal {
  color: #568a89 !important;
}
.txt-color-redLight {
  color: #a65858 !important;
}
.bg-color-blue {
  background-color: #60747c !important;
}
.bg-color-blueLight {
  background-color: #ccdadf !important;
}
.bg-color-blueDark {
  background-color: #4c4f53 !important;
}
.bg-color-green {
  background-color: #356e35 !important;
}
.bg-color-greenLight {
  background-color: #71843f !important;
}
.bg-color-greenDark {
  background-color: #496949 !important;
}
.bg-color-red {
  background-color: #931313 !important;
}
.bg-color-yellow {
  background-color: #d4c737 !important;
}
.bg-color-yellowLight {
  background-color: #fff03d !important;
}
.bg-color-orange {
  background-color: #c79121 !important;
}
.bg-color-orangeLight {
  background-color: #ee9000 !important;
}
.bg-color-orangeDark {
  background-color: #a57225 !important;
}
.bg-color-pink {
  background-color: #ac5287 !important;
}
.bg-color-pinkDark {
  background-color: #a8829f !important;
}
.bg-color-purple {
  background-color: #65596b !important;
}
.bg-color-darken {
  background-color: #404040 !important;
}
.bg-color-silver {
  background-color: #b4b4b4 !important;
}
.bg-color-lighten {
  background-color: #d5e7ec !important;
}
.bg-color-white {
  background-color: #ffffff !important;
}
.bg-color-grayDark {
  background-color: #525252 !important;
}
.bg-color-magenta {
  background-color: #6e3671 !important;
}
.bg-color-teal {
  background-color: #568a89 !important;
}
.bg-color-redLight {
  background-color: #a65858 !important;
}
/*
 * Animations
 */
@-webkit-keyframes flash {
  0%,
  100%,
  50% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@keyframes flash {
  0%,
  100%,
  50% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@-webkit-keyframes shake {
  0%,
  100% {
    -webkit-transform: translateX(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translateX(-10px);
  }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translateX(10px);
  }
}
@keyframes shake {
  0%,
  100% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translateX(-10px);
    -ms-transform: translateX(-10px);
    transform: translateX(-10px);
  }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translateX(10px);
    -ms-transform: translateX(10px);
    transform: translateX(10px);
  }
}
@-webkit-keyframes bounce {
  0%,
  100%,
  20%,
  50%,
  80% {
    -webkit-transform: translateY(0);
  }
  40% {
    -webkit-transform: translateY(-30px);
  }
  60% {
    -webkit-transform: translateY(-15px);
  }
}
@keyframes bounce {
  0%,
  100%,
  20%,
  50%,
  80% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  40% {
    -webkit-transform: translateY(-30px);
    -ms-transform: translateY(-30px);
    transform: translateY(-30px);
  }
  60% {
    -webkit-transform: translateY(-15px);
    -ms-transform: translateY(-15px);
    transform: translateY(-15px);
  }
}
@-webkit-keyframes tada {
  0% {
    -webkit-transform: scale(1);
  }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -webkit-transform: scale(1) rotate(0);
  }
}
@keyframes tada {
  0% {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
  }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
    -ms-transform: scale(0.9) rotate(-3deg);
    transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
    -ms-transform: scale(1.1) rotate(3deg);
    transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
    -ms-transform: scale(1.1) rotate(-3deg);
    transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -webkit-transform: scale(1) rotate(0);
    -ms-transform: scale(1) rotate(0);
    transform: scale(1) rotate(0);
  }
}
@-webkit-keyframes swing {
  100%,
  20%,
  40%,
  60%,
  80% {
    -webkit-transform-origin: top center;
  }
  20% {
    -webkit-transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
  }
  100% {
    -webkit-transform: rotate(0deg);
  }
}
@keyframes swing {
  20% {
    -webkit-transform: rotate(15deg);
    -ms-transform: rotate(15deg);
    transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
    -ms-transform: rotate(-10deg);
    transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
    -ms-transform: rotate(5deg);
    transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
    -ms-transform: rotate(-5deg);
    transform: rotate(-5deg);
  }
  100% {
    -webkit-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    transform: rotate(0deg);
  }
}
@-webkit-keyframes wobble {
  0% {
    -webkit-transform: translateX(0);
  }
  15% {
    -webkit-transform: translateX(-25%) rotate(-5deg);
  }
  30% {
    -webkit-transform: translateX(20%) rotate(3deg);
  }
  45% {
    -webkit-transform: translateX(-15%) rotate(-3deg);
  }
  60% {
    -webkit-transform: translateX(10%) rotate(2deg);
  }
  75% {
    -webkit-transform: translateX(-5%) rotate(-1deg);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@keyframes wobble {
  0% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  15% {
    -webkit-transform: translateX(-25%) rotate(-5deg);
    -ms-transform: translateX(-25%) rotate(-5deg);
    transform: translateX(-25%) rotate(-5deg);
  }
  30% {
    -webkit-transform: translateX(20%) rotate(3deg);
    -ms-transform: translateX(20%) rotate(3deg);
    transform: translateX(20%) rotate(3deg);
  }
  45% {
    -webkit-transform: translateX(-15%) rotate(-3deg);
    -ms-transform: translateX(-15%) rotate(-3deg);
    transform: translateX(-15%) rotate(-3deg);
  }
  60% {
    -webkit-transform: translateX(10%) rotate(2deg);
    -ms-transform: translateX(10%) rotate(2deg);
    transform: translateX(10%) rotate(2deg);
  }
  75% {
    -webkit-transform: translateX(-5%) rotate(-1deg);
    -ms-transform: translateX(-5%) rotate(-1deg);
    transform: translateX(-5%) rotate(-1deg);
  }
  100% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scale(1);
  }
  50% {
    -webkit-transform: scale(1.1);
  }
  100% {
    -webkit-transform: scale(1);
  }
}
@keyframes pulse {
  0% {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
  }
  50% {
    -webkit-transform: scale(1.1);
    -ms-transform: scale(1.1);
    transform: scale(1.1);
  }
  100% {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
  }
}
@-webkit-keyframes flip {
  0% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    -webkit-animation-timing-function: ease-out;
  }
  40% {
    -webkit-transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    -webkit-animation-timing-function: ease-out;
  }
  50% {
    -webkit-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    -webkit-animation-timing-function: ease-in;
  }
  80% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    -webkit-animation-timing-function: ease-in;
  }
  100% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    -webkit-animation-timing-function: ease-in;
  }
}
@keyframes flip {
  0% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    -ms-transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out;
  }
  40% {
    -webkit-transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    -ms-transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out;
  }
  50% {
    -webkit-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    -ms-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }
  80% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    -ms-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }
  100% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    -ms-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }
}
@-webkit-keyframes flipInX {
  0% {
    -webkit-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
  40% {
    -webkit-transform: perspective(400px) rotateX(-10deg);
  }
  70% {
    -webkit-transform: perspective(400px) rotateX(10deg);
  }
  100% {
    -webkit-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
}
@keyframes flipInX {
  0% {
    -webkit-transform: perspective(400px) rotateX(90deg);
    -ms-transform: perspective(400px) rotateX(90deg);
    transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
  40% {
    -webkit-transform: perspective(400px) rotateX(-10deg);
    -ms-transform: perspective(400px) rotateX(-10deg);
    transform: perspective(400px) rotateX(-10deg);
  }
  70% {
    -webkit-transform: perspective(400px) rotateX(10deg);
    -ms-transform: perspective(400px) rotateX(10deg);
    transform: perspective(400px) rotateX(10deg);
  }
  100% {
    -webkit-transform: perspective(400px) rotateX(0deg);
    -ms-transform: perspective(400px) rotateX(0deg);
    transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
}
@-webkit-keyframes flipOutX {
  0% {
    -webkit-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
}
@keyframes flipOutX {
  0% {
    -webkit-transform: perspective(400px) rotateX(0deg);
    -ms-transform: perspective(400px) rotateX(0deg);
    transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: perspective(400px) rotateX(90deg);
    -ms-transform: perspective(400px) rotateX(90deg);
    transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
}
@-webkit-keyframes flipInY {
  0% {
    -webkit-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
  40% {
    -webkit-transform: perspective(400px) rotateY(-10deg);
  }
  70% {
    -webkit-transform: perspective(400px) rotateY(10deg);
  }
  100% {
    -webkit-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
}
@keyframes flipInY {
  0% {
    -webkit-transform: perspective(400px) rotateY(90deg);
    -ms-transform: perspective(400px) rotateY(90deg);
    transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
  40% {
    -webkit-transform: perspective(400px) rotateY(-10deg);
    -ms-transform: perspective(400px) rotateY(-10deg);
    transform: perspective(400px) rotateY(-10deg);
  }
  70% {
    -webkit-transform: perspective(400px) rotateY(10deg);
    -ms-transform: perspective(400px) rotateY(10deg);
    transform: perspective(400px) rotateY(10deg);
  }
  100% {
    -webkit-transform: perspective(400px) rotateY(0deg);
    -ms-transform: perspective(400px) rotateY(0deg);
    transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
}
@-webkit-keyframes flipOutY {
  0% {
    -webkit-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
}
@keyframes flipOutY {
  0% {
    -webkit-transform: perspective(400px) rotateY(0deg);
    -ms-transform: perspective(400px) rotateY(0deg);
    transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: perspective(400px) rotateY(90deg);
    -ms-transform: perspective(400px) rotateY(90deg);
    transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
}
@-webkit-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-webkit-keyframes fadeInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@keyframes fadeInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(20px);
    -ms-transform: translateY(20px);
    transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-20px);
    -ms-transform: translateY(-20px);
    transform: translateY(-20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes fadeInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@keyframes fadeInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
    -ms-transform: translateX(-20px);
    transform: translateX(-20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes fadeInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@keyframes fadeInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(20px);
    -ms-transform: translateX(20px);
    transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes fadeInUpBig {
  0% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@keyframes fadeInUpBig {
  0% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
    -ms-transform: translateY(2000px);
    transform: translateY(2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes fadeInDownBig {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@keyframes fadeInDownBig {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
    -ms-transform: translateY(-2000px);
    transform: translateY(-2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes fadeInLeftBig {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@keyframes fadeInLeftBig {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
    -ms-transform: translateX(-2000px);
    transform: translateX(-2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes fadeInRightBig {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@keyframes fadeInRightBig {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
    -ms-transform: translateX(2000px);
    transform: translateX(2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@-webkit-keyframes fadeOutUp {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-20px);
  }
}
@keyframes fadeOutUp {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-20px);
    -ms-transform: translateY(-20px);
    transform: translateY(-20px);
  }
}
@-webkit-keyframes fadeOutDown {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(20px);
  }
}
@keyframes fadeOutDown {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(20px);
    -ms-transform: translateY(20px);
    transform: translateY(20px);
  }
}
@-webkit-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
  }
}
@keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
    -ms-transform: translateX(-20px);
    transform: translateX(-20px);
  }
}
@-webkit-keyframes fadeOutRight {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(20px);
  }
}
@keyframes fadeOutRight {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(20px);
    -ms-transform: translateX(20px);
    transform: translateX(20px);
  }
}
@-webkit-keyframes fadeOutUpBig {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
}
@keyframes fadeOutUpBig {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
    -ms-transform: translateY(-2000px);
    transform: translateY(-2000px);
  }
}
@-webkit-keyframes fadeOutDownBig {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
}
@keyframes fadeOutDownBig {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
    -ms-transform: translateY(2000px);
    transform: translateY(2000px);
  }
}
@-webkit-keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
}
@keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
    -ms-transform: translateX(-2000px);
    transform: translateX(-2000px);
  }
}
@-webkit-keyframes fadeOutRightBig {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
}
@keyframes fadeOutRightBig {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
    -ms-transform: translateX(2000px);
    transform: translateX(2000px);
  }
}
@-webkit-keyframes bounceIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0.3);
  }
  50% {
    opacity: 1;
    -webkit-transform: scale(1.05);
  }
  70% {
    -webkit-transform: scale(0.9);
  }
  100% {
    -webkit-transform: scale(1);
  }
}
@keyframes bounceIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0.3);
    -ms-transform: scale(0.3);
    transform: scale(0.3);
  }
  50% {
    opacity: 1;
    -webkit-transform: scale(1.05);
    -ms-transform: scale(1.05);
    transform: scale(1.05);
  }
  70% {
    -webkit-transform: scale(0.9);
    -ms-transform: scale(0.9);
    transform: scale(0.9);
  }
  100% {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
  }
}
@-webkit-keyframes slideInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
  100% {
    -webkit-transform: translateY(0);
  }
}
@keyframes slideInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
    -ms-transform: translateY(-2000px);
    transform: translateY(-2000px);
  }
  100% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes slideInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@keyframes slideInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
    -ms-transform: translateX(-2000px);
    transform: translateX(-2000px);
  }
  100% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes slideInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@keyframes slideInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
    -ms-transform: translateX(2000px);
    transform: translateX(2000px);
  }
  100% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes slideOutLeft {
  0% {
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
}
@keyframes slideOutLeft {
  0% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
    -ms-transform: translateX(-2000px);
    transform: translateX(-2000px);
  }
}
@-webkit-keyframes slideOutRight {
  0% {
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
}
@keyframes slideOutRight {
  0% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
    -ms-transform: translateX(2000px);
    transform: translateX(2000px);
  }
}
@-webkit-keyframes slideOutUp {
  0% {
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
}
@keyframes slideOutUp {
  0% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
    -ms-transform: translateY(-2000px);
    transform: translateY(-2000px);
  }
}
@-webkit-keyframes bounceInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateY(-30px);
  }
  80% {
    -webkit-transform: translateY(10px);
  }
  100% {
    -webkit-transform: translateY(0);
  }
}
@keyframes bounceInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
    -ms-transform: translateY(2000px);
    transform: translateY(2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateY(-30px);
    -ms-transform: translateY(-30px);
    transform: translateY(-30px);
  }
  80% {
    -webkit-transform: translateY(10px);
    -ms-transform: translateY(10px);
    transform: translateY(10px);
  }
  100% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes bounceInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateY(30px);
  }
  80% {
    -webkit-transform: translateY(-10px);
  }
  100% {
    -webkit-transform: translateY(0);
  }
}
@keyframes bounceInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
    -ms-transform: translateY(-2000px);
    transform: translateY(-2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateY(30px);
    -ms-transform: translateY(30px);
    transform: translateY(30px);
  }
  80% {
    -webkit-transform: translateY(-10px);
    -ms-transform: translateY(-10px);
    transform: translateY(-10px);
  }
  100% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes bounceInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateX(30px);
  }
  80% {
    -webkit-transform: translateX(-10px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@keyframes bounceInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
    -ms-transform: translateX(-2000px);
    transform: translateX(-2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateX(30px);
    -ms-transform: translateX(30px);
    transform: translateX(30px);
  }
  80% {
    -webkit-transform: translateX(-10px);
    -ms-transform: translateX(-10px);
    transform: translateX(-10px);
  }
  100% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes bounceInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateX(-30px);
  }
  80% {
    -webkit-transform: translateX(10px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@keyframes bounceInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
    -ms-transform: translateX(2000px);
    transform: translateX(2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateX(-30px);
    -ms-transform: translateX(-30px);
    transform: translateX(-30px);
  }
  80% {
    -webkit-transform: translateX(10px);
    -ms-transform: translateX(10px);
    transform: translateX(10px);
  }
  100% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
}
@-webkit-keyframes bounceOut {
  0% {
    -webkit-transform: scale(1);
  }
  25% {
    -webkit-transform: scale(0.95);
  }
  50% {
    opacity: 1;
    -webkit-transform: scale(1.1);
  }
  100% {
    opacity: 0;
    -webkit-transform: scale(0.3);
  }
}
@keyframes bounceOut {
  0% {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
  }
  25% {
    -webkit-transform: scale(0.95);
    -ms-transform: scale(0.95);
    transform: scale(0.95);
  }
  50% {
    opacity: 1;
    -webkit-transform: scale(1.1);
    -ms-transform: scale(1.1);
    transform: scale(1.1);
  }
  100% {
    opacity: 0;
    -webkit-transform: scale(0.3);
    -ms-transform: scale(0.3);
    transform: scale(0.3);
  }
}
@-webkit-keyframes bounceOutUp {
  0% {
    -webkit-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateY(20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
}
@keyframes bounceOutUp {
  0% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateY(20px);
    -ms-transform: translateY(20px);
    transform: translateY(20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
    -ms-transform: translateY(-2000px);
    transform: translateY(-2000px);
  }
}
@-webkit-keyframes bounceOutDown {
  0% {
    -webkit-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateY(-20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
}
@keyframes bounceOutDown {
  0% {
    -webkit-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateY(-20px);
    -ms-transform: translateY(-20px);
    transform: translateY(-20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
    -ms-transform: translateY(2000px);
    transform: translateY(2000px);
  }
}
@-webkit-keyframes bounceOutLeft {
  0% {
    -webkit-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateX(20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
}
@keyframes bounceOutLeft {
  0% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateX(20px);
    -ms-transform: translateX(20px);
    transform: translateX(20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
    -ms-transform: translateX(-2000px);
    transform: translateX(-2000px);
  }
}
@-webkit-keyframes bounceOutRight {
  0% {
    -webkit-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateX(-20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
}
@keyframes bounceOutRight {
  0% {
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateX(-20px);
    -ms-transform: translateX(-20px);
    transform: translateX(-20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
    -ms-transform: translateX(2000px);
    transform: translateX(2000px);
  }
}
@-webkit-keyframes rotateIn {
  0% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateIn {
  0% {
    -webkit-transform-origin: center center;
    -ms-transform-origin: center center;
    transform-origin: center center;
    -webkit-transform: rotate(-200deg);
    -ms-transform: rotate(-200deg);
    transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: center center;
    -ms-transform-origin: center center;
    transform-origin: center center;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
}
@-webkit-keyframes rotateInUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
}
@-webkit-keyframes rotateInDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(-90deg);
    -ms-transform: rotate(-90deg);
    transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
}
@-webkit-keyframes rotateInUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(-90deg);
    -ms-transform: rotate(-90deg);
    transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
}
@-webkit-keyframes rotateInDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
}
@-webkit-keyframes rotateOut {
  0% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(200deg);
    opacity: 0;
  }
}
@keyframes rotateOut {
  0% {
    -webkit-transform-origin: center center;
    -ms-transform-origin: center center;
    transform-origin: center center;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: center center;
    -ms-transform-origin: center center;
    transform-origin: center center;
    -webkit-transform: rotate(200deg);
    -ms-transform: rotate(200deg);
    transform: rotate(200deg);
    opacity: 0;
  }
}
@-webkit-keyframes rotateOutUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
}
@keyframes rotateOutUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(-90deg);
    -ms-transform: rotate(-90deg);
    transform: rotate(-90deg);
    opacity: 0;
  }
}
@-webkit-keyframes rotateOutDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
}
@keyframes rotateOutDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -ms-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg);
    opacity: 0;
  }
}
@-webkit-keyframes rotateOutUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
}
@keyframes rotateOutUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg);
    opacity: 0;
  }
}
@-webkit-keyframes rotateOutDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
}
@keyframes rotateOutDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -ms-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate(-90deg);
    -ms-transform: rotate(-90deg);
    transform: rotate(-90deg);
    opacity: 0;
  }
}
@-webkit-keyframes hinge {
  0% {
    -webkit-transform: rotate(0);
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  20%,
  60% {
    -webkit-transform: rotate(80deg);
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  40% {
    -webkit-transform: rotate(60deg);
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  80% {
    -webkit-transform: rotate(60deg) translateY(0);
    opacity: 1;
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  100% {
    -webkit-transform: translateY(700px);
    opacity: 0;
  }
}
@keyframes hinge {
  0% {
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
    -webkit-transform-origin: top left;
    -ms-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }
  20%,
  60% {
    -webkit-transform: rotate(80deg);
    -ms-transform: rotate(80deg);
    transform: rotate(80deg);
    -webkit-transform-origin: top left;
    -ms-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }
  40% {
    -webkit-transform: rotate(60deg);
    -ms-transform: rotate(60deg);
    transform: rotate(60deg);
    -webkit-transform-origin: top left;
    -ms-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }
  80% {
    -webkit-transform: rotate(60deg) translateY(0);
    -ms-transform: rotate(60deg) translateY(0);
    transform: rotate(60deg) translateY(0);
    opacity: 1;
    -webkit-transform-origin: top left;
    -ms-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }
  100% {
    -webkit-transform: translateY(700px);
    -ms-transform: translateY(700px);
    transform: translateY(700px);
    opacity: 0;
  }
}
@-webkit-keyframes rollIn {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-100%) rotate(-120deg);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0) rotate(0deg);
  }
}
@keyframes rollIn {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-100%) rotate(-120deg);
    -ms-transform: translateX(-100%) rotate(-120deg);
    transform: translateX(-100%) rotate(-120deg);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0) rotate(0deg);
    -ms-transform: translateX(0) rotate(0deg);
    transform: translateX(0) rotate(0deg);
  }
}
@-webkit-keyframes rollOut {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0) rotate(0deg);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(100%) rotate(120deg);
  }
}
@keyframes rollOut {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0) rotate(0deg);
    -ms-transform: translateX(0) rotate(0deg);
    transform: translateX(0) rotate(0deg);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(100%) rotate(120deg);
    -ms-transform: translateX(100%) rotate(120deg);
    transform: translateX(100%) rotate(120deg);
  }
}
@-webkit-keyframes lightSpeedIn {
  0% {
    -webkit-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
  60% {
    -webkit-transform: translateX(-20%) skewX(30deg);
    opacity: 1;
  }
  80% {
    -webkit-transform: translateX(0) skewX(-15deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: translateX(0) skewX(0deg);
    opacity: 1;
  }
}
@keyframes lightSpeedIn {
  0% {
    -webkit-transform: translateX(100%) skewX(-30deg);
    -ms-transform: translateX(100%) skewX(-30deg);
    transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
  60% {
    -webkit-transform: translateX(-20%) skewX(30deg);
    -ms-transform: translateX(-20%) skewX(30deg);
    transform: translateX(-20%) skewX(30deg);
    opacity: 1;
  }
  80% {
    -webkit-transform: translateX(0) skewX(-15deg);
    -ms-transform: translateX(0) skewX(-15deg);
    transform: translateX(0) skewX(-15deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: translateX(0) skewX(0deg);
    -ms-transform: translateX(0) skewX(0deg);
    transform: translateX(0) skewX(0deg);
    opacity: 1;
  }
}
@-webkit-keyframes lightSpeedOut {
  0% {
    -webkit-transform: translateX(0) skewX(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
}
@keyframes lightSpeedOut {
  0% {
    -webkit-transform: translateX(0) skewX(0deg);
    -ms-transform: translateX(0) skewX(0deg);
    transform: translateX(0) skewX(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: translateX(100%) skewX(-30deg);
    -ms-transform: translateX(100%) skewX(-30deg);
    transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
}
@-webkit-keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
  }
}
@-ms-keyframes spin {
  0% {
    -ms-transform: rotate(0deg);
  }
  100% {
    -ms-transform: rotate(359deg);
  }
}
@keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    -ms-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@-webkit-keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@-ms-keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-webkit-keyframes pace-spinner {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@-ms-keyframes pace-spinner {
  0% {
    -ms-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@keyframes pace-spinner {
  0% {
    -webkit-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
.animated {
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
}
.animated.fast {
  -webkit-animation-duration: .4s;
  -ms-animation-duration: .4s;
  animation-duration: .4s;
}
.animated.hinge {
  -webkit-animation-duration: 2s;
  animation-duration: 2s;
}
.animated.flash {
  -webkit-animation-name: flash;
  animation-name: flash;
}
.animated.shake {
  -webkit-animation-name: shake;
  animation-name: shake;
}
.animated.bounce {
  -webkit-animation-name: bounce;
  animation-name: bounce;
}
.animated.tada {
  -webkit-animation-name: tada;
  animation-name: tada;
}
.animated.swing {
  -webkit-transform-origin: top center;
  -ms-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-name: swing;
  animation-name: swing;
}
.animated.wobble {
  -webkit-animation-name: wobble;
  animation-name: wobble;
}
.animated.pulse {
  -webkit-animation-name: pulse;
  animation-name: pulse;
}
.animated.flip {
  -webkit-backface-visibility: visible!important;
  -webkit-animation-name: flip;
  -ms-backface-visibility: visible!important;
  backface-visibility: visible!important;
  animation-name: flip;
}
.animated.flipInX {
  -webkit-backface-visibility: visible!important;
  -webkit-animation-name: flipInX;
  -ms-backface-visibility: visible!important;
  backface-visibility: visible!important;
  animation-name: flipInX;
}
.animated.flipOutX {
  -webkit-animation-name: flipOutX;
  -webkit-backface-visibility: visible!important;
  animation-name: flipOutX;
  -ms-backface-visibility: visible!important;
  backface-visibility: visible!important;
}
.animated.flipInY {
  -webkit-backface-visibility: visible!important;
  -webkit-animation-name: flipInY;
  -ms-backface-visibility: visible!important;
  backface-visibility: visible!important;
  animation-name: flipInY;
}
.animated.flipOutY {
  -webkit-backface-visibility: visible!important;
  -webkit-animation-name: flipOutY;
  -ms-backface-visibility: visible!important;
  backface-visibility: visible!important;
  animation-name: flipOutY;
}
.animated.fadeIn {
  -webkit-animation-name: fadeIn;
  animation-name: fadeIn;
}
.animated.fadeInUp {
  -webkit-animation-name: fadeInUp;
  animation-name: fadeInUp;
}
.animated.fadeInDown {
  -webkit-animation-name: fadeInDown;
  animation-name: fadeInDown;
}
.animated.fadeInLeft {
  -webkit-animation-name: fadeInLeft;
  animation-name: fadeInLeft;
}
.animated.fadeInRight {
  -webkit-animation-name: fadeInRight;
  animation-name: fadeInRight;
}
.animated.fadeInUpBig {
  -webkit-animation-name: fadeInUpBig;
  animation-name: fadeInUpBig;
}
.animated.fadeInDownBig {
  -webkit-animation-name: fadeInDownBig;
  animation-name: fadeInDownBig;
}
.animated.fadeInLeftBig {
  -webkit-animation-name: fadeInLeftBig;
  animation-name: fadeInLeftBig;
}
.animated.fadeInRightBig {
  -webkit-animation-name: fadeInRightBig;
  animation-name: fadeInRightBig;
}
.animated.fadeOut {
  -webkit-animation-name: fadeOut;
  animation-name: fadeOut;
}
.animated.fadeOutUp {
  -webkit-animation-name: fadeOutUp;
  animation-name: fadeOutUp;
}
.animated.fadeOutDown {
  -webkit-animation-name: fadeOutDown;
  animation-name: fadeOutDown;
}
.animated.fadeOutLeft {
  -webkit-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft;
}
.animated.fadeOutRight {
  -webkit-animation-name: fadeOutRight;
  animation-name: fadeOutRight;
}
.animated.fadeOutUpBig {
  -webkit-animation-name: fadeOutUpBig;
  animation-name: fadeOutUpBig;
}
.animated.fadeOutDownBig {
  -webkit-animation-name: fadeOutDownBig;
  animation-name: fadeOutDownBig;
}
.animated.fadeOutLeftBig {
  -webkit-animation-name: fadeOutLeftBig;
  animation-name: fadeOutLeftBig;
}
.animated.fadeOutRightBig {
  -webkit-animation-name: fadeOutRightBig;
  animation-name: fadeOutRightBig;
}
.animated.bounceIn {
  -webkit-animation-name: bounceIn;
  animation-name: bounceIn;
}
.animated.slideInDown {
  -webkit-animation-name: slideInDown;
  animation-name: slideInDown;
}
.animated.slideInLeft {
  -webkit-animation-name: slideInLeft;
  animation-name: slideInLeft;
}
.animated.slideInRight {
  -webkit-animation-name: slideInRight;
  animation-name: slideInRight;
}
.animated.slideOutLeft {
  -webkit-animation-name: slideOutLeft;
  animation-name: slideOutLeft;
}
.animated.slideOutRight {
  -webkit-animation-name: slideOutRight;
  animation-name: slideOutRight;
}
.animated.slideOutUp {
  -webkit-animation-name: slideOutUp;
  animation-name: slideOutUp;
}
.animated.bounceInUp {
  -webkit-animation-name: bounceInUp;
  animation-name: bounceInUp;
}
.animated.bounceInDown {
  -webkit-animation-name: bounceInDown;
  animation-name: bounceInDown;
}
.animated.bounceInLeft {
  -webkit-animation-name: bounceInLeft;
  animation-name: bounceInLeft;
}
.animated.bounceInRight {
  -webkit-animation-name: bounceInRight;
  animation-name: bounceInRight;
}
.animated.bounceOut {
  -webkit-animation-name: bounceOut;
  animation-name: bounceOut;
}
.animated.bounceOutUp {
  -webkit-animation-name: bounceOutUp;
  animation-name: bounceOutUp;
}
.animated.bounceOutDown {
  -webkit-animation-name: bounceOutDown;
  animation-name: bounceOutDown;
}
.animated.bounceOutLeft {
  -webkit-animation-name: bounceOutLeft;
  animation-name: bounceOutLeft;
}
.animated.bounceOutRight {
  -webkit-animation-name: bounceOutRight;
  animation-name: bounceOutRight;
}
.animated.rotateIn {
  -webkit-animation-name: rotateIn;
  animation-name: rotateIn;
}
.animated.rotateInUpLeft {
  -webkit-animation-name: rotateInUpLeft;
  animation-name: rotateInUpLeft;
}
.animated.rotateInDownLeft {
  -webkit-animation-name: rotateInDownLeft;
  animation-name: rotateInDownLeft;
}
.animated.rotateInUpRight {
  -webkit-animation-name: rotateInUpRight;
  animation-name: rotateInUpRight;
}
.animated.rotateInDownRight {
  -webkit-animation-name: rotateInDownRight;
  animation-name: rotateInDownRight;
}
.animated.rotateOut {
  -webkit-animation-name: rotateOut;
  animation-name: rotateOut;
}
.animated.rotateOutUpLeft {
  -webkit-animation-name: rotateOutUpLeft;
  animation-name: rotateOutUpLeft;
}
.animated.rotateOutDownLeft {
  -webkit-animation-name: rotateOutDownLeft;
  animation-name: rotateOutDownLeft;
}
.animated.rotateOutUpRight {
  -webkit-animation-name: rotateOutUpRight;
  animation-name: rotateOutUpRight;
}
.animated.rotateOutDownRight {
  -webkit-animation-name: rotateOutDownRight;
  animation-name: rotateOutDownRight;
}
.animated.rollIn {
  -webkit-animation-name: rollIn;
  animation-name: rollIn;
}
.animated.rollOut {
  -webkit-animation-name: rollOut;
  animation-name: rollOut;
}
.animated.lightSpeedIn {
  -webkit-animation-name: lightSpeedIn;
  animation-name: lightSpeedIn;
  -webkit-animation-timing-function: ease-out;
  animation-timing-function: ease-out;
  -webkit-animation-duration: .5s;
  animation-duration: .5s;
}
.animated.lightSpeedOut {
  -webkit-animation-name: lightSpeedOut;
  animation-name: lightSpeedOut;
  -webkit-animation-timing-function: ease-in;
  animation-timing-function: ease-in;
  -webkit-animation-duration: .25s;
  animation-duration: .25s;
}
.animated.fade {
  opacity: 0;
  -webkit-transition: opacity .15s linear;
  transition: opacity .15s linear;
}
[class*=" bg-"],
[class^=bg-] {
  -webkit-filter: none!important;
  filter: none!important;
}
/*
 * Icons styles
 */
.square {
  display: block;
  float: left;
  margin-right: 10px;
  height: 20px;
  width: 20px;
}
.icon-color-good {
  color: #40ac2b;
}
.icon-color-bad {
  color: #ed1c24;
}
.percent-sign:after {
  content: " %";
  line-height: normal;
}
.degree-sign:after {
  content: " Â°F";
  line-height: normal;
}
.ui-state-default .ui-icon[class*=" icon-"] {
  background: 0 0;
  margin-left: -12px;
}
.ui-icon-carat-1-n {
  background-position: 0 0;
}
.ui-icon-carat-1-ne {
  background-position: -16px 0;
}
.ui-icon-carat-1-e {
  background-position: -32px 0;
}
.ui-icon-carat-1-e:before {
  content: "\f105";
  font-family: FontAwesome;
  font-size: 14px;
  display: inline;
}
.ui-icon-carat-1-se {
  background-position: -48px 0;
}
.ui-icon-carat-1-s {
  background-position: -64px 0;
}
.ui-icon-carat-1-sw {
  background-position: -80px 0;
}
.ui-icon-carat-1-w {
  background-position: -96px 0;
}
.ui-icon-carat-1-nw {
  background-position: -112px 0;
}
.ui-icon-carat-2-n-s {
  background-position: -128px 0;
}
.ui-icon-carat-2-e-w {
  background-position: -144px 0;
}
.ui-icon-triangle-1-n {
  background-position: 0 -16px;
}
.ui-icon-triangle-1-ne {
  background-position: -16px -16px;
}
.ui-icon-triangle-1-e {
  background-position: -32px -16px;
}
.ui-icon-triangle-1-se {
  background-position: -48px -16px;
}
.ui-icon-triangle-1-s {
  background-position: -64px -16px;
}
.ui-icon-triangle-1-sw {
  background-position: -80px -16px;
}
.ui-icon-triangle-1-w {
  background-position: -96px -16px;
}
.ui-icon-triangle-1-nw {
  background-position: -112px -16px;
}
.ui-icon-triangle-2-n-s {
  background-position: -128px -16px;
}
.ui-icon-triangle-2-e-w {
  background-position: -144px -16px;
}
.ui-icon-arrow-1-n {
  background-position: 0 -32px;
}
.ui-icon-arrow-1-ne {
  background-position: -16px -32px;
}
.ui-icon-arrow-1-e {
  background-position: -32px -32px;
}
.ui-icon-arrow-1-se {
  background-position: -48px -32px;
}
.ui-icon-arrow-1-s {
  background-position: -64px -32px;
}
.ui-icon-arrow-1-sw {
  background-position: -80px -32px;
}
.ui-icon-arrow-1-w {
  background-position: -96px -32px;
}
.ui-icon-arrow-1-nw {
  background-position: -112px -32px;
}
.ui-icon-arrow-2-n-s {
  background-position: -128px -32px;
}
.ui-icon-arrow-2-ne-sw {
  background-position: -144px -32px;
}
.ui-icon-arrow-2-e-w {
  background-position: -160px -32px;
}
.ui-icon-arrow-2-se-nw {
  background-position: -176px -32px;
}
.ui-icon-arrowstop-1-n {
  background-position: -192px -32px;
}
.ui-icon-arrowstop-1-e {
  background-position: -208px -32px;
}
.ui-icon-arrowstop-1-s {
  background-position: -224px -32px;
}
.ui-icon-arrowstop-1-w {
  background-position: -240px -32px;
}
.ui-icon-arrowthick-1-n {
  background-position: 0 -48px;
}
.ui-icon-arrowthick-1-ne {
  background-position: -16px -48px;
}
.ui-icon-arrowthick-1-e {
  background-position: -32px -48px;
}
.ui-icon-arrowthick-1-se {
  background-position: -48px -48px;
}
.ui-icon-arrowthick-1-s {
  background-position: -64px -48px;
}
.ui-icon-arrowthick-1-sw {
  background-position: -80px -48px;
}
.ui-icon-arrowthick-1-w {
  background-position: -96px -48px;
}
.ui-icon-arrowthick-1-nw {
  background-position: -112px -48px;
}
.ui-icon-arrowthick-2-n-s {
  background-position: -128px -48px;
}
.ui-icon-arrowthick-2-ne-sw {
  background-position: -144px -48px;
}
.ui-icon-arrowthick-2-e-w {
  background-position: -160px -48px;
}
.ui-icon-arrowthick-2-se-nw {
  background-position: -176px -48px;
}
.ui-icon-arrowthickstop-1-n {
  background-position: -192px -48px;
}
.ui-icon-arrowthickstop-1-e {
  background-position: -208px -48px;
}
.ui-icon-arrowthickstop-1-s {
  background-position: -224px -48px;
}
.ui-icon-arrowthickstop-1-w {
  background-position: -240px -48px;
}
.ui-icon-arrowreturnthick-1-w {
  background-position: 0 -64px;
}
.ui-icon-arrowreturnthick-1-n {
  background-position: -16px -64px;
}
.ui-icon-arrowreturnthick-1-e {
  background-position: -32px -64px;
}
.ui-icon-arrowreturnthick-1-s {
  background-position: -48px -64px;
}
.ui-icon-arrowreturn-1-w {
  background-position: -64px -64px;
}
.ui-icon-arrowreturn-1-n {
  background-position: -80px -64px;
}
.ui-icon-arrowreturn-1-e {
  background-position: -96px -64px;
}
.ui-icon-arrowreturn-1-s {
  background-position: -112px -64px;
}
.ui-icon-arrowrefresh-1-w {
  background-position: -128px -64px;
}
.ui-icon-arrowrefresh-1-n {
  background-position: -144px -64px;
}
.ui-icon-arrowrefresh-1-e {
  background-position: -160px -64px;
}
.ui-icon-arrowrefresh-1-s {
  background-position: -176px -64px;
}
.ui-icon-arrow-4 {
  background-position: 0 -80px;
}
.ui-icon-arrow-4-diag {
  background-position: -16px -80px;
}
.ui-icon-extlink {
  background-position: -32px -80px;
}
.ui-icon-newwin {
  background-position: -48px -80px;
}
.ui-icon-refresh {
  background-position: -64px -80px;
}
.ui-icon-shuffle {
  background-position: -80px -80px;
}
.ui-icon-transfer-e-w {
  background-position: -96px -80px;
}
.ui-icon-transferthick-e-w {
  background-position: -112px -80px;
}
.ui-icon-folder-collapsed {
  background-position: 0 -96px;
}
.ui-icon-folder-open {
  background-position: -16px -96px;
}
.ui-icon-document {
  background-position: -32px -96px;
}
.ui-icon-document-b {
  background-position: -48px -96px;
}
.ui-icon-note {
  background-position: -64px -96px;
}
.ui-icon-mail-closed {
  background-position: -80px -96px;
}
.ui-icon-mail-open {
  background-position: -96px -96px;
}
.ui-icon-suitcase {
  background-position: -112px -96px;
}
.ui-icon-comment {
  background-position: -128px -96px;
}
.ui-icon-person {
  background-position: -144px -96px;
}
.ui-icon-print {
  background-position: -160px -96px;
}
.ui-icon-trash {
  background-position: -176px -96px;
}
.ui-icon-locked {
  background-position: -192px -96px;
}
.ui-icon-unlocked {
  background-position: -208px -96px;
}
.ui-icon-bookmark {
  background-position: -224px -96px;
}
.ui-icon-tag {
  background-position: -240px -96px;
}
.ui-icon-home {
  background-position: 0 -112px;
}
.ui-icon-flag {
  background-position: -16px -112px;
}
.ui-icon-calendar {
  background-position: -32px -112px;
}
.ui-icon-cart {
  background-position: -48px -112px;
}
.ui-icon-pencil {
  background-position: -64px -112px;
}
.ui-icon-clock {
  background-position: -80px -112px;
}
.ui-icon-disk {
  background-position: -96px -112px;
}
.ui-icon-calculator {
  background-position: -112px -112px;
}
.ui-icon-zoomin {
  background-position: -128px -112px;
}
.ui-icon-zoomout {
  background-position: -144px -112px;
}
.ui-icon-search {
  background-position: -160px -112px;
}
.ui-icon-wrench {
  background-position: -176px -112px;
}
.ui-icon-gear {
  background-position: -192px -112px;
}
.ui-icon-heart {
  background-position: -208px -112px;
}
.ui-icon-star {
  background-position: -224px -112px;
}
.ui-icon-link {
  background-position: -240px -112px;
}
.ui-icon-cancel {
  background-position: 0 -128px;
}
.ui-icon-plus {
  background-position: -16px -128px;
}
.ui-icon-plusthick {
  background-position: -32px -128px;
}
.ui-icon-minus {
  background-position: -48px -128px;
}
.ui-icon-minusthick {
  background-position: -64px -128px;
}
.ui-icon-close {
  background-position: -80px -128px;
}
.ui-icon-closethick {
  background-position: -96px -128px;
}
.ui-icon-key {
  background-position: -112px -128px;
}
.ui-icon-lightbulb {
  background-position: -128px -128px;
}
.ui-icon-scissors {
  background-position: -144px -128px;
}
.ui-icon-clipboard {
  background-position: -160px -128px;
}
.ui-icon-copy {
  background-position: -176px -128px;
}
.ui-icon-contact {
  background-position: -192px -128px;
}
.ui-icon-image {
  background-position: -208px -128px;
}
.ui-icon-video {
  background-position: -224px -128px;
}
.ui-icon-script {
  background-position: -240px -128px;
}
.ui-icon-alert {
  background-position: 0 -144px;
}
.ui-icon-info {
  background-position: -16px -144px;
}
.ui-icon-notice {
  background-position: -32px -144px;
}
.ui-icon-help {
  background-position: -48px -144px;
}
.ui-icon-check {
  background-position: -64px -144px;
}
.ui-icon-bullet {
  background-position: -80px -144px;
}
.ui-icon-radio-on {
  background-position: -96px -144px;
}
.ui-icon-radio-off {
  background-position: -112px -144px;
}
.ui-icon-pin-w {
  background-position: -128px -144px;
}
.ui-icon-pin-s {
  background-position: -144px -144px;
}
.ui-icon-play {
  background-position: 0 -160px;
}
.ui-icon-pause {
  background-position: -16px -160px;
}
.ui-icon-seek-next {
  background-position: -32px -160px;
}
.ui-icon-seek-prev {
  background-position: -48px -160px;
}
.ui-icon-seek-end {
  background-position: -64px -160px;
}
.ui-icon-seek-first,
.ui-icon-seek-start {
  background-position: -80px -160px;
}
.ui-icon-stop {
  background-position: -96px -160px;
}
.ui-icon-eject {
  background-position: -112px -160px;
}
.ui-icon-volume-off {
  background-position: -128px -160px;
}
.ui-icon-volume-on {
  background-position: -144px -160px;
}
.ui-icon-power {
  background-position: 0 -176px;
}
.ui-icon-signal-diag {
  background-position: -16px -176px;
}
.ui-icon-signal {
  background-position: -32px -176px;
}
.ui-icon-battery-0 {
  background-position: -48px -176px;
}
.ui-icon-battery-1 {
  background-position: -64px -176px;
}
.ui-icon-battery-2 {
  background-position: -80px -176px;
}
.ui-icon-battery-3 {
  background-position: -96px -176px;
}
.ui-icon-circle-plus {
  background-position: 0 -192px;
}
.ui-icon-circle-minus {
  background-position: -16px -192px;
}
.ui-icon-circle-close {
  background-position: -32px -192px;
}
.ui-icon-circle-triangle-e {
  background-position: -48px -192px;
}
.ui-icon-circle-triangle-s {
  background-position: -64px -192px;
}
.ui-icon-circle-triangle-w {
  background-position: -80px -192px;
}
.ui-icon-circle-triangle-n {
  background-position: -96px -192px;
}
.ui-icon-circle-arrow-e {
  background-position: -112px -192px;
}
.ui-icon-circle-arrow-s {
  background-position: -128px -192px;
}
.ui-icon-circle-arrow-w {
  background-position: -144px -192px;
}
.ui-icon-circle-arrow-n {
  background-position: -160px -192px;
}
.ui-icon-circle-zoomin {
  background-position: -176px -192px;
}
.ui-icon-circle-zoomout {
  background-position: -192px -192px;
}
.ui-icon-circle-check {
  background-position: -208px -192px;
}
.ui-icon-circlesmall-plus {
  background-position: 0 -208px;
}
.ui-icon-circlesmall-minus {
  background-position: -16px -208px;
}
.ui-icon-circlesmall-close {
  background-position: -32px -208px;
}
.ui-icon-squaresmall-plus {
  background-position: -48px -208px;
}
.ui-icon-squaresmall-minus {
  background-position: -64px -208px;
}
.ui-icon-squaresmall-close {
  background-position: -80px -208px;
}
.ui-icon-grip-dotted-vertical {
  background-position: 0 -224px;
}
.ui-icon-grip-dotted-horizontal {
  background-position: -16px -224px;
}
.ui-icon-grip-solid-vertical {
  background-position: -32px -224px;
}
.ui-icon-grip-solid-horizontal {
  background-position: -48px -224px;
}
.ui-icon-gripsmall-diagonal-se {
  background-position: -64px -224px;
}
.ui-icon-grip-diagonal-se {
  background-position: -80px -224px;
}
.ui-button-icon-primary.ui-icon[class*=" icon-"]:before,
.ui-button-icon-primary.ui-icon[class^=icon-]:before,
.ui-button-icon-secondary.ui-icon[class*=" icon-"]:before,
.ui-button-icon-secondary.ui-icon[class^=icon-]:before {
  font-size: inherit;
  margin-left: 7px!important;
  margin-left: 5px;
  display: inline;
  text-decoration: inherit;
  color: inherit;
}
/*
 * Typos styles
 */
@font-face {
  font-family: 'Ubuntu';
  src: url('fonts/Ubuntu-C.eot');
  src: url('fonts/Ubuntu-C.eot?#iefix') format('embedded-opentype'), url('fonts/Ubuntu-C.woff') format('woff'), url('fonts/Ubuntu-C.ttf') format('truetype'), url('fonts/Ubuntu-C.svg') format('svg');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'Ubuntu-Light';
  src: url('fonts/Ubuntu-L.eot');
  src: url('fonts/Ubuntu-L.eot?#iefix') format('embedded-opentype'), url('fonts/Ubuntu-L.woff') format('woff'), url('fonts/Ubuntu-L.ttf') format('truetype'), url('fonts/Ubuntu-L.svg') format('svg');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'Ubuntu-Bold';
  src: url('fonts/Ubuntu-B.eot');
  src: url('fonts/Ubuntu-B.eot?#iefix') format('embedded-opentype'), url('fonts/Ubuntu-B.woff') format('woff'), url('fonts/Ubuntu-B.ttf') format('truetype'), url('fonts/Ubuntu-B.svg') format('svg');
  font-weight: bold;
  font-style: normal;
}
html,
body {
  font-family: Ubuntu, Arial, Helvetica, sans-serif;
}
a:active,
a:focus,
a:hover,
button,
button:active,
button:focus,
embed,
input::-moz-focus-inner,
object {
  outline: 0;
}
.hidden {
  display: none;
}
.hidden-desktop {
  display: none!important;
}
.no-visible {
  visibility: hidden!important;
}
.pull-right {
  float: right!Important;
}
.pull-left {
  float: left!Important;
}
.align-top {
  vertical-align: top!important;
}
.align-base {
  vertical-align: baseline!important;
}
.opaque {
  opacity: 1!important;
}
.disabled {
  color: #fff;
}
.btn-default.disabled {
  color: #999;
}
xmp {
  overflow: auto;
}
.nowrap {
  white-space: nowrap;
}
.truncated {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.no-space {
  margin: 0;
}
.no-space > [class*=col-] {
  margin: 0!important;
  padding-right: 0;
  padding-left: 0;
}
.no-margin {
  margin: 0!important;
}
.no-x-margin {
  margin-left: 0!important;
  margin-right: 0!important;
}
.no-y-margin {
  margin-top: 0!important;
  margin-bottom: 0!important;
}
.margin-5 {
  margin: 5px !important;
}
.margin-10 {
  margin: 10px !important;
}
.margin-20 {
  margin: 20px !important;
}
.margin-x-0 {
  margin-left: 0px!important;
  margin-right: 0px!important;
}
.margin-x-5 {
  margin-left: 5px!important;
  margin-right: 5px!important;
}
.margin-x-10 {
  margin-left: 10px!important;
  margin-right: 10px!important;
}
.margin-x-20 {
  margin-left: 20px!important;
  margin-right: 20px!important;
}
.margin-y-0 {
  margin-top: 0px!important;
  margin-bottom: 0px!important;
}
.margin-y-5 {
  margin-top: 5px!important;
  margin-bottom: 5px!important;
}
.margin-y-10 {
  margin-top: 10px!important;
  margin-bottom: 10px!important;
}
.margin-y-20 {
  margin-top: 20px!important;
  margin-bottom: 20px!important;
}
.margin-top-0 {
  margin-top: 0!important;
}
.margin-top-5 {
  margin-top: 5px!important;
}
.margin-top-10 {
  margin-top: 10px!important;
}
.margin-top-20 {
  margin-top: 20px!important;
}
.margin-bottom-0 {
  margin-bottom: 0!important;
}
.margin-bottom-5 {
  margin-bottom: 5px!important;
}
.margin-bottom-10 {
  margin-bottom: 10px!important;
}
.margin-bottom-20 {
  margin-bottom: 20px!important;
}
.margin-left-0 {
  margin-left: 0!important;
}
.margin-left-5 {
  margin-left: 5px!important;
}
.margin-left-10 {
  margin-left: 10px!important;
}
.margin-left-20 {
  margin-left: 20px!important;
}
.margin-right-0 {
  margin-right: 0!important;
}
.margin-right-5 {
  margin-right: 5px!important;
}
.margin-right-10 {
  margin-right: 10px!important;
}
.margin-right-20 {
  margin-right: 20px!important;
}
.bordered {
  border: 1px solid #dddddd;
}
.bordered:hover {
  border: 1px solid #bbbbbb;
}
.bordered.nohover:hover {
  border-color: #dddddd;
}
.no-border,
.well[class*=" bg-"].no-border {
  border-width: 0!important;
}
.no-border-transparent {
  border-color: transparent!important;
}
.no-border-radius {
  border-radius: 0;
}
.border-0 {
  border-width: 0!important;
}
.border-1 {
  border-width: 1px!important;
}
.width-100 {
  width: 100px;
  max-width: 100px;
}
.width-200 {
  width: 200px;
  max-width: 200px;
}
.width-300 {
  width: 300px;
  max-width: 300px;
}
.width-400 {
  width: 400px;
  max-width: 400px;
}
.width-500 {
  width: 500px;
  max-width: 500px;
}
.padding-5 {
  padding: 5px!important;
}
.padding-7 {
  padding: 7px!important;
}
.padding-10 {
  padding: 10px!important;
}
.padding-20 {
  padding: 20px!important;
}
.padding-x-0 {
  padding-left: 0px!important;
  padding-right: 0px!important;
}
.padding-x-5 {
  padding-left: 5px!important;
  padding-right: 5px!important;
}
.padding-x-10 {
  padding-left: 10px!important;
  padding-right: 10px!important;
}
.padding-x-20 {
  padding-left: 20px!important;
  padding-right: 20px!important;
}
.padding-y-0 {
  padding-top: 0px!important;
  padding-bottom: 0px!important;
}
.padding-y-5 {
  padding-top: 5px!important;
  padding-bottom: 5px!important;
}
.padding-y-10 {
  padding-top: 10px!important;
  padding-bottom: 10px!important;
}
.padding-y-20 {
  padding-top: 20px!important;
  padding-bottom: 20px!important;
}
.padding-top-0 {
  padding-top: 0!important;
}
.padding-top-5 {
  padding-top: 5px!important;
}
.padding-top-10 {
  padding-top: 10px!important;
}
.padding-top-20 {
  padding-top: 20px!important;
}
.padding-bottom-0 {
  padding-bottom: 0!important;
}
.padding-bottom-5 {
  padding-bottom: 5px!important;
}
.padding-bottom-10 {
  padding-bottom: 10px!important;
}
.padding-bottom-20 {
  padding-bottom: 20px!important;
}
.padding-left-0 {
  padding-left: 0!important;
}
.padding-left-5 {
  padding-left: 5px!important;
}
.padding-left-10 {
  padding-left: 10px!important;
}
.padding-left-20 {
  padding-left: 20px!important;
}
.padding-right-0 {
  padding-right: 0!important;
}
.padding-right-5 {
  padding-right: 5px!important;
}
.padding-right-10 {
  padding-right: 10px!important;
}
.padding-right-20 {
  padding-right: 20px!important;
}
.no-padding {
  padding: 0!important;
}
.no-padding .md-editor,
.widget-body.no-padding .cke_chrome {
  border: 0;
}
.no-padding > pre {
  margin: 30px;
}
.no-padding .dataTables_wrapper table,
.no-padding > table {
  border: 0!important;
  margin-bottom: 0!important;
  border-bottom-width: 0!important;
}
.no-padding .dataTables_wrapper table tr td:first-child,
.no-padding > table tr td:first-child,
.no-padding .dataTables_wrapper table tr th:first-child,
.no-padding > table tr th:first-child {
  border-left: 0!important;
}
.no-padding .dataTables_wrapper table tr td:last-child,
.no-padding > table tr td:last-child,
.no-padding .dataTables_wrapper table tr th:last-child,
.no-padding > table tr th:last-child {
  border-right: 0!important;
}
.no-padding .dataTables_wrapper table tr:last-child td,
.no-padding > table tr:last-child td {
  border-bottom: 0;
}
.no-padding-bottom {
  padding-bottom: 0!important;
}
.no-x-padding {
  padding-left: 0!important;
  padding-right: 0!important;
}
.no-y-padding {
  padding-top: 0!important;
  padding-bottom: 0!important;
}
.no-content-padding {
  margin: -10px -14px 0 -14px;
}
@media (min-width: 768px) and (max-width: 880px) {
  .no-content-padding {
    margin: 0 -14px !important;
  }
}
@media (max-width: 767px) {
  .no-content-padding {
    margin: 0 -5px !important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .no-content-padding {
    margin: 0 -5px !important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .no-content-padding {
    margin: 0 -5px !important;
  }
}
.clearfix,
.inner-space:after {
  zoom: 1;
}
.clearfix:after,
.inner-space:after {
  clear: both;
}
.clearfix:after,
.inner-space:after,
.clearfix:before,
.inner-space:before {
  display: block;
  visibility: hidden;
  overflow: hidden;
  content: "\0020";
  height: 0;
  font-size: 0;
  line-height: 0;
}
.display-inline {
  display: inline-block !important;
}
.display-normal {
  display: inline!important;
}
.hover-transparent {
  opacity: .5;
}
.hover-transparent:hover {
  opacity: 1;
}
.row-seperator-header {
  margin: 15px 14px 20px;
  border-bottom: 0;
  display: block;
  color: #646464;
  font-size: 20px;
  font-weight: 400;
}
.text-align-center,
.text-center {
  text-align: center!important;
}
.text-align-left,
.text-left {
  text-align: left!important;
}
.text-align-right,
.text-right {
  text-align: right!important;
}
.center-canvas,
.center-child-canvas > canvas {
  display: block!important;
  margin: 0 auto!important;
}
.semi-bold {
  font-weight: 400!important;
}
.ultra-light {
  font-weight: 300!important;
}
.font-xs {
  font-size: 85%!important;
}
.font-sm {
  font-size: 95%!important;
}
.font-md {
  font-size: 130%!important;
}
.font-lg {
  font-size: 160%!important;
}
.font-xl {
  font-size: 200%!important;
}
.font-400 {
  font-size: 400%!important;
}
.badge {
  font-size: 11px;
  padding: 4px 6px 1px;
}
.label {
  padding: 0.3em .6em .1em;
}
.cursor-pointer {
  cursor: pointer;
}
.selected {
  border: 1px solid #0091d9!important;
}
.selected:before {
  display: block;
  position: absolute;
  content: "\f00c";
  color: #fff;
  right: 4px;
  font-family: FontAwesome;
  z-index: 1002;
}
.selected:after {
  width: 0;
  height: 0;
  border-top: 35px solid #0091d9;
  border-left: 35px solid rgba(0, 0, 0, 0);
  position: absolute;
  display: block;
  right: 0;
  content: ".";
  top: 0;
  z-index: 1001;
}
/*
 * Components layout
 */
html {
  margin: 0;
  padding: 0;
  height: 100%;
  overflow-x: hidden!important;
  background-color: #e5e2cf;
}
body {
  margin: 0;
  padding: 0;
  height: 100%;
  overflow: hidden;
  background-color: #e5e2cf;
  direction: ltr;
}
body.container {
  position: relative;
  padding: 0;
  border-left: 1px solid #bfbfbf;
  border-right: 1px solid #bfbfbf;
  -webkit-box-shadow: 0 2px 70px rgba(0, 0, 0, 0.45);
  box-shadow: 0 2px 70px rgba(0, 0, 0, 0.45);
}
body.nooverflow {
  position: fixed;
  overflow: hidden;
  width: 100%;
}
#main {
  display: block;
  margin-left: 220px;
  padding: 0;
  min-height: 500px;
  -webkit-transition: all 0.1s ease-out;
  transition: all 0.1s ease-out;
}
@media (max-width: 979px) {
  #main {
    margin-left: 0;
  }
}
#content {
  padding: 10px;
  position: relative;
  left: 0;
  -webkit-transition: left 0.1s ease-out;
  transition: left 0.1s ease-out;
}
@media (max-width: 767px) {
  #content {
    padding-left: 5px;
    padding-right: 5px;
  }
}
.page-title {
  margin: 12px 0 15px;
}
.page-title span {
  font-size: 16px;
  color: #333;
  display: inline-block;
  vertical-align: 1px;
}
.page-title span i {
  padding: 0 5px;
}
aside {
  display: block;
  width: 220px;
  overflow: hidden;
  min-height: 100%;
}
aside,
aside nav li.divider {
  background: #829db0;
  /*background: -webkit-gradient(linear, left top, right top, color-stop(93%, #829db0), color-stop(100%, #6f8696));
		background: -webkit-linear-gradient(left, #829db0 93%, #6f8696 100%);
		background: -webkit-gradient(linear, top left, top right, from(#829db0), to(#6f8696));
		background: -webkit-linear-gradient(left, #829db0 93%, #6f8696 100%);
		background: linear-gradient(to right, #829db0 93%, #6f8696 100%);*/
}
#header {
  display: block;
  height: 49px;
  position: relative;
  margin: 0;
  padding: 0 13px 0 0;
  background-color: #f3f3f3;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f3f3f3), to(#e2e2e2));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#f3f3f3), to(#e2e2e2));
  background-image: -webkit-linear-gradient(top, #f3f3f3, #e2e2e2);
  background-image: linear-gradient(to bottom, #f3f3f3, #e2e2e2);
  background-repeat: repeat-x;
}
@media (max-width: 767px) {
  #header {
    padding-right: 5px;
  }
}
@media only screen and (max-width: 679px) {
  #header {
    padding-right: 5px;
    background: #fff;
  }
}
#header > :first-child {
  width: 220px;
}
#header > div {
  display: inline-block;
  vertical-align: middle;
  height: 49px;
  float: left;
}
#header > div.open {
  font-weight: 700;
}
.fixed-header #header {
  position: fixed;
  width: 100%;
  z-index: 1001;
}
.container.fixed-header #header {
  max-width: 1164px;
}
.fixed-header #header .ajax-dropdown {
  z-index: 1000;
}
.fixed-header #shortcut {
  position: fixed;
}
.fixed-header #main {
  margin-top: 49px;
}
#top-links > div {
  display: inline-block;
}
@media (min-width: 768px) and (max-width: 1089px) {
  #top-links > div {
    display: none;
  }
  #top-links > div:first-child {
    display: inline-block;
  }
}
@media (max-width: 767px) {
  #top-links > div {
    display: none;
  }
}
.top-menu {
  display: inline-block;
  padding: 7px 13px 0;
  position: relative;
}
@media (max-width: 767px) {
  .top-menu {
    display: none;
  }
}
.top-menu > span {
  display: block;
}
.top-menu > :first-child {
  display: block;
  color: #bfbfbf;
  font-size: 10px;
  font-weight: 700;
  text-transform: uppercase;
  text-shadow: 0 0 1px #fff;
  padding-left: 0;
  text-align: left;
}
.top-selector {
  max-width: 97%;
  white-space: nowrap;
  background: 0 0;
  border: 0;
  padding: 0;
  text-align: left;
  color: #555;
  font-size: 14px;
  cursor: pointer;
}
.top-selector:hover {
  color: #333;
}
@media (max-width: 979px) {
  #login-info {
    display: none;
  }
}
#login-info > span {
  display: inline-block;
  height: 39px;
  float: left;
}
#login-info > span .badge {
  position: absolute;
  top: -5px;
  right: -9px;
  cursor: pointer;
  background: #0091d9;
  display: inline-block;
  font-size: 10px;
  -webkit-box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  color: #fff;
  font-weight: 700;
  border-radius: 50%;
  padding: 3px;
  text-align: center;
  line-height: normal;
}
#login-info span#activity {
  border-radius: 2px;
  cursor: default!important;
  display: inline-block;
  font-weight: 700;
  height: 24px;
  width: 24px;
  padding: 2px;
  text-align: center;
  text-decoration: none!important;
  -moz-user-select: none;
  -webkit-user-select: none;
  background-color: #f8f8f8;
  background-image: -webkit-gradient(linear, left top, left bottom, from(#f8f8f8), to(#f1f1f1));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#f8f8f8), to(#f1f1f1));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
  border: 1px solid #bfbfbf;
  color: #c4bab6;
  font-size: 19px;
  margin: 5px 0 0;
  position: relative;
}
#login-info span#activity:hover {
  border: 1px solid #bfbfbf;
  -webkit-transition: all 0s;
  transition: all 0s;
  cursor: pointer!important;
  -webkit-box-shadow: inset 0 0 4px 1px rgba(0, 0, 0, 0.08);
  box-shadow: inset 0 0 4px 1px rgba(0, 0, 0, 0.08);
}
#logo {
  display: inline-block;
  width: 175px;
  margin-top: 7px;
  margin-left: 9px;
}
@media (min-width: 768px) and (max-width: 880px) {
  #logo {
    margin-top: 10px;
  }
}
@media (max-width: 767px) {
  #logo {
    margin-top: 10px;
    margin-left: 4px;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #logo {
    margin-top: 10px;
    margin-left: 4px;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  #logo {
    width: 135px;
    margin-top: 10px;
    margin-left: 4px;
  }
}
#logo img {
  max-width: 175px;
  max-height: 36px;
  padding-left: 3px;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  #logo-group {
    width: 169px!important;
  }
}
#activity.active .badge {
  background: #006fa6!important;
}
.header-search {
  position: relative;
}
@media (max-width: 767px) {
  .header-search {
    display: none;
  }
}
.header-search.pull-right {
  margin-left: 6px;
}
@media (max-width: 979px) {
  .header-search.pull-right {
    margin-left: 0;
  }
}
.header-search > input[type=text] {
  display: block;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  min-width: 200px;
  width: 100%;
  height: 30px;
  padding: 0 10px;
  outline: 0;
  border-width: 1px;
  border-style: solid;
  border-radius: 0;
  border-color: #bfbfbf;
  background: #fff;
  color: #404040;
  appearance: normal;
  -moz-appearance: none;
  -webkit-appearance: none;
  margin-top: 10px;
  line-height: normal;
}
@media (min-width: 768px) and (max-width: 979px) {
  .header-search > input[type=text] {
    margin-top: 9px;
  }
}
.header-search > button {
  background: 0 0;
  border: 0;
  color: #6D6A69;
  font-size: 17px;
  height: 30px;
  line-height: 30px;
  margin: 0;
  padding: 0;
  position: absolute;
  right: 0;
  top: 10px;
  width: 30px;
  z-index: 2;
}
#search-mobile {
  display: none;
}
@media (max-width: 767px) {
  #search-mobile {
    display: block;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #search-mobile {
    display: block;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  #search-mobile {
    margin-left: 0;
  }
}
@media (max-width: 767px) {
  .search-mobile .header-search {
    display: block;
    position: absolute;
    top: 0;
    width: 100%;
    height: 49px;
    background: #333;
    padding: 0 2px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    left: 0;
  }
  .search-mobile .header-search > input[type=text] {
    margin-top: 2px;
    height: 45px;
    border-color: #333;
    padding-right: 75px;
  }
  .search-mobile .header-search > button {
    height: 29px;
    line-height: 29px;
    background: #DDD;
    right: 44px;
  }
  .search-mobile #search-mobile {
    display: none;
  }
  .search-mobile #cancel-search-js {
    display: block;
  }
}
#cancel-search-js {
  position: absolute;
  display: none;
  background: #a90329;
  z-index: 3;
  color: #fff;
  padding: 0;
  right: 10px;
  top: 10px;
  text-align: center;
  height: 29px;
  line-height: 29px;
  width: 30px;
  font-size: 17px;
  text-decoration: none!important;
}
#left-panel {
  position: absolute;
  top: 49px;
  left: 0;
  z-index: 1002;
  -webkit-transition: left 0.1s ease-out;
  transition: left 0.1s ease-out;
}
@media (max-width: 979px) {
  #left-panel {
    left: -220px;
  }
}
.fixed-navigation #left-panel {
  position: fixed;
  z-index: 998;
}
@media (max-width: 767px) {
  .fixed-navigation #left-panel {
    position: absolute!important;
  }
}
#left-panel .version {
  position: absolute;
  bottom: 2px;
  width: 100%;
  text-align: center;
  font-size: 11px;
  color: #333;
}
#ribbon {
  height: 40px;
  background: #6f8696;
  padding: 0 40px 0 13px;
  position: relative;
}
@media (max-width: 767px) {
  #ribbon {
    padding-left: 5px;
    padding-right: 5px;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #ribbon {
    border-bottom: 1px solid #CFCFCF;
    border-top: 1px solid #E6E6E6;
    background: #F5F5F5;
  }
}
#ribbon .breadcrumb {
  display: inline-block;
  margin: 0;
  padding: 12px 34px 10px 0!important;
  background: 0 0;
  vertical-align: top;
}
#ribbon .breadcrumb,
#ribbon .breadcrumb a {
  color: #ddd!important;
  text-decoration: none!Important;
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #ribbon .breadcrumb,
  #ribbon .breadcrumb a {
    color: #6D6C6C!important;
  }
}
#ribbon .breadcrumb > li + li:before {
  padding: 0 1px 0 5px;
}
#ribbon .breadcrumb li:last-child,
#ribbon .breadcrumb > .active {
  color: #eee;
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #ribbon .breadcrumb li:last-child,
  #ribbon .breadcrumb > .active {
    color: #333!important;
  }
}
.fixed-ribbon #ribbon {
  position: fixed;
  right: 0;
  left: 220px;
  top: 49px;
  z-index: 999;
}
@media (max-width: 979px) {
  .fixed-ribbon #ribbon {
    left: 0;
  }
}
.container.fixed-ribbon #ribbon {
  width: 944px;
  left: 590px;
}
.fixed-ribbon #content {
  padding-top: 50px;
}
@media (max-width: 767px) {
  .fixed-ribbon #content {
    padding-top: 52px;
  }
}
.minified.fixed-ribbon #ribbon {
  left: 45px;
}
.hidden-menu.fixed-ribbon #ribbon {
  left: 10px;
}
@media (max-width: 979px) {
  .hidden-menu.fixed-ribbon #ribbon {
    left: 220px;
  }
}
.hidden-ribbon #ribbon {
  height: 1px;
  min-height: 1px;
  max-height: 1px;
}
.hidden-ribbon #ribbon > * {
  display: none;
}
.ribbon {
  position: absolute;
  right: 9px;
  top: -4px;
}
.header-dropdown-list {
  list-style: none;
  float: right;
  position: relative;
  margin: 0;
  padding-left: 10px;
}
.header-dropdown-list > li {
  display: inline-block;
  padding-right: 5px;
}
.header-dropdown-list > li > .dropdown-toggle {
  margin-top: 16px;
  display: block;
}
.smart-accordion-default.panel-group .panel + .panel {
  margin-top: -1px;
}
.smart-accordion-default.panel-group .panel-heading {
  padding: 0;
}
.smart-accordion-default.panel-group .panel-title a {
  display: block;
  padding: 10px 15px;
  text-decoration: none!important;
}
.smart-accordion-default .panel-group .panel,
.smart-accordion-default .panel-heading {
  border-radius: 0;
}
.smart-accordion-default .panel-default {
  border-color: #c3c3c3;
}
.smart-accordion-default .panel-default > .panel-heading {
  background-color: #fcfcfc;
}
.smart-accordion-default .panel-title > a.collapsed > .fa,
.smart-accordion-default .panel-title > a > :first-child {
  display: none;
}
.smart-accordion-default .panel-title > a.collapsed > :first-child {
  display: inline-block;
}
.no-padding .smart-accordion-default > div {
  border-left: 0!important;
  border-right: 0!important;
}
.no-padding .smart-accordion-default > div:first-child {
  border-top: 0!important;
}
.no-padding .smart-accordion-default > div:last-child {
  border-bottom: 0!important;
}
#logo-group *,
.login-info,
.login-info *,
.minified .menu-item-parent {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.login-info {
  display: block;
  font-size: 12px;
  height: 39px;
  color: #333;
  border: solid transparent;
  margin: 2px 0 0 10px !important;
  float: right;
}
.login-info a,
.login-info strong {
  text-transform: capitalize;
  font-size: 14px;
  display: inline-block;
  color: #333;
  text-decoration: none;
  margin-left: 5px;
}
.login-info a:hover,
.login-info strong {
  color: #666;
}
.login-info span {
  /*height: 38px;*/
  display: inline-block;
  padding: 0 10px;
  /*border-bottom: 1px solid #1A1817;*/
}
.login-info img {
  width: 25px;
  height: auto;
  display: inline-block;
  vertical-align: middle;
  margin-top: -3px;
  margin-right: 7px;
  margin-left: 0;
  border-left: 3px solid #fff;
}
.minifyme {
  border-bottom: 1px solid #302F2F;
  background: #454545;
  color: #A8A8A8;
  text-align: center;
  padding: 1px 0 0;
  width: 36px;
  height: 28px;
  display: block;
  position: absolute;
  right: -3px;
  border-radius: 5px 0 0 5px;
  cursor: pointer;
  margin-top: 5px;
  font-size: 19px;
  -webkit-transition: all .1s linear 0s;
  transition: all .1s linear 0s;
}
.minifyme:hover {
  background: #646464;
  color: #E4E4E4;
  right: 0;
}
.minified .minifyme {
  right: 0;
  color: #A8A8A8;
  position: relative;
  width: 100%;
  border-radius: 0;
  margin: 0;
  height: 32px;
  font-size: 23px;
}
.minified .minifyme .fa:before {
  content: "\f0a9";
}
.minified #left-panel {
  width: 45px;
  overflow: visible;
}
@media (max-width: 979px) {
  .minified #left-panel {
    left: 0;
  }
}
.minified #main {
  margin-left: 45px;
}
.minified #left-panel > ul > li,
.minified nav > ul > li {
  overflow: visible;
  /*border-bottom: 1px solid #1A1817;
			border-top: 1px solid #525151;*/
}
.minified #left-panel > ul > li > ul::before,
.minified nav > ul > li > ul::before {
  border-left: 0;
}
.minified #left-panel > ul > li,
.minified nav > ul > li,
.minified #left-panel > ul > li a,
.minified nav > ul > li a {
  position: relative;
}
.minified #left-panel ul > li > a,
.minified nav ul > li > a {
  padding: 12px 11px 10px;
  display: block;
}
.minified #left-panel > ul > li > a .fa.fa-fw,
.minified nav > ul > li > a .fa.fa-fw {
  display: block;
  width: auto;
  text-align: center;
  padding: 0;
}
.minified #left-panel > ul > li > a > i,
.minified nav > ul > li > a > i {
  text-align: center;
  margin: 0;
  display: block;
}
.minified #left-panel > ul > li.active > a::before,
.minified nav > ul > li.active > a::before {
  content: "\f0d9";
}
.minified #left-panel ul ul li a,
.minified nav ul ul li a {
  padding-top: 5px;
  padding-bottom: 5px;
  padding-left: 14px;
}
.minified #left-panel ul ul li li a,
.minified nav ul ul li li a {
  padding-left: 25px;
}
.minified #left-panel > ul ul li::before,
.minified nav > ul ul li::before,
.minified #left-panel > ul > li > ul::before,
.minified nav > ul > li > ul::before {
  left: 12px;
}
.minified #left-panel > ul > li > a .menu-item-parent,
.minified nav > ul > li > a .menu-item-parent,
.minified #left-panel > ul > li > a > b,
.minified nav > ul > li > a > b {
  display: none;
}
.minified #left-panel > ul > li > a > .menu-item-parent,
.minified nav > ul > li > a > .menu-item-parent {
  display: none;
  position: absolute;
  left: 40px;
  top: -3px;
  width: 186px;
  height: 36px;
  line-height: 38px;
  background-color: #f5f5f5;
  color: #333;
  z-index: 3;
  -webkit-box-shadow: 2px 1px 2px 0 rgba(0, 0, 0, 0.2);
  box-shadow: 2px 1px 2px 0 rgba(0, 0, 0, 0.2);
  border-left: 1px solid #bfbfbf;
  border-top: 1px solid #D8D4D4;
  border-bottom: 1px solid #fff;
  padding-left: 12px;
}
.minified #left-panel > ul > li > ul,
.minified nav > ul > li > ul {
  display: none!important;
  position: absolute;
  left: 40px;
  width: 200px;
  z-index: 5;
  border: 1px solid #bfbfbf;
  min-height: 180px;
  -webkit-box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, 0.2);
  box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, 0.2);
  background: #627685;
  margin-top: -3px;
}
.minified #left-panel ul > li > ul > li > ul,
.minified nav ul > li > ul > li > ul {
  position: relative;
  left: 13px;
  border: 0;
  margin-left: -12px;
  width: 197px;
}
.minified #left-panel > ul > li:hover > a > .menu-item-parent,
.minified nav > ul > li:hover > a > .menu-item-parent,
.minified #left-panel > ul > li:hover > ul,
.minified nav > ul > li:hover > ul {
  display: block!important;
}
.minified #left-panel > ul > li > ul > li,
.minified nav > ul > li > ul > li {
  background-color: rgba(91, 103, 113, 0.8);
  /*background-color: rgba(69, 69, 69, .9);*/
}
.minified #left-panel > ul > li > ul > li > ul > li,
.minified nav > ul > li > ul > li > ul > li {
  background-color: #627685;
}
.minified #left-panel > ul > li > ul > li > a,
.minified nav > ul > li > ul > li > a,
.minified #left-panel > ul > li > ul > li > ul > li > a,
.minified nav > ul > li > ul > li > ul > li > a {
  padding-top: 7px;
  padding-bottom: 7px;
}
.minified #left-panel > ul > li > ul > li > ul > li a,
.minified nav > ul > li > ul > li > ul > li a {
  padding-top: 6px;
  padding-bottom: 6px;
}
.minified #left-panel > ul > ul,
.minified nav > ul > ul {
  min-height: 100px!important;
  max-height: 180px!important;
  overflow-y: scroll;
  overflow-x: hidden;
  background: #ed1c24!important;
}
.minified #left-panel > ul ul li::before,
.minified nav > ul ul li::before {
  border: 0;
}
.minified #left-panel ul ul ul ul li a,
.minified nav ul ul ul ul li a {
  padding-left: 45px;
}
.minified #left-panel ul ul ul ul ul li a,
.minified nav ul ul ul ul ul li a {
  padding-left: 62px;
}
.minified #left-panel ul ul ul ul ul ul li a,
.minified nav ul ul ul ul ul ul li a {
  padding-left: 82px;
}
.minified #left-panel .version {
  display: none;
}
.minified .slimScrollDiv,
.minified .slimScrollDiv > :first-child {
  overflow: visible!important;
}
.minified .slimScrollBar,
.minified .slimScrollRail {
  display: none;
}
.slimScrollDiv,
.slimScrollDiv > :first-child {
  overflow: hidden;
}
@media (max-width: 979px) {
  #hide-menu i,
  #logout i {
    color: #6D6A69;
    font-size: 100%;
  }
}
@media (min-width: 0) and (max-width: 880px) {
  #hide-menu i,
  #logout i {
    font-size: 121%;
  }
}
.hidden-menu #left-panel {
  left: -210px;
  z-index: 1002;
}
@media (max-width: 979px) {
  .hidden-menu #left-panel {
    left: 0;
  }
}
.hidden-menu #left-panel:hover {
  left: 0;
}
.hidden-menu #main {
  margin-left: 10px;
}
.minified.hidden-menu #main {
  margin-left: 0;
}
@media (max-width: 979px) {
  .hidden-menu #main {
    position: relative;
    left: 210px;
  }
}
@media (max-width: 979px) {
  .hidden-menu #hide-menu i {
    color: #fff;
  }
}
@media (min-width: 768px) and (max-width: 880px) {
  .hidden-menu #hide-menu i::before {
    content: "\f0c9";
  }
}
@media (max-width: 767px) {
  .hidden-menu #hide-menu i {
    color: #fff;
  }
  .hidden-menu #hide-menu i::before {
    content: "\f0c9";
  }
}
.hidden-menu #hide-menu > :first-child > a {
  background-color: #e8e8e8;
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0, #686868 100%);
  background-image: -webkit-gradient(linear, top left, bottom left, from(#5a5a5a), to(#686868));
  background-image: -webkit-linear-gradient(top, #5a5a5a 0, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  color: #fff;
  border-color: #494949;
  -webkit-box-shadow: inset 0 0 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 0 3px 1px rgba(0, 0, 0, 0.15);
}
@media (min-width: 768px) and (max-width: 979px) {
  .hidden-menu #hide-menu > :first-child > a {
    margin-top: 9px;
    width: 40px;
  }
}
.hidden-menu #hide-menu > :first-child > a:active {
  -webkit-box-shadow: inset 0 0 6px 1px rgba(0, 0, 0, 0.2);
  box-shadow: inset 0 0 6px 1px rgba(0, 0, 0, 0.2);
}
.hidden-menu .minifyme,
.minified #hide-menu {
  display: none;
}
.no-menu #left-panel {
  left: -220px;
  z-index: 0;
}
.no-menu #main {
  margin-left: 0;
}
.no-menu #hide-menu {
  display: none;
}
#shortcut {
  position: absolute;
  top: 0;
  left: 0;
  height: auto;
  width: 100%;
  background-color: #33302F;
  background-color: rgba(0, 0, 0, 0.85);
  z-index: 1009;
  display: none;
  color: #fff;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
#shortcut ul {
  padding: 15px 20px 10px;
  list-style: none;
  margin: 0;
  -webkit-box-shadow: 0 4px 10px rgba(0, 0, 0, 0.3);
  box-shadow: 0 4px 10px rgba(0, 0, 0, 0.3);
  border-bottom: 1px solid #423F3F;
}
#shortcut ul li {
  display: inline-block;
  width: auto;
}
#shortcut ul li .ams-metro-tile {
  margin: 0 3px 3px;
  border: 0;
  border-radius: 0;
}
#shortcut ul li .ams-metro-tile:hover {
  color: #fff;
  text-decoration: none;
}
#shortcut ul li .ams-metro-tile:active,
#shortcut ul li .ams-metro-tile:focus {
  left: 0;
  top: 0;
}
.shortcut-on #response-btn {
  display: none!important;
}
.shortcut-on #left-bar .navbar,
.shortcut-on #main .navbar {
  border: 0!important;
}
#sparks {
  display: block;
  list-style: none;
  margin: 10px 0 0;
  padding: 0;
  text-align: right;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  #sparks {
    text-align: center;
    background: #E0E0E0;
    padding: 10px 0;
    margin-bottom: 15px;
  }
}
#sparks li {
  display: inline-block;
  border-left: 1px dotted #c7c7c7;
  padding: 0 10px;
  max-height: 47px;
  overflow: hidden;
  text-align: left;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  #sparks li {
    padding: 0 10px 0 20px;
  }
}
#sparks li:last-child {
  padding-right: 0;
}
#sparks li:first-child {
  border-left: 0;
  padding-left: 0;
}
#sparks li h5 {
  color: #555;
  float: left;
  font-size: 11px;
  font-weight: 400;
  margin: -3px 0 0 0;
  padding: 0;
  border: 0;
  text-transform: uppercase;
}
#sparks li span {
  color: #636363;
  display: block;
}
.sparks-info {
  min-width: 70px;
}
.sparks-info span {
  font-size: 18px;
  line-height: 20px;
  margin: 0;
  text-transform: none;
}
.sparks-info .sparkline {
  display: block;
  float: right;
  margin: 3px 0 0 20px;
}
#heat-fill {
  display: block;
  position: relative;
  margin-bottom: 20px;
  background: #333;
  height: 7px;
  width: 200px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMgAAAABCAIAAAAU3Xa1AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDowMDE4MkZGMzMzOTgxMUUzODZBQUNFQUNFOTk0NEUxRiIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDowMDE4MkZGNDMzOTgxMUUzODZBQUNFQUNFOTk0NEUxRiI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjAwMTgyRkYxMzM5ODExRTM4NkFBQ0VBQ0U5OTQ0RTFGIiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjAwMTgyRkYyMzM5ODExRTM4NkFBQ0VBQ0U5OTQ0RTFGIi8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+rG8MDAAAAM5JREFUeNpUUtESwyAIg8ft9v8/W4ElBPWKV1AIiKEeEWVuVlWjINSVONBnirQDxukNgcuyTQsBzLHMDsLIQQw+nIL71JqNJ5GZJXApFNpmtlagQjfS2xGbkFA4Iwu+hu0sK3Wl3nOwNv7TvPrWk3X0eW9dK1pU9hK2eTuWb2ySJmlziutA3iBxmblPNvA5PNsuUpoDY80+Z0SW1IRpDEqwC58C14tsr1f8le8si0aojdADr/1UjaclsFashX8GGkL9wDxtRsV6ft/PX4ABADRzhOVIOJaAAAAAAElFTkSuQmCC);
}
.fill-a,
.fill-b {
  width: 20px;
  text-align: right;
  overflow: hidden;
  text-overflow: ellipsis;
  display: block;
  background: #fff;
  padding-right: 4px;
  position: absolute;
  left: 0;
  margin-top: -7px;
  font-weight: 700;
}
.fill-b {
  text-align: left;
  position: absolute;
  right: 0;
  left: auto;
  top: 0;
  width: 60px;
  padding-left: 4px;
  padding-right: 0;
}
.cke_top {
  background: rgba(248, 248, 248, 0.9) !important;
  background-image: none!important;
}
/**
 * Messages boxes
 */
.MessageBox {
  width: 100%;
  height: 100%;
  position: fixed;
  top: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.6);
  z-index: 100000;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBox {
    width: 100%;
    height: 100%;
    position: fixed;
    top: 0;
    left: 0;
    background: rgba(0, 0, 0, 0.6);
    z-index: 100000;
  }
}
.MessageBoxContainer {
  top: 35%;
  color: #fff;
  position: relative;
  width: 100%;
  background-color: #232323;
  background-color: rgba(0, 0, 0, 0.8);
  padding: 20px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxContainer {
    top: 25%;
    color: #fff;
    position: relative;
    width: 100%;
    background-color: #232323;
  }
}
.MessageBoxContainer input,
.MessageBoxContainer select {
  width: 50%;
  padding: 5px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxContainer input,
  .MessageBoxContainer select {
    width: 50%;
    padding: 5px;
  }
}
.MessageBoxMiddle {
  position: relative;
  left: 20%;
  width: 60%;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxMiddle {
    position: relative;
    left: 0;
    width: 100%;
    padding: 3px;
  }
}
.MessageBoxMiddle .MsgTitle {
  letter-spacing: -1px;
  font-size: 24px;
  font-weight: 300;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxMiddle .MsgTitle {
    font-size: 22px;
  }
}
.MessageBoxMiddle .pText {
  font-style: 30px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxMiddle {
    font-style: 10px;
  }
}
.MessageBoxButtonSection {
  width: 100%;
  height: 30px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxButtonSection {
    width: 100%;
    height: 30px;
  }
}
.MessageBoxButtonSection button {
  float: right;
  margin-right: 7px;
  padding-left: 15px;
  padding-right: 15px;
  font-size: 14px;
  font-weight: 700;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .MessageBoxButtonSection button {
    float: right;
    margin-right: 5px;
    padding-left: 15px;
    padding-right: 15px;
  }
}
.LoadingBoxContainer {
  top: 20%;
  color: #fff;
  position: relative;
  width: 100%;
  background-color: #232323;
}
.LoadingBoxContainer .MsgTitle {
  font-size: 26px;
}
.LoadingBoxContainer .pText {
  font-style: 30px;
}
.LoadingBoxMiddle {
  position: relative;
  left: 20%;
  width: 50%;
  padding: 10px;
}
#LoadingPoints {
  position: absolute;
}
#divMiniIcons {
  position: fixed;
  width: 415px;
  right: 10px;
  bottom: 180px;
  z-index: 9999;
  float: right;
}
#divMiniIcons .cajita {
  text-align: center;
  vertical-align: middle;
  padding: 4px 6px;
  color: #FFF;
  float: right;
  cursor: pointer;
  display: block;
  background-color: red;
  font-size: 17px;
  margin-left: 4px;
  margin-top: 5px;
}
#divMiniIcons .cajita:active {
  top: 1px;
  left: 1px;
  position: relative;
}
#divSmallBoxes {
  position: fixed;
  right: 0;
  top: 0;
  z-index: 9999;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  #divSmallBoxes {
    position: fixed;
    width: 90%;
    right: 0;
    top: 0;
  }
}
.BigBox {
  position: fixed;
  right: 10px;
  bottom: 10px;
  background-color: #004d60;
  padding: 10px 10px 5px;
  width: 390px;
  height: 150px;
  color: #fff;
  z-index: 99999;
  box-sizing: content-box;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  border-left: 5px solid rgba(0, 0, 0, 0.15);
  overflow: hidden;
}
.BigBox span {
  font-size: 17px;
  font-weight: 300;
  letter-spacing: -1px;
  padding: 5px 0!important;
  display: block;
}
.BigBox p {
  font-size: 13px;
  margin-top: 10px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .BigBox {
    width: 88%;
  }
}
.BigBox .bigboxicon {
  font-size: 30px;
  text-align: left;
  position: absolute;
  top: 120px;
  left: 6px;
  z-index: 0;
}
.BigBox .bigboxnumber {
  width: 100%;
  text-align: right;
  font-size: 25px;
}
.SmallBox {
  position: absolute;
  right: 5px;
  top: 20px;
  width: 420px;
  color: #fff;
  z-index: 9999;
  overflow: hidden;
  border: 1px solid transparent;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .SmallBox {
    width: 95%;
  }
}
.SmallBox:hover {
  border: 1px solid #fff;
  cursor: pointer;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .SmallBox:hover {
    -webkit-box-shadow: 0 0 10px #888;
    box-shadow: 0 0 10px #888;
    cursor: pointer;
  }
}
.SmallBox .foto {
  font-size: 50px;
  position: absolute;
  left: 17px;
}
.SmallBox .textoFull {
  width: 93%;
  float: left;
  padding-left: 20px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .SmallBox .textoFull {
    width: 93%;
    float: left;
    padding-left: 20px;
  }
}
.SmallBox .textoFoto {
  width: 78%;
  margin: 3px 20px 3px 80px;
  float: left;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .SmallBox .textoFoto {
    width: 55%;
    margin: 3px 20px 3px 80px;
    float: left;
  }
}
.SmallBox span {
  font-size: 17px;
  font-weight: 300;
  letter-spacing: -1px;
  display: block;
  margin: 4px 0;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .SmallBox span {
    font-size: 16px;
  }
}
.SmallBox p {
  font-size: 13px;
  margin-top: 2px;
}
@media screen and (max-width: 450px) and (max-width: 767px) {
  .SmallBox p {
    font-size: 12px;
    margin-top: 2px;
  }
}
.btnClose {
  position: absolute;
  right: 10px;
  height: 16px;
  width: 15px;
  cursor: pointer;
  font-size: 18px;
  opacity: .5;
  display: block;
  top: 15px;
}
.btnClose:hover {
  opacity: 1;
}
.miniPic {
  position: absolute;
  bottom: 8px;
  right: 9px;
}
.miniIcon {
  height: 100%;
  font-size: 20px;
}
/*
 * Menus styles
 */
nav {
  padding-top: 40px;
}
nav ul {
  width: 100%;
  padding: 40px 28px 25px 0;
  padding: 0;
  margin: 0;
  font-size: 13px;
  line-height: .5em;
  list-style: none;
  position: relative;
  background-color: #627685;
}
nav ul li {
  overflow: hidden;
}
nav ul li.divider {
  height: 20px;
  border: 0;
}
nav ul li.header {
  font-family: "Ubuntu-Light", Arial, Helvetica, sans-serif;
  font-size: 14px;
  font-weight: bold;
  color: #eee;
  background-color: #b13510;
  border-top-color: #d44918;
  border-bottom-color: #a13812;
  padding: 4px 10px 4px 20px;
  line-height: 18px;
}
.minified #left-panel nav ul li.header {
  padding: 5px;
  color: #b94015;
  line-height: 0;
  max-height: 10px;
  overflow: hidden;
}
nav ul li a {
  line-height: normal;
  font-size: 14px;
  padding: 10px 10px 10px 11px;
  color: #f4e8cf;
  display: block;
  font-weight: 400;
  text-decoration: none!important;
  position: relative;
}
nav ul li a:active {
  background: #616161!important;
}
nav ul li a:focus {
  color: #c9c9c9;
}
nav ul li a:hover {
  color: #fff;
  text-decoration: none;
}
nav ul li.active > a {
  background-color: #627685;
  color: #fff!important;
  position: relative;
}
nav ul li.active > a:before {
  content: "\f0d9";
  font-family: FontAwesome;
  display: block;
  height: 27px;
  line-height: 14px;
  width: 27px;
  position: absolute;
  right: -21px;
  font-size: 20px;
  color: #eee;
}
nav ul li.active.open > a:before {
  content: "";
}
nav ul li.active.open > a.active:before {
  content: "\f0d9";
}
nav ul li li {
  border-bottom: 0;
  position: relative;
}
nav ul .active > a {
  color: #fefefe!important;
  position: relative;
}
nav ul b {
  float: right;
  font-size: 14px;
  margin-top: -1px;
}
nav ul span.menu-item-parent {
  display: inline-block;
  margin: 0;
  padding: 0;
}
nav ul ul {
  margin: 0;
  display: none;
  background: rgba(91, 103, 113, 0.8);
  padding: 7px 0;
}
nav ul ul > li:hover b {
  color: #D5D9E2;
}
nav ul ul li {
  margin: 0;
  padding: 0;
}
nav ul ul li > a {
  padding-left: 42px;
  font-size: 12px;
  font-weight: 400;
  outline: 0;
}
nav ul ul li > a:hover {
  background-color: #46545e;
  color: #fff;
}
nav ul ul li > a.active {
  margin-left: 30px;
  padding-left: 12px;
  background-color: #296191;
}
nav ul ul ul {
  background: 0 0;
  padding: 0;
}
nav ul ul ul li a {
  color: #bfbfbf;
  padding: 8px 10px 8px 60px;
  font-size: 11px;
}
nav ul ul ul li a:hover {
  background-color: #46545e;
  color: #fff;
}
nav ul ul ul li a.active {
  margin-left: 50px;
  padding-left: 10px;
}
nav ul ul ul ul li a {
  padding-left: 90px;
}
nav ul ul ul ul li a.active {
  margin-left: 80px;
  padding-left: 10px;
}
nav ul ul ul ul ul li a {
  padding-left: 110px;
}
nav ul ul ul ul ul li a.active {
  margin-left: 100px;
  padding-left: 10px;
}
nav ul ul ul ul ul ul li a {
  padding-left: 130px;
}
nav ul ul ul ul ul ul li a.active {
  margin-left: 120px;
  padding-left: 10px;
}
nav ul ul b {
  color: #B3B3B3;
}
nav > ul > li {
  border-top: 1px solid #718999;
  border-bottom: 1px solid #576975;
}
nav > ul > li:hover > ul::before,
nav > ul > li:hover > ul > li::before {
  border-color: #ACACAC!important;
}
nav > ul > li > a > .badge.pull-right {
  margin-right: 15px;
}
nav > ul > li > a b {
  position: absolute!important;
  right: 10px;
  top: 10px;
}
nav > ul > li > a > i {
  margin-right: 5px;
  width: 15px;
  display: inline-block;
  text-align: center;
  position: relative;
}
nav > ul > li > a > i > em {
  font-size: 9px;
  display: block;
  padding: 2px;
  position: absolute;
  top: -8px;
  right: -6px;
  text-decoration: none;
  font-style: normal;
  background: #ED1C24;
  color: #fff;
  min-width: 13px;
  border-radius: 50%;
  max-height: 13px;
  line-height: 8px;
  font-weight: 700;
  vertical-align: baseline;
  white-space: nowrap;
  text-align: center;
  border: 1px solid rgba(255, 255, 255, 0.1);
}
nav > ul > li > ul::before {
  content: "";
  display: block;
  position: absolute;
  z-index: 1;
  left: 23px;
  top: 0;
  bottom: 0;
  border-left: 1px solid #7A7A7A;
}
nav > ul > li > ul > li > a,
nav > ul > li > ul > li > ul > li > a {
  padding-top: 5px;
  padding-bottom: 5px;
}
nav > ul ul li a i {
  font-size: 14px!important;
  width: 18px!important;
  text-align: center!important;
}
nav > ul ul li::before {
  content: "";
  display: block;
  position: absolute;
  width: 8px;
  left: 23px;
  top: 13px;
  border-top: 1px solid #7A7A7A;
  z-index: 1;
}
nav > ul ul ul li::before {
  content: "";
  display: block;
  position: absolute;
  width: 18px;
  left: 10px;
  top: 17px;
  border-top: 1px solid transparent;
}
@media (min-width: 768px) {
  .navbar-nav > li > a {
    padding-top: 17px;
    padding-bottom: 15px;
  }
}
.ui-menu {
  display: block;
  width: 155px;
  padding: 2px;
  -webkit-box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  background: #fff;
  border: 1px solid rgba(0, 0, 0, 0.2);
  z-index: 1;
  list-style: none;
  margin: 0;
  margin-bottom: 2em;
  outline: 0;
}
.ui-menu .ui-menu {
  margin-top: -3px;
  position: absolute;
  list-style: none;
}
.ui-menu .ui-menu-item {
  margin: 0;
  padding: 0;
  width: 100%;
  list-style: none;
  list-style-image: url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);
}
.ui-menu .ui-menu-item a {
  text-decoration: none;
  display: block;
  padding: 2px .4em;
  line-height: 1.5;
  min-height: 0;
  font-weight: 400;
}
.ui-menu .ui-menu-item a.ui-corner-all {
  border-radius: 0;
}
.ui-menu .ui-menu-item a.ui-state-active,
.ui-menu .ui-menu-item a.ui-state-focus,
.ui-menu .ui-menu-item a.ui-widget-content {
  font-weight: 700;
  margin: 0;
  background-color: #428BCA;
  border-color: #357EBD;
  color: #FFF;
  display: block;
  white-space: nowrap;
}
.ui-menu .ui-menu-item a.ui-state-active {
  padding: 1px .4em;
}
.ui-menu .ui-menu-item a .ui-menu-icon {
  width: auto;
  height: auto;
  top: 0;
  left: auto;
  right: auto;
  bottom: auto;
  text-indent: 0;
}
.ui-menu .ui-menu-divider {
  margin: 5px -2px 5px -2px;
  height: 0;
  font-size: 0;
  line-height: 0;
  border-width: 1px 0 0;
}
.ui-menu .ui-state-disabled {
  margin: .4em 0 .2em!important;
  background: none!important;
  color: #999!important;
  font-weight: 400!important;
  cursor: default;
  line-height: 1.5;
}
.ui-menu .ui-state-disabled a {
  cursor: default;
}
.ui-menu .ui-menu-icons {
  position: relative;
}
.ui-menu .ui-menu-icons .ui-menu-item a {
  position: relative;
  padding-left: 2em;
}
.ui-menu .ui-icon {
  position: absolute;
  top: .2em;
  left: .2em;
}
.ui-menu .ui-menu-icon {
  position: static;
  float: right;
}
.open > .dropdown-menu {
  -webkit-animation-name: flipInX;
  animation-name: flipInX;
  -webkit-animation-duration: .4s;
  animation-duration: .4s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
}
.dropdown-menu-xs {
  min-width: 37px;
}
.dropdown-menu-xs > li > a {
  padding: 3px 10px;
}
.dropdown-menu-xs > li > a:hover i {
  color: #fff!important;
}
.dropdown-submenu {
  position: relative;
}
.dropdown-submenu > .dropdown-menu {
  top: 0;
  left: 100%;
  margin-top: -6px;
  margin-left: -1px;
}
.dropdown-submenu:hover > .dropdown-menu {
  display: block;
}
.dropdown-submenu > a:after {
  display: block;
  content: " ";
  float: right;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
  border-width: 5px 0 5px 5px;
  border-left-color: #bfbfbf;
  margin-top: 5px;
  margin-right: -10px;
}
.dropdown-submenu:hover > a:after {
  border-left-color: #fff;
}
.dropdown-submenu.pull-left {
  float: none;
}
.dropdown-submenu.pull-left > .dropdown-menu {
  left: -100%;
  margin-left: 10px;
}
.ajax-dropdown {
  position: absolute;
  display: none;
  z-index: 1003;
  top: 48px;
  left: 16px;
  width: 344px;
  height: 435px;
  border-radius: 0;
  -webkit-box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  padding: 10px;
  background: #fff;
  border: 1px solid #b3b3b3;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .ajax-dropdown {
    width: 299px;
    height: 320px;
    left: 0;
    top: 49px;
  }
}
.ajax-dropdown:after,
.ajax-dropdown:before {
  bottom: 100%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}
.ajax-dropdown:before {
  border-color: rgba(131, 131, 131, 0);
  border-bottom-color: #838383;
  border-width: 8px;
  left: 50%;
  margin-left: -8px;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .ajax-dropdown:before {
    margin-left: -14px;
  }
}
.ajax-dropdown:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #fff;
  border-width: 7px;
  left: 50%;
  margin-left: -7px;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .ajax-dropdown:after {
    margin-left: -13px;
  }
}
.ajax-dropdown > :last-child {
  font-size: 13px;
  display: block;
  padding: 5px 0;
  line-height: 22px;
  font-weight: 400;
}
.ajax-dropdown > :first-child {
  margin: 0 0 3px;
  padding: 0 0 9px;
}
.ajax-dropdown .fa-4x.fa-border {
  border-width: 3px;
  border-radius: 50%;
  display: block;
  margin: 0 auto;
  width: 46px;
  text-align: center;
  color: #D1D1D1;
  border-color: #D1D1D1;
}
.ajax-dropdown .btn-group .btn {
  font-weight: 700;
  text-transform: capitalize;
}
.ajax-dropdown .btn-group > :nth-child(2) {
  border-right-width: 0;
  border-left-width: 0;
}
.ajax-dropdown .btn-group .btn:active {
  top: 0;
  left: 0;
}
.active + .ajax-dropdown {
  -webkit-animation-name: flipInY;
  animation-name: flipInY;
  -webkit-animation-duration: .7s;
  animation-duration: .7s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
}
.dropdown-large {
  position: static!important;
}
.dropdown-menu-large {
  margin-left: 16px;
  margin-right: 16px;
  padding: 20px 0;
}
.dropdown-menu-large > li > ul {
  padding: 0;
  margin: 0;
}
.dropdown-menu-large > li > ul > li {
  list-style: none;
}
.dropdown-menu-large > li > ul > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: 400;
  line-height: 1.428571429;
  color: #333;
  white-space: normal;
}
.dropdown-menu-large > li ul > li > a:focus,
.dropdown-menu-large > li ul > li > a:hover {
  text-decoration: none;
  color: #262626;
  background-color: #f5f5f5;
}
.dropdown-menu-large .disabled > a,
.dropdown-menu-large .disabled > a:focus,
.dropdown-menu-large .disabled > a:hover {
  color: #999;
}
.dropdown-menu-large .disabled > a:focus,
.dropdown-menu-large .disabled > a:hover {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
  cursor: not-allowed;
}
.dropdown-menu-large .dropdown-header {
  color: #428bca;
  font-size: 18px;
}
@media (max-width: 768px) {
  .dropdown-menu-large {
    margin-left: 0;
    margin-right: 0;
  }
  .dropdown-menu-large > li {
    margin-bottom: 30px;
  }
  .dropdown-menu-large > li:last-child {
    margin-bottom: 0;
  }
  .dropdown-menu-large .dropdown-header {
    padding: 3px 15px!important;
  }
}
.wijmo-wijmenu {
  padding: 0 20px;
  background-color: #222;
  background-repeat: repeat-x;
  background-image: -webkit-gradient(linear, top left, bottom left, from(#333333), to(#222222));
  background-image: -webkit-linear-gradient(top, #333333, #222222);
  background-image: linear-gradient(top, #333333, #222222);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#333333', endColorstr='#222222', GradientType=0);
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}
.wijmo-wijmenu .ui-state-default .wijmo-wijmenu-text {
  color: #bfbfbf;
}
.wijmo-wijmenu .ui-state-hover {
  background: #444;
  background: rgba(255, 255, 255, 0.05);
}
.wijmo-wijmenu .ui-state-hover .wijmo-wijmenu-text {
  color: #fff;
}
.wijmo-wijmenu .ui-widget-header h3 {
  position: relative;
  margin-top: 1px;
  padding: 0;
}
.wijmo-wijmenu h3 a {
  color: #fff;
  display: block;
  float: left;
  font-size: 20px;
  font-weight: 200;
  line-height: 1;
  margin-left: -20px;
  margin-top: 1px;
  padding: 8px 20px 12px;
}
.wijmo-wijmenu h3 a:hover {
  background-color: rgba(255, 255, 255, 0.05);
  color: #fff;
  text-decoration: none;
}
.wijmo-wijmenu .ui-widget-header {
  border: 0;
}
.wijmo-wijmenu .wijmo-wijmenu-parent .wijmo-wijmenu-child {
  padding: .3em 0;
}
.wijmo-wijmenu .wijmo-wijmenu-item {
  margin: 0;
  border: 0;
}
.wijmo-wijmenu .wijmo-wijmenu-item .wijmo-wijmenu-child {
  background: #333;
  border: 0;
  margin: 0;
  padding: 6px 0;
  width: 160px;
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
}
.wijmo-wijmenu a.wijmo-wijmenu-link {
  margin: 0;
  line-height: 19px;
  padding: 10px 10px 11px;
  border: 0;
  border-radius: 0;
}
.wijmo-wijmenu .wijmo-wijmenu-child .wijmo-wijmenu-link {
  display: block;
  float: none;
  padding: 4px 15px;
  width: auto;
}
.wijmo-wijmenu .wijmo-wijmenu-child .wijmo-wijmenu-text {
  float: none;
}
.wijmo-wijmenu .wijmo-wijmenu-item .wijmo-wijmenu-child .ui-state-hover {
  background: #191919;
}
.wijmo-wijmenu .wijmo-wijmenu-item .wijmo-wijmenu-separator {
  padding: 5px 0;
  background-image: none;
  background-color: #222;
  border-top: 1px solid #444;
  border-bottom: 0;
  border-left: 0;
  border-right: 0;
}
.wijmo-wijmenu .wijmo-wijmenu-item input {
  -moz-transition: none 0s ease 0s;
  background-color: rgba(255, 255, 255, 0.3);
  border: 1px solid #111;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px 0 rgba(255, 255, 255, 0.25);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px 0 rgba(255, 255, 255, 0.25);
  color: rgba(255, 255, 255, 0.75);
  font-family: Ubuntu, Helvetica, Arial, sans-serif;
  line-height: 1;
  margin: 5px 10px 0;
  padding: 4px 9px;
  width: 100px;
}
.wijmo-wijmenu .wijmo-wijmenu-item input:hover {
  background-color: rgba(255, 255, 255, 0.5);
  color: #fff;
}
.wijmo-wijmenu .wijmo-wijmenu-item input:focus {
  background-color: #fff;
  border: 0 none;
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  color: #404040;
  outline: 0 none;
  padding: 5px 10px;
  text-shadow: 0 1px 0 #fff;
}
.wijmo-wijmenu .ui-state-default {
  text-shadow: none;
  -webkit-box-shadow: none;
  box-shadow: none;
  color: #bfbfbf;
  -webkit-filter: none;
  filter: none;
}
/*
 * Tabs
 */
.tabs-below > .nav-tabs,
.tabs-left > .nav-tabs,
.tabs-right > .nav-tabs {
  border-bottom: 0;
}
.nav-tabs.bordered {
  background: #fff;
  border: 1px solid #ddd;
}
.nav-tabs.bordered > :first-child a {
  border-left-width: 0!important;
}
.nav-tabs.bordered + .tab-content {
  border: 1px solid #ddd;
  border-top: 0;
}
.nav-tabs > li > a {
  padding: 4px 10px;
  border-radius: 0;
  color: #333;
}
.nav-tabs > li > a .label {
  display: inline-block;
  font-size: 11px;
  margin-left: 5px;
  opacity: .5;
}
.nav-tabs > li > a .badge {
  font-size: 11px;
  padding: 4px 5px 2px;
  opacity: .5;
  margin-left: 5px;
  min-width: 17px;
  font-weight: 400;
}
.tabs-left .nav-tabs > li > a .badge {
  margin-right: 5px;
  margin-left: 0;
}
.nav-tabs > li > a > .fa {
  opacity: .5;
}
.nav-tabs.small > li > a {
  padding: 2px 8px;
  font-size: 90%;
}
.nav-tabs.tiny > li > a {
  padding: 1px 6px;
  font-size: 75%;
}
.nav-tabs > li.active > a {
  -webkit-box-shadow: 0 -2px 0 #57889c;
  box-shadow: 0 -2px 0 #57889c;
  border-top-width: 0!important;
  margin-top: 1px!important;
  font-weight: 700;
}
.nav-tabs > li.active > a .badge,
.nav-tabs > li.active > a .label,
.nav-tabs > li.active > a > .fa {
  opacity: 1;
}
.tabs-left .nav-tabs > li.active > a {
  -webkit-box-shadow: -2px 0 0 #57889c;
  box-shadow: -2px 0 0 #57889c;
  border-top-width: 1px!important;
  border-left: 0!important;
  margin-left: 1px!important;
}
.tabs-right .nav-tabs > li.active > a {
  -webkit-box-shadow: 2px 0 0 #57889c;
  box-shadow: 2px 0 0 #57889c;
  border-top-width: 1px!important;
  border-right: 0!important;
  margin-right: 1px!important;
}
.tabs-below .nav-tabs > li.active > a {
  -webkit-box-shadow: 0 2px 0 #57889c;
  box-shadow: 0 2px 0 #57889c;
  border-bottom-width: 0!important;
  border-top: 0!important;
  margin-top: 0!important;
}
.tabs-left > .nav-tabs > li,
.tabs-right > .nav-tabs > li,
.tabs-left > .nav-pills > li,
.tabs-right > .nav-pills > li {
  float: none;
}
.tabs-left > .nav-tabs > li > a,
.tabs-right > .nav-tabs > li > a,
.tabs-left > .nav-pills > li > a,
.tabs-right > .nav-pills > li > a {
  min-width: 74px;
  margin-right: 0;
  margin-bottom: 3px;
}
.tabs-left .nav-pills > li.active > a {
  border: 0!important;
  box-shadow: none!important;
  -webkit-box-shadow: none!important;
}
.tabs-left > .nav-pills,
.tabs-left > .nav-tabs {
  float: left;
  margin-right: 19px;
  border-right: 1px solid #ddd;
}
.tabs-left > .nav-pills {
  border-right: 0;
}
.tabs-left > .nav-tabs > li > a {
  margin-right: -1px;
}
.tabs-left > .nav-tabs > li > a:focus,
.tabs-left > .nav-tabs > li > a:hover {
  border-color: #eee #d5d5d5 #eee #eee;
}
.tabs-left > .nav-tabs .active > a,
.tabs-left > .nav-tabs .active > a:focus,
.tabs-left > .nav-tabs .active > a:hover {
  border-color: #d5d5d5 transparent #d5d5d5 #ddd;
  *border-right-color: #fff;
}
.tabs-left > .tab-content {
  margin-left: 109px;
}
.tabs-right > .nav-tabs {
  float: right;
  margin-left: 19px;
  border-left: 1px solid #ddd;
}
.tabs-right > .nav-tabs > li > a {
  margin-left: -1px;
}
.tabs-right > .nav-tabs > li > a:focus,
.tabs-right > .nav-tabs > li > a:hover {
  border-color: #eee #eee #eee #ddd;
}
.tabs-right > .nav-tabs .active > a,
.tabs-right > .nav-tabs .active > a:focus,
.tabs-right > .nav-tabs .active > a:hover {
  border-color: #ddd #ddd #ddd transparent;
  *border-left-color: #fff;
}
.tabs-pull-right.nav-tabs > li,
.tabs-pull-right.nav-pills > li {
  float: right;
}
.tabs-pull-right.nav-tabs > li:first-child > a,
.tabs-pull-right.nav-pills > li:first-child > a {
  margin-right: 1px;
}
.tabs-pull-right.bordered.nav-pills > li:first-child > a,
.tabs-pull-right.bordered.nav-tabs > li:first-child > a {
  border-left-width: 1px!important;
  margin-right: 0;
  border-right-width: 0;
}
.tabs-below > .nav-tabs {
  border-top: 1px solid #ddd;
}
.tabs-below > .nav-tabs > li {
  margin-top: -1px;
  margin-bottom: 0;
}
.tabs-below > .nav-tabs > li > a:focus,
.tabs-below > .nav-tabs > li > a:hover {
  border-top-color: #ddd;
  border-bottom-color: transparent;
}
.tabs-below > .nav-tabs > .active > a,
.tabs-below > .nav-tabs > .active > a:focus,
.tabs-below > .nav-tabs > .active > a:hover {
  border-color: transparent #ddd #ddd;
}
.pill-content > .pill-pane,
.tab-content > .pill-pane,
.pill-content > .tab-pane,
.tab-content > .tab-pane {
  display: none;
}
.pill-content > .active,
.tab-content > .active,
.pill-content > .active,
.tab-content > .active {
  display: block;
}
.pill-content.transparent,
.tab-content.transparent {
  background-color: transparent;
}
.pill-content.bordered,
.tab-content.bordered,
.pill-content.bordered:hover,
.tab-content.bordered:hover {
  border-top: 0;
}
.ams-widget > header > .nav-tabs.pull-left > li:first-child a {
  border-left-width: 0!important;
}
/*
 * Contents styles
 */
h1,
h2,
h3,
h4 {
  margin: 0;
  font-family: "Ubuntu-Bold", Arial, Helvetica, Sans-Serif;
  font-weight: 300;
}
h1 {
  letter-spacing: -1px;
  font-size: 24px;
  margin: 10px 0;
}
h1 small {
  font-size: 18px;
  font-weight: 300;
  letter-spacing: -1px;
}
h2 {
  letter-spacing: -1px;
  font-size: 22px;
  margin: 20px 0 15px;
  line-height: normal;
}
h3 {
  display: block;
  font-size: 19px;
  font-weight: 400;
  margin: 16px 0 10px;
  line-height: normal;
}
h4 {
  line-height: normal;
  font-size: 17px;
  font-weight: 300;
  margin: 12px 0 8px;
}
h5 {
  font-size: 15px;
  font-weight: 300;
  margin: 10px 0 6px;
  line-height: normal;
}
h6 {
  font-size: 14px;
  margin: 10px 0 4px;
  font-weight: 300;
  line-height: normal;
}
hr .simple {
  margin-top: 10px;
  margin-bottom: 10px;
  border-style: dashed;
}
img.online {
  border-left-color: #40ac2b!important;
}
img.busy {
  border-left-color: #ed1c24!important;
}
img.offline {
  border-left-color: #ddd!important;
}
img.away {
  border-left-color: #ffc40d!important;
}
[data-ams-url],
[data-ams-click-handler] {
  cursor: pointer;
}
label {
  font-weight: 400;
}
article.sortable-grid {
  min-height: 30px;
}
.caret {
  border-top: 5px solid;
  border-right: 5px solid transparent;
  border-left: 5px solid transparent;
}
.outside {
  position: absolute;
  left: -9999px;
}
@media (max-width: 979px) {
  .visible-tablet {
    display: inline-block !important;
  }
}
@media (max-width: 979px) {
  .hidden-tablet,
  .display-inline.hidden-tablet {
    display: none!important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .hidden-tablet {
    display: none!important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .visible-mobile {
    display: inline-block !important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .hidden-mobile {
    display: none!important;
  }
}
@media only screen and (min-width: 768px) {
  .modal-dialog.modal-large {
    width: 80%;
    max-width: 900px;
  }
}
@media only screen and (min-width: 768px) {
  .modal-dialog.modal-medium {
    width: 60%;
    max-width: 650px;
  }
}
@media only screen and (min-width: 768px) {
  .modal-dialog.modal-small {
    width: 40%;
    max-width: 450px;
  }
}
.viewport-y {
  overflow-y: auto;
}
.viewport-y.viewport-100 {
  max-height: 100px;
}
.viewport-y.viewport-200 {
  max-height: 200px;
}
.viewport-y.viewport-300 {
  max-height: 300px;
}
.viewport-x {
  overflow-x: auto;
}
.viewport-x.viewport-100 {
  max-width: 100px;
}
.viewport-x.viewport-200 {
  max-width: 200px;
}
.viewport-x.viewport-300 {
  max-width: 300px;
}
.lead {
  font-size: 19px;
}
.alert {
  margin-bottom: 20px;
  margin-top: 0;
  color: #675100;
  border-width: 0;
  border-left-width: 5px;
  padding: 10px;
  border-radius: 0;
}
.alert .close {
  top: 0;
  right: -5px;
  line-height: 20px;
}
.alert-heading {
  font-weight: 600;
}
.alert-danger {
  border-color: #963b49;
  color: #fff;
  background: #c46a69;
  text-shadow: none;
}
.alert-warning {
  border-color: #e5c693;
  color: #6b6d31;
  background: #ecdfb0;
}
.alert-success {
  border-color: #8eb589;
  color: #296829;
  background: #cee0cf;
}
.alert-info {
  border-color: #9cb4c5;
  color: #346597;
  background: #d6dde7;
}
.alert ul {
  margin-left: 25px;
  list-style-position: outside;
  list-style-type: square;
}
.ams-form > .alert {
  margin: 5px;
  padding: 5px;
  box-shadow: none!important;
  -webkit-box-shadow: none!important;
  border-radius: 0!important;
}
.well {
  background: #fbfbfb;
  border: 1px solid #ddd;
  box-shadow: 0 1px 1px #ececec;
  -webkit-box-shadow: 0 1px 1px #ececec;
  position: relative;
}
.well.well-clean {
  -webkit-box-shadow: none;
  box-shadow: none;
  border-color: transparent;
}
.well.well-glass {
  -webkit-box-shadow: none;
  box-shadow: none;
  border-color: transparent;
  background-color: rgba(255, 255, 255, 0.25);
  color: #fff;
}
.well.well-light {
  background: #fff;
  border: 1px solid #e2e2e2;
}
.widget-body .well {
  margin-bottom: 0;
}
.well.transparent {
  border: 0!important;
  background: none!important;
}
.ams-widget.well.transparent > div,
.ams-widget.well.transparent > div .widget-body {
  padding: 0!important;
}
.well[class*=" bg-"],
.well[class^=bg-] {
  border: 1px solid #555!important;
}
.note {
  margin-top: 6px;
  padding: 0 1px;
  font-size: 11px;
  line-height: 15px;
  color: #999;
}
.subscript {
  font-size: 21px;
  color: #999;
}
.display-image {
  margin-top: -60px;
  margin-right: 20px;
}
.terms-body {
  max-height: 400px;
  overflow: auto;
}
.timeline-seperator {
  display: block;
  text-align: center;
  color: #999;
  margin: 20px 0 0;
}
.timeline-seperator > :first-child {
  padding: 4px 5px;
  border: 1px dashed rgba(0, 0, 0, 0.1);
  background: #fff;
  font-size: 11px;
  border-radius: 4px;
}
.timeline-seperator .btn,
.timeline-seperator .btn + .dropdown-menu {
  margin-right: 15px;
}
.timeline-seperator:after {
  display: block;
  content: " ";
  margin: 0 20px;
  border-bottom: 1px dashed rgba(0, 0, 0, 0.1);
  margin-top: -8px;
}
.progress {
  position: relative;
  margin-bottom: 20px;
  overflow: hidden;
  height: 22px;
  background: #eee;
  box-shadow: 0 1px 0 transparent, 0 0 0 1px #e3e3e3 inset;
  -webkit-box-shadow: 0 1px 0 transparent, 0 0 0 1px #e3e3e3 inset;
  border-radius: 0;
}
.progress-bar {
  float: left;
  width: 0;
  height: 100%;
  font-size: 11px;
  color: #fff;
  text-align: center;
  background-color: #57889c;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  font-weight: 700;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-image: url(../img/pattern/overlay-pattern.png);
}
.progress-striped .progress-bar {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
  background-size: 40px 40px;
}
.progress.active .progress-bar {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -ms-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
}
.progress-bar-danger {
  background-color: #a90329;
}
.progress-striped .progress-bar-danger {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-success {
  background-color: #739e73;
}
.progress-striped .progress-bar-success {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-warning {
  background-color: #c79121;
}
.progress-striped .progress-bar-warning {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-info {
  background-color: #57889c;
}
.progress-striped .progress-bar-info {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress .bar-info,
.progress-info .bar {
  background: #57889c;
}
.progress-micro {
  height: 3px!important;
  line-height: 3px!important;
}
.progress-xs {
  height: 7px!important;
  line-height: 7px!important;
}
.progress-sm {
  height: 14px!important;
  line-height: 14px!important;
}
.progress-lg {
  height: 30px!important;
  line-height: 30px!important;
}
.progress .progress-bar {
  position: absolute;
  overflow: hidden;
  line-height: 20px;
}
.progress .progressbar-back-text {
  position: absolute;
  width: 100%;
  height: 100%;
  font-size: 12px;
  line-height: 20px;
  text-align: center;
}
.progress .progressbar-front-text {
  display: block;
  width: 100%;
  font-size: 12px;
  line-height: 20px;
  text-align: center;
}
.progress.right .progress-bar {
  right: 0;
}
.progress.right .progressbar-front-text {
  position: absolute;
  right: 0;
}
.progress.vertical {
  width: 25px;
  height: 100%;
  min-height: 150px;
  margin-right: 20px;
  display: inline-block;
  margin-bottom: 0;
}
.progress.vertical.bottom {
  position: relative;
}
.progress.vertical.bottom .progress-bar {
  position: absolute;
  bottom: 0;
}
.progress.vertical.bottom .progressbar-front-text {
  position: absolute;
  bottom: 0;
}
.progress.vertical .progress-bar {
  width: 100%;
  height: 0;
  -webkit-transition: height .6s ease;
  transition: height .6s ease;
}
.progress.wide-bar {
  width: 40px;
}
.dd {
  position: relative;
  display: block;
  margin: 0;
  padding: 0;
  max-width: 600px;
  list-style: none;
  font-size: 13px;
  line-height: 20px;
}
@media only screen and (min-width: 700px) {
  .dd {
    float: left;
    width: 100%;
  }
  .dd + .dd {
    margin-left: 2%;
  }
}
.dd-header.calender-spacer {
  height: 46px;
  display: block;
}
.dd-list {
  display: block;
  position: relative;
  margin: 0;
  padding: 0;
  list-style: none;
}
.dd-list .dd-list {
  padding-left: 30px;
}
.dd-collapsed .dd-list {
  display: none;
}
.dd-empty {
  border: 1px dashed #bbb;
  min-height: 100px;
  background-color: #eee;
  background-image: -webkit-linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff), -webkit-linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff);
  background-image: linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff), linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff);
  -webkit-background-size: 60px 60px;
  background-size: 60px 60px;
  background-position: 0 0, 30px 30px;
}
.dd-empty,
.dd-placeholder {
  margin: 5px 0;
  padding: 0;
  min-height: 30px;
  background: #f2fbff;
  border: 1px dashed #b6bcbf;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.dd-empty,
.dd-item,
.dd-placeholder {
  display: block;
  position: relative;
  margin: 0;
  padding: 0;
  min-height: 20px;
  font-size: 13px;
  line-height: 20px;
}
.dd-handle {
  display: block;
  font-size: 15px;
  margin: 5px 0;
  padding: 7px 15px;
  color: #333;
  text-decoration: none;
  border: 1px solid #cfcfcf;
  background: #fbfbfb;
}
.dd-handle:hover,
.dd-handle:hover + .dd-list .dd-handle {
  background: #FDDFB3!important;
  border: 1px solid #FAA937;
  color: #333!important;
}
.dd-handle > span {
  font-size: 13px;
  color: #777;
}
.dd-hover > .dd-handle {
  background: #2ea8e5!important;
}
.dd-item > button {
  position: relative;
  cursor: pointer;
  float: left;
  width: 25px;
  height: 20px;
  margin: 7px 10px;
  line-height: 22px!important;
  padding: 0;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden;
  border: 0;
  background: rgba(0, 0, 0, 0);
  text-align: center;
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 18px;
}
.dd-item > button:before {
  content: '\f055';
  display: block;
  position: absolute;
  width: 100%;
  text-align: center;
  text-indent: 0;
  color: #0091d9;
}
.dd-item > button[data-action=collapse]:before {
  content: '\f056';
  color: #a90329;
}
.dd-dragel {
  position: absolute;
  pointer-events: none;
  z-index: 9999;
}
.dd-dragel > .dd-item .dd-handle {
  margin-top: 0;
}
.dd-dragel > .dd-item > .dd-handle {
  border-left-width: 4px;
}
.dd-dragel .dd-handle {
  -webkit-box-shadow: 2px 4px 6px 0 rgba(0, 0, 0, 0.1);
  box-shadow: 2px 4px 6px 0 rgba(0, 0, 0, 0.1);
}
.dd-dragel > li.dd-item.dd3-item {
  position: relative;
  top: 10px;
  left: 10px;
  z-index: 999;
}
.vertical-bars {
  padding: 0;
  margin: 0;
}
.vertical-bars:after {
  content: "";
  display: block;
  height: 0;
  clear: both;
}
.vertical-bars li {
  padding: 14px 0;
  width: 25%;
  display: block;
  float: left;
  text-align: center;
}
.vertical-bars li:first-child {
  border-left: 0;
}
.vertical-bars > li > .progress.vertical {
  margin: 0 auto;
  float: none;
}
.vertical-bars > li > .progress.vertical:first-child {
  margin-left: auto;
}
.bar-holder {
  padding: 18px 15px;
}
.bar-holder:first-child {
  border-top: 0;
}
.bar-holder .progress {
  margin: 0;
}
.pagination.pagination-alt > li > a {
  box-shadow: none;
  -webkit-box-shadow: none;
  border: 0;
  margin-left: -1px;
}
.pagination.pagination-alt > li:first-child > a {
  padding-left: 0;
}
.pagination > li > a,
.pagination > li > span {
  padding: 7px 12px 5px;
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
}
.pagination-xs > li > a,
.pagination-xs > li > span {
  padding: 5px 9px 3px;
  font-size: 12px;
}
.panel-purple {
  border-color: #6e587a;
}
.panel-purple > .panel-heading {
  color: #fff;
  background-color: #6e587a;
  border-color: #6e587a;
}
.panel-greenLight {
  border-color: #71843f;
}
.panel-greenLight > .panel-heading {
  color: #fff;
  background-color: #71843f;
  border-color: #71843f;
}
.panel-greenDark {
  border-color: #496949;
}
.panel-greenDark > .panel-heading {
  color: #fff;
  background-color: #496949;
  border-color: #496949;
}
.panel-darken {
  border-color: #333;
}
.panel-darken > .panel-heading {
  color: #fff;
  background-color: #404040;
  border-color: #404040;
}
.panel-pink {
  border-color: #ac5287;
}
.panel-pink > .panel-heading {
  color: #fff;
  background-color: #ac5287;
  border-color: #ac5287;
}
.panel-green {
  border-color: #356e35;
}
.panel-green > .panel-heading {
  color: #fff;
  background-color: #356e35;
  border-color: #356e35;
}
.panel-blueLight {
  border-color: #92a2a8;
}
.panel-blueLight > .panel-heading {
  color: #fff;
  background-color: #92a2a8;
  border-color: #92a2a8;
}
.panel-pinkDark {
  border-color: #a8829f;
}
.panel-pinkDark > .panel-heading {
  color: #fff;
  background-color: #a8829f;
  border-color: #a8829f;
}
.panel-redLight {
  border-color: #a65858;
}
.panel-redLight > .panel-heading {
  color: #fff;
  background-color: #a65858;
  border-color: #a65858;
}
.panel-red {
  border-color: #a90329;
}
.panel-red > .panel-heading {
  color: #fff;
  background-color: #a90329;
  border-color: #a90329;
}
.panel-teal {
  border-color: #568a89;
}
.panel-teal > .panel-heading {
  color: #fff;
  background-color: #568a89;
  border-color: #568a89;
}
.panel-orange {
  border-color: #c79121;
}
.panel-orange > .panel-heading {
  color: #fff;
  background-color: #c79121;
  border-color: #c79121;
}
.panel-blueDark {
  border-color: #4c4f53;
}
.panel-blueDark > .panel-heading {
  color: #fff;
  background-color: #4c4f53;
  border-color: #4c4f53;
}
.panel-magenta {
  border-color: #6e3671;
}
.panel-magenta > .panel-heading {
  color: #fff;
  background-color: #6e3671;
  border-color: #6e3671;
}
.panel-blue {
  border-color: #57889c;
}
.panel-blue > .panel-heading {
  color: #fff;
  background-color: #57889c;
  border-color: #57889c;
}
.panel-footer > .btn-block {
  border-radius: 0;
  border-bottom: 0;
  border-left: 0;
  border-right: 0;
}
.notification-body {
  padding: 0 0 0 3px;
  margin: 0;
  list-style: none;
}
.notification-body *,
.notification-body:after *,
.notification-body:before * {
  box-sizing: border-box !important;
  -webkit-box-sizing: border-box !important;
  -moz-box-sizing: border-box !important;
}
.notification-body > li {
  border-bottom: 1px solid #E9E9E9;
  position: relative;
}
.notification-body > li > span {
  background: #fff;
  display: block;
  min-height: 25px;
  overflow: hidden;
  padding: 8px 10px 13px;
  white-space: normal;
}
.notification-body > li > span:hover {
  background: #F0F4F7;
  color: #667F8F;
}
.notification-body > li a.msg {
  padding-left: 50px!important;
}
.notification-body > li a,
.notification-body > li a span {
  display: block;
  position: relative;
  overflow: hidden;
}
.notification-body > li a,
.notification-body > li a:hover {
  text-decoration: none;
}
.notification-body > li:hover .progress {
  background: #fff;
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #a7a7a7 inset;
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #cccccc inset;
}
.notification-body > li:hover .text-muted {
  color: #333;
}
.notification-body .from {
  font-size: 14px;
  line-height: normal;
  color: #333;
  font-weight: 400;
  margin-right: 60px;
  margin-bottom: 6px;
  height: 20px;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
.notification-body .unread {
  background: #FFFFE0;
}
.notification-body .unread .unread .from {
  font-weight: 700;
}
.notification-body time {
  position: absolute;
  top: 3px;
  right: 0;
  font-size: 11px;
  font-weight: 400;
  color: #058dc7;
}
.notification-body .msg-body,
.notification-body .subject {
  font-size: 13px;
  color: #A0A0A0;
  max-height: 35px;
  width: 100%;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
.notification-body .subject {
  font-size: 13px;
  color: #333;
  max-height: 22px;
}
.ajax-notifications {
  height: 365px;
  display: block;
  overflow: auto;
  margin-right: -10px;
  margin-left: -10px;
  border-bottom: 1px solid #CECECE;
  border-top: 1px solid #CECECE;
  background: #E9E9E9;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .ajax-notifications {
    height: 250px;
  }
}
.ajax-notifications > .alert.alert-transparent {
  background-color: transparent;
  border-color: transparent;
  color: #757575;
  margin: 13px 10px;
}
.ajax-notifications > .alert > :first-child {
  margin-bottom: 10px;
  font-weight: 400;
}
.arrow-box-up:before,
.arrow-box-up:after {
  bottom: 100%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}
.arrow-box-up:before {
  border-color: rgba(131, 131, 131, 0);
  border-bottom-color: #838383;
  border-width: 8px;
  left: 50%;
  margin-left: -8px;
}
.arrow-box-up:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #fff;
  border-width: 7px;
  left: 50%;
  margin-left: -7px;
}
.arrow-box-up-right:before,
.arrow-box-up-right:after {
  bottom: 100%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}
.arrow-box-up-right:before {
  border-color: rgba(131, 131, 131, 0);
  border-bottom-color: #838383;
  border-width: 8px;
  right: 9px;
  margin-left: -8px;
}
.arrow-box-up-right:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #fff;
  border-width: 7px;
  right: 10px;
  margin-left: -7px;
}
.tooltip-inner {
  padding: 5px 10px;
  font-size: 11px;
  font-family: Ubuntu, Arial, Helvetica, sans-serif;
  font-weight: 700;
  border-radius: 0;
}
.jqstooltip {
  padding: 7px!important;
  border-radius: 3px!important;
  border: 0!important;
  background-color: #000!important;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
.jqstooltip .jqsfield {
  font-family: Ubuntu, Arial, sans-serif;
  font-size: 11px;
}
.dd3-content {
  display: block;
  margin: 5px 0;
  padding: 6px 10px 8px 40px;
  font-size: 15px;
  color: #333;
  text-decoration: none;
  border: 1px solid #cfcfcf;
  background: #fbfbfb;
}
.dd3-content:hover {
  color: #2ea8e5;
  background: #fff;
}
.dd-dragel > .dd3-item > .dd3-content {
  margin: 0;
}
.dd3-item > button {
  margin-left: 38px;
}
.dd3-handle {
  position: absolute;
  margin: 0;
  left: 0;
  top: 0;
  cursor: move;
  width: 30px;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden;
  border: 1px solid #aaa;
  background: #bfbfbf;
  background: -webkit-gradient(linear, top left, bottom left, from(#dddddd), to(#bbbbbb));
  background: -webkit-linear-gradient(top, #dddddd 0, #bbbbbb 100%);
  background: linear-gradient(top, #dddddd 0, #bbbbbb 100%);
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 18px;
  padding: 8px 15px;
}
.dd3-handle:before {
  content: '\f0c9';
  display: block;
  position: absolute;
  left: 0;
  top: 3px;
  width: 100%;
  text-align: center;
  text-indent: 0;
  color: #818181;
  font-weight: 400;
  line-height: 28px;
}
.dd3-handle:hover:before {
  color: #C27616;
}
/*
 * Nestable lists
 */
.nestable-lists {
  display: block;
  clear: both;
  padding: 30px 0;
  width: 100%;
  border: 0;
  border-top: 2px solid #bfbfbf;
  border-bottom: 2px solid #bfbfbf;
}
#nestable-menu {
  padding: 0;
  margin: 10px 0 20px;
}
#nestable-output,
#nestable2-output {
  width: 100%;
  padding: 5px;
}
/*
 * Custom items
 */
.custom-scroll::-webkit-scrollbar {
  -webkit-overflow-scrolling: touch;
  height: 10px;
  width: 10px;
}
.custom-scroll::-webkit-scrollbar:hover {
  background-color: #E9E9E9;
  border: 1px solid #dbdbdb;
}
.custom-scroll::-webkit-scrollbar-button:start:decrement,
.custom-scroll::-webkit-scrollbar-button:end:increment {
  background: 0 0;
  display: block;
  height: 0;
}
.custom-scroll::-webkit-scrollbar-track {
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  border: solid transparent;
}
.custom-scroll::-webkit-scrollbar-track-piece {
  -o-border-radius: 0;
  background-color: transparent;
  border-radius: 0;
}
.custom-scroll::-webkit-scrollbar-thumb {
  -webkit-box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: rgba(0, 0, 0, 0.2);
  border: 0;
  box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
}
.custom-scroll::-webkit-scrollbar-thumb:vertical,
.custom-scroll::-webkit-scrollbar-thumb:horizontal {
  -o-border-radius: 0;
  background-color: #bfbfbf;
  border-radius: 0;
}
.custom-scroll::-webkit-scrollbar-thumb:active {
  -webkit-box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.33);
  background-color: rgba(0, 0, 0, 0.44);
  box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.33);
}
.custom-scroll::-webkit-scrollbar-thumb:hover {
  background-color: #959595;
}
.air {
  position: absolute;
  z-index: 5;
}
.air-bottom {
  bottom: 0;
}
.air-top {
  top: 0;
}
.air-top-right {
  top: 0;
  right: 0;
}
.air-top-left {
  top: 0;
  left: 0;
}
.air-bottom-left {
  bottom: 0;
  left: 0;
}
.air-bottom-right {
  bottom: 0;
  right: 0;
}
.tree {
  min-height: 20px;
  border-radius: 4px;
}
.tree li {
  list-style-type: none;
  margin: 0;
  padding: 5px;
  position: relative;
}
.tree li:after,
.tree li:before {
  content: '';
  left: -20px;
  position: absolute;
  right: auto;
}
.tree li:before {
  border-left: 1px solid #999;
  bottom: 50px;
  height: 100%;
  top: -11px;
  width: 1px;
  -webkit-transition: "border-color 0.1s ease 0.1s";
  transition: "border-color 0.1s ease 0.1s";
}
.tree li:last-child::before {
  height: 30px;
}
.tree li:after {
  border-top: 1px solid #999;
  height: 20px;
  top: 18px;
  width: 25px;
}
.tree li span {
  border: 1px dotted #999;
  border-radius: 5px;
  display: inline-block;
  padding: 3px 8px;
  text-decoration: none;
  -webkit-transition: color 0.2s ease 0.1s, background-color 0.2s ease 0.1s, border-color 0.3s ease 0.2s;
  transition: color 0.2s ease 0.1s, background-color 0.2s ease 0.1s, border-color 0.3s ease 0.2s;
}
.tree li.parent_li > span {
  cursor: pointer;
  padding: 7px;
}
.tree li.parent_li > span:hover {
  background-color: #DF8505;
  border: 1px solid #C67605;
  color: #fff;
}
.tree li.parent_li > span:hover + ul li::before {
  border-left-color: #F89406;
}
.tree li.parent_li > span:hover + ul li::after {
  border-top-color: #F89406;
}
.tree li.parent_li > span:hover + ul li span {
  background: #FDDFB3!important;
  border: 1px solid #FAA937;
  color: #000;
}
.tree li.parent_li > span:hover,
.tree li.parent_li > span:hover + ul li span {
  background: #eee;
  border: 1px solid #94a0b4;
  color: #000;
}
.tree ul ul {
  padding-left: 34px;
  padding-top: 10px;
}
.tree ul ul li:hover {
  background: rgba(0, 0, 0, 0.015);
}
.tree > ul {
  padding-left: 0;
}
.tree > ul > li :after,
.tree > ul > li :before {
  border: 0;
}
.pace {
  -webkit-pointer-events: none;
  pointer-events: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.pace-inactive {
  display: none;
}
.pace .pace-progress {
  background: #3276b1;
  position: fixed;
  z-index: 2000;
  top: 0;
  left: 0;
  height: 2px;
  -webkit-transition: width 1s;
  transition: width 1s;
}
.pace .pace-progress-inner {
  display: block;
  position: absolute;
  right: 0;
  width: 100px;
  height: 100%;
  -webkit-box-shadow: 0 0 10px #29d, 0 0 5px #29d;
  box-shadow: 0 0 10px #29d, 0 0 5px #29d;
  opacity: 1;
  -webkit-transform: rotate(3deg) translate(0, -4px);
  -ms-transform: rotate(3deg) translate(0, -4px);
  transform: rotate(3deg) translate(0, -4px);
}
.pace .pace-activity {
  display: block;
  position: fixed;
  z-index: 2000;
  top: 63px;
  right: 40px;
  width: 14px;
  height: 14px;
  border: solid 2px transparent;
  border-top-color: #29d;
  border-left-color: #29d;
  border-radius: 10px;
  -webkit-animation: pace-spinner 400ms linear infinite;
  -ms-animation: pace-spinner 400ms linear infinite;
  animation: pace-spinner 400ms linear infinite;
}
/*
 * Tables and datatables
 */
.table-full {
  width: 100%;
}
.table-wrap {
  overflow: auto;
}
.table.has-tickbox thead tr th:first-child {
  width: 18px;
}
.table.has-tickbox.ams-form tbody tr td:first-child .checkbox,
.table.has-tickbox.ams-form tbody tr td:first-child .radio,
.table.has-tickbox.ams-form thead tr th:first-child .checkbox,
.table.has-tickbox.ams-form thead tr th:first-child .radio {
  padding: 0!important;
}
.table-tight td,
.table-tight th {
  padding: 4px 8px!important;
}
.table-mini td,
.table-mini th {
  padding: 1px 8px!important;
}
.table-bordered > thead > tr > td,
.table-bordered > thead > tr > th {
  border-width: 1px;
}
.table-bordered .no-padding > .table-bordered {
  border: 0!important;
}
.table-bordered .no-padding > .table-bordered tbody tr td:first-child,
.table-bordered .no-padding > .table-bordered thead tr td:first-child,
.table-bordered .no-padding > .table-bordered thead tr th:first-child {
  border-left-width: 0!important;
}
.table-bordered .no-padding > .table-bordered tbody tr td:last-child,
.table-bordered .no-padding > .table-bordered thead tr th:last-child {
  border-right-width: 0!important;
}
.table-bordered .no-padding > .table-bordered tbody tr:last-child td {
  border-bottom-width: 0!important;
}
.no-padding .note-editable .table-bordered {
  border: 1px solid #ddd!important;
}
tr.bordered-bottom th,
tr.bordered-bottom td {
  border-bottom: 1px solid #ddd;
}
.dt-row {
  padding: 4px 10px;
}
.dt-top-row {
  height: 0;
  line-height: 0;
  position: relative;
}
.dt-bottom-row {
  background: #fafafa;
  font-size: 11px;
  overflow: hidden;
  padding: 5px 10px;
  border-top: 1px solid #ccc;
  -webkit-box-shadow: inset 0 1px #fff;
  -ms-box-shadow: inset 0 1px #fff;
  box-shadow: inset 0 1px #fff;
}
.dataTables_length {
  position: absolute;
  right: 13px;
  top: -35px;
}
.dataTables_length select {
  width: 60px;
  padding: 3px;
  font-size: 13px;
  border: 1px solid #bbb;
}
.dataTables_filter {
  position: absolute;
  left: 10px;
  top: -35px;
}
.dataTables_filter input {
  padding: 3px 8px 1px;
  font-size: 13px;
}
.dataTables_filter .form-control {
  height: 28px;
}
.dataTables_filter .input-group {
  width: 180px!important;
}
.dataTables_filter input select {
  border: 1px solid #bbb;
}
.dataTables_paginate {
  margin: 4px 0 0;
}
.dataTables_paginate .pagination {
  margin: 0;
}
.dt-wrapper {
  overflow: hidden;
}
.dataTables_wrapper {
  position: relative;
}
.dataTables_wrapper table.table {
  clear: both;
  max-width: inherit;
  margin-bottom: 0;
}
.dataTables_wrapper table.table thead th {
  white-space: nowrap;
  text-overflow: ellipsis;
  -ms-text-overflow: ellipsis;
}
.dataTables_wrapper table.table thead .sorting,
.dataTables_wrapper table.table thead .sorting_asc,
.dataTables_wrapper table.table thead .sorting_asc_disabled,
.dataTables_wrapper table.table thead .sorting_desc,
.dataTables_wrapper table.table thead .sorting_desc_disabled {
  cursor: pointer;
  padding-right: 20px;
}
.dataTables_wrapper table.table thead .sorting {
  background: url(../img/datatable/sort_both.png) no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_asc {
  background: url(../img/datatable/sort_asc.png) no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_desc {
  background: url(../img/datatable/sort_desc.png) no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_asc_disabled {
  background: url(../img/datatable/sort_asc_disabled.png) no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_desc_disabled {
  background: url(../img/datatable/sort_desc_disabled.png) no-repeat center right;
}
.dataTables_wrapper table.table tbody tr.active th,
.dataTables_wrapper table.table tbody tr.active td {
  background-color: #08C;
  color: #fff;
}
.dataTables_wrapper table.table tbody tr.active:hover td,
.dataTables_wrapper table.table tbody tr.active:hover th {
  background-color: #0075b0!important;
}
.dataTables_wrapper table.dataTable th:active {
  outline: 0;
}
.dataTables_wrapper .table-striped tbody tr.active:nth-child(odd) td,
.dataTables_wrapper .table-striped tbody tr.active:nth-child(odd) th {
  background-color: #017ebc;
}
.dataTables_wrapper select {
  min-height: inherit;
}
.dataTables_wrapper table + .row {
  margin-bottom: 0;
  margin-top: 10px;
}
.dataTables_wrapper .dt_actions {
  float: left;
  margin-right: 20px;
}
.dataTables_wrapper .bottom,
.dataTables_wrapper .top {
  background-color: #f5f5f5;
  border: 1px solid #CCC;
  padding: 15px;
}
.dataTables_wrapper div.DTTT .btn:hover {
  text-decoration: none!important;
}
.dataTables_wrapper ul.DTTT_dropdown.dropdown-menu a {
  color: #333!important;
}
.dataTables_wrapper ul.DTTT_dropdown.dropdown-menu li:hover a {
  background-color: #08c;
  color: #fff!important;
}
.dataTables_wrapper div.DTTT_print_info.modal {
  height: 150px;
  margin-top: -75px;
  text-align: center;
}
.dataTables_wrapper div.DTTT_print_info h6 {
  font-weight: 400;
  font-size: 28px;
  line-height: 28px;
  margin: 1em;
}
.dataTables_wrapper div.DTTT_print_info p {
  font-size: 14px;
  line-height: 20px;
}
.dataTables_wrapper div.DTFC_LeftFootWrapper table,
.dataTables_wrapper div.DTFC_LeftHeadWrapper table,
.dataTables_wrapper table.DTFC_Cloned tr.even {
  background-color: #fff;
}
.dataTables_wrapper div.DTFC_LeftHeadWrapper table {
  margin-bottom: 0!important;
  border-top-right-radius: 0!important;
  border-bottom-left-radius: 0!important;
  border-bottom-right-radius: 0!important;
}
.dataTables_scrollBody {
  -webkit-overflow-scrolling: touch;
}
.top .dataTables_info {
  float: none;
}
div.dt-bottom-row .dataTables_info {
  float: left;
  padding-top: 10px;
  font-size: 12px;
}
.dataTables_full {
  width: 100%!important;
}
.dataTables_empty {
  text-align: center!important;
  font-size: 15px;
  background: #fff!important;
  padding: 20px 0!important;
  cursor: default;
}
.dataTables_scroll {
  clear: both;
}
.dataTables_scrollHeadInner table.table-bordered {
  border-radius: 4px 4px 0 0;
}
.dataTables_scrollHeadInner table.table-bordered,
.dataTables_scrollHeadInner table.table-bordered thead {
  border-bottom: 0;
}
.dataTables_scrollBody table {
  border-top: 0;
}
.dataTables_processing {
  position: absolute;
  top: 50%;
  margin-top: -24px;
  z-index: 100;
  left: 50%;
  width: 250px;
  margin-left: -125px;
  border: 1px solid #ddd;
  text-align: center;
  color: #000;
  background: #fff;
  font-size: 15px!important;
  -webkit-box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  -ms-box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  padding: 10px 0;
}
.dataTables_wrapper .center {
  text-align: center;
}
.dataTables_wrapper .details,
.dataTables_wrapper .details:hover {
  background: #ddd!important;
}
.dataTables_wrapper .details table td {
  background: #fff!important;
}
.dataTables_scrollHeadInner table.table,
.dataTables_wrapper .details table.table {
  margin: 0!important;
}
.dataTables_scrollHead table {
  margin-bottom: 0!important;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.dataTables_scrollHead table thead tr:last-child th:first-child {
  border-bottom-left-radius: 0!important;
  border-bottom-right-radius: 0!important;
}
.DTFC_LeftHeadWrapper table thead tr:last-child td:first-child,
.DTFC_LeftHeadWrapper table thead tr:last-child th:first-child {
  border-bottom-left-radius: 0!important;
  border-bottom-right-radius: 0!important;
}
.DTFC_LeftBodyWrapper table,
.dataTables_scrollBody table {
  border-top: 0;
  margin-bottom: 0!important;
}
.DTFC_LeftBodyWrapper tbody tr:first-child td,
.DTFC_LeftBodyWrapper tbody tr:first-child th,
div.DTFC_LeftFootWrapper table,
div.dataTables_scrollBody tbody tr:first-child th,
div.dataTables_scrollFoot table {
  border-top: 0;
}
/*
 * Datatables ColVis plug-in
 */
.ColVis {
  position: absolute;
  right: 83px;
  top: -35px;
}
.ColVis_collection {
  position: relative;
  width: 180px;
  background-color: #fff;
  border: 1px solid rgba(0, 0, 0, 0.2);
  -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  z-index: 1102;
  padding-top: 3px;
  padding-left: 10px;
  list-style-type: none;
  list-style-position: outside;
}
.ColVis_collection .ColVis_Button {
  position: relative;
  margin-right: 3px;
  height: 30px;
  background-color: #fff;
  border: 1px solid #d0d0d0;
  cursor: hand;
  padding: 3px 5px;
}
.ColVis_collection button.ColVis_Button {
  padding: 4px 12px;
  height: 26px;
  background-color: #fff;
  border: 0;
  width: 100%;
  float: none;
  font-size: 12px;
}
.ColVis_collection button.ColVis_Button + button.ColVis_Button {
  border-top: 1px solid #e1e1e1;
}
.ColVis_collection button.ColVis_Button button.ColVis_Button input {
  margin: 0;
}
button.ColVis_Button {
  padding: 4px 5px;
  text-align: left;
}
button.ColVis_Button::-moz-focus-inner {
  border: 0!important;
  padding: 0;
}
.ColVis_collectionBackground {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: #000;
  z-index: 1100;
}
div.ColVis_catcher {
  position: absolute;
  z-index: 1101;
}
span.ColVis_radio {
  display: inline-block;
  width: 20px;
  vertical-align: -2px;
}
.ColVis_text_hover,
div.ColVis_collection button.ColVis_Button:hover {
  background: #F2F2F2;
  color: #222;
}
/*
 * Datatables columns reorder plug-in
 */
table.DTCR_clonedTable {
  background-color: #fff;
  z-index: 202;
}
div.DTCR_pointer {
  width: 1px;
  background-color: #0259C4;
  z-index: 201;
}
ul.DTTT_dropdown.dropdown-menu li {
  position: relative;
}
ul.DTTT_dropdown.dropdown-menu li:hover a {
  background-color: #f2f2f2;
  color: #333!important;
}
.table_tools_group {
  position: absolute;
  right: 83px;
  top: -37px;
}
.DTTT.btn-group {
  position: absolute;
  top: -38px;
  right: 83px;
}
.DTTT_dropdown {
  z-index: 2002;
}
.DTFC_LeftHeadWrapper {
  border-bottom: 1px solid #ddd;
}
div.DTTT_container {
  position: relative;
  float: right;
  margin-bottom: 1em;
}
a.DTTT_button,
button.DTTT_button,
div.DTTT_button {
  position: relative;
  float: left;
  margin-right: 3px;
  padding: 5px 8px;
  border: 1px solid #999;
  cursor: pointer;
  *cursor: hand;
  font-size: .88em;
  color: #000!important;
  -o-border-radius: 2px;
  border-radius: 2px;
  -webkit-box-shadow: 1px 1px 3px #ccc;
  -ms-box-shadow: 1px 1px 3px #ccc;
  -o-box-shadow: 1px 1px 3px #ccc;
  box-shadow: 1px 1px 3px #ccc;
  background: #fff;
  background: -webkit-gradient(linear, top left, bottom left, from(#ffffff), color-stop(89%, #f3f3f3), to(#f9f9f9));
  background: -webkit-linear-gradient(top, #ffffff 0, #f3f3f3 89%, #f9f9f9 100%);
  background: linear-gradient(top, #ffffff 0, #f3f3f3 89%, #f9f9f9 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f9f9f9', GradientType=0);
}
a.DTTT_button:hover,
button.DTTT_button:hover,
div.DTTT_button:hover {
  border: 1px solid #666;
  text-decoration: none!important;
  -webkit-box-shadow: 1px 1px 3px #999;
  -ms-box-shadow: 1px 1px 3px #999;
  -o-box-shadow: 1px 1px 3px #999;
  box-shadow: 1px 1px 3px #999;
  background: #f3f3f3;
  background: -webkit-gradient(linear, top left, bottom left, from(#f3f3f3), color-stop(89%, #e2e2e2), to(#f4f4f4));
  background: -webkit-linear-gradient(top, #f3f3f3 0, #e2e2e2 89%, #f4f4f4 100%);
  background: linear-gradient(top, #f3f3f3 0, #e2e2e2 89%, #f4f4f4 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f3f3f3', endColorstr='#f4f4f4', GradientType=0);
}
button.DTTT_button {
  height: 30px;
  padding: 3px 8px;
}
.DTTT_button embed {
  outline: 0;
}
a.DTTT_disabled,
button.DTTT_disabled,
div.DTTT_disabled {
  color: #999;
  border: 1px solid #d0d0d0;
  background: #fff;
  background: -webkit-gradient(linear, top left, bottom left, from(#ffffff), color-stop(89%, #f9f9f9), to(#fafafa));
  background: -webkit-linear-gradient(top, #ffffff 0, #f9f9f9 89%, #fafafa 100%);
  background: linear-gradient(top, #ffffff 0, #f9f9f9 89%, #fafafa 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#fafafa', GradientType=0);
}
table.DTTT_selectable tbody tr {
  cursor: pointer;
  *cursor: hand;
}
table.dataTable tr.DTTT_selected.odd td.sorting_1,
table.dataTable tr.DTTT_selected.odd td.sorting_2,
table.dataTable tr.DTTT_selected.odd td.sorting_3 {
  background-color: #9FAFD1;
}
table.dataTable tr.DTTT_selected.even td.sorting_1,
table.dataTable tr.DTTT_selected.even td.sorting_2,
table.dataTable tr.DTTT_selected.even td.sorting_3 {
  background-color: #B0BED9;
}
div.DTTT_collection {
  width: 150px;
  padding: 8px 8px 4px;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.4);
  background-color: #f3f3f3;
  background-color: rgba(255, 255, 255, 0.3);
  overflow: hidden;
  z-index: 2002;
  -o-border-radius: 5px;
  border-radius: 5px;
  -webkit-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  -ms-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  -o-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
}
div.DTTT_collection a.DTTT_button,
div.DTTT_collection button.DTTT_button,
div.DTTT_collection div.DTTT_button {
  position: relative;
  left: 0;
  right: 0;
  display: block;
  float: none;
  margin-bottom: 4px;
  -webkit-box-shadow: 1px 1px 3px #999;
  -ms-box-shadow: 1px 1px 3px #999;
  -o-box-shadow: 1px 1px 3px #999;
  box-shadow: 1px 1px 3px #999;
}
div.DTTT_collection_background {
  z-index: 2001;
}
.DTTT_print_info {
  position: fixed;
  top: 50%;
  left: 50%;
  width: 400px;
  height: 150px;
  margin-left: -200px;
  margin-top: -75px;
  text-align: center;
  color: #333;
  padding: 10px 30px;
  background: #fff;
  background: -webkit-gradient(linear, top left, bottom left, from(#ffffff), color-stop(89%, #f3f3f3), to(#f9f9f9));
  background: -webkit-linear-gradient(top, #ffffff 0, #f3f3f3 89%, #f9f9f9 100%);
  background: linear-gradient(top, #ffffff 0, #f3f3f3 89%, #f9f9f9 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f9f9f9', GradientType=0);
  opacity: .95;
  border: 1px solid #000;
  border: 1px solid rgba(0, 0, 0, 0.5);
  -o-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  -ms-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  -o-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
}
.DTTT_print_info h6 {
  font-weight: 400;
  font-size: 28px;
  line-height: 28px;
  margin: 1em;
}
.DTTT_print_info p {
  font-size: 14px;
  line-height: 20px;
}
/*
 * Forms styles
 */
.form hr {
  margin-left: -13px;
  margin-right: -13px;
  border-color: rgba(0, 0, 0, 0.1);
  margin-top: 20px;
  margin-bottom: 20px;
}
.form fieldset {
  display: block;
  border: 0;
  background: rgba(255, 255, 255, 0.9);
  position: relative;
}
.form header,
.form legend {
  display: block;
  padding: 8px 0;
  border-bottom: 1px dashed rgba(0, 0, 0, 0.2);
  background: #fff;
  font-size: 16px;
  font-weight: 300;
  color: #222;
  margin: 25px 0 20px;
}
.no-padding .form header {
  margin: 25px 14px 0;
}
.form header:first-child {
  margin-top: 10px;
}
.form .form-group:last-child,
.form .form-group:last-child .note,
.form fieldset .form-group:last-child,
.form fieldset .form-group:last-child .note {
  margin-bottom: 0;
}
fieldset {
  position: relative;
}
legend {
  font-weight: 400;
  margin-top: 0;
  background: 0 0;
}
i.hint {
  vertical-align: super;
  opacity: 0.5;
}
i.hint:hover {
  opacity: 0.9;
}
.nohints i.hint {
  display: none;
}
.input-group-addon {
  padding: 6px 10px 5px;
  border-radius: 0;
  transition: background-color 0.3s;
  -webkit-transition: background-color 0.3s;
}
.input-group-addon .fa {
  font-size: 14px;
}
.input-group-addon .fa-2x,
.input-group-addon .fa-lg {
  font-size: 2em;
}
.input-group-addon .fa-3x,
.input-group-addon .fa-4x,
.input-group-addon .fa-5x {
  font-size: 30px;
}
.input-group-addon .checkbox,
.input-group-addon .radio {
  min-height: 0;
  margin-right: 0!important;
  padding-top: 0;
}
.input-group-addon label input[type=checkbox].checkbox + span,
.input-group-addon label input[type=checkbox].checkbox + span:before,
.input-group-addon label input[type=radio].radiobox + span,
.input-group-addon label input[type=radio].radiobox + span:before {
  margin-right: 0;
}
.input-group-addon .onoffswitch,
.input-group-addon .onoffswitch-label {
  margin: 0;
}
input[type=text]:focus + .input-group-addon {
  border-color: #0091d9;
  background-color: #72a0ce;
  color: #fff;
}
.has-warning input[type=text]:focus + .input-group-addon {
  border-color: #7f6a1e;
  background-color: #cead35;
  color: #fff;
}
.has-error input[type=text]:focus + .input-group-addon {
  border-color: #c46a69;
  background-color: #c46a69;
  color: #fff;
}
.has-success input[type=text]:focus + .input-group-addon {
  border-color: #446b46;
  background-color: #588a5a;
  color: #fff;
}
.input-icon-left > i {
  right: auto;
  left: 24px;
}
.input-icon-left .form-control {
  padding-left: 29px;
}
.input-icon-right {
  position: relative;
}
.input-icon-right .form-control {
  padding-right: 27px;
}
.input-icon-left > i,
.input-icon-right > i {
  position: absolute;
  right: 10px;
  top: 30%;
  font-size: 16px;
  color: #bfbfbf;
}
.form-actions {
  display: block;
  padding: 13px 14px 15px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(249, 249, 249, 0.9);
  margin-top: 25px;
  margin-left: -13px;
  margin-right: -13px;
  margin-bottom: -13px;
  text-align: right;
}
.well .form-actions {
  margin-left: -19px;
  margin-right: -19px;
  margin-bottom: -19px;
}
.well.well-lg .form-actions {
  margin-left: -24px;
  margin-right: -24px;
  margin-bottom: -24px;
}
.well.well-sm .form-actions {
  margin-left: -9px;
  margin-right: -9px;
  margin-bottom: -9px;
}
.popover-content .form-actions {
  margin: 0 -14px -9px;
  border-radius: 0 0 3px 3px;
  padding: 9px 14px;
}
.no-padding .form .form-actions {
  margin: 0;
  display: block;
  padding: 13px 14px 15px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
  text-align: right;
  margin-top: 25px;
}
:focus {
  outline: 0!important;
}
.filter_column input {
  padding: 0px 3px;
}
.filter_column input,
.filter_column select {
  width: 100%;
  color: rgba(0, 0, 0, 0.5);
  border: 1px solid #CCC;
  border-radius: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.uneditable-input:focus,
input[type=color]:focus,
input[type=date]:focus,
input[type=datetime-local]:focus,
input[type=datetime]:focus,
input[type=email]:focus,
input[type=month]:focus,
input[type=number]:focus,
input[type=password]:focus,
input[type=search]:focus,
input[type=tel]:focus,
input[type=text]:focus,
input[type=time]:focus,
input[type=url]:focus,
input[type=week]:focus,
.filter_column input:focus,
.filter_column select:focus,
select:focus,
textarea:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  outline: thin dotted 9;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
}
.form-control {
  padding: 7px 12px 5px;
}
.form-control,
.input-lg,
.input-sm,
.input-xs {
  border-radius: 0 !important;
}
.input-xs {
  height: 24px;
  padding: 3px 10px 1px;
  font-size: 11px;
  line-height: 1.5;
}
.fileinput {
  padding-top: 3px;
}
input[type=checkbox].checkbox,
input[type=radio].radiobox {
  visibility: hidden;
  position: absolute;
  z-index: 20;
  width: 18px;
  height: 18px;
}
.checkbox input[type=checkbox].checkbox + span,
.checkbox input[type=radio].radiobox + span,
.checkbox-inline input[type=checkbox].checkbox + span,
.checkbox-inline input[type=radio].radiobox + span,
.radio input[type=checkbox].checkbox + span,
.radio input[type=radio].radiobox + span,
.radiobox-inline input[type=checkbox].checkbox + span,
.radiobox-inline input[type=radio].radiobox + span {
  margin-left: -20px;
}
.form-inline .checkbox input[type=checkbox].checkbox + span,
.form-inline .checkbox input[type=radio].radiobox + span,
.form-inline .checkbox-inline input[type=checkbox].checkbox + span,
.form-inline .checkbox-inline input[type=radio].radiobox + span,
.form-inline .radio input[type=checkbox].checkbox + span,
.form-inline .radio input[type=radio].radiobox + span,
.form-inline .radiobox-inline input[type=checkbox].checkbox + span,
.form-inline .radiobox-inline input[type=radio].radiobox + span {
  margin-left: 0;
}
input[type=checkbox].checkbox + span,
input[type=radio].radiobox + span,
label input[type=checkbox].checkbox + span,
label input[type=radio].radiobox + span {
  vertical-align: middle;
  line-height: 20px;
}
input[type=checkbox].checkbox + span,
input[type=radio].radiobox + span,
input[type=checkbox].checkbox + span:after,
input[type=radio].radiobox + span:after,
input[type=checkbox].checkbox:before,
input[type=radio].radiobox:before {
  box-sizing: content-box !important;
  -webkit-box-sizing: content-box !important;
  -moz-box-sizing: content-box !important;
}
label input[type=checkbox].checkbox + span,
label input[type=radio].radiobox + span {
  position: relative;
  z-index: 19;
  display: inline-block;
  margin: 0;
  line-height: 17px;
  min-height: 14px;
  min-width: 14px;
  margin-right: 5px;
}
label input[type=checkbox].checkbox + span:hover,
label input[type=radio].radiobox + span:hover {
  cursor: pointer;
}
label input[type=checkbox].checkbox + span:before,
label input[type=radio].radiobox + span:before {
  font-family: FontAwesome;
  font-size: 12px;
  border-radius: 0;
  content: "\a0";
  display: inline-block;
  text-align: center;
  vertical-align: middle;
  padding: 1px;
  height: 12px;
  line-height: 12px;
  min-width: 12px;
  margin-right: 5px;
  border: 1px solid #bfbfbf;
  background-color: #f4f4f4;
  font-weight: 400;
  margin-top: -1px;
}
label input[type=checkbox].checkbox + span:before {
  content: "\a0";
}
label input[type=checkbox].checkbox:checked + span {
  font-weight: 700;
}
label input[type=checkbox].checkbox:checked + span:before {
  content: "\f00c";
  color: #2E7BCC;
}
label input[type=checkbox].checkbox.style-1 + span:before {
  color: #333;
  background: #fff;
  text-shadow: none;
  -webkit-box-shadow: none!important;
  box-shadow: none!important;
  border-width: 1px;
  height: 12px;
  line-height: 13px;
  min-width: 12px;
}
label input[type=checkbox].checkbox.style-1:checked + span {
  font-weight: 400;
}
label input[type=checkbox].checkbox.style-1:checked + span:before {
  color: #333;
  border-color: #333;
}
label input[type=checkbox].checkbox.style-2 + span:before {
  background: 0 0;
  border-color: #c1c1c1;
  -webkit-box-shadow: none;
  box-shadow: none;
}
label input[type=checkbox].checkbox.style-2:checked + span {
  font-weight: 400;
}
label input[type=checkbox].checkbox.style-2:checked + span:before {
  content: "\f00c";
  color: #66665e;
  border-color: #4d90fe;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6MUQ0MEM4RUFEQUE4MTFFMkEwMjM5NzlCRjAxM0UwRjciIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6MUQ0MEM4RUJEQUE4MTFFMkEwMjM5NzlCRjAxM0UwRjciPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDoxRDQwQzhFOERBQTgxMUUyQTAyMzk3OUJGMDEzRTBGNyIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDoxRDQwQzhFOURBQTgxMUUyQTAyMzk3OUJGMDEzRTBGNyIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/PsD/PVAAAAAQSURBVHjaYv7//78vQIABAAlYA05NMPppAAAAAElFTkSuQmCC) #ffffff;
}
label input[type=checkbox].checkbox.style-3:checked + span:before {
  color: #fff;
  border-color: #a90329;
  background: #a90329;
}
label:active input[type=checkbox].checkbox + span:before {
  -webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
  box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
}
label:hover input[type=checkbox].checkbox + span:before {
  color: #2E7BCC;
  border-color: #2E7BCC;
}
label:hover input[type=checkbox].checkbox.style-1 + span:before {
  border-color: #333;
}
label:hover input[type=checkbox].checkbox.style-2 + span:before {
  -webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 0 0 rgba(255, 255, 255, 0.2);
  box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 0 0 rgba(255, 255, 255, 0.2);
}
label:hover input[type=checkbox].checkbox.style-2:checked + span:before {
  -webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
  box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
}
label:hover input[type=checkbox].checkbox.style-3 + span:before {
  color: #fff;
  border-color: #A90327;
}
label:active input[type=checkbox].checkbox:checked + span:before {
  color: #fff;
  background: #2E7BCC;
  border-color: #2E7BCC;
}
label:active input[type=checkbox].checkbox.style-1:checked + span:before {
  color: #fff;
  background: #333;
  border-color: #333;
}
label:active input[type=checkbox].checkbox.style-2 + span:before,
label:active input[type=checkbox].checkbox.style-2:checked + span:before {
  color: #66665e;
  background: 0 0;
  border-color: #c1c1c1;
  -webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
  box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
}
label:active input[type=checkbox].checkbox.style-3:checked + span:before {
  color: #a90329;
  background: #fff;
  border-color: #a90329;
}
label input[type=checkbox][disabled].checkbox + span,
label input[type=checkbox][disabled].checkbox:checked + span {
  color: #A7A7A7;
  cursor: not-allowed;
}
label input[type=checkbox][disabled].checkbox:checked + span:before {
  content: "\f00c";
}
label input[type=checkbox][disabled].checkbox.style-2:checked + span:before {
  content: "\f00c";
}
label input[type=checkbox][disabled].checkbox + span:before,
label input[type=checkbox][disabled].checkbox:checked + span:before,
label input[type=checkbox][disabled].checkbox:checked + span:before {
  background: #eee!important;
  border-color: #CCC!important;
  -webkit-box-shadow: none;
  color: #A7A7A7;
  box-shadow: none!important;
}
label:hover input[type=checkbox][disabled].checkbox:checked + span:before {
  color: #A7A7A7;
  cursor: not-allowed;
}
label:hover input[type=checkbox][disabled].checkbox:checked + span:before {
  background: #eee!important;
  border-color: #CCC!important;
  -webkit-box-shadow: none;
  color: #A7A7A7;
  box-shadow: none!important;
}
label input[type=radio].radiobox + span:before {
  content: "\a0";
  border-radius: 50%;
  -webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 0 0 rgba(255, 255, 255, 0.2);
  box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 0 0 rgba(255, 255, 255, 0.2);
}
label input[type=radio].radiobox:checked + span {
  font-weight: 700;
}
label input[type=radio].radiobox:checked + span:before {
  content: "\f111";
  color: #2E7BCC;
}
label input[type=radio].radiobox.style-1 + span:before {
  font-size: 9px;
  background: #fff;
  text-shadow: none;
  -webkit-box-shadow: none!important;
  box-shadow: none!important;
  border-width: 1px;
  height: 13px;
  line-height: 13px;
  min-width: 13px;
}
label input[type=radio].radiobox.style-1:checked + span:before {
  font-size: 10px;
  color: #333;
  border-color: #333;
  background: #fff;
}
label input[type=radio].radiobox.style-1:checked + span {
  font-weight: 400;
}
label input[type=radio].radiobox.style-2:checked + span {
  font-weight: 400;
}
label input[type=radio].radiobox.style-2:checked + span:before {
  color: #66665e;
  border-color: #4d90fe;
  font-size: 9px;
}
label input[type=radio].radiobox.style-3:checked + span:before {
  color: #a90329;
  border-color: #a90329;
}
label:hover input[type=radio].radiobox + span:before,
label:hover input[type=radio].radiobox:checked + span:before {
  color: #2E7BCC;
  border-color: #2E7BCC;
}
label:hover input[type=radio].radiobox.style-1 + span:before,
label:hover input[type=radio].radiobox.style-1:checked + span:before {
  color: #333;
  border-color: #333;
  background: #fff;
}
label:hover input[type=radio].radiobox.style-2:checked + span:before {
  color: #66665e;
  border-color: #4d90fe;
}
label:hover input[type=radio].radiobox.style-3 + span:before,
label:hover input[type=radio].radiobox.style-3:checked + span:before {
  color: #a90329;
  border-color: #a90329;
}
label:active input[type=radio].radiobox + span:before {
  -webkit-box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
  box-shadow: inset 0 2px 3px 0 rgba(0, 0, 0, 0.3), 0 1px 0 0 rgba(255, 255, 255, 0.4);
}
label input[type=radio][disabled].radiobox + span,
label input[type=radio][disabled].radiobox:checked + span,
label input[type=radio][disabled].radiobox:checked + span:before {
  color: #A7A7A7;
  cursor: not-allowed;
}
label input[type=radio][disabled].radiobox:checked + span:before {
  content: "\f111";
}
label input[type=radio][disabled].radiobox + span:before,
label input[type=radio][disabled].radiobox:checked + span:before {
  background: #eee!important;
  border-color: #CCC!important;
  -webkit-box-shadow: none;
  box-shadow: none;
  color: #A7A7A7;
}
label:active input[type=radio][disabled].radiobox:checked + span:before,
label:hover input[type=radio][disabled].radiobox:checked + span:before {
  background: #eee!important;
  border-color: #CCC!important;
  -webkit-box-shadow: none;
  box-shadow: none;
  color: #A7A7A7;
}
textarea.clone {
  position: absolute;
  visibility: hidden;
}
.textarea-div {
  background-color: #FFF;
  border: 1px solid #CCC;
  border-bottom: 0;
  margin: 10px 0 0;
}
.textarea-controls {
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  padding: 5px;
  display: block;
  background-color: #FFF;
  border: 1px solid #CCC;
  border-top: 0;
  height: 43px;
  line-height: 33px;
  overflow: hidden;
}
.textarea-controls > label {
  margin: 3px 10px 0;
}
.textarea-controls .ams-form .checkbox {
  padding-left: 22px!important;
}
.typearea {
  cursor: text;
  overflow-x: hidden;
  overflow-y: auto;
  max-height: 90px;
  padding: 5px 25px 5px 5px;
  position: relative;
  border-bottom: 1px solid #EEE;
}
.typearea textarea {
  width: 100%;
  border-color: transparent!important;
  box-sizing: border-box;
  box-shadow: none;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -webkit-box-shadow: none;
  overflow: hidden;
  padding: 0;
  margin: 0;
  -webkit-transition: height .2s;
  transition: height .2s;
  outline: 0;
  resize: none;
  min-height: 61px;
}
.error-box {
  max-width: 900px;
  margin: 0 auto;
}
.error-text {
  font-weight: 400;
  color: #fff;
  letter-spacing: -4px;
  font-size: 700%;
  margin-bottom: 30px;
  text-shadow: 0 1px 0 #cccccc, 0 2px 0 #bfbfbf, 0 3px 0 #bbbbbb, 0 4px 0 #b9b9b9, 0 5px 0 #aaaaaa, 0 6px 1px rgba(0, 0, 0, 0.1), 0 0 5px rgba(0, 0, 0, 0.1), 0 1px 3px rgba(0, 0, 0, 0.3), 0 3px 5px rgba(0, 0, 0, 0.2), 0 5px 10px rgba(0, 0, 0, 0.25), 0 10px 10px rgba(0, 0, 0, 0.2), 0 20px 20px rgba(0, 0, 0, 0.15);
}
.error-search {
  width: 300px;
  margin: 0 auto 20px;
}
.error-icon-shadow {
  text-shadow: 0 1px 0 #803838, 0 2px 0 #a85d5d, 0 3px 0 #b86565, 0 4px 0 #d86f6f, 0 5px 0 #b3a5a5, 0 6px 1px rgba(131, 51, 51, 0.1), 0 0 5px rgba(102, 30, 30, 0.1), 0 1px 3px rgba(95, 15, 15, 0.3), 0 3px 5px rgba(100, 23, 23, 0.2), 0 5px 10px rgba(114, 30, 30, 0.25), 0 10px 10px rgba(94, 15, 15, 0.2), 0 20px 20px rgba(121, 38, 38, 0.15);
}
.form-inline .checkbox,
.form-inline .radiobox {
  padding-left: 0;
}
.ams-form {
  position: relative;
  margin: 0;
  outline: 0;
  color: #333;
}
.ams-form *,
.ams-form :after,
.ams-form :before {
  margin: 0;
  padding: 0;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.ams-form header {
  display: block;
  padding: 8px 0;
  border-bottom: 1px dashed rgba(0, 0, 0, 0.2);
  background: #fff;
  font-size: 16px;
  font-weight: 300;
  color: #232323;
  margin: 10px 14px 0;
}
.ams-form fieldset {
  display: block;
  position: relative;
  padding: 10px 15px 5px;
  border: 0;
  background: rgba(255, 255, 255, 0.9);
}
.ams-form fieldset[disabled] > section,
.ams-form fieldset[disabled] > article,
.ams-form fieldset[disabled] > div {
  opacity: 0.5;
}
.ams-form fieldset.switched > section,
.ams-form fieldset.switched > article,
.ams-form fieldset.switched > div {
  display: none;
}
.ams-form fieldset.switched legend {
  border-bottom: 0;
}
.ams-form fieldset.bordered {
  margin: 10px;
  border: 1px solid rgba(192, 192, 192, 0.8);
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.ams-form fieldset.bordered.switched {
  border: 1px solid transparent;
}
.ams-form fieldset.bordered legend {
  width: auto;
  padding: 3px 10px 1px;
  border: 1px solid rgba(192, 192, 192, 0.8);
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.ams-form fieldset + fieldset {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
}
.ams-form legend {
  padding-top: 10px;
}
.ams-form legend.inner,
.ams-form legend .inner {
  font-weight: 300;
  font-size: 14.5px!important;
}
.ams-form legend.switcher {
  font-weight: 300;
  font-size: 16.5px;
  border: 0;
  padding-bottom: 0;
  cursor: pointer;
}
.ams-form legend .fa {
  color: #3276b1;
  font-size: 75%;
}
.ams-form legend .hint {
  vertical-align: top;
  font-size: 1em;
}
.ams-form legend label.checkbox {
  display: inline-block;
  margin-bottom: 0px;
  min-height: 18px;
}
.ams-form legend label.checkbox i {
  position: absolute;
  left: 3px;
  top: -1px;
}
.ams-form > .modal-viewport > fieldset > legend {
  padding-top: 0;
}
.ams-form section {
  margin-bottom: 10px;
  position: relative;
}
.ams-form .form-group {
  padding: 5px 10px;
}
.ams-form label.checkbox,
.ams-form label.radio {
  padding-top: 0;
}
.ams-form input.input-lg {
  height: 44px;
  padding: 10px 16px;
  font-size: 17px;
  line-height: 1.33;
}
.ams-form input.input-sm {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
}
.ams-form input.input-xs {
  height: 24px;
  padding: 2px 10px;
  font-size: 11px;
  line-height: 1.5;
}
.ams-form select.input-sm {
  height: 30px;
  line-height: 15px;
  font-size: 12px;
}
.ams-form select.input-sm + i {
  height: 10px;
}
.ams-form select.input-lg {
  height: 44px;
  line-height: 22px;
  font-size: 17px;
}
.ams-form select.input-lg + i {
  height: 11px;
  top: 17px;
}
.ams-form .row {
  margin: 0 -15px;
}
.ams-form .row:after {
  display: table;
  content: '';
  clear: both;
}
.ams-form .col-1 {
  width: 8.33%;
}
.ams-form .col-2 {
  width: 16.66%;
}
.ams-form .col-3 {
  width: 25%;
}
.ams-form .col-4 {
  width: 33.33%;
}
.ams-form .col-5 {
  width: 41.66%;
}
.ams-form .col-6 {
  width: 50%;
}
.ams-form .col-8 {
  width: 66.67%;
}
.ams-form .col-9 {
  width: 75%;
}
.ams-form .col-10 {
  width: 83.33%;
}
.ams-form .col {
  float: left;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}
@media screen and (max-width: 600px) {
  .ams-form .col {
    float: none;
    width: 100%;
  }
}
@media screen and (max-width: 600px) {
  .ams-form .col .label {
    text-align: left;
    padding-left: 20px;
  }
}
.ams-form footer {
  display: block;
  padding: 7px 25px 15px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
}
.ams-form footer:after {
  display: table;
  clear: both;
  content: '';
}
.ams-form footer .btn {
  float: right;
  height: 31px;
  margin: 10px 0 0 5px;
  padding: 0 22px;
  font: 300 15px/29px Ubuntu, Helvetica, Arial, sans-serif;
  cursor: pointer;
}
.ams-form footer .btn.btn-info {
  float: left;
}
.ams-form footer .submit-message {
  display: inline-block;
}
.ams-form .message {
  display: none;
  color: #6fb679;
}
.ams-form .message i {
  display: block;
  margin: 0 auto 20px;
  width: 81px;
  height: 81px;
  border: 1px solid #6fb679;
  border-radius: 50%;
  font-size: 30px;
  line-height: 81px;
}
.ams-form.submitted fieldset,
.ams-form.submitted footer {
  display: none;
}
.ams-form.submitted .message {
  display: block;
  padding: 25px 30px;
  background: rgba(255, 255, 255, 0.9);
  font: 300 18px/27px Ubuntu, Helvetica, Arial, sans-serif;
  text-align: center;
}
.ams-form .note {
  margin-top: 6px;
  padding: 0 1px;
  font-size: 11px;
  line-height: 15px;
  color: #999;
}
.ams-form .note a {
  font-size: 13px;
}
.ams-form .note-success {
  color: #6fb679;
}
.ams-form .control-label {
  display: block;
  margin-top: 4px;
  margin-bottom: 6px;
  padding-top: 0;
  line-height: 19px;
  font-weight: 400;
  font-size: 13px;
  color: #666;
  text-align: right;
}
@media screen and (max-width: 992px) {
  .ams-form .control-label {
    text-align: left;
    margin-bottom: 0;
  }
}
.ams-form .control-label.col {
  text-align: right;
}
@media screen and (max-width: 600px) {
  .ams-form .control-label.col {
    text-align: left;
    padding-left: 20px;
  }
}
.ams-form .control-label span {
  margin-right: 10px;
}
.ams-form .control-label span::after {
  content: " *";
  color: transparent;
}
.ams-form .control-label span > .hint {
  margin-top: -2px;
}
.ams-form .control-label .col {
  margin: 0;
  padding-top: 7px;
}
.ams-form label.input span.textline-field {
  display: block;
  margin-top: 4px;
  margin-bottom: 6px;
  padding-top: 0;
  line-height: 19px;
  font-size: 13px;
}
.ams-form .required-field .control-label span::after {
  color: red;
}
.ams-form .tooltip {
  position: absolute;
  z-index: 99999;
  left: -9999px;
  padding: 2px 8px 3px;
  font-size: 11px;
  line-height: 16px;
  font-weight: 400;
  background: rgba(0, 0, 0, 0.9);
  color: #fff;
  opacity: 0;
  transition: margin .3s, opacity .3s;
  -webkit-transition: margin .3s, opacity .3s;
}
.ams-form .tooltip:after {
  position: absolute;
  content: '';
}
.ams-form .tooltip-top-right {
  bottom: 100%;
  margin-bottom: 15px;
}
.ams-form .tooltip-top-right:after {
  top: 100%;
  right: 11px;
  border-top: 4px solid rgba(0, 0, 0, 0.9);
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.ams-form .input input:focus + .tooltip-top-right,
.ams-form .textarea textarea:focus + .tooltip-top-right {
  right: 0;
  left: auto;
  margin-bottom: 5px;
}
.ams-form .tooltip-top-left {
  bottom: 100%;
  margin-bottom: 15px;
}
.ams-form .tooltip-top-left:after {
  top: 100%;
  left: 11px;
  border-top: 4px solid rgba(0, 0, 0, 0.9);
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.ams-form .input input:focus + .tooltip-top-left,
.ams-form .textarea textarea:focus + .tooltip-top-left {
  right: auto;
  left: 0;
  margin-bottom: 5px;
}
.ams-form .tooltip-right {
  top: 4px;
  white-space: nowrap;
  margin-left: 15px;
}
.ams-form .tooltip-right:after {
  top: 6px;
  right: 100%;
  border-top: 4px solid transparent;
  border-right: 4px solid rgba(0, 0, 0, 0.9);
  border-bottom: 4px solid transparent;
}
.ams-form .input input:focus + .tooltip-right,
.ams-form .textarea textarea:focus + .tooltip-right {
  left: 100%;
  margin-left: 5px;
}
.ams-form .tooltip-left {
  top: 4px;
  white-space: nowrap;
  margin-right: 15px;
}
.ams-form .tooltip-left:after {
  top: 6px;
  left: 100%;
  border-top: 4px solid transparent;
  border-bottom: 4px solid transparent;
  border-left: 4px solid rgba(0, 0, 0, 0.9);
}
.ams-form .input input:focus + .tooltip-left,
.ams-form .textarea textarea:focus + .tooltip-left {
  right: 100%;
  left: auto;
  margin-right: 5px;
}
.ams-form .tooltip-bottom-right {
  top: 100%;
  margin-top: 15px;
}
.ams-form .tooltip-bottom-right:after {
  bottom: 100%;
  right: 11px;
  border-right: 4px solid transparent;
  border-bottom: 4px solid rgba(0, 0, 0, 0.9);
  border-left: 4px solid transparent;
}
.ams-form .input input:focus + .tooltip-bottom-right,
.ams-form .textarea textarea:focus + .tooltip-bottom-right {
  right: 0;
  left: auto;
  margin-top: 5px;
}
.ams-form .tooltip-bottom-left {
  top: 100%;
  margin-top: 15px;
}
.ams-form .tooltip-bottom-left:after {
  bottom: 100%;
  left: 11px;
  border-right: 4px solid transparent;
  border-bottom: 4px solid rgba(0, 0, 0, 0.9);
  border-left: 4px solid transparent;
}
.ams-form .input input:focus + .tooltip-bottom-left,
.ams-form .textarea textarea:focus + .tooltip-bottom-left {
  right: auto;
  left: 0;
  margin-top: 5px;
}
.ams-form .inline-group {
  margin: 0 -30px -4px 0;
}
.ams-form .inline-group:after {
  content: '';
  display: table;
  clear: both;
}
.ams-form .inline-group .checkbox,
.ams-form .inline-group .radio {
  float: left;
  margin-right: 30px;
}
.ams-form .inline-group .checkbox:last-child,
.ams-form .inline-group .radio:last-child {
  margin-bottom: 4px;
}
.ams-form .btn {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.ams-form .button {
  float: right;
  height: 31px;
  overflow: hidden;
  margin: 10px 0 0 5px;
  padding: 0 25px;
  outline: 0;
  border: 0;
  font: 300 15px/31px Ubuntu, Helvetica, Arial, sans-serif;
  text-decoration: none;
  color: #fff;
  cursor: pointer;
  background-color: #3276B1;
  opacity: .8;
  transition: opacity .2s;
  -webkit-transition: opacity .2s;
}
.ams-form .button:hover {
  opacity: 1;
}
.ams-form .button.button-secondary {
  background-color: #b3b3b3;
}
.ams-form .button,
.ams-form .checkbox,
.ams-form .input,
.ams-form .radio,
.ams-form .select,
.ams-form .textarea,
.ams-form .toggle {
  display: block;
  position: relative;
  font-weight: 400;
}
.ams-form .input input,
.ams-form .select select,
.ams-form .textarea textarea {
  display: block;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  height: 28px;
  padding: 6px 8px;
  outline: 0;
  border-width: 1px;
  border-style: solid;
  border-radius: 0;
  background: #fff;
  font: 13px/16px Ubuntu, Helvetica, Arial, sans-serif;
  color: #404040;
  appearance: normal;
  -moz-appearance: none;
  -webkit-appearance: none;
}
.ams-form .input input.display-mode,
.ams-form .select select.display-mode,
.ams-form .textarea textarea.display-mode {
  border: none;
  padding: 0;
  margin-top: 2px;
  margin-bottom: 3px;
  height: 14px;
  line-height: 1em;
}
.ams-form .input input:focus + .tooltip,
.ams-form .textarea textarea:focus + .tooltip {
  opacity: 1;
}
.ams-form .input .icon-prepend + input,
.ams-form .textarea .icon-prepend + textarea {
  padding-left: 37px;
}
.ams-form .input .icon-append + input,
.ams-form .textarea .icon-append + textarea {
  padding-right: 37px;
}
.ams-form .input .icon-prepend + .icon-append + input,
.ams-form .textarea .icon-prepend + .icon-append + textarea {
  padding-left: 37px;
}
.ams-form .input-file .button {
  position: absolute;
  top: 3px;
  right: 3px;
  float: none;
  height: 22px;
  margin: 0;
  padding: 0 14px;
  font-size: 13px;
  line-height: 22px;
}
.ams-form .input-file .button:hover {
  -webkit-box-shadow: none;
  box-shadow: none;
}
.ams-form .input-file .button input {
  position: absolute;
  top: 0;
  right: 0;
  padding: 0;
  font-size: 30px;
  cursor: pointer;
  opacity: 0;
}
.ams-form .select select {
  padding: 5px;
}
.ams-form .select i {
  position: absolute;
  top: 9px;
  right: 11px;
  width: 5px;
  height: 11px;
  background: #fff;
}
.ams-form .select i:before,
.ams-form .select i:after {
  content: '';
  position: absolute;
  right: 0;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.ams-form .select i:before {
  top: 0;
  border-bottom: 4px solid #404040;
}
.ams-form .select i:after {
  bottom: 0;
  border-top: 4px solid #404040;
}
.ams-form .select-multiple select {
  height: auto;
}
.ams-form .textarea textarea {
  height: auto;
  resize: none;
}
.ams-form .textarea-resizable textarea {
  resize: vertical;
}
.ams-form .textarea-expandable textarea {
  height: 31px;
}
.ams-form .textarea-expandable textarea:focus {
  height: auto;
}
.ams-form .checkbox,
.ams-form .radio {
  margin-bottom: 4px;
  padding-left: 25px;
  line-height: 25px;
  color: #404040;
  cursor: pointer;
  font-size: 13px;
}
.ams-form .checkbox:last-child,
.ams-form .radio:last-child {
  margin-bottom: 0;
}
.ams-form .checkbox i,
.ams-form .radio i {
  display: block;
  position: absolute;
  top: 3px;
  left: 0;
  width: 17px;
  height: 17px;
  outline: 0;
  border-width: 1px;
  border-style: solid;
  background: #FFF;
}
.ams-form .checkbox input,
.ams-form .radio input {
  position: absolute;
  left: -9999px;
}
.ams-form .checkbox input + i:after,
.ams-form .radio input + i:after {
  position: absolute;
  opacity: 0;
  transition: opacity .1s;
  -webkit-transition: opacity .1s;
}
.ams-form .checkbox input:checked + i:after,
.ams-form .radio input:checked + i:after {
  opacity: 1;
}
.ams-form .radio input + i:after {
  background-color: #3276B1;
}
.ams-form .checkbox input + i:after {
  content: '\f00c';
  top: -1px;
  left: 1px;
  width: 15px;
  height: 15px;
  font: 400 16px/19px FontAwesome;
  text-align: center;
}
.ams-form .checkbox input + i:after {
  color: #3276B1;
}
.ams-form .checkbox input:checked:hover + i:after {
  content: '\f00d';
}
.ams-form .checkbox input:checked:disabled:hover + i:after {
  content: '\f00c';
}
.ams-form .radio input + i:after {
  content: '';
  top: 4px;
  left: 4px;
  width: 9px;
  height: 9px;
  border-radius: 50%;
}
.ams-form .checkbox + .checkbox,
.ams-form .radio + .radio {
  margin-top: 0;
}
.ams-form.table td .checkbox i,
.ams-form.table td .radio i,
.ams-form.table th .checkbox i,
.ams-form.table th .radio i {
  top: 0!important;
}
.ams-form .inner .checkbox {
  min-height: 13px;
}
.ams-form .inner .checkbox i {
  width: 13px;
  height: 13px;
}
.ams-form .inner .checkbox input + i:after {
  width: 11px;
  height: 11px;
  font: 300 12px/16px FontAwesome;
}
.ams-form .toggle {
  margin-bottom: 4px;
  padding-right: 61px;
  font-size: 15px;
  line-height: 25px;
  color: #404040;
  cursor: pointer;
}
.ams-form .toggle:last-child {
  margin-bottom: 0;
}
.ams-form .toggle.state-error input:checked + i {
  background: #fff0f0;
}
.ams-form .toggle.state-success input:checked + i {
  background: #f0fff0;
}
.ams-form .toggle input {
  position: absolute;
  left: -9999px;
}
.ams-form .toggle input:checked + i:before {
  right: 36px;
}
.ams-form .toggle input:checked + i:after {
  content: attr(data-swchon-text);
  text-align: right;
}
.ams-form .toggle i {
  display: block;
  position: absolute;
  content: '';
  top: 4px;
  right: 0;
  width: 49px;
  height: 17px;
  border-width: 1px;
  border-style: solid;
  border-radius: 12px;
  background: #fff;
}
.ams-form .toggle i:before {
  display: block;
  position: absolute;
  content: '';
  z-index: 1;
  top: 4px;
  right: 4px;
  width: 9px;
  height: 9px;
  border-radius: 50%;
  opacity: 1;
  transition: right .2s;
  -webkit-transition: right .2s;
  background-color: #3276B1;
}
.ams-form .toggle i:after {
  position: absolute;
  content: attr(data-swchoff-text);
  top: 2px;
  right: 8px;
  left: 8px;
  font-style: normal;
  font-size: 9px;
  line-height: 17px;
  font-weight: 700;
  text-align: left;
  color: #5f5f5f;
}
.ams-form .checkbox:hover i,
.ams-form .radio:hover i,
.ams-form .toggle:hover i {
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
}
.ams-form .checkbox:active i,
.ams-form .radio:active i,
.ams-form .toggle:active i {
  background: #F0F0F0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
}
.ams-form .checkbox input:checked + i,
.ams-form .radio input:checked + i,
.ams-form .toggle input:checked + i {
  border-color: #3276B1;
}
.ams-form .rating {
  margin-bottom: 4px;
  font-size: 13px;
  line-height: 25px;
  color: #404040;
}
.ams-form .rating:last-child {
  margin-bottom: 0;
}
.ams-form .rating.state-error + em {
  margin-top: -4px;
  margin-bottom: 4px;
}
.ams-form .rating input {
  position: absolute;
  left: -9999px;
}
.ams-form .rating input + label:hover,
.ams-form .rating input + label:hover ~ label {
  color: #3276B1;
}
.ams-form .rating input:checked ~ label {
  color: #3276B1;
}
.ams-form .rating label {
  display: block;
  float: right;
  height: 17px;
  margin-top: 5px;
  padding: 0 2px;
  font-size: 17px;
  line-height: 17px;
  cursor: pointer;
  color: #ccc;
  transition: color .3s;
  -webkit-transition: color .3s;
}
.ams-form .icon-append,
.ams-form .icon-prepend {
  position: absolute;
  top: 4px;
  width: 20px;
  height: 20px;
  font-size: 14px;
  line-height: 20px;
  text-align: center;
  color: #A2A2A2;
}
.ams-form .icon-append {
  right: 4px;
  padding-left: 2px;
  border-left-width: 1px;
  border-left-style: solid;
}
.ams-form .icon-append-2 {
  right: 31px;
}
.ams-form .icon-prepend {
  left: 4px;
  padding-right: 2px;
  border-right-width: 1px;
  border-right-style: solid;
}
.ams-form .icon-prepend-2 {
  left: 31px;
}
.ams-form .checkbox i,
.ams-form .icon-append,
.ams-form .icon-prepend,
.ams-form .input input,
.ams-form .radio i,
.ams-form .select select,
.ams-form .textarea textarea,
.ams-form .toggle i {
  border-color: #BDBDBD;
  transition: border-color 0.3s;
  -webkit-transition: border-color 0.3s;
}
.ams-form .input.bordered:hover,
.ams-form .checkbox:hover i,
.ams-form .input:hover input,
.ams-form .radio:hover i,
.ams-form .select:hover select,
.ams-form .textarea:hover textarea,
.ams-form .toggle:hover i {
  border-color: rgba(82, 168, 236, 0.7);
}
.ams-form .checkbox input:focus + i,
.ams-form .input input:focus,
.ams-form .radio input:focus + i,
.ams-form .select select:focus,
.ams-form .textarea textarea:focus,
.ams-form .toggle input:focus + i {
  border-color: rgba(82, 168, 236, 0.7);
  outline: 0;
  outline: thin dotted 9;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.7);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.7);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.7);
}
.ams-form .checkbox.state-error i,
.ams-form .radio.state-error i,
.ams-form .state-error input,
.ams-form .state-error select,
.ams-form .state-error textarea,
.ams-form .toggle.state-error i {
  background: #fff0f0;
  border-color: rgba(255, 60, 60, 0.8) !important;
}
.ams-form .checkbox.state-error i:focus,
.ams-form .radio.state-error i:focus,
.ams-form .state-error input:focus,
.ams-form .state-error select:focus,
.ams-form .state-error textarea:focus,
.ams-form .toggle.state-error i:focus {
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(255, 60, 60, 0.6) !important;
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(255, 60, 60, 0.6) !important;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(255, 60, 60, 0.6) !important;
}
.ams-form .state-error .select2-container .select2-choice,
.ams-form .state-error .select2-container .select2-choices {
  border-color: rgba(255, 60, 60, 0.8) !important;
}
.ams-form .state-error .select2-container .select2-choice:focus,
.ams-form .state-error .select2-container .select2-choices:focus {
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(255, 60, 60, 0.6) !important;
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(255, 60, 60, 0.6) !important;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(255, 60, 60, 0.6) !important;
}
.ams-form .checkbox.state-success i,
.ams-form .radio.state-success i,
.ams-form .state-success input,
.ams-form .state-success select,
.ams-form .state-success textarea,
.ams-form .toggle.state-success i {
  background: #f0fff0;
  border-color: #7DC27D;
}
.ams-form .button.state-disabled,
.ams-form .checkbox.state-disabled,
.ams-form .input.state-disabled input,
.ams-form .radio.state-disabled,
.ams-form .select.state-disabled,
.ams-form .textarea.state-disabled,
.ams-form .toggle.state-disabled {
  cursor: default!important;
  opacity: .6!important;
}
.ams-form .checkbox.state-disabled:hover i,
.ams-form .input.state-disabled:hover input,
.ams-form .radio.state-disabled:hover i,
.ams-form .select.state-disabled:hover select,
.ams-form .textarea.state-disabled:hover textarea,
.ams-form .toggle.state-disabled:hover i {
  border-color: #e5e5e5!important;
}
.ams-form .state-disabled.checkbox input + i:after,
.ams-form .state-disabled.checkbox input:checked + i,
.ams-form .state-disabled.radio input + i:after,
.ams-form .state-disabled.radio input:checked + i,
.ams-form .state-disabled.toggle input:checked + i {
  border-color: #e5e5e5!important;
  color: #333!important;
}
.ams-form .ui-widget-content .ui-spinner-input {
  margin: 0;
  border: 0;
  -webkit-box-shadow: none!important;
  box-shadow: none!important;
  height: 29px;
}
.ams-form .state-error {
  color: #D56161;
}
.ams-form .state-error select + i {
  background: #FFF0F0;
  -webkit-box-shadow: 0 0 0 9px #FFF0F0;
  box-shadow: 0 0 0 9px #FFF0F0;
}
.ams-form .state-error + em {
  display: block;
  margin-top: 6px;
  padding: 0 1px;
  font-style: normal;
  font-size: 11px;
  line-height: 15px;
  color: #D56161;
}
.ams-form .state-success select + i {
  background: #f0fff0;
  -webkit-box-shadow: 0 0 0 9px #f0fff0;
  box-shadow: 0 0 0 9px #f0fff0;
}
.ams-form .state-disabled.radio input + i:after {
  background-color: #333;
}
.ams-form .form-tiny .form-group {
  padding: 0px 10px;
}
.ams-form .form-tiny .control-label {
  margin-top: 2px;
  margin-bottom: 3px;
  line-height: 14px;
}
.ams-form .form-tiny label.input span.textline-field {
  margin-top: 2px;
  margin-bottom: 3px;
  line-height: 14px;
}
.ams-form .form-nomargin .control-label,
.ams-form.form-nomargin .control-label {
  margin-top: 0;
  margin-bottom: 0;
}
.ams-form .form-nomargin label.input span.textline-field,
.ams-form.form-nomargin label.input span.textline-field {
  margin-top: 0;
  margin-bottom: 0;
}
.ams-form .form-nopadding .form-group,
.ams-form.form-nopadding .form-group {
  padding: 0 10px 1px;
}
.ams-form-modal {
  position: fixed;
  z-index: 1;
  display: none;
  width: 400px;
}
.ams-form-modal-overlay {
  position: fixed;
  top: 0;
  left: 0;
  display: none;
  width: 100%;
  height: 100%;
  background: rgba(0, 0, 0, 0.7);
}
.state-error .icon-append,
.state-error .icon-prepend {
  color: #ed1c24;
}
/*
 * X-editable - v1.5.0
 */
.editableform {
  margin-bottom: 0;
}
.editableform .control-group {
  margin-bottom: 0;
  white-space: nowrap;
}
.editableform .editable-date {
  padding: 0;
  margin: 0;
  float: left;
}
.editableform-loading {
  background: url(../img/loading.gif) center center no-repeat;
  height: 25px;
  width: auto;
  min-width: 25px;
}
.editable-buttons {
  display: inline-block;
  vertical-align: top;
  margin-left: 7px;
  zoom: 1;
  *display: inline;
}
.editable-buttons.editable-buttons-bottom {
  display: block;
  margin-top: 7px;
  margin-left: 0;
}
.editable-buttons .editable-cancel {
  margin-left: 7px;
}
.editable-buttons button.ui-button-icon-only {
  height: 24px;
  width: 30px;
}
.editable-inline .add-on .icon-th {
  margin-top: 3px;
  margin-left: 1px;
}
.editable-inline .editableform-loading {
  background-position: left 5px;
}
.editable-input {
  vertical-align: top;
  display: inline-block;
  width: auto;
  white-space: normal;
  zoom: 1;
  *display: inline;
}
.editable-input .datepicker {
  top: 0;
  left: 0;
  padding: 4px;
}
.editable-input .datepicker:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -7px;
  left: 6px;
}
.editable-input .datepicker:after {
  content: '';
  display: inline-block;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #fff;
  position: absolute;
  top: -6px;
  left: 7px;
}
.editable-input .datepicker > div {
  display: none;
}
.editable-input .datepicker table {
  width: 100%;
  min-width: 214px;
  margin: 0;
}
.editable-input .datepicker thead tr:first-child th {
  cursor: pointer;
}
.editable-input .datepicker thead tr:first-child th:hover {
  background: #eee;
}
.editable-input .datepicker td,
.editable-input .datepicker th {
  text-align: center;
  width: 24px;
  height: 20px;
}
.editable-input .datepicker th.switch {
  width: 145px;
}
.editable-input .datepicker th.next,
.editable-input .datepicker th.prev {
  font-size: 19.5px;
}
.editable-input .datepicker td span {
  display: block;
  width: 47px;
  height: 54px;
  line-height: 54px;
  float: left;
  margin: 2px;
  cursor: pointer;
}
.editable-input .datepicker td span:hover {
  background: #eee;
}
.editable-input .datepicker td span.active {
  background: #3276b1;
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-radius: 3px;
}
.editable-input .datepicker td span.old {
  color: #555;
}
.editable-input .datepicker td.day:hover {
  background: #eee;
  cursor: pointer;
}
.editable-input .datepicker td.day.disabled,
.editable-input .datepicker td.new,
.editable-input .datepicker td.old {
  color: #555;
}
.editable-input .datepicker td.active,
.editable-input .datepicker td.active:hover {
  background: #3276b1;
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-radius: 3px;
}
.editable-input .datepicker.prev i,
.editable-input .datepicker.next i {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 14px;
}
.editable-input .datepicker.prev i:before {
  content: "\f060";
}
.editable-input .datepicker.next i:before {
  content: "\f061";
}
.editable-checklist label {
  white-space: nowrap;
}
.editable-checklist label input[type=checkbox],
.editable-checklist label span {
  vertical-align: middle;
  margin: 0;
}
.editable-wysihtml5 {
  width: 566px;
  height: 250px;
}
.editable-pre-wrapped {
  white-space: pre-wrap;
}
.editable-container.editable-popup {
  max-width: none!important;
}
.editable-container.popover {
  width: auto;
}
.editable-container.editable-inline {
  display: inline-block;
  vertical-align: middle;
  width: auto;
  zoom: 1;
  *display: inline;
}
.editable-container.ui-widget {
  font-size: inherit;
  z-index: 9990;
}
.editable-click,
a.editable-click,
a.editable-click:hover {
  text-decoration: none;
  border-bottom: dashed 1px #08c;
}
.editable-click.editable-disabled,
a.editable-click.editable-disabled,
a.editable-click.editable-disabled:hover {
  color: #585858;
  cursor: default;
  border-bottom: 0;
}
.editable-empty,
.editable-empty:focus,
.editable-empty:hover {
  font-style: italic;
  color: #D14;
  text-decoration: none;
}
.editable-unsaved {
  font-weight: 700;
}
.editable-bg-transition {
  -webkit-transition: background-color 1400ms ease-out;
  transition: background-color 1400ms ease-out;
}
.form-horizontal .editable {
  padding-top: 5px;
  display: inline-block;
}
.editable-address {
  display: block;
  margin-bottom: 5px;
}
.editable-address span {
  width: 70px;
  display: inline-block;
}
.editable-clear {
  clear: both;
  font-size: .9em;
  text-decoration: none;
  text-align: right;
}
.editable-clear-x {
  background: url(../img/clear.png) center center no-repeat;
  display: block;
  width: 13px;
  height: 13px;
  position: absolute;
  opacity: .6;
  z-index: 100;
  top: 50%;
  right: 6px;
  margin-top: -6px;
}
.editable-clear-x:hover {
  opacity: 1;
}
.editable-error-block {
  max-width: 300px;
  margin: 5px 0 0;
  width: auto;
  white-space: normal;
}
.editable-error-block.ui-state-error {
  padding: 3px;
}
.editable-error {
  color: red;
}
.input-append.date .add-on i,
.input-prepend.date .add-on i {
  display: block;
  cursor: pointer;
  width: 16px;
  height: 16px;
}
/*
 * JQuery-UI widgets
 */
.ui-timepicker-div .ui-widget-header {
  margin-bottom: 8px;
}
.ui-timepicker-div dl {
  text-align: left;
}
.ui-timepicker-div dl dt {
  float: left;
  clear: left;
  padding: 0 0 0 5px;
}
.ui-timepicker-div dl dd {
  margin: 17px 10px 12px 40%;
}
.ui-timepicker-div td {
  font-size: 90%;
}
.ui-tpicker-grid-label {
  background: 0 0;
  border: 0;
  margin: 0;
  padding: 0;
}
.ui-timepicker-rtl {
  direction: rtl;
}
.ui-timepicker-rtl dl {
  text-align: right;
  padding: 0 5px 0 0;
}
.ui-timepicker-rtl dl dt {
  float: right;
  clear: right;
}
.ui-timepicker-rtl dl dd {
  margin: 0 40% 10px 10px;
}
#login {
  background: #fff;
  overflow: visible;
}
#login .container {
  border: 0;
}
#login #header {
  margin: 0;
  height: 71px;
  border-bottom: 1px solid #eee!important;
  overflow: hidden;
  padding: 0 30px;
  -webkit-background-clip: padding-box;
  border-width: 0;
  min-height: 28px;
  background: #f4f4f4!important;
  margin-bottom: 20px;
}
@media (min-width: 768px) and (max-width: 880px) {
  #login #header {
    padding: 0 5px!important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #login #header {
    padding: 0 5px!important;
  }
}
#login #header #logo {
  margin-top: 22px;
  margin-left: 0;
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #login #header #logo {
    margin-top: 22px;
  }
}
#login #header #logo img {
  width: 137px;
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  #login #header #logo img {
    width: 135px;
  }
}
#login-header-space {
  float: right;
  text-align: right;
  display: block;
  vertical-align: middle;
  line-height: 71px;
}
#login-header-space > :first-child {
  font-size: 13px;
  margin-right: 14px;
  vertical-align: -3px;
  font-weight: 400;
}
#login-header-space > * {
  display: inline-block;
}
#login-header-space .btn {
  font-weight: 700;
  text-transform: uppercase;
}
#login #main {
  background: #fff;
  margin: 0;
}
#login .hero {
  background-image: url(../img/gradient/login.png);
  background-repeat: no-repeat;
  background-position: 0 137px;
  height: 360px;
  width: 100%;
  float: left;
}
#login h4.paragraph-header {
  color: #565656;
  font-size: 15px;
  font-weight: 400;
  line-height: 22px;
  margin-top: 15px;
  width: 270px;
}
#login h5.about-heading {
  color: #565656;
  font-size: 15px;
  font-weight: 700;
  line-height: 24px;
  margin: 0 0 5px;
}
#login .login-header-big {
  font-weight: 400;
}
#login .login-desc-box-l {
  min-height: 350px;
  width: 50%;
}
#login .login-app-icons {
  vertical-align: top;
  margin-top: 90px;
  width: 300px;
}
.bootstrapWizard {
  display: block;
  list-style: none;
  padding: 0;
  position: relative;
  width: 100%;
}
.bootstrapWizard a:active,
.bootstrapWizard a:focus,
.bootstrapWizard a:hover {
  text-decoration: none;
}
.bootstrapWizard li {
  display: block;
  float: left;
  width: 25%;
  text-align: center;
  padding-left: 0;
}
.bootstrapWizard li:before {
  border-top: 3px solid #55606E;
  content: "";
  display: block;
  font-size: 0;
  overflow: hidden;
  position: relative;
  top: 11px;
  right: 1px;
  width: 100%;
  z-index: 1;
}
.bootstrapWizard li:first-child:before {
  left: 50%;
  max-width: 50%;
}
.bootstrapWizard li:last-child:before {
  max-width: 50%;
  width: 50%;
}
.bootstrapWizard li .step {
  background: #B2B5B9;
  color: #fff;
  display: inline;
  font-size: 15px;
  font-weight: 700;
  padding: 7px 13px;
  border: 3px solid transparent;
  border-radius: 50%;
  line-height: normal;
  position: relative;
  text-align: center;
  z-index: 2;
  -webkit-transition: all .1s linear 0s;
  transition: all .1s linear 0s;
}
.bootstrapWizard li .step i {
  font-size: 10px;
  font-weight: 400;
  position: relative;
  top: -1.5px;
}
.bootstrapWizard li.complete .step {
  background: #0aa66e;
  padding: 1px 6px;
  border: 3px solid #55606E;
}
.bootstrapWizard li.active .step,
.bootstrapWizard li.active.complete .step {
  background: #0091d9;
  color: #fff;
  font-weight: 700;
  padding: 7px 13px;
  font-size: 15px;
  border-radius: 50%;
  border: 3px solid #55606E;
}
.bootstrapWizard li .title {
  color: #bfbfbf;
  display: block;
  font-size: 13px;
  line-height: 15px;
  max-width: 100%;
  position: relative;
  table-layout: fixed;
  text-align: center;
  top: 20px;
  word-wrap: break-word;
  z-index: 104;
}
.bootstrapWizard li.active .title,
.bootstrapWizard li.complete .title {
  color: #2B3D53;
}
.wizard-actions {
  display: block;
  list-style: none;
  padding: 0;
  position: relative;
  width: 100%;
}
.wizard-actions li {
  display: inline;
}
.fuelux .wizard {
  position: relative;
  overflow: hidden;
  background-color: #f9f9f9;
  border: 1px solid #d4d4d4;
  border-radius: 4px;
  *zoom: 1;
  -webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
}
.fuelux .wizard:after,
.fuelux .wizard:before {
  display: table;
  line-height: 0;
  content: "";
}
.fuelux .wizard:after {
  clear: both;
}
.fuelux .wizard ul {
  width: 4000px;
  padding: 0;
  margin: 0;
  list-style: none outside none;
}
.fuelux .wizard ul.previous-disabled li.complete {
  cursor: default;
}
.fuelux .wizard ul.previous-disabled li.complete:hover {
  color: #356e35;
  cursor: default;
  background: #f3f4f5;
}
.fuelux .wizard ul.previous-disabled li.complete:hover .chevron:before {
  border-left-color: #f3f4f5;
}
.fuelux .wizard ul li {
  position: relative;
  float: left;
  height: 46px;
  padding: 0 20px 0 30px;
  margin: 0;
  font-size: 16px;
  line-height: 46px;
  color: #999;
  cursor: default;
  background: #ededed;
}
.fuelux .wizard ul li:first-child {
  padding-left: 20px;
  border-radius: 4px 0 0 4px;
}
.fuelux .wizard ul li.complete {
  color: #296829;
  background: #f3f4f5;
}
.fuelux .wizard ul li.complete:hover {
  cursor: pointer;
  background: #e7eff8;
}
.fuelux .wizard ul li.complete:hover .chevron:before {
  border-left: 14px solid #e7eff8;
}
.fuelux .wizard ul li.complete .chevron:before {
  border-left: 14px solid #f3f4f5;
}
.fuelux .wizard ul li.active {
  color: #3a87ad;
  background: #f1f6fc;
}
.fuelux .wizard ul li.active .chevron:before {
  border-left: 14px solid #f1f6fc;
}
.fuelux .wizard ul li .chevron {
  position: absolute;
  top: 0;
  right: -14px;
  z-index: 1;
  display: block;
  border: 24px solid transparent;
  border-right: 0;
  border-left: 14px solid #d4d4d4;
}
.fuelux .wizard ul li .chevron:before {
  position: absolute;
  top: -24px;
  right: 1px;
  display: block;
  border: 24px solid transparent;
  border-right: 0;
  border-left: 14px solid #ededed;
  content: "";
}
.fuelux .wizard ul li .badge {
  margin-right: 8px;
}
.fuelux .wizard .actions {
  position: absolute;
  right: 0;
  z-index: 2;
  float: right;
  padding-right: 15px;
  padding-left: 15px;
  line-height: 46px;
  vertical-align: middle;
  background-color: #eee;
  border-left: 1px solid #d4d4d4;
}
.fuelux .wizard .actions a {
  margin-right: 8px;
  font-size: 12px;
  line-height: 45px;
}
.fuelux .wizard .actions .btn-prev i {
  margin-right: 5px;
}
.fuelux .wizard .actions .btn-next i {
  margin-left: 5px;
}
.fuelux .fuelux .step-content .step-pane {
  display: none;
}
.fuelux .fuelux .step-content .active {
  display: block;
}
.fuelux .fuelux .step-content .active .btn-group .active {
  display: inline-block;
}
.ams-metro-tile {
  float: left;
  display: block;
  background-color: #fff;
  width: 100px;
  height: 70px;
  cursor: pointer;
  -webkit-box-shadow: inset 0 0 1px #FFC;
  box-shadow: inset 0 0 1px #FFC;
  border: 1px dotted #C5C5C5;
  text-decoration: none;
  color: #fff;
  font-weight: 300;
  font-smooth: always;
  margin: 0 10px 20px 0;
  padding: 5px;
  position: relative;
}
.ams-metro-tile:hover {
  z-index: 10;
  -webkit-transform: scale(1.07);
  -moz-transform: scale(1.07);
}
.ams-metro-tile.big-cubes {
  width: 120px;
  height: 120px;
}
.ams-metro-tile.double {
  width: 249px;
}
.ams-metro-tile:active {
  top: 1px;
  left: 1px;
}
.ams-metro-tile .iconbox {
  text-align: center;
}
.ams-metro-tile .iconbox i {
  display: block;
  margin: 15px auto 0;
  height: 75px;
}
.ams-metro-tile .iconbox span {
  display: block;
  text-align: left;
  line-height: 1em;
}
.ams-metro-tile .iconbox span > span {
  position: absolute;
  right: -5px;
  bottom: -10px;
  border-radius: 50%;
  padding: 6px 4px 3px;
  border: 1px solid #fff;
}
.client-form header {
  padding: 15px 13px;
  margin: 0;
  border-bottom-style: solid;
  border-bottom-color: rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
}
/*
 * Buttons
 */
.customfile-button {
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: 400;
  line-height: 1.428571429;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  border: 1px solid #ccc;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -o-user-select: none;
  user-select: none;
}
.btn,
a:link,
button {
  -webkit-tap-highlight-color: rgba(169, 3, 41, 0.5);
}
.btns {
  margin: 0;
  padding: 0;
  list-style: none;
}
.btns > li {
  display: inline-block;
  margin-bottom: 7px;
}
.btn {
  padding: 6px 12px;
  border-radius: 2px;
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
}
.btn:active {
  position: relative;
  top: 1px;
  left: 1px;
}
.btn.btn-ribbon {
  background-color: #5b6771;
  color: #fff;
  padding: 1px 5px;
  line-height: 20px;
  vertical-align: middle;
  height: 21px;
  display: block;
  border: 0;
  float: left;
  margin: 0 8px 0 0;
  cursor: pointer;
}
.btn.btn-ribbon > i {
  font-size: 111%;
}
.btn-xs {
  padding: 1px 5px;
  line-height: 1.3em;
}
.btn-sm {
  padding: 3px 10px;
}
.btn-lg {
  padding: 9px 15px;
}
.btn-xl {
  padding: 11px 15px;
}
.btn-circle {
  width: 30px;
  height: 30px;
  text-align: center;
  padding: 7px 0 5px;
  font-size: 12px;
  line-height: 18px;
  border-radius: 50%;
}
.btn-circle.btn-lg {
  width: 50px;
  height: 50px;
  padding: 9px 15px 7px;
  font-size: 18px;
  line-height: 30px;
  border-radius: 50%;
}
.btn-circle.btn-xl {
  width: 70px;
  height: 70px;
  padding: 11px 15px 9px;
  font-size: 24px;
  line-height: 50px;
  border-radius: 50%;
}
.btn-metro {
  margin: 0 0 20px;
  padding-top: 15px;
  padding-bottom: 15px;
}
.btn-metro > span {
  display: block;
  vertical-align: bottom;
  margin-top: 10px;
  text-transform: uppercase;
}
.btn-metro > span > span.label {
  position: absolute;
  top: 0;
  right: 0;
}
/*.btn-primary {
	background-color: #627685;
	border-color: #46545e;

	&:hover,
	&:focus,
	&:active,
	&.active,
	.open .dropdown-toggle& {
		background-color: rgba(91, 103, 113, 0.8);
		border-color: #46545e;
	}
}*/
.btn-label {
  position: relative;
  left: -12px;
  display: inline-block;
  padding: 7px 12px 5px;
  background: rgba(0, 0, 0, 0.15);
  border-radius: 3px 0 0 3px;
}
.btn-labeled {
  padding-top: 0;
  padding-bottom: 0;
}
.btn-select-tick i {
  display: none;
}
.btn-select-tick .btn:hover i {
  opacity: .3;
  display: block;
}
.btn-select-tick .active i {
  display: block;
  opacity: 1!important;
}
.btn-header.pull-right {
  margin-left: 6px;
}
@media (min-width: 768px) and (max-width: 979px) {
  .btn-header a {
    margin-top: 9px!important;
    /*width: 40px!important;*/
  }
}
@media (min-width: 768px) and (max-width: 880px) {
  .btn-header a {
    margin-top: 9px!important;
    /*width: 40px!important;*/
    /*height: 39px!important;*/
    line-height: 26px!important;
  }
}
@media (max-width: 767px) {
  .btn-header a {
    margin-top: 5px!important;
    width: 40px!important;
    height: 39px!important;
    line-height: 34px!important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .btn-header a {
    margin-top: 5px!important;
    width: 40px!important;
    height: 39px!important;
    line-height: 34px!important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .btn-header a {
    margin-top: 5px!important;
    width: 40px!important;
    height: 39px!important;
    line-height: 34px!important;
  }
}
.btn-header a > span {
  font-size: 13px;
  font-weight: 400;
  line-height: 30px;
  height: 30px;
  display: inline-block;
}
@media (min-width: 768px) and (max-width: 880px) {
  .btn-header.transparent a {
    border: 0!important;
    background: 0 0;
    margin-left: 0;
    width: 25px!important;
    -webkit-box-shadow: none!important;
    box-shadow: none!important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
}
@media (max-width: 767px) {
  .btn-header.transparent a:hover {
    color: #a90329;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .btn-header.transparent a {
    border: 0!important;
    background: 0 0;
    margin-left: 0;
    width: 25px!important;
    -webkit-box-shadow: none!important;
    box-shadow: none!important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .btn-header.transparent a {
    border: 0!important;
    background: 0 0;
    margin-left: 0;
    width: 25px!important;
    -webkit-box-shadow: none!important;
    box-shadow: none!important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
}
.btn-header > :first-child > a {
  border-radius: 2px;
  cursor: default!important;
  display: inline-block;
  font-weight: 700;
  height: 30px;
  min-width: 30px;
  padding: 3px;
  text-align: center;
  text-decoration: none!important;
  -moz-user-select: none;
  -webkit-user-select: none;
  background-color: #f8f8f8;
  background-image: -webkit-gradient(linear, left top, left bottom, from(#f8f8f8), to(#f1f1f1));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#f8f8f8), to(#f1f1f1));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
  border: 1px solid #bfbfbf;
  color: #6D6A69;
  font-size: 17px;
  margin: 10px 0 0;
}
.btn-header > :first-child > a:hover {
  border: 1px solid #bfbfbf;
  color: #222;
  -webkit-transition: all 0s;
  transition: all 0s;
  cursor: pointer;
  -webkit-box-shadow: inset 0 0 4px 1px rgba(0, 0, 0, 0.08);
  box-shadow: inset 0 0 4px 1px rgba(0, 0, 0, 0.08);
}
.btn-header > :first-child > a:active {
  background-color: #e8e8e8;
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #e8e8e8), color-stop(100%, #ededed));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#e8e8e8), to(#ededed));
  background-image: -webkit-linear-gradient(top, #e8e8e8 0, #ededed 100%);
  background-image: linear-gradient(to bottom, #e8e8e8 0, #ededed 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#e8e8e8', endColorstr='#ededed', GradientType=0);
  -webkit-box-shadow: inset 0 0 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 0 3px 1px rgba(0, 0, 0, 0.15);
}
.ribbon-button-alignment {
  padding-top: 10px;
  display: inline-block;
}
.ribbon-button-alignment.pull-right > .btn.btn-ribbon {
  margin: 0 0 0 8px;
}
.header-btn {
  margin-top: 5px;
}
/*
 * Widgets styles
 */
.widget-header > :first-child {
  margin: 13px 0;
}
.widget-toolbar {
  display: inline-block;
  position: relative;
  float: right;
  width: auto;
  height: 29px;
  line-height: 29px;
  border-left: 1px solid rgba(0, 0, 0, 0.09);
  cursor: pointer;
  padding: 0 8px;
  text-align: center;
}
.widget-toolbar.no-border {
  border-left: 0;
}
.widget-toolbar > :first-child {
  text-align: left;
}
.widget-toolbar .ams-form label.checkbox,
.widget-toolbar .ams-form label.radio {
  line-height: 29px;
}
.widget-toolbar .ams-form .icon-append,
.widget-toolbar .ams-form .icon-prepend {
  top: 3px!important;
}
.widget-toolbar.ams-form .icon-append,
.widget-toolbar.ams-form .icon-prepend {
  top: 3px!important;
}
.widget-toolbar > .ams-form {
  margin-top: 2px;
}
.widget-toolbar > .ams-form .toggle:last-child {
  font-size: 12px;
  line-height: 29px;
}
.widget-toolbar > .ams-form .checkbox input + i,
.widget-toolbar > .ams-form .radio input + i,
.widget-toolbar > .ams-form .toggle input + i {
  border-width: 1px;
  border-color: #C7C7C7!important;
  margin-top: -1px;
  -webkit-box-shadow: 0 1px 1px #FFF, 0 1px 1px #858585 inset;
  box-shadow: 0 1px 1px #FFF, 0 1px 1px #858585 inset;
}
.widget-toolbar .btn-group {
  margin-top: -3px;
}
.widget-toolbar > .btn {
  margin-top: -3px;
  font-size: 12px!important;
  padding: 1px 8px!important;
}
.widget-toolbar > .label {
  display: inline-block;
  vertical-align: middle;
  margin-top: -3px;
  text-align: center;
  font-size: 12px;
  padding: 4px 7px;
}
.widget-toolbar > .badge {
  padding: 5px;
  font-size: 14px;
  border-radius: 50%;
  font-weight: 400;
  min-width: 24px;
  text-align: center!important;
}
.widget-toolbar .progress {
  width: 130px;
  margin: 7px 0 0;
  height: 18px!important;
  font-size: 12px;
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #d1d1d1 inset;
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #d1d1d1 inset;
}
.widget-toolbar .progress-bar {
  font-size: 12px;
}
.widget-toolbar .pagination {
  margin: 4px 0;
}
.widget-toolbar .pagination > li > a {
  padding: 2px 7px;
}
.widget-toolbar .widget-text-input {
  max-width: 220px;
}
.widget-toolbar input[type=text] {
  height: 28px!important;
  margin-top: 2px;
}
.widget-body.no-padding {
  padding: 0;
  margin: 0;
}
.widget-body.no-padding .alert {
  margin: 5px 5px 0;
  padding: 10px;
  box-shadow: none!important;
  -webkit-box-shadow: none!important;
  border-radius: 0!important;
}
.widget-body > table {
  margin-bottom: 0;
}
.widget-body-ajax-loading::before {
  display: block;
  position: absolute;
  content: url(../img/ajax-loader.gif);
  padding-top: 18%;
  text-align: center;
  font-weight: 700;
  font-size: 16px;
  color: #fff;
  background: rgba(255, 255, 255, 0.4);
  height: 100%;
  z-index: 1;
  width: 100%;
}
.widget-body-ajax-loading:hover {
  cursor: wait!important;
}
.widget-body-toolbar,
.ams-form.widget-body-toolbar {
  display: block;
  padding: 8px 10px;
  margin: -13px -13px 13px;
  min-height: 42px;
  border-bottom: 1px solid #ccc;
  background: #fafafa;
}
.no-padding .widget-body-toolbar,
.no-padding .ams-form.widget-body-toolbar,
.no-padding.widget-body-toolbar,
.no-padding.ams-form.widget-body-toolbar {
  display: block;
  margin: 0;
}
.ams-form .widget-body-toolbar .inline-group,
.widget-body-toolbar.ams-form .inline-group {
  float: left;
  margin-top: 4px;
}
.widget-body-toolbar .btn {
  vertical-align: middle;
}
.widget-body-toolbar .btn-xs {
  margin-top: 5px;
}
.widget-content-padding {
  padding: 20px;
}
.widget-content-padding .well {
  margin-bottom: 0;
}
.widget-footer {
  display: block;
  position: relative;
  min-height: 32px;
  vertical-align: middle;
  margin: 0 -13px -13px;
  padding: 5px;
  border-top: 1px solid #E4E4E4;
  text-align: right;
  background-color: #F8F7F7;
}
.no-padding .widget-footer {
  margin: 0;
}
.widget-footer.ams-form > label {
  margin-top: 4px;
  display: block;
}
.ams-widget {
  position: relative;
  margin: 0 0 15px;
  padding: 0;
  -khtml-border-radius: 0;
  border-radius: 0;
}
.ams-widget header .nav-tabs {
  border-bottom-color: transparent;
}
.ams-widget header .nav-tabs > li > a {
  border-radius: 0;
  border: 0;
  padding: 5px 15px 4px;
}
.ams-widget header .nav-tabs > li.active > a,
.ams-widget header .nav-tabs > li.active > a:focus,
.ams-widget header .nav-tabs > li.active > a:hover {
  color: #555;
  background-color: #FFF;
  border: 1px solid #C2C2C2;
  border-bottom-color: transparent;
  border-top: 0;
  cursor: default;
}
.ams-widget header:first-child .nav-tabs {
  float: left;
}
.ams-widget header:first-child .nav-tabs li {
  padding-left: 0;
}
.ams-widget header:first-child .nav-tabs li a {
  color: #333333;
}
.ams-widget header:first-child .nav-tabs.pull-right li:last-child a {
  margin-right: 0 !important;
  border-right: 0 !important;
}
.ams-widget header .nav-pills {
  margin: 3px;
}
.ams-widget header .nav-pills > li > a {
  padding: 3px 5px 4px;
}
.ams-widget > header {
  height: 30px;
  padding: 0;
  line-height: 40px;
  color: #333333;
  border: 1px solid #C2C2C2;
  background: #fafafa;
}
.ams-widget > header h2 {
  display: inline-block;
  position: relative;
  width: auto;
  height: 100%;
  margin: 0;
  font-size: 14px;
  line-height: 31px;
  font-weight: 400;
  letter-spacing: 0;
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .ams-widget > header h2 {
    width: 135px;
    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden;
  }
}
.rtl .ams-widget > header h2 {
  float: right;
  text-align: right;
}
.ams-widget > header > h2 {
  margin-left: 10px;
  float: left;
}
.rtl .ams-widget > header {
  padding: 0 7px 0 0;
}
.ams-widget > header .widget-icon {
  display: block;
  float: left;
  width: 16px;
  height: 16px;
  margin: 10px 10px 0 0;
  zoom: 1;
  z-index: 400;
}
.rtl .ams-widget > header .widget-icon {
  float: right;
  margin: 10px 0 0 7px;
}
.ams-widget > header > .widget-icon {
  display: block;
  position: relative;
  float: left;
  margin: 0 -10px 0 2px;
  width: 28px;
  height: 28px;
  font-size: 111%;
  line-height: 29px;
  text-align: center;
}
.ams-widget > header > :first-child.widget-icon {
  margin-left: 0;
}
.ams-widget > div {
  position: relative;
  float: left;
  width: 100%;
  font-size: 13px;
  -khtml-border-radius: 0;
  border-radius: 0;
  margin: 0;
  padding: 13px 13px 0;
  background-color: #fff !important;
  border-width: 1px 1px 2px;
  border-style: solid;
  border-top: 0;
  border-right-color: #CCC !important;
  border-bottom-color: #CCC !important;
  border-left-color: #CCC !important;
}
.ams-widget .widget-body {
  position: relative;
  min-height: 100px;
  padding-bottom: 13px;
}
.ams-widget .widget-body.widget-hide-overflow {
  overflow: hidden;
}
.ams-widget.well {
  margin: 0 0 30px;
}
.ams-widget.well header {
  display: none;
}
.ams-widget.well > div {
  border: 0!important;
  box-shadow: none!important;
  -webkit-box-shadow: none!important;
}
.ams-widget.well.transparent .widget-body.no-padding {
  margin: 0 !important;
}
.ams-widget-ctrls {
  width: auto;
  float: right;
  padding: 0;
  margin: 0;
}
.ams-widget-ctrls a {
  display: inline-block;
  padding: 0;
  margin: 0;
  text-decoration: none;
  font-size: 14px;
  text-align: center;
  line-height: 29px;
  color: #333;
}
.ams-widget-ctrls .button-icon {
  position: relative;
  float: left;
  min-width: 28px;
  height: 28px;
  font-family: Ubuntu, Arial, Helvetica, sans-serif;
  border-left: 1px solid rgba(0, 0, 0, 0.09);
}
.ams-widget-ctrls .button-icon :hover {
  background-color: rgba(0, 0, 0, 0.05);
}
.rtl .ams-widget-ctrls .button-icon {
  margin: 0 0 5px 5px;
}
.rtl .ams-widget-ctrls {
  float: left;
  padding: 10px 0 0 3px;
  margin: 0;
}
.ams-widget-loader {
  display: none;
  float: right;
  width: 28px;
  height: 28px;
  margin: 0;
  text-align: center;
  line-height: 28px;
  background-repeat: no-repeat;
  background-position: center center;
}
.rtl .ams-widget-loader {
  float: left;
}
.ams-widget-editbox {
  display: none;
  padding: 10px;
  border-bottom: 1px solid #B1B1B1;
  background-color: #fff;
  margin: -13px -13px 13px;
}
.no-padding .ams-widget-editbox {
  margin: 0 0 10px;
}
.ams-widget,
.ams-widget-editbox,
.ams-widget > div {
  zoom: 1;
}
.ams-widget:after,
.ams-widget-editbox:after,
.ams-widget > div:after {
  clear: both;
}
.ams-widget:before,
.ams-widget-editbox:before,
.ams-widget > div:before,
.ams-widget:after,
.ams-widget-editbox:after,
.ams-widget > div:after {
  display: block;
  visibility: hidden;
  overflow: hidden;
  content: "\0020";
  height: 0;
  font-size: 0;
  line-height: 0;
}
.ui-sortable .ams-widget-sortable > header {
  cursor: move;
  line-height: normal;
  -khtml-border-radius: 0;
  border-radius: 0;
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
}
.ui-sortable .ams-widget-sortable.ams-widget-collapsed > header {
  -khtml-border-radius: 0;
  border-radius: 0;
}
.ams-widget-timestamp {
  margin: 10px 0 0;
  color: #868686;
  font-size: 12px;
  font-style: italic;
}
.ams-widget-placeholder {
  margin-bottom: 28px;
  padding: 0;
  background-color: #FFC;
  border: 1px dashed #A7A7A7;
  -khtml-border-radius: 0;
  border-radius: 0;
  -webkit-box-sizing: border-box;
  -khtml-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.ams-widget-remove-colors {
  color: #333 !important;
  padding: 0 !important;
  background: none !important;
}
.ams-widget-color-magenta > header {
  color: #ffffff;
  background: #6e3671;
  border-color: #6e3671 !important;
}
.ams-widget-color-magenta .nav-tabs li:not(.active) a,
.ams-widget-color-magenta > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-magenta .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-pink > header {
  color: #ffffff;
  background: #ac5287;
  border-color: #ac5287 !important;
}
.ams-widget-color-pink .nav-tabs li:not(.active) a,
.ams-widget-color-pink > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-pink .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-pinkDark > header {
  color: #ffffff;
  background: #a8829f;
  border-color: #a8829f !important;
}
.ams-widget-color-pinkDark .nav-tabs li:not(.active) a,
.ams-widget-color-pinkDark > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-pinkDark .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-yellow > header {
  color: #ffffff;
  background: #d4c737;
  border-color: #d4c737 !important;
}
.ams-widget-color-yellow .nav-tabs li:not(.active) a,
.ams-widget-color-yellow > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-yellow .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-orange > header {
  color: #ffffff;
  background: #c79121;
  border-color: #c79121 !important;
}
.ams-widget-color-orange .nav-tabs li:not(.active) a,
.ams-widget-color-orange > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-orange .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-orangeDark > header {
  color: #ffffff;
  background: #a57225;
  border-color: #a57225 !important;
}
.ams-widget-color-orangeDark .nav-tabs li:not(.active) a,
.ams-widget-color-orangeDark > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-orangeDark .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-darken > header {
  color: #ffffff;
  background: #404040;
  border-color: #404040 !important;
}
.ams-widget-color-darken .nav-tabs li:not(.active) a,
.ams-widget-color-darken > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-darken .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-purple > header {
  color: #ffffff;
  background: #65596b;
  border-color: #65596b !important;
}
.ams-widget-color-purple .nav-tabs li:not(.active) a,
.ams-widget-color-purple > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-purple .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-teal > header {
  color: #ffffff;
  background: #568a89;
  border-color: #568a89 !important;
}
.ams-widget-color-teal .nav-tabs li:not(.active) a,
.ams-widget-color-teal > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-teal .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-blueDark > header {
  color: #ffffff;
  background: #4c4f53;
  border-color: #4c4f53 !important;
}
.ams-widget-color-blueDark .nav-tabs li:not(.active) a,
.ams-widget-color-blueDark > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-blueDark .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-blue > header {
  color: #ffffff;
  background: #60747c;
  border-color: #60747c !important;
}
.ams-widget-color-blue .nav-tabs li:not(.active) a,
.ams-widget-color-blue > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-blue .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-blueLight > header {
  color: #ffffff;
  background: #ccdadf;
  border-color: #ccdadf !important;
}
.ams-widget-color-blueLight .nav-tabs li:not(.active) a,
.ams-widget-color-blueLight > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-blueLight .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-red > header {
  color: #ffffff;
  background: #931313;
  border-color: #931313 !important;
}
.ams-widget-color-red .nav-tabs li:not(.active) a,
.ams-widget-color-red > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-red .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-redLight > header {
  color: #ffffff;
  background: #a65858;
  border-color: #a65858 !important;
}
.ams-widget-color-redLight .nav-tabs li:not(.active) a,
.ams-widget-color-redLight > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-redLight .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-white > header {
  color: #c8c8c8;
  background: #ffffff;
  border-color: #c8c8c8 !important;
}
.ams-widget-color-white .nav-tabs li:not(.active) a,
.ams-widget-color-white > header > .ams-widget-ctrls a {
  color: #c8c8c8 !important;
}
.ams-widget-color-white .nav-tabs li a:hover {
  color: #838383 !important;
}
.ams-widget-color-greenDark > header {
  color: #ffffff;
  background: #496949;
  border-color: #496949 !important;
}
.ams-widget-color-greenDark .nav-tabs li:not(.active) a,
.ams-widget-color-greenDark > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-greenDark .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-green > header {
  color: #ffffff;
  background: #356e35;
  border-color: #356e35 !important;
}
.ams-widget-color-green .nav-tabs li:not(.active) a,
.ams-widget-color-green > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-green .nav-tabs li a:hover {
  color: #333333 !important;
}
.ams-widget-color-greenLight > header {
  color: #ffffff;
  background: #71843f;
  border-color: #71843f !important;
}
.ams-widget-color-greenLight .nav-tabs li:not(.active) a,
.ams-widget-color-greenLight > header > .ams-widget-ctrls a {
  color: #ffffff !important;
}
.ams-widget-color-greenLight .nav-tabs li a:hover {
  color: #333333 !important;
}
#ams-widget-fullscreen-mode {
  position: fixed;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  z-index: 99999;
}
#ams-widget-fullscreen-mode .ams-widget {
  margin: 0;
  -khtml-border-radius: 0;
  border-radius: 0;
}
#ams-widget-fullscreen-mode > div {
  overflow-y: scroll;
  -khtml-border-radius: 0;
  border-radius: 0;
}
#ams-widget-fullscreen-mode > div > header {
  cursor: default;
}
/*
 * On/off switch
 */
.onoffswitch {
  position: relative;
  width: 50px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  margin-top: 3px;
  margin-bottom: 3px;
  margin-left: 5px;
  display: inline-block;
  vertical-align: middle;
}
.onoffswitch-container {
  margin-top: 4px;
  margin-left: 7px;
  display: inline-block;
}
.onoffswitch-checkbox {
  display: none;
}
.onoffswitch-label {
  display: block;
  overflow: hidden;
  cursor: pointer;
  border: 1px solid #626262;
  border-radius: 50px;
  border-color: #adadad #b3b3b3 #9e9e9e;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.onoffswitch-inner {
  width: 200%;
  margin-left: -100%;
  display: block;
}
.onoffswitch-inner:after,
.onoffswitch-inner:before {
  float: left;
  width: 50%;
  height: 15px;
  padding: 0;
  line-height: 17px;
  font-size: 10px;
  font-family: Ubuntu, Trebuchet, Arial, sans-serif;
  font-weight: 700;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.onoffswitch-inner:before {
  content: attr(data-swchon-text);
  text-shadow: 0 -1px 0 #333333;
  padding-left: 7px;
  background-color: #3276b1;
  color: #fff;
  -webkit-box-shadow: inset 0 2px 6px rgba(0, 0, 0, 0.5), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 2px 6px rgba(0, 0, 0, 0.5), 0 1px 2px rgba(0, 0, 0, 0.05);
  text-align: left;
}
.onoffswitch-inner:after {
  content: attr(data-swchoff-text);
  padding-right: 7px;
  text-shadow: 0 -1px 0 #ffffff;
  background-color: #fff;
  color: #555;
  text-align: right;
  -webkit-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.onoffswitch-switch {
  width: 19px;
  height: 19px;
  margin: -2px;
  background: #fff;
  border: 1px solid #9a9a9a;
  border-radius: 50px;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 32px;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  background-color: #f4f4f4;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#eeeeee));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#ffffff), to(#eeeeee));
  background-image: -webkit-linear-gradient(top, #ffffff, #eeeeee);
  background-image: linear-gradient(to bottom, #ffffff, #eeeeee);
  background-repeat: repeat-x;
  -webkit-box-shadow: 1px 1px 4px 0 rgba(0, 0, 0, 0.3);
  box-shadow: 1px 1px 4px 0 rgba(0, 0, 0, 0.3);
}
.onoffswitch-checkbox + .onoffswitch-label .onoffswitch-switch:before,
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch:before {
  content: "\f00d";
  color: #a90329;
  display: block;
  text-align: center;
  line-height: 19px;
  font-size: 10px;
  text-shadow: 0 -1px 0 #ffffff;
  font-weight: 700;
  font-family: FontAwesome;
}
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch:before {
  content: "\f00c";
  color: #57889c;
}
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-inner {
  margin-left: 0;
  display: block;
}
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch {
  right: 0;
}
.onoffswitch-switch:hover {
  background-color: #eee;
}
.onoffswitch-switch:active {
  background-color: #eee;
  -webkit-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.onoffswitch-checkbox:checked:disabled + .onoffswitch-label .onoffswitch-inner:before,
.onoffswitch-checkbox:disabled + .onoffswitch-label .onoffswitch-inner:after {
  text-shadow: 0 1px 0 #fff;
  background: #bfbfbf;
  color: #333;
}
.onoffswitch-checkbox:checked:disabled + .onoffswitch-label .onoffswitch-switch,
.onoffswitch-checkbox:disabled + .onoffswitch-label .onoffswitch-switch {
  background-color: #f4f4f4;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#bfbfbf), to(#f4f4f4));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#bfbfbf), to(#f4f4f4));
  background-image: -webkit-linear-gradient(top, #bfbfbf, #f4f4f4);
  background-image: linear-gradient(to bottom, #bfbfbf, #f4f4f4);
  -webkit-box-shadow: none!important;
  box-shadow: none!important;
}
.onoffswitch-checkbox:checked:disabled + .onoffswitch-label .onoffswitch-label,
.onoffswitch-checkbox:disabled + .onoffswitch-label {
  border-color: #ababab #999 #878787!important;
}
.onoffswitch-checkbox:checked + .onoffswitch-label {
  border-color: #3276b1 #2a6395 #255681;
}
.onoffswitch + span,
.onoffswitch-title {
  display: inline-block;
  vertical-align: middle;
  margin-top: -5px;
}
/*
 * Select2 widget
 */
label.with-icon .select2-parent {
  margin-right: 27px;
}
label.with-icons .select2-parent {
  margin-right: 54px;
}
.select2-container {
  margin: 0;
  position: relative;
  display: inline-block;
  zoom: 1;
  *display: inline;
  vertical-align: middle;
}
.select2-container .select2-choice {
  display: block;
  height: 26px;
  padding: 0 0 0 8px;
  overflow: hidden;
  position: relative;
  border: 1px solid #ccc;
  white-space: nowrap;
  line-height: 26px;
  color: #444;
  text-decoration: none;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  background-color: #fff;
}
label.bordered .select2-container .select2-choice {
  border-color: transparent;
}
.select2-container .select2-choice:hover {
  border: 1px solid rgba(82, 168, 236, 0.7);
}
.select2-container .select2-choice > .select2-chosen {
  margin-right: 26px;
  display: block;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.select2-container .select2-choice > .select2-chosen abbr {
  display: none;
  width: 12px;
  height: 12px;
  position: absolute;
  right: 24px;
  top: 8px;
  font-size: 1px;
  text-decoration: none;
  border: 0;
  cursor: pointer;
  outline: 0;
}
.select2-container .select2-choice > .select2-chosen abbr:hover {
  cursor: pointer;
}
.select2-container.select2-drop-above .select2-choice {
  border-bottom-color: #ccc;
}
.select2-container.select2-allowclear .select2-choice .select2-chosen {
  margin-right: 42px;
}
.select2-container.select2-allowclear .select2-choice abbr {
  display: inline-block;
}
.select2-container .select2-arrow {
  display: inline-block;
  width: 20px;
  height: 20px;
  position: absolute;
  right: 3px;
  top: 3px;
  padding: 0 0 0 2px;
  border-left: 1px solid #ccc;
  line-height: 22px;
  -webkit-background-clip: padding-box;
}
.select2-container .select2-arrow b {
  width: 100%;
  height: 100%;
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  position: relative;
  font-size: 14px;
}
.select2-container .select2-arrow b:before {
  content: "\f107";
  width: 100%;
  height: 100%;
  text-align: center;
  display: block;
}
.select2-container,
.select2-drop,
.select2-search,
.select2-search input {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.select2-container-active .select2-choice,
.select2-container-active .select2-choices {
  border: 1px solid rgba(82, 168, 236, 0.7) !important;
  outline: 0;
}
.select2-drop-mask {
  border: 0;
  margin: 0;
  padding: 0;
  position: fixed;
  left: 0;
  top: 0;
  min-height: 100%;
  min-width: 100%;
  height: auto;
  width: auto;
  opacity: 0;
  z-index: 9998;
  background: #fff;
  filter: alpha(opacity=0);
}
.select2-drop {
  margin-top: -1px;
  width: 100%;
  position: absolute;
  z-index: 9999;
  top: 100%;
  background: #fff;
  color: #000;
  border: 1px solid #ccc;
  border-top: 0;
  -webkit-box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
  box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
}
.select2-drop.select2-drop-above {
  margin-bottom: 0;
  border-top: 1px solid rgba(82, 168, 236, 0.7);
  border-top-width: 3px;
  border-bottom: 0;
  -webkit-box-shadow: 0 -4px 5px rgba(0, 0, 0, 0.15);
  box-shadow: 0 -4px 5px rgba(0, 0, 0, 0.15);
}
.select2-drop.select2-drop-above.select2-drop-active {
  border-top-width: 3px;
}
.select2-drop.select2-drop-above .select2-search input {
  margin-top: 4px;
}
.select2-drop.select2-drop-above .select2-search:before {
  top: 34%;
}
.select2-drop-auto-width {
  border-top: 1px solid #ccc;
  width: auto;
}
.select2-drop-auto-width .select2-search {
  padding-top: 4px;
}
.select2-drop-active {
  border: 1px solid rgba(82, 168, 236, 0.7);
  border-top: 0;
  border-bottom-width: 3px;
}
.select2-search {
  display: inline-block;
  width: 100%;
  min-height: 26px;
  margin: 0;
  padding-left: 4px;
  padding-right: 4px;
  position: relative;
  z-index: 10000;
  white-space: nowrap;
}
.select2-search:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  position: absolute;
  content: "\f002";
  top: 25%;
  right: 10px;
  color: #686868!important;
}
.select2-search input {
  width: 100%;
  height: auto!important;
  min-height: 26px;
  padding: 4px 20px 3px 5px;
  margin: 0;
  outline: 0;
  font-size: 1em;
  border: 1px solid #aaa;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: #fff;
  background: -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: -webkit-gradient(linear, top left, bottom left, from(#ffffff), to(#eeeeee));
  background: -webkit-linear-gradient(top, #ffffff 85%, #eeeeee 99%);
  background: linear-gradient(top, #ffffff 85%, #eeeeee 99%);
}
.select2-search input.select2-active {
  background-origin: padding-box;
  background: #ffffff url(../img/select2-spinner.gif) no-repeat right 24px top 50%;
  background: url(../img/select2-spinner.gif) no-repeat right 24px top 50%, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: url(../img/select2-spinner.gif) no-repeat right 24px top 50%, -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url(../img/select2-spinner.gif) no-repeat right 24px top 50%, -webkit-gradient(linear, top left, bottom left, from(#ffffff), to(#eeeeee));
  background: url(../img/select2-spinner.gif) no-repeat right 24px top 50%, -webkit-linear-gradient(top, #ffffff 85%, #eeeeee 99%);
  background: url(../img/select2-spinner.gif) no-repeat right 24px top 50%, linear-gradient(top, #ffffff 85%, #eeeeee 99%);
}
.select2-dropdown-open .select2-choice {
  border-bottom-color: transparent;
  -webkit-box-shadow: 0 1px 0 #fff inset;
  box-shadow: 0 1px 0 #fff inset;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  background-color: #fff;
}
.select2-dropdown-open.select2-drop-above .select2-choice,
.select2-dropdown-open.select2-drop-above .select2-choices {
  border: 1px solid #5D98CC;
  border-top-color: transparent;
}
.select2-dropdown-open .select2-choice .select2-arrow {
  background: 0 0;
  border-left: 0;
  -webkit-filter: none;
  filter: none;
}
.select2-dropdown-open .select2-choice .select2-arrow b {
  background-position: -18px 1px;
}
.select2-results {
  max-height: 200px;
  padding: 0 0 0 4px;
  margin: 4px 4px 4px 0;
  position: relative;
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}
.select2-results .select2-selected {
  opacity: 0.5;
}
.select2-results ul.select2-result-sub {
  margin: 0;
  padding-left: 0;
}
.select2-results ul.select2-result-sub > li .select2-result-label {
  padding-left: 20px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 40px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 60px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 80px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 100px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 110px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 120px;
}
.select2-results li {
  list-style: none;
  display: list-item;
  background-image: none;
}
.select2-results li.select2-result-with-children > .select2-result-label {
  font-weight: 700;
}
.select2-results .select2-result-label {
  padding: 3px 7px 4px;
  margin: 0;
  cursor: pointer;
  min-height: 1em;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.select2-results .select2-highlighted {
  background: #3276b1;
  color: #fff;
}
.select2-results li em {
  background: #feffde;
  font-style: normal;
}
.select2-results .select2-highlighted em {
  background: 0 0;
}
.select2-results .select2-highlighted ul {
  background: #fff;
  color: #000;
}
.select2-results .select2-no-results,
.select2-results .select2-searching,
.select2-results .select2-selection-limit {
  background: #f4f4f4;
  display: list-item;
  padding: 3px 5px;
  opacity: 0.5;
}
.select2-results-results .select2-disabled {
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
.select2-results-results .select2-disabled.select2-highlighted {
  color: #666;
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
.select2-results-results .select2-selected {
  display: none;
}
.select2-no-results {
  padding-left: 20px;
}
.select2-no-results:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f05a";
  margin-right: 5px;
}
.select2-more-results {
  background: #f4f4f4;
  display: list-item;
}
.select2-more-results.select2-active {
  background: #f4f4f4 url(../img/select2-spinner.gif) no-repeat 100%;
}
.select2-default {
  color: #999!important;
}
.select2-container.select2-container-disabled .select2-choice {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
.select2-container.select2-container-disabled .select2-choice .select2-arrow {
  background-color: #f4f4f4;
  background-image: none;
  border-left: 0;
}
.select2-container.select2-container-disabled .select2-choice abbr {
  display: none;
}
.select2-container-multi.select2-container-active .select2-choices {
  border: 1px solid rgba(82, 168, 236, 0.7);
  outline: 0;
}
.select2-container-multi .select2-choices {
  height: auto!important;
  height: 1%;
  min-height: 26px;
  margin: 0;
  padding: 0;
  position: relative;
  border: 1px solid #ccc;
  cursor: text;
  overflow: hidden;
  background-color: #fff;
}
label.bordered .select2-container-multi .select2-choices {
  border-color: transparent;
}
.select2-container-multi .select2-choices:hover {
  border: 1px solid rgba(82, 168, 236, 0.7) !important;
}
label.bordered .select2-container-multi .select2-choices:hover {
  border-color: transparent !important;
}
.select2-container-multi .select2-choices li {
  float: left;
  list-style: none;
}
.select2-container-multi .select2-choices .select2-search-field {
  margin: 0;
  padding: 0;
  white-space: nowrap;
}
.select2-container-multi .select2-choices .select2-search-field input {
  max-height: 24px;
  padding: 3px 5px;
  margin: 1px 0;
  font-family: Ubuntu, sans-serif;
  font-size: 100%;
  color: #666;
  outline: 0;
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: transparent!important;
}
.select2-container-multi .select2-choices .select2-search-field input.select2-active {
  background: #ffffff url(../img/select2-spinner.gif) no-repeat 99% !important;
}
.select2-container-multi .select2-choices .select2-search-choice {
  padding: 1px 28px 1px 8px;
  margin: 2px 0 2px 2px;
  position: relative;
  line-height: 18px;
  color: #fff;
  cursor: default;
  border: 1px solid #2a6395;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  background-color: #3276b1;
}
.select2-container-multi .select2-choices .select2-search-choice .select2-chosen {
  cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice-focus {
  opacity: .8;
}
.select2-container-multi .select2-search-choice-close {
  display: block;
  top: 0;
  right: -2px;
  padding: 3px 0px 3px 6px;
}
.select2-container-multi .select2-search-choice-close:hover {
  background: rgba(0, 0, 0, 0.3);
}
.select2-container-multi.select2-container-disabled .select2-choices {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice {
  padding: 3px 5px;
  border: 1px solid #4a90cc;
  background-image: none;
  background-color: #86b4dd;
  cursor: not-allowed;
}
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close {
  display: none;
  background: 0 0;
}
.select2-locked {
  padding: 3px 5px!important;
}
.select2-search-choice-close {
  display: block;
  min-width: 20px;
  min-height: 14px;
  position: absolute;
  right: 3px;
  top: 3px;
  margin: 0;
  padding: 0;
  font-size: 15px;
  text-decoration: none!important;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.select2-search-choice-close:before {
  color: #fff;
  content: "\f057";
}
.select2-result-selectable .select2-match,
.select2-result-unselectable .select2-match {
  text-decoration: underline;
}
.select2-offscreen,
.select2-offscreen:focus {
  clip: rect(0 0 0 0) !important;
  width: 1px!important;
  height: 1px!important;
  border: 0!important;
  margin: 0!important;
  padding: 0!important;
  overflow: hidden!important;
  position: absolute!important;
  outline: 0!important;
  left: 0!important;
  top: 0!important;
}
.select2-display-none {
  display: none;
}
.select2-measure-scrollbar {
  position: absolute;
  top: -10000px;
  left: -10000px;
  width: 100px;
  height: 100px;
  overflow: scroll;
}
.multiselect-container {
  position: absolute;
  list-style-type: none;
  margin: 0;
  padding: 0;
}
.multiselect-container .input-group {
  margin: 5px;
}
.multiselect-container > li {
  padding: 0;
}
.multiselect-container > li > a.multiselect-all label {
  font-weight: 700;
}
.multiselect-container > li > a > label {
  margin: 0;
  height: 100%;
  cursor: pointer;
  font-weight: 400;
}
.multiselect-container > li > a > label.checkbox,
.multiselect-container > li > a > label.radio {
  margin: 0;
}
.multiselect-container > li > a > label > input[type=checkbox] {
  margin-bottom: 5px;
}
.multiselect-container > li > label.multiselect-group {
  margin: 0;
  padding: 3px 20px;
  height: 100%;
  font-weight: 700;
}
.btn-group > .btn-group:nth-child(2) > .multiselect.btn {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
/*
 * Standard Bootstrap widgets
 */
.color-select {
  list-style: none;
  margin: 0;
  padding: 4px;
  min-width: 166px;
  max-width: 156px;
  right: -3px;
}
.color-select li {
  display: block;
  margin: 2px;
  float: left;
}
.color-select li span {
  display: block;
  width: 22px;
  height: 22px;
  padding: 0;
  background: #333;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  border: 1px solid rgba(0, 0, 0, 0.1);
  cursor: pointer;
}
.color-select li span:hover {
  border: 3px solid rgba(0, 0, 0, 0.2);
}
.widget-toolbar .dropdown-menu.color-select {
  right: -1px;
}
.color-box {
  display: block;
  position: relative;
  width: 22px;
  height: 22px;
  padding: 0;
  background: #333;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  border: 1px solid rgba(255, 255, 255, 0.3) !important;
  cursor: pointer;
  vertical-align: middle;
  outline: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(255, 255, 255, 0.3) !important;
}
.color-box:hover,
.open .color-box {
  outline: 1px solid rgba(0, 0, 0, 0.1) !important;
}
.color-box:hover {
  -webkit-transform: scale(1.07);
  -moz-transform: scale(1.07);
}
.color-box:active {
  top: 1px;
  left: 1px;
}
.widget-toolbar > .color-box {
  margin-top: 7px;
  width: 18px;
  height: 18px;
  outline: 1px solid rgba(0, 0, 0, 0.2);
}
.widget-toolbar > .color-box:active,
.widget-toolbar > .color-box:focus,
.widget-toolbar > .color-box:hover {
  outline: 1px solid rgba(0, 0, 0, 0.25) !important;
}
/*
 * Full calendar
 */
.ams-widget #calendar {
  margin-top: -18px;
}
#calendar-buttons {
  position: absolute;
  right: 14px;
  top: 5px;
}
#calendar-container {
  position: relative;
}
#external-events > li {
  margin: 6px 4px 6px 0;
  display: inline-block;
}
#external-events > li > :first-child {
  padding: 5px 10px 10px;
  cursor: move;
  display: block;
}
#external-events > li > :first-child:after {
  color: #fff;
  color: rgba(255, 255, 255, 0.7);
  content: attr(data-description);
  font-size: 11px;
  font-weight: 400;
  display: block;
  line-height: 0;
  margin: 7px 0;
  text-transform: lowercase;
}
.fc {
  direction: ltr;
  text-align: left;
}
.fc .fc-header-space {
  padding-left: 10px;
}
.fc table,
html .fc {
  font-size: 12px;
}
.fc table {
  border-collapse: collapse;
  border-spacing: 0;
}
.fc th,
.fc td {
  padding: 0;
  vertical-align: top;
}
.fc .ui-resizable-handle {
  display: block;
  position: absolute;
  z-index: 99999;
  overflow: hidden;
  font-size: 300%;
  line-height: 50%;
}
.fc .ui-draggable-dragging .fc-event-bg {
  display: none;
}
.fc-border-separate thead tr,
.fc-border-separate .table thead tr {
  background-color: #eee;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f2f2f2), to(#fafafa));
  background-image: -webkit-linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  background-image: -linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  font-size: 12px;
}
.fc-border-separate thead tr th {
  padding: 4px;
  line-height: 1.428571429;
}
tr td.fc-first,
tr.fc-first th.fc-first {
  border-left: 0;
}
tr.fc-last td {
  border-bottom: 0;
}
.fc-header .fc-button {
  margin-bottom: 1em;
  vertical-align: top;
  margin-right: -1px;
}
.fc-header .fc-corner-right {
  margin-right: 1px;
}
.fc-header .ui-corner-right {
  margin-right: 0;
}
.fc-header .fc-state-hover,
.fc-header .ui-state-hover {
  z-index: 2;
}
.fc-header .fc-state-down {
  z-index: 3;
}
.fc-header .fc-state-active,
.fc-header .ui-state-active {
  z-index: 4;
}
.fc-header td {
  white-space: nowrap;
}
.fc-header-left {
  width: 25%;
  text-align: left;
}
.fc-header-center {
  text-align: center;
}
.fc-header-right {
  width: 25%;
  text-align: right;
}
.fc-header-title {
  display: inline-block;
  vertical-align: top;
}
.fc-header-title h2 {
  margin-top: 0;
  white-space: nowrap;
}
.ams-widget .fc-header-title h2 {
  text-shadow: 0 1px 0 #fff;
  margin-top: -12px;
  margin-left: 10px;
  font-size: 14px;
  font-weight: 700;
  margin-bottom: 0;
}
.fc-content {
  clear: both;
}
.fc-view {
  width: 100%;
  overflow: hidden;
}
.fc-widget-content,
.fc-widget-header {
  border: 1px solid #ccc;
  border-right: 0;
}
.fc-state-highlight {
  background: #ffc;
}
.fc-cell-overlay {
  background: #9cf;
  opacity: .2;
  filter: alpha(opacity=20);
}
.fc-button {
  position: relative;
  display: inline-block;
  cursor: pointer;
}
.fc-button-inner {
  position: relative;
  float: left;
  overflow: hidden;
}
.fc-state-default {
  border-width: 1px 0;
}
.fc-state-default .fc-button-inner {
  border-width: 0 1px;
}
.fc-state-default,
.fc-state-default .fc-button-inner {
  border-style: solid;
  border-color: #ccc #bbb #aaa;
  background: #F3F3F3;
  color: #000;
}
.fc-state-default .fc-button-effect {
  position: absolute;
  top: 50%;
  left: 0;
}
.fc-state-default .fc-button-effect span {
  position: absolute;
  top: -100px;
  left: 0;
  width: 500px;
  height: 100px;
  border-width: 100px 0 0 1px;
  border-style: solid;
  border-color: #fff;
  background: #444;
  opacity: .09;
  filter: alpha(opacity=9);
}
.fc-state-hover .fc-button-inner {
  border-color: #999;
}
.fc-state-down .fc-button-inner {
  border-color: #555;
  background: #777;
}
.fc-state-active .fc-button-inner {
  border-color: #555;
  background: #777;
  color: #fff;
}
.fc-state-disabled {
  cursor: default;
}
.fc-state-disabled .fc-button-inner {
  color: #999;
  border-color: #ddd;
}
.fc-state-disabled .fc-button-effect {
  display: none;
}
.fc-button-content {
  position: relative;
  float: left;
  height: 1.9em;
  line-height: 1.9em;
  padding: 0 .6em;
  white-space: nowrap;
}
.fc-button-content .fc-icon-wrap {
  position: relative;
  float: left;
  top: 50%;
}
.fc-button-content .ui-icon {
  position: relative;
  float: left;
  margin-top: -50%;
  *margin-top: 0;
  *top: -50%;
}
.fc-event {
  border-style: solid;
  border-width: 0;
  font-size: .85em;
  cursor: default;
}
.fc-rtl .fc-event {
  text-align: right;
}
.fc-event-draggable,
a.fc-event {
  cursor: pointer;
}
a.fc-event {
  text-decoration: none;
}
.fc-event-skin {
  color: #FFF;
  border-right: 0!important;
  cursor: move;
}
.fc-event-skin .fa:before {
  display: block;
  font-size: 14px;
  position: absolute;
  right: 4px;
  top: 3px;
}
.fc-event-inner {
  position: relative;
  width: 100%;
  height: 100%;
  border-style: solid;
  border-width: 0;
  overflow: hidden;
}
.fc-event-hori {
  border-width: 1px 0;
  margin-bottom: 1px;
}
.fc-event-hori .ui-resizable-e {
  top: 0!important;
  right: -3px !important;
  width: 7px!important;
  height: 100%!important;
  cursor: e-resize;
}
.fc-event-hori .ui-resizable-w {
  top: 0!important;
  left: -3px !important;
  width: 7px!important;
  height: 100%!important;
  cursor: w-resize;
}
.fc-event-hori .ui-resizable-handle {
  _padding-bottom: 14px;
}
.fc-corner-left {
  margin-left: 1px;
}
.fc-corner-left .fc-button-inner,
.fc-corner-left .fc-event-inner {
  margin-left: -1px;
}
.fc-corner-right {
  margin-right: 1px;
}
.fc-corner-right .fc-button-inner,
.fc-corner-right .fc-event-inner {
  margin-right: -1px;
}
.fc-corner-right .fc-event-inner {
  border-left: 6px solid rgba(0, 0, 0, 0.15);
  padding-left: 2px;
  padding-right: 15px;
}
.fc-corner-top {
  margin-top: 1px;
}
.fc-corner-top .fc-event-inner {
  margin-top: -1px;
  border-top-width: 1px;
}
.fc-corner-bottom {
  margin-bottom: 1px;
}
.fc-corner-bottom .fc-event-inner {
  margin-bottom: -1px;
  border-bottom-width: 1px;
}
table.fc-table-separate {
  border-collapse: separate;
}
.fc-table-separate td,
.fc-table-separate th {
  border-width: 1px 0 0 1px;
}
.fc-table-separate td.fc-last,
.fc-table-separate th.fc-last {
  border-right-width: 1px;
}
.fc-table-separate tr.fc-last td,
.fc-table-separate tr.fc-last th {
  border-bottom-width: 1px;
}
.fc-table-separate tbody tr.fc-first td,
.fc-table-separate tbody tr.fc-first th {
  border-top-width: 0;
}
.fc-grid th {
  text-align: center;
}
.fc-grid .fc-day-number {
  float: right;
  padding: 0 2px;
}
.fc-grid .fc-other-month .fc-day-number {
  opacity: .3;
  filter: alpha(opacity=30);
}
.fc-grid .fc-day-content {
  clear: both;
  padding: 2px 2px 1px;
}
.fc-grid .fc-event-time {
  font-weight: 700;
}
.fc-rtl .fc-grid .fc-day-number {
  float: left;
}
.fc-rtl .fc-grid .fc-event-time {
  float: right;
}
.fc-agenda table {
  border-collapse: separate;
}
.fc-agenda .fc-agenda-axis {
  width: 50px;
  padding: 0 4px;
  vertical-align: middle;
  text-align: right;
  white-space: nowrap;
  font-weight: 400;
}
.fc-agenda .fc-day-content {
  padding: 2px 2px 1px;
}
.fc-agenda-days th {
  text-align: center;
}
.fc-agenda-days .fc-agenda-axis {
  border-right-width: 1px;
}
.fc-agenda-days .fc-col0 {
  border-left-width: 0;
}
.fc-agenda-allday th {
  border-width: 0 1px;
}
.fc-agenda-allday .fc-day-content {
  min-height: 34px;
  _height: 34px;
}
.fc-agenda-divider-inner {
  height: 2px;
  overflow: hidden;
}
.fc-widget-header .fc-agenda-divider-inner {
  background: #eee;
}
.fc-agenda-slots th {
  border-width: 1px 1px 0;
}
.fc-agenda-slots td {
  border-width: 1px 0 0;
  background: 0 0;
}
.fc-agenda-slots td div {
  height: 20px;
}
.fc-agenda-slots tr.fc-slot0 td,
.fc-agenda-slots tr.fc-slot0 th {
  border-top-width: 0;
}
.fc-agenda-slots tr.fc-minor td,
.fc-agenda-slots tr.fc-minor th {
  border-top-style: dotted;
}
.fc-agenda-slots tr.fc-minor th.ui-widget-header {
  *border-top-style: solid;
}
.fc-event-time,
.fc-event-title {
  padding: 3px 0 2px 3px;
  display: inline-block;
  line-height: 16px;
  font-weight: 700;
  font-size: 11px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.fc-event-vert {
  border-width: 0 1px;
}
.fc-event-vert .fc-event-content,
.fc-event-vert .fc-event-head {
  position: relative;
  z-index: 2;
  width: 100%;
  overflow: hidden;
}
.fc-event-vert .fc-event-time {
  white-space: nowrap;
  font-size: 10px;
}
.fc-event-vert .fc-event-bg {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: #fff;
  opacity: .3;
  filter: alpha(opacity=30);
}
.fc-event-vert .ui-resizable-s {
  bottom: 0!important;
  width: 100%!important;
  height: 8px!important;
  overflow: hidden!important;
  line-height: 8px!important;
  font-size: 11px!important;
  font-family: monospace;
  text-align: center;
  cursor: s-resize;
}
.fc-select-helper .fc-event-bg {
  display: none;
}
.fc-agenda .ui-resizable-resizing {
  _overflow: hidden;
}
/*
 * Colorpicker
 */
.colorpicker {
  zoom: 1;
  top: 0;
  left: 0;
  padding: 4px;
  min-width: 120px;
  margin-top: 1px;
  border-top-right-radius: 4px;
  border-top-left-radius: 4px;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}
.colorpicker:after {
  clear: both;
}
.colorpicker:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -7px;
  left: 6px;
}
.colorpicker:after {
  content: '';
  display: inline-block;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #fff;
  position: absolute;
  top: -6px;
  left: 7px;
}
.colorpicker.alpha {
  min-width: 140px;
}
.colorpicker.alpha .colorpicker-alpha {
  display: block;
}
.colorpicker div {
  position: relative;
}
.colorpicker-saturation {
  width: 100px;
  height: 100px;
  background-image: url(../img/saturation.png);
  cursor: crosshair;
  float: left;
}
.colorpicker-saturation i {
  display: block;
  height: 5px;
  width: 5px;
  border: 1px solid #000;
  position: absolute;
  top: 0;
  left: 0;
  margin: -4px 0 0 -4px;
}
.colorpicker-saturation i b {
  display: block;
  height: 5px;
  width: 5px;
  border: 1px solid #fff;
}
.colorpicker-color {
  height: 10px;
  margin-top: 5px;
  clear: both;
  background-image: url(../img/alpha.png);
  background-position: 0 100%;
}
.colorpicker-color div {
  height: 10px;
}
.colorpicker-alpha,
.colorpicker-hue {
  width: 15px;
  height: 100px;
  float: left;
  cursor: row-resize;
  margin-left: 4px;
  margin-bottom: 4px;
}
.colorpicker-alpha i,
.colorpicker-hue i {
  display: block;
  height: 1px;
  background: #000;
  border-top: 1px solid #fff;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  margin-top: -1px;
}
.colorpicker-hue {
  background-image: url(../img/hue.png);
}
.colorpicker-alpha {
  background-image: url(../img/alpha.png);
  display: none;
}
.input-append.color .add-on i,
.input-prepend.color .add-on i {
  display: block;
  cursor: pointer;
  width: 16px;
  height: 16px;
}
/*
 * Timepicker
 */
.bootstrap-timepicker {
  position: relative;
}
.bootstrap-timepicker.pull-right .bootstrap-timepicker-widget.dropdown-menu {
  left: auto;
  right: 0;
}
.bootstrap-timepicker.pull-right .bootstrap-timepicker-widget.dropdown-menu:before {
  left: auto;
  right: 12px;
}
.bootstrap-timepicker.pull-right .bootstrap-timepicker-widget.dropdown-menu:after {
  left: auto;
  right: 13px;
}
.bootstrap-timepicker .add-on {
  cursor: pointer;
}
.bootstrap-timepicker .add-on i {
  display: inline-block;
  width: 16px;
  height: 16px;
}
@media (max-width: 767px) {
  .bootstrap-timepicker,
  .bootstrap-timepicker .dropdown-menu {
    width: 100%;
  }
}
.bootstrap-timepicker-widget.dropdown-menu {
  padding: 4px;
}
.bootstrap-timepicker-widget.dropdown-menu.open {
  display: inline-block;
}
.bootstrap-timepicker-widget.dropdown-menu:before {
  border-bottom: 7px solid rgba(0, 0, 0, 0.2);
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
}
.bootstrap-timepicker-widget.dropdown-menu:after {
  border-bottom: 6px solid #FFF;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
}
.bootstrap-timepicker-widget.timepicker-orient-left:before {
  left: 6px;
}
.bootstrap-timepicker-widget.timepicker-orient-left:after {
  left: 7px;
}
.bootstrap-timepicker-widget.timepicker-orient-right:before {
  right: 6px;
}
.bootstrap-timepicker-widget.timepicker-orient-right:after {
  right: 7px;
}
.bootstrap-timepicker-widget.timepicker-orient-top:before {
  top: -7px;
}
.bootstrap-timepicker-widget.timepicker-orient-top:after {
  top: -6px;
}
.bootstrap-timepicker-widget.timepicker-orient-bottom:before {
  bottom: -7px;
  border-bottom: 0;
  border-top: 7px solid #999;
}
.bootstrap-timepicker-widget.timepicker-orient-bottom:after {
  bottom: -6px;
  border-bottom: 0;
  border-top: 6px solid #fff;
}
.bootstrap-timepicker-widget a.btn,
.bootstrap-timepicker-widget input {
  border-radius: 4px;
}
.bootstrap-timepicker-widget table {
  width: 100%;
  margin: 0;
}
.bootstrap-timepicker-widget table table td {
  text-align: center;
  height: 30px;
  margin: 0;
  padding: 2px;
}
.bootstrap-timepicker-widget table table td:not(.separator) {
  min-width: 30px;
}
.bootstrap-timepicker-widget table table td span {
  width: 100%;
}
.bootstrap-timepicker-widget table table td a {
  border: 1px transparent solid;
  width: 100%;
  display: inline-block;
  margin: 0;
  padding: 8px 0;
  outline: 0;
  color: #333;
}
.bootstrap-timepicker-widget table table td a:hover {
  text-decoration: none;
  background-color: #eee;
  border-radius: 4px;
  border-color: #ddd;
}
.bootstrap-timepicker-widget table table td a i {
  margin-top: 2px;
  font-size: 18px;
}
.bootstrap-timepicker-widget table table td input {
  width: 25px;
  margin: 0;
  text-align: center;
}
@media (min-width: 767px) {
  .bootstrap-timepicker-widget.modal {
    width: 200px;
    margin-left: -100px;
  }
}
.bootstrap-timepicker-widget .modal-content {
  padding: 4px;
}
/*
 * Note editor
 */
.note-editor {
  border: 1px solid #a9a9a9;
}
.note-editor.fullscreen {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1050;
  width: 100%;
}
.note-editor.fullscreen.fullscreen .note-editable {
  background-color: #fff;
}
.note-editor.codeview .note-editable,
.note-editor.fullscreen .note-resizebar {
  display: none;
}
.note-editor.codeview .note-codeable {
  display: block;
}
.note-editor .note-toolbar {
  padding-bottom: 5px;
  padding-left: 5px;
  margin: 0;
  background-color: #f5f5f5;
  border-bottom: 1px solid #a9a9a9;
}
.note-editor .note-toolbar > .btn-group {
  margin-top: 5px;
  margin-right: 5px;
  margin-left: 0;
}
.note-editor .note-toolbar .note-table .dropdown-menu {
  min-width: 0;
  padding: 5px;
}
.note-editor .note-toolbar .note-table .dropdown-menu .note-dimension-picker {
  font-size: 18px;
}
.note-editor .note-toolbar .note-table .dropdown-menu .note-dimension-picker .note-dimension-picker-mousecatcher {
  position: absolute!important;
  z-index: 3;
  width: 10em;
  height: 10em;
  cursor: pointer;
}
.note-editor .note-toolbar .note-table .note-table .dropdown-menu .note-dimension-picker .note-dimension-picker-unhighlighted {
  position: relative!important;
  z-index: 1;
  width: 5em;
  height: 5em;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASAgMAAAAroGbEAAAACVBMVEUAAIj4+Pjp6ekKlAqjAAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfYAR0BKhmnaJzPAAAAG0lEQVQI12NgAAOtVatWMTCohoaGUY+EmIkEAEruEzK2J7tvAAAAAElFTkSuQmCC) repeat;
}
.note-editor .note-toolbar .note-table .note-table .dropdown-menu .note-dimension-picker .note-dimension-picker-highlighted {
  position: absolute!important;
  z-index: 2;
  width: 1em;
  height: 1em;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASAgMAAAAroGbEAAAACVBMVEUAAIjd6vvD2f9LKLW+AAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfYAR0BKwNDEVT0AAAAG0lEQVQI12NgAAOtVatWMTCohoaGUY+EmIkEAEruEzK2J7tvAAAAAElFTkSuQmCC) repeat;
}
.note-editor .note-toolbar .note-style blockquote,
.note-editor .note-toolbar .note-editor .note-toolbar .note-style h1,
.note-editor .note-toolbar .note-editor .note-toolbar .note-style h2,
.note-editor .note-toolbar .note-editor .note-toolbar .note-style h3,
.note-editor .note-toolbar .note-editor .note-toolbar .note-style h4,
.note-editor .note-toolbar .note-editor .note-toolbar .note-style h5,
.note-editor .note-toolbar .note-editor .note-toolbar .note-style h6 {
  margin: 0;
}
.note-editor .note-toolbar .note-color .dropdown-toggle {
  width: 20px;
  padding-left: 5px;
}
.note-editor .note-toolbar .note-color .dropdown-menu {
  min-width: 290px;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group {
  margin: 0;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group:first-child {
  margin: 0 5px;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group .note-palette-title {
  margin: 2px 7px;
  font-size: 12px;
  text-align: center;
  border-bottom: 1px solid #eee;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group .note-color-reset {
  padding: 0 3px;
  margin: 5px;
  font-size: 12px;
  cursor: pointer;
  border-radius: 5px;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group .note-color-reset:hover {
  background: #eee;
}
.note-editor .note-toolbar .note-para .dropdown-menu {
  min-width: 153px;
  padding: 5px;
}
.note-editor .note-toolbar .note-para .note-para li:first-child {
  margin-bottom: 5px;
}
.note-editor .note-statusbar {
  background-color: #f5f5f5;
}
.note-editor .note-statusbar .note-resizebar {
  width: 100%;
  height: 8px;
  cursor: s-resize;
}
.note-editor .note-statusbar .note-resizebar .note-icon-bar {
  width: 20px;
  margin: 1px auto;
  border-top: 1px solid #a9a9a9;
}
.note-editor .note-popover .popover {
  max-width: none;
}
.note-editor .note-popover .popover .popover-content {
  padding: 5px;
}
.note-editor .note-popover .popover .popover-content a {
  display: inline-block;
  max-width: 200px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  vertical-align: middle;
}
.note-editor .note-popover .popover .popover-content .btn-group + .btn-group {
  margin-left: 5px;
}
.note-editor .note-popover .popover .arrow {
  left: 20px;
}
.note-editor .note-handle .note-control-selection {
  position: absolute;
  display: none;
  border: 1px solid #000;
}
.note-editor .note-handle .note-control-selection > div {
  position: absolute;
}
.note-editor .note-handle .note-control-selection .note-control-selection-bg {
  width: 100%;
  height: 100%;
  background-color: #000;
  -webkit-opacity: .3;
  -khtml-opacity: .3;
  -moz-opacity: .3;
  opacity: .3;
  -ms-filter: alpha(opacity=30);
  filter: alpha(opacity=30);
}
.note-editor .note-handle .note-control-selection .note-control-handle,
.note-editor .note-handle .note-control-selection .note-control-holder {
  width: 7px;
  height: 7px;
  border: 1px solid #000;
}
.note-editor .note-handle .note-control-selection .note-control-sizing {
  width: 7px;
  height: 7px;
  background-color: #fff;
  border: 1px solid #000;
}
.note-editor .note-handle .note-control-selection .note-control-nw {
  top: -5px;
  left: -5px;
  border-right: 0;
  border-bottom: 0;
}
.note-editor .note-handle .note-control-selection .note-control-ne {
  top: -5px;
  right: -5px;
  border-bottom: 0;
  border-left: 0;
}
.note-editor .note-handle .note-control-selection .note-control-sw {
  bottom: -5px;
  left: -5px;
  border-top: 0;
  border-right: 0;
}
.note-editor .note-handle .note-control-selection .note-control-se {
  right: -5px;
  bottom: -5px;
  cursor: se-resize;
}
.note-editor .note-handle .note-control-selection .note-control-selection-info {
  right: 0;
  bottom: 0;
  padding: 5px;
  margin: 5px;
  font-size: 12px;
  color: #fff;
  background-color: #000;
  border-radius: 5px;
  -webkit-opacity: .7;
  -khtml-opacity: .7;
  -moz-opacity: .7;
  opacity: .7;
  -ms-filter: alpha(opacity=70);
  filter: alpha(opacity=70);
}
.note-editor .note-dialog > div {
  display: none;
}
.note-editor .note-dialog .note-image-dialog .note-dropzone {
  min-height: 200px;
  font-size: 30px;
  line-height: 6;
  color: #d3d3d3;
  text-align: center;
  border: 4px dashed #d3d3d3;
}
.note-editor .note-dialog .note-help-dialog {
  font-size: 12px;
  color: #ccc;
  background: 0 0;
  background-color: #222!important;
  border: 0;
  -webkit-opacity: .9;
  -khtml-opacity: .9;
  -moz-opacity: .9;
  opacity: .9;
  -ms-filter: alpha(opacity=90);
  filter: alpha(opacity=90);
}
.note-editor .note-dialog .note-help-dialog .modal-content {
  background: 0 0;
  border: 1px solid #fff;
  border-radius: 5px;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.note-editor .note-dialog .note-help-dialog a {
  font-size: 12px;
  color: #fff;
}
.note-editor .note-dialog .note-help-dialog .title {
  padding-bottom: 5px;
  font-size: 14px;
  font-weight: 700;
  color: #fff;
  border-bottom: #fff 1px solid;
}
.note-editor .note-dialog .note-help-dialog .modal-close {
  font-size: 14px;
  color: #dd0;
  cursor: pointer;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut-layout {
  width: 100%;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut-layout td {
  vertical-align: top;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut {
  margin-top: 8px;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut th {
  font-size: 13px;
  color: #dd0;
  text-align: left;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut th:first-child {
  min-width: 110px;
  padding-right: 10px;
  font-family: "Courier New";
  color: #dd0;
  text-align: right;
}
.note-editor .note-editable {
  padding: 10px;
  overflow: scroll;
  outline: 0;
}
.note-editor .note-codeable {
  display: none;
  width: 100%;
  padding: 10px;
  margin-bottom: 0;
  font-family: Menlo, Monaco, monospace, sans-serif;
  font-size: 14px;
  color: #ccc;
  background-color: #222;
  border: 0;
  border-radius: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  resize: none;
}
.note-editor .dropdown-menu {
  min-width: 90px;
}
.note-editor .dropdown-menu.right {
  right: 0;
  left: auto;
}
.note-editor .dropdown-menu.right::before {
  right: 9px;
  left: auto!important;
}
.note-editor .dropdown-menu.right::after {
  right: 10px;
  left: auto!important;
}
.note-editor .dropdown-menu .dropdown-menu li a i {
  color: #00bfff;
  visibility: hidden;
}
.note-editor .dropdown-menu .dropdown-menu li a.checked i {
  visibility: visible;
}
.note-editor .note-color-palette {
  line-height: 1;
}
.note-editor .note-color-palette div .note-color-btn {
  width: 17px;
  height: 17px;
  padding: 0;
  margin: 0;
  border: 1px solid #fff;
}
.note-editor .note-color-palette div .note-color-btn:hover {
  border: 1px solid #000;
}
.no-padding .note-editor {
  border: 0;
}
.note-editor .note-editable {
  background-color: rgba(48, 126, 204, 0.05);
}
.note-editor .note-editable:focus {
  background-color: #fff;
}
.note-editor .note-statusbar .note-resizebar {
  border-top: 1px solid #DBDBDB;
}
.note-editor .note-statusbar:hover {
  background: #EEE;
}
.note-editor .note-statusbar:active {
  background: #eaeaea;
}
/*
 * MD editor
 */
.md-editor {
  display: block;
  border: 1px solid #ddd;
}
.md-editor.active {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.md-editor .md-footer,
.md-editor > .md-header {
  display: block;
  padding: 6px 4px;
  background: #f5f5f5;
}
.md-editor > .md-preview {
  background: #fff;
  border-top: 1px dashed #ddd;
  border-bottom: 1px dashed #ddd;
  min-height: 10px;
  padding: 10px;
}
.md-editor > textarea {
  font-family: Monaco, Menlo, Consolas, "Courier New", monospace;
  font-size: 13px;
  outline: 0;
  outline: thin dotted \9;
  margin: 0;
  display: block;
  width: 100%;
  border: 0;
  padding: 10px;
  border-top: 1px dashed #ddd;
  border-bottom: 1px dashed #ddd;
  border-radius: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: #eee;
}
.md-editor > textarea:focus {
  -webkit-box-shadow: none;
  box-shadow: none;
  background: #fff;
}
/*
 * Twitter Typeahead
 */
.twitter-typeahead .tt-hint,
.twitter-typeahead .tt-query {
  margin-bottom: 0;
}
.tt-dropdown-menu {
  min-width: 160px;
  margin-top: 2px;
  padding: 5px 0;
  background-color: #fff;
  border: 1px solid #bfbfbf;
  border: 1px solid rgba(0, 0, 0, 0.2);
  *border-right-width: 2px;
  *border-bottom-width: 2px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.tt-suggestion {
  display: block;
  padding: 3px 20px;
}
.tt-suggestion.tt-is-under-cursor {
  color: #fff;
  background-color: #0081c2;
}
.tt-suggestion.tt-is-under-cursor a {
  color: #fff;
}
.tt-suggestion p {
  margin: 0;
}
/*
 * DropZone
 */
.dropzone,
.dropzone *,
.dropzone-previews,
.dropzone-previews * {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.dropzone .dz-preview,
.dropzone-previews .dz-preview {
  background: rgba(255, 255, 255, 0.8);
  position: relative;
  display: inline-block;
  margin: 10px;
  vertical-align: top;
  border: 1px solid #acacac;
  padding: 6px;
  -webkit-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.16);
  box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.16);
  font-size: 14px;
}
.dropzone .dz-preview.dz-file-preview,
.dropzone-previews .dz-preview.dz-file-preview {
  display: none;
}
.dropzone .dz-preview .dz-details,
.dropzone-previews .dz-preview .dz-details {
  width: 100px;
  height: 100px;
  position: relative;
  background: #ebebeb;
  padding: 5px;
  margin-bottom: 22px;
}
.dropzone .dz-preview .dz-details .dz-filename,
.dropzone-previews .dz-preview .dz-details .dz-filename {
  overflow: hidden;
  height: 100%;
}
.dropzone .dz-preview .dz-details img,
.dropzone-previews .dz-preview .dz-details img {
  position: absolute;
  top: 0;
  left: 0;
  width: 100px;
  height: 100px;
}
.dropzone .dz-preview .dz-details .dz-size,
.dropzone-previews .dz-preview .dz-details .dz-size {
  position: absolute;
  bottom: -28px;
  left: 3px;
  height: 28px;
  line-height: 28px;
}
.dropzone .dz-preview.dz-error .dz-error-mark,
.dropzone-previews .dz-preview.dz-error .dz-error-mark,
.dropzone .dz-preview.dz-success .dz-success-mark,
.dropzone-previews .dz-preview.dz-success .dz-success-mark {
  display: block;
  opacity: 1;
  -ms-filter: none;
  -webkit-filter: none;
  filter: none;
}
.dropzone .dz-preview:hover .dz-details img,
.dropzone-previews .dz-preview:hover .dz-details img {
  display: none;
}
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark,
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark {
  display: block;
  position: absolute;
  width: 40px;
  height: 40px;
  font-size: 30px;
  text-align: center;
  right: -10px;
  top: -10px;
  opacity: 0;
  -ms-filter: "alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.4s ease-in-out;
  transition: opacity 0.4s ease-in-out;
  background-image: url(../img/dropzone/spritemap.png);
  background-repeat: no-repeat;
}
.dropzone .dz-preview .dz-error-mark span,
.dropzone-previews .dz-preview .dz-error-mark span,
.dropzone .dz-preview .dz-success-mark span,
.dropzone-previews .dz-preview .dz-success-mark span {
  display: none;
}
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark {
  color: #8cc657;
  background-position: -268px -163px;
}
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark {
  color: #ee162d;
  background-position: -268px -123px;
}
.dropzone .dz-preview.dz-error .dz-progress .dz-upload,
.dropzone-previews .dz-preview.dz-error .dz-progress .dz-upload {
  background: #ee1e2d;
}
.dropzone .dz-preview .dz-progress,
.dropzone-previews .dz-preview .dz-progress {
  position: absolute;
  top: 100px;
  left: 6px;
  right: 6px;
  height: 6px;
  background: #d7d7d7;
  display: none;
}
.dropzone .dz-preview .dz-progress .dz-upload,
.dropzone-previews .dz-preview .dz-progress .dz-upload {
  position: absolute;
  bottom: 0;
  background-color: #8cc657;
  -webkit-animation: loading .4s linear infinite;
  -ms-animation: loading .4s linear infinite;
  animation: loading .4s linear infinite;
  -webkit-transition: width 0.3s ease-in-out;
  transition: width 0.3s ease-in-out;
  border-radius: 2px;
  top: 0;
  left: 0;
  width: 0;
  height: 100%;
  background-image: url(../img/dropzone/spritemap.png);
  background-repeat: repeat-x;
  background-position: 0 -400px;
}
.dropzone .dz-preview.dz-processing .dz-progress,
.dropzone-previews .dz-preview.dz-processing .dz-progress {
  display: block;
}
.dropzone .dz-preview .dz-error-message,
.dropzone-previews .dz-preview .dz-error-message {
  position: absolute;
  top: -5px;
  left: -20px;
  background: rgba(245, 245, 245, 0.8);
  padding: 8px 10px;
  color: #800;
  min-width: 140px;
  max-width: 500px;
  z-index: 500;
  display: block;
  opacity: 0;
  -ms-filter: "alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.3s ease-in-out;
  transition: opacity 0.3s ease-in-out;
}
.dropzone .dz-preview:hover.dz-error .dz-error-message,
.dropzone-previews .dz-preview:hover.dz-error .dz-error-message {
  display: block;
  opacity: 1;
  -ms-filter: none;
  -webkit-filter: none;
  filter: none;
}
.dropzone .dz-preview.dz-image-preview:hover .dz-details img,
.dropzone-previews .dz-preview.dz-image-preview:hover .dz-details img {
  display: block;
  opacity: .1;
  -ms-filter: "alpha(Opacity=10)";
  filter: alpha(opacity=10);
}
.dropzone .dz-preview.dz-success .dz-progress,
.dropzone-previews .dz-preview.dz-success .dz-progress {
  display: block;
  opacity: 0;
  -ms-filter: "alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.4s ease-in-out;
  transition: opacity 0.4s ease-in-out;
}
.dropzone a.dz-remove,
.dropzone-previews a.dz-remove {
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #fafafa), color-stop(1, #eeeeee));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#fafafa), to(#eeeeee));
  background-image: -webkit-linear-gradient(top, #fafafa 0, #eeeeee 100%);
  background-image: linear-gradient(top, #fafafa 0, #eeeeee 100%);
  border-radius: 2px;
  border: 1px solid #eee;
  text-decoration: none;
  display: block;
  padding: 4px 5px;
  text-align: center;
  color: #aaa;
  margin-top: 26px;
}
.dropzone a.dz-remove:hover,
.dropzone-previews a.dz-remove:hover {
  color: #666;
}
.dropzone {
  position: relative;
  padding: 1em;
  border: 1px solid rgba(0, 0, 0, 0.03);
  min-height: 360px;
  border-radius: 3px;
  background: rgba(0, 0, 0, 0.03);
  background-image: -webkit-gradient(linear, left top, right bottom, color-stop(0.25, rgba(0, 0, 0, 0.03)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(0, 0, 0, 0.03)), color-stop(0.75, rgba(0, 0, 0, 0.03)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: -webkit-linear-gradient(315deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-color: #FAFCFD;
  -webkit-background-size: 16px 16px;
  background-size: 16px 16px;
}
.dropzone .dz-drag-hover {
  background: rgba(0, 0, 0, 0.04);
}
.dropzone.dz-clickable,
.dropzone.dz-clickable .dz-message,
.dropzone.dz-clickable .dz-message span {
  cursor: pointer;
}
.dropzone.dz-clickable * {
  cursor: default;
}
.dropzone .dz-message {
  opacity: 1;
  -ms-filter: none;
  -webkit-filter: none;
  filter: none;
}
.dropzone .dz-drag-hover {
  background-image: -webkit-gradient(linear, left top, right bottom, color-stop(0.25, rgba(0, 0, 0, 0.03)), color-stop(0.25, rgba(0, 0, 0, 0)), color-stop(0.5, rgba(0, 0, 0, 0)), color-stop(0.5, rgba(0, 0, 0, 0.03)), color-stop(0.75, rgba(0, 0, 0, 0.03)), color-stop(0.75, rgba(0, 0, 0, 0)), to(rgba(0, 0, 0, 0)));
  background-image: -webkit-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, rgba(0, 0, 0, 0) 25%, rgba(0, 0, 0, 0) 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, rgba(0, 0, 0, 0) 75%, rgba(0, 0, 0, 0));
  background-image: -webkit-linear-gradient(315deg, rgba(0, 0, 0, 0.03) 25%, rgba(0, 0, 0, 0) 25%, rgba(0, 0, 0, 0) 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, rgba(0, 0, 0, 0) 75%, rgba(0, 0, 0, 0));
  background-image: linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, rgba(0, 0, 0, 0) 25%, rgba(0, 0, 0, 0) 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, rgba(0, 0, 0, 0) 75%, rgba(0, 0, 0, 0));
  background-color: #fafafa;
  -webkit-background-size: 22px 22px;
  background-size: 22px 22px;
  border: 5px dashed #ccc;
}
.dropzone .dz-default.dz-message {
  opacity: 1;
  -ms-filter: none;
  -webkit-filter: none;
  filter: none;
  -webkit-transition: opacity 0.3s ease-in-out;
  transition: opacity 0.3s ease-in-out;
  background-image: url(../img/dropzone/spritemap.png);
  background-repeat: no-repeat;
  background-position: 0 0;
  position: absolute;
  width: 428px;
  height: 123px;
  margin-left: -214px;
  margin-top: -61.5px;
  top: 50%;
  left: 50%;
}
.dropzone .dz-default.dz-message span {
  display: none;
}
.dropzone.dz-square .dz-default.dz-message {
  background-position: 0 -123px;
  width: 268px;
  margin-left: -134px;
  height: 174px;
  margin-top: -87px;
}
.dropzone.dz-drag-hover .dz-message {
  opacity: .15;
  -ms-filter: "alpha(Opacity=15)";
  filter: alpha(opacity=15);
}
.dropzone.dz-started .dz-message {
  display: block;
  opacity: 0;
  -ms-filter: "alpha(Opacity=0)";
  filter: alpha(opacity=0);
}
.irs {
  position: relative;
  display: block;
  height: 40px;
}
.irs-line {
  position: relative;
  display: block;
  overflow: hidden;
  height: 8px;
  top: 25px;
  background: #eee;
}
.irs-line-left,
.irs-line-mid,
.irs-line-right {
  position: absolute;
  display: block;
  top: 0;
  height: 8px;
}
.irs-line-left {
  left: 0;
  width: 10%;
}
.irs-line-mid {
  left: 10%;
  width: 80%;
}
.irs-line-right {
  right: 0;
  width: 10%;
}
.irs-diapason {
  position: absolute;
  display: block;
  left: 0;
  width: 100%;
}
.irs-slider {
  position: absolute;
  display: block;
  cursor: default;
  z-index: 1;
  width: 10px;
  height: 22px;
  top: 17px;
  border: 1px solid #fff;
  background: #858585;
}
.irs-slider:hover {
  background: #6c6c6c;
}
.irs-slider.single {
  left: 10px;
}
.irs-slider.single:before {
  position: absolute;
  display: block;
  content: "";
  top: -50%;
  left: -150%;
  width: 400%;
  height: 200%;
  background: rgba(0, 0, 0, 0);
}
.irs-slider.from {
  left: 100px;
}
.irs-slider.from:before {
  position: absolute;
  display: block;
  content: "";
  top: -50%;
  left: -300%;
  width: 400%;
  height: 200%;
  background: rgba(0, 0, 0, 0);
}
.irs-slider.to {
  left: 300px;
}
.irs-slider.to:before {
  position: absolute;
  display: block;
  content: "";
  top: -50%;
  left: 0;
  width: 400%;
  height: 200%;
  background: rgba(0, 0, 0, 0);
}
.irs-slider.last {
  z-index: 2;
}
.irs-max,
.irs-min {
  color: #999;
  font-size: 12px;
  line-height: 1.333;
  text-shadow: none;
  top: 0;
  padding: 1px 3px;
  background: rgba(0, 0, 0, 0.1);
  border-radius: 0;
}
.lt-ie9 .irs-max,
.lt-ie9 .irs-min {
  background: #bfbfbf;
}
.irs-min {
  position: absolute;
  display: block;
  left: 0;
  cursor: default;
}
.irs-max {
  position: absolute;
  display: block;
  right: 0;
  cursor: default;
}
.irs-from,
.irs-single,
.irs-to {
  position: absolute;
  display: block;
  top: 0;
  left: 0;
  cursor: default;
  white-space: nowrap;
}
.lt-ie9 .irs-from,
.lt-ie9 .irs-single,
.lt-ie9 .irs-to {
  background: #999;
}
.irs-grid {
  position: absolute;
  display: none;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 20px;
}
.irs-with-grid {
  height: 60px;
}
.irs-with-grid .irs-grid {
  display: block;
}
.irs-grid-pol {
  position: absolute;
  top: 0;
  left: 0;
  width: 1px;
  height: 8px;
  background: #99a4ac;
}
.irs-grid-pol.small {
  height: 4px;
}
.irs-grid-text {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100px;
  white-space: nowrap;
  text-align: center;
  font-size: 9px;
  line-height: 9px;
  color: #99a4ac;
}
.irs-diapason {
  background: #3276b1;
  height: 8px;
  top: 25px;
}
.irs .irs-from,
.irs .irs-single,
.irs .irs-to {
  color: #fff;
  font-size: 10px;
  line-height: 1.333;
  text-shadow: none;
  padding: 1px 5px;
  background: rgba(0, 0, 0, 0.4);
  border-radius: 0;
}
#irs-active-slider {
  background: #686868;
  -webkit-box-shadow: rgba(0, 0, 0, 0.3) 1px 1px 1px 0;
  box-shadow: rgba(0, 0, 0, 0.3) 1px 1px 1px 0;
  width: 12px;
  height: 24px;
  top: 16px;
}
/*
 * Google maps
 */
.google_maps {
  width: 100%;
  height: 350px;
  position: relative;
}
.google_maps * {
  box-sizing: content-box;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
}
.google_maps img {
  max-width: none;
}
/*
 * JQuery-UI for Bootstrap
 */
.slider {
  margin-top: 0;
  margin-bottom: 30px;
}
.slider.slider-vertical {
  margin-bottom: 0;
  margin-right: 5px;
}
.ui-helper-hidden {
  display: none;
}
.ui-helper-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}
.ui-helper-reset {
  margin: 0;
  padding: 0;
  border: 0;
  outline: 0;
  line-height: 1.3;
  text-decoration: none;
  font-size: 100%;
  list-style: none;
}
.ui-helper-clearfix {
  display: block;
  min-height: 0;
}
.ui-helper-clearfix:after,
.ui-helper-clearfix:before {
  content: "";
  display: table;
  border-collapse: collapse;
}
.ui-helper-clearfix:after {
  content: ".";
  display: block;
  height: 0;
  clear: both;
  visibility: hidden;
}
* html .ui-helper-clearfix {
  height: 1%;
}
.ui-helper-zfix {
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  position: absolute;
  opacity: 0;
  filter: alpha(opacity=0);
}
.ui-front {
  z-index: 100;
}
.ui-state-disabled {
  cursor: default !important;
}
.ui-icon {
  display: block;
  width: 16px;
  height: 16px;
  text-indent: -99999px;
  overflow: hidden;
  background-repeat: no-repeat;
}
/*
 * UI widget
 */
.ui-widget {
  font-family: Ubuntu, Helvetica, Arial, sans-serif;
  font-size: 13px;
}
.ui-widget :active {
  outline: 0;
}
.ui-widget .ui-widget {
  font-size: 13px;
}
.ui-widget button,
.ui-widget input,
.ui-widget select,
.ui-widget textarea {
  font-family: Ubuntu, Helvetica, Arial, sans-serif;
  font-size: inherit;
}
.ui-widget-content {
  border: 1px solid #aaa;
  background: #fff;
  color: #404040;
}
.ui-widget-content .ui-icon {
  background: none!important;
}
.ui-widget-header {
  font-weight: 700;
  background-color: #F5F5F5;
  border-color: #DDD;
  color: #333;
}
.ui-widget-header a {
  color: #222;
}
.ui-widget-overlay {
  position: fixed;
  background: #AAA;
  width: 100%;
  height: 200%;
  top: 0;
  left: 0;
  z-index: 999;
  opacity: .3;
  filter: alpha(opacity=30);
}
.ui-widget-shadow {
  margin: -8px 0 0 -8px;
  padding: 8px;
  background: #aaa;
  opacity: .3;
  filter: alpha(opacity=30);
  border-radius: 8px;
}
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default {
  color: #333;
  background-color: #fff;
  font-weight: 400;
  border: 1px solid #ccc;
}
.ui-state-default a,
.ui-state-default a:link,
.ui-state-default a:visited {
  color: #555;
  text-decoration: none;
}
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default {
  text-shadow: none;
}
.ui-state-default,
.ui-state-error,
.ui-state-highlight {
  position: relative;
  border-width: 1px;
  border-style: solid;
}
.ui-state-default p,
.ui-state-error p,
.ui-state-highlight p {
  font-size: 13px;
  font-weight: 400;
  line-height: 18px;
  margin: 7px 15px;
}
.ui-state-highlight,
.ui-widget-content .ui-state-highlight,
.ui-widget-header .ui-state-highlight {
  color: #3a87ad;
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.ui-state-highlight a,
.ui-widget-content .ui-state-highlight a,
.ui-widget-header .ui-state-highlight a {
  color: #2d6987;
}
.ui-state-error,
.ui-widget-content .ui-state-error,
.ui-widget-header .ui-state-error {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #eed3d7;
}
.ui-state-error a,
.ui-state-error-text,
.ui-widget-content .ui-state-error a,
.ui-widget-content .ui-state-error-text,
.ui-widget-header .ui-state-error a,
.ui-widget-header .ui-state-error-text {
  color: #953b39;
}
.ui-state-focus,
.ui-state-hover,
.ui-widget-content .ui-state-focus,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-focus,
.ui-widget-header .ui-state-hover {
  color: #333;
  background-color: #ebebeb;
  border-color: #adadad;
  text-decoration: none;
}
.ui-state-hover a:hover,
.ui-state-hover a:link,
.ui-state-hover a:visited {
  color: #333;
  text-decoration: none;
}
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active {
  border: 1px solid #adadad;
  font-weight: 400;
  color: #333;
}
.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
  color: #333;
  text-decoration: none;
}
.ui-state-disabled,
.ui-widget-content .ui-state-disabled,
.ui-widget-header .ui-state-disabled {
  opacity: .35;
  filter: alpha(opacity=35);
  background-image: none;
}
.ui-state-disabled .ui-icon,
.ui-widget-content .ui-state-disabled .ui-icon,
.ui-widget-header .ui-state-disabled .ui-icon {
  filter: alpha(opacity=35);
}
.ui-priority-primary,
.ui-widget-content .ui-priority-primary,
.ui-widget-header .ui-priority-primary {
  font-weight: 700;
}
.ui-priority-secondary,
.ui-widget-content .ui-priority-secondary,
.ui-widget-header .ui-priority-secondary {
  opacity: .7;
  filter: alpha(opacity=70);
  font-weight: 400;
}
.ui-corner-all {
  border-radius: 0;
}
.ui-corner-left,
.ui-corner-tl,
.ui-corner-top {
  border-top-left-radius: 4px;
}
.ui-corner-right,
.ui-corner-top,
.ui-corner-tr {
  border-top-right-radius: 4px;
}
.ui-corner-bl,
.ui-corner-bottom,
.ui-corner-left {
  border-bottom-left-radius: 4px;
}
.ui-corner-bottom,
.ui-corner-br,
.ui-corner-right {
  border-bottom-right-radius: 4px;
}
.ui-autocomplete {
  position: absolute;
  top: 0;
  left: 0;
  cursor: default;
}
input[type=color].ui-autocomplete-loading,
input[type=date].ui-autocomplete-loading,
input[type=datetime-local].ui-autocomplete-loading,
input[type=datetime].ui-autocomplete-loading,
input[type=email].ui-autocomplete-loading,
input[type=month].ui-autocomplete-loading,
input[type=number].ui-autocomplete-loading,
input[type=password].ui-autocomplete-loading,
input[type=search].ui-autocomplete-loading,
input[type=tel].ui-autocomplete-loading,
input[type=text].ui-autocomplete-loading,
input[type=time].ui-autocomplete-loading,
input[type=url].ui-autocomplete-loading,
input[type=week].ui-autocomplete-loading {
  background-image: url(../img/select2-spinner.gif) !important;
  background-repeat: no-repeat;
  background-position: 99% 50%;
  padding-right: 27px;
}
/*
 * UI buttons
 */
.ui-btn-lg {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33;
  border-radius: 6px;
}
.ui-btn-sm,
.ui-btn-xs {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
.ui-btn-xs {
  padding: 1px 5px;
}
.ui-btn-block {
  display: block;
  width: 100%;
  padding-right: 0;
  padding-left: 0;
}
.ui-btn-block + .ui-btn-block {
  margin-top: 5px;
}
input[type=button].ui-btn-block,
input[type=reset].ui-btn-block,
input[type=submit].ui-btn-block {
  width: 100%;
}
.ui-button {
  display: inline-block;
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: 400;
  line-height: 1.428571429;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  border: 1px solid #ccc;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -o-user-select: none;
  user-select: none;
}
.ui-button:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.ui-button:focus,
.ui-button:hover {
  color: #333;
  background-color: #ebebeb;
  border-color: #adadad;
  text-decoration: none;
}
fieldset[disabled] .ui-button,
fieldset[disabled] .ui-button.ui-state-active,
fieldset[disabled] .ui-button:active,
fieldset[disabled] .ui-button:focus,
fieldset[disabled] .ui-button:hover,
.ui-button.disabled,
.ui-button.disabled.active,
.ui-button.disabled:active,
.ui-button.disabled:focus,
.ui-button.disabled:hover,
.ui-button[disabled],
.ui-button[disabled].active,
.ui-button[disabled]:active,
.ui-button[disabled]:focus,
.ui-button[disabled]:hover {
  background-color: #fff;
  border-color: #ccc;
}
.ui-button-text-icon-primary .ui-button-icon-primary {
  float: left;
}
.ui-button-text-icon-primary {
  padding: 2px 7px 3px;
}
.ui-button-primary {
  color: #fff;
  background-color: #428bca;
  border-color: #357ebd;
}
.ui-button-warning {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.ui-button-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.ui-button-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.ui-button-inverse {
  color: #fff;
  background-color: #222;
  border-color: #080808;
}
.ui-button-success {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.ui-button-error {
  color: #fff;
  background-color: #c43c35;
  border-color: #882a25;
}
.ui-button-danger:hover,
.ui-button-info:hover,
.ui-button-inverse:hover,
.ui-button-primary:hover,
.ui-button-success:hover,
.ui-button-warning:hover {
  text-decoration: none;
}
.ui-button-primary:focus,
.ui-button-primary:hover {
  color: #fff;
  background-color: #3276b1;
  border-color: #285e8e;
}
.ui-button-success:hover {
  color: #fff;
  background-color: #47a447;
  border-color: #398439;
}
.ui-button-info:hover {
  color: #fff;
  background-color: #39b3d7;
  border-color: #269abc;
}
.ui-button-danger:hover {
  color: #fff;
  background-color: #d2322d;
  border-color: #ac2925;
}
.ui-button-warning:hover {
  color: #fff;
  background-color: #ed9c28;
  border-color: #d58512;
}
.ui-button-inverse:hover {
  color: #fff;
  background-color: #363636;
  border-color: #000;
}
.ui-button-icon-only {
  width: 2.2em;
}
.ui-button-icons-only {
  width: 3.4em;
}
button.ui-button-icons-only {
  width: 3.7em;
}
.ui-button-text-icon-primary .ui-button-icon-primary.ui-icon {
  margin-top: 5px;
}
.ui-button .ui-button-text {
  display: block;
  line-height: normal;
}
.ui-button-icon-only .ui-button-text,
.ui-button-icons-only .ui-button-text {
  padding: .4em;
  text-indent: -9999px;
  display: none;
}
.ui-button-text-icon-primary .ui-button-text,
.ui-button-text-icons .ui-button-text {
  padding: .4em 1em .4em 2.1em;
}
.ui-button-text-icon-secondary .ui-button-text,
.ui-button-text-icons .ui-button-text {
  padding: .4em 2.1em .4em 1em;
}
.ui-button-text-icons .ui-button-text {
  padding-left: 2.1em;
  padding-right: 2.1em;
}
input.ui-button {
  padding: .4em 1em;
}
.ui-button-icon-only .ui-icon,
.ui-button-icons-only .ui-icon,
.ui-button-text-icon-primary .ui-icon,
.ui-button-text-icon-secondary .ui-icon,
.ui-button-text-icons .ui-icon {
  margin-bottom: 0;
  margin-top: 0;
  top: 50%;
}
.ui-button-icon-only .ui-icon {
  left: 50%;
  margin-left: -8px;
  margin-right: -6px;
}
.ui-button-icons-only .ui-button-icon-primary,
.ui-button-text-icon-primary .ui-button-icon-primary,
.ui-button-text-icons .ui-button-icon-primary {
  left: .5em;
}
.ui-button-icons-only .ui-button-icon-secondary,
.ui-button-text-icon-secondary .ui-button-icon-secondary,
.ui-button-text-icons .ui-button-icon-secondary {
  right: .5em;
}
.ui-buttonset {
  margin-right: 7px;
}
.ui-buttonset .ui-state-active {
  color: #fff;
  background-color: #428bca;
  border-color: #357ebd;
}
.ui-buttonset .ui-state-active.ui-state-hover {
  color: #fff;
  background-color: #3276b1;
  border-color: #285e8e;
}
.ui-buttonset .ui-button {
  margin-left: 0;
  margin-right: -0.4em;
}
button.ui-button::-moz-focus-inner {
  border: 0;
  padding: 0;
}
/*
 * UI slider
 */
.ui-slider {
  position: relative;
  text-align: left;
}
.ui-slider.ui-state-disabled .ui-slider-handle,
.ui-slider.ui-state-disabled .ui-slider-range {
  -webkit-filter: inherit;
  filter: inherit;
}
.ui-slider .ui-slider-handle {
  position: absolute;
  z-index: 2;
  width: 16px;
  height: 18px;
  cursor: default;
}
.ui-slider .ui-slider-range {
  position: absolute;
  z-index: 1;
  font-size: .7em;
  display: block;
  border: 0;
  background-position: 0 0;
  color: #fff;
  background-color: #0e90d2;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#149bdf), to(#0480be));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#149bdf), to(#0480be));
  background-image: -webkit-linear-gradient(top, #149bdf, #0480be);
  background-image: linear-gradient(to bottom, #149bdf, #0480be);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff149bdf', endColorstr='#ff0480be', GradientType=0);
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: width .6s ease;
  transition: width .6s ease;
}
.ui-slider-horizontal {
  height: 10px;
  background: #D5D5D5;
  border: 0;
}
.ui-slider-horizontal .ui-slider-handle {
  top: -0.3em;
  margin-left: -0.6em;
  background-color: #fff;
  border-color: #CCC;
}
.ui-slider-horizontal .ui-slider-handle:focus {
  background-color: #fff;
  border-color: #357EBD;
}
.ui-slider-horizontal .ui-slider-handle:hover {
  background-color: #fff;
  border-color: #285E8E;
  outline: 0;
}
.ui-slider-horizontal .ui-slider-handle:active {
  background-color: #428BCA;
  border-color: #3276B1;
}
.ui-slider-horizontal .ui-slider-range {
  top: 0;
  height: 100%;
}
.ui-slider-horizontal .ui-slider-range-min {
  left: 0;
}
.ui-slider-horizontal .ui-slider-range-max {
  right: 0;
}
.ui-slider-vertical {
  width: .8em;
  height: 100px;
}
.ui-slider-vertical .ui-slider-handle {
  left: -0.3em;
  margin-left: 0;
  margin-bottom: -0.6em;
}
.ui-slider-vertical .ui-slider-range {
  left: 0;
  width: 100%;
}
.ui-slider-vertical .ui-slider-range-min {
  bottom: 0;
}
.ui-slider-vertical .ui-slider-range-max {
  top: 0;
}
/*
 * UI tabs
 */
.ui-tabs {
  position: relative;
  border: 0;
  border-radius: 0;
}
.ui-tabs .ui-tabs-panel {
  display: block;
  border-radius: 0;
  background: 0 0;
}
.ui-tabs .ui-tabs-nav {
  margin-bottom: 0;
  border: solid #ddd;
  border-width: 0 0 1px;
  border-radius: 0;
  background: 0 0;
}
.ui-tabs .ui-tabs-nav li {
  position: relative;
  top: 0;
  float: left;
  margin-bottom: -1px;
  margin-right: 3px;
  border: 0;
  list-style: none;
  white-space: nowrap;
  background: 0 0;
  -webkit-filter: none;
  filter: none;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active:hover {
  background: #fff;
  cursor: text;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active a {
  border: 1px solid #ddd;
  border-bottom: 1px solid #fff;
  background-color: #fff;
  color: #555;
  font-weight: 700;
  border-top-width: 0!important;
  margin-top: 1px!important;
  -webkit-box-shadow: 0 -2px 0 #57889c;
  box-shadow: 0 -2px 0 #57889c;
}
.ui-tabs .ui-tabs-nav li a {
  float: left;
  padding: 8px 12px;
  font-weight: 400;
  text-decoration: none;
  outline: 0;
  background: 0 0;
  border-radius: 0;
  background-color: #F5F5F5;
  border: 1px solid #F5F5F5;
  border-bottom: 1px solid #ddd;
  color: #838383;
}
.ui-tabs .ui-tabs-nav li a:hover {
  border: 1px solid #f5f5f5;
  border-bottom: 1px solid #ddd;
  background-color: #f5f5f5;
}
.ui-tabs .ui-tabs-nav li.ui-state-disabled a,
.ui-tabs .ui-tabs-nav li.ui-tabs-active a,
.ui-tabs .ui-tabs-nav li.ui-tabs-loading a {
  cursor: text;
}
.ui-tabs .ui-tabs-nav .ui-state-default {
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.ui-tabs .ui-tabs-panel {
  border: 1px solid #ddd;
  margin: 0;
  padding: 10px 13px;
  border-top: 0;
}
.ui-tabs .ui-tabs-hide {
  display: none!important;
}
/*
 * UI tooltip
 */
.ui-tooltip {
  display: block;
  font-size: 11px;
  opacity: .8;
  position: absolute;
  visibility: visible;
  z-index: 1024;
  max-width: 200px;
  background: #000;
  border: 1px solid #000;
  color: #FFF;
  padding: 3px 8px;
  text-align: center;
  text-decoration: none;
  -webkit-box-shadow: inset 0 1px 0 #000;
  box-shadow: inset 0 1px 0 #000;
  border-radius: 4px;
}
body .ui-tooltip {
  border-width: 1px;
}
/*
 * UI spinner
 */
.ui-spinner {
  position: relative;
  display: inline-block;
  overflow: hidden;
  width: 100%;
  padding: 0;
  vertical-align: middle;
}
.ui-spinner-input {
  margin: 0!important;
  height: 30px;
  padding: 6px 24px 6px 12px;
  border: 0;
  background: 0 0;
  vertical-align: middle;
}
.ui-spinner-input.spinner-left {
  padding: 6px 12px 6px 24px;
}
.ui-spinner-input.spinner-left + .ui-spinner-button,
.ui-spinner-input.spinner-left + .ui-spinner-button + .ui-spinner-button {
  right: auto;
  left: 0;
}
.ui-spinner-input.spinner-both {
  padding: 6px 30px;
}
.ui-spinner-input.spinner-both + .ui-spinner-button + .ui-spinner-button {
  left: 0;
  right: auto;
}
.ui-spinner-input.spinner-both + .ui-spinner-button,
.ui-spinner-input.spinner-both + .ui-spinner-button + .ui-spinner-button {
  height: 30px;
  width: 25px;
}
.ui-spinner-input.spinner-both + .ui-spinner-up + .ui-spinner-down:before,
.ui-spinner-input.spinner-both + .ui-spinner-up:before {
  margin-top: 8px;
}
.ui-spinner-button {
  width: 19px;
  height: 50%;
  font-size: .5em;
  padding: 0;
  margin: 0;
  text-align: center;
  position: absolute;
  cursor: default;
  display: block;
  overflow: hidden;
  right: 0;
}
.ui-spinner a.ui-spinner-button {
  border-top: 0;
  border-bottom: 0;
  border-right: 0;
}
.ui-spinner .ui-icon {
  position: absolute;
  margin-top: -8px;
  top: 50%;
  left: 0;
}
.ui-spinner-down,
.ui-spinner-up {
  background: #739e73;
  border-radius: 0;
}
.ui-spinner-down:before,
.ui-spinner-up:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f067";
  color: #fff;
  font-size: 14px;
  margin-top: 1px;
}
.ui-spinner-down > :first-child,
.ui-spinner-up > :first-child {
  display: none;
}
.ui-spinner-up {
  top: 0;
}
.ui-spinner-up:active,
.ui-spinner-up:focus,
.ui-spinner-up:hover {
  background: #5b835b;
}
.ui-spinner-down {
  bottom: 0;
  background: #c2032f;
}
.ui-spinner-down:before {
  content: "\f068";
}
.ui-spinner-down:active,
.ui-spinner-down:focus,
.ui-spinner-down:hover {
  background: #77021d;
}
.ui-spinner .ui-icon-triangle-1-s {
  background-position: -65px -16px;
}
/*
 * UI date picker
 */
.ui-datepicker {
  width: 17em;
  padding: .2em .2em 0;
  display: none;
}
.ui-datepicker-header {
  position: relative;
  border: 0;
  font-weight: 700;
  width: 100%;
  padding: 4px 0;
  background-color: #f5f5f5;
  color: gray;
}
.ui-datepicker-next,
.ui-datepicker-prev {
  position: absolute;
  top: 2px;
  width: 1.8em;
  height: 1.8em;
  text-align: center;
  margin-top: 2px;
}
.ui-datepicker-next > :first-child,
.ui-datepicker-prev > :first-child {
  text-indent: 0!important;
}
.ui-datepicker-next span,
.ui-datepicker-prev span {
  display: block;
  position: absolute;
  left: 50%;
  margin-left: -8px;
  top: 50%;
  margin-top: -8px;
}
.ui-datepicker-prev {
  left: 2px;
}
.ui-datepicker-next {
  right: 2px;
}
.ui-datepicker-title {
  margin: 0 2.3em;
  line-height: 1.8em;
  text-align: center;
}
.ui-datepicker-title select {
  font-size: 1em;
  margin: 1px 0;
}
.ui-datepicker select.ui-datepicker-month-year {
  width: 100%;
}
.ui-datepicker select.ui-datepicker-month,
.ui-datepicker select.ui-datepicker-year {
  width: 49%;
}
.ui-datepicker table {
  width: 100%;
  font-size: .9em;
  border-collapse: collapse;
  margin: 0 0 .4em;
}
.ui-datepicker th {
  padding: .7em .3em;
  text-align: center;
  border: 0;
  font-weight: 700;
  color: gray;
}
.ui-datepicker td {
  border: 0;
  padding: 1px;
}
.ui-datepicker td:hover {
  color: #fff;
}
.ui-datepicker td a {
  margin-bottom: 0;
  border: 0;
}
.ui-datepicker td a,
.ui-datepicker td span {
  display: block;
  padding: .2em;
  text-align: right;
  text-decoration: none;
}
.ui-datepicker td .ui-state-default {
  border: 0;
  background: 0 0;
  margin-bottom: 0;
  padding: 5px;
  color: gray;
  text-align: center;
  -webkit-filter: none;
  filter: none;
}
.ui-datepicker td .ui-state-highlight {
  color: #fff;
  background-color: #A90329;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-radius: 0;
}
.ui-datepicker td .ui-state-active {
  color: #333;
  background-color: #ebebeb;
  margin-bottom: 0;
  font-size: normal;
  text-shadow: 0;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-radius: 0;
}
.ui-datepicker td .ui-state-hover {
  color: #fff;
  background: #428bca;
  background-color: #428bca;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-color: #357ebd;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-radius: 0;
}
.ui-datepicker-buttonpane {
  background-image: none;
  margin: .7em 0 0;
  padding: 0 .2em;
  border-left: 0;
  border-right: 0;
  border-bottom: 0;
}
.ui-datepicker-buttonpane button {
  float: right;
  margin: .5em .2em .4em;
  cursor: pointer;
  padding: .2em .6em .3em;
  width: auto;
  overflow: visible;
}
.ui-datepicker-buttonpane button.ui-datepicker-current {
  float: left;
}
.ui-datepicker-multi {
  width: auto;
}
.ui-datepicker-multi .ui-datepicker-group {
  float: left;
}
.ui-datepicker-multi .ui-datepicker-group table {
  width: 95%;
  margin: 0 auto .4em;
}
.ui-datepicker-multi-2 .ui-datepicker-group {
  width: 50%;
}
.ui-datepicker-multi-3 .ui-datepicker-group {
  width: 33.3%;
}
.ui-datepicker-multi-4 .ui-datepicker-group {
  width: 25%;
}
.ui-datepicker-multi .ui-detepicker-group-last .ui-datepicker-header,
.ui-datepicker-multi .ui-datepicket-group-middle .ui-datepicker-header {
  border-left-width: 0;
}
.ui-datepicker-multi .ui-datepicker-buttonpane {
  clear: left;
}
.ui-datepicker-row-break {
  clear: both;
  width: 100%;
  font-size: 0;
}
.ui-datepicker-rtl {
  direction: rtl;
}
.ui-datepicker-rtl .ui-datepicker-prev {
  right: 2px;
  left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next {
  left: 2px;
  right: auto;
}
.ui-datepicker-rtl .ui-datepicker-prev:hover {
  right: 1px;
  left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next:hover {
  left: 1px;
  right: auto;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane {
  clear: right;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button {
  float: left;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button.ui-datepicker-current,
.ui-datepicker-rtl .ui-datepicker-group {
  float: right;
}
.ui-datepicker-rtl .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-rtl .ui-datepicker-group-middle .ui-datepicker-header {
  border-right-width: 0;
  border-left-width: 1px;
}
.ui-datepicker-cover {
  display: none;
  display: block;
  position: absolute;
  z-index: -1;
  -webkit-filter: mask();
  filter: mask();
  top: -4px;
  left: -4px;
  width: 200px;
  height: 200px;
}
.ui-datepicker-today a {
  background-color: #BFBFBF;
  cursor: pointer;
  padding: 0 4px;
  margin-bottom: 0;
}
.ui-datepicker-today a:hover {
  background-color: gray;
  color: #fff;
}
/*
 * UI progressbar
 */
.ui-progressbar {
  height: 2em;
  margin-bottom: 20px;
  border: 0;
  overflow: hidden;
  background-color: #f7f7f7;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f5f5f5), to(#f9f9f9));
  background-image: -webkit-gradient(linear, top left, bottom left, from(#f5f5f5), to(#f9f9f9));
  background-image: -webkit-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: linear-gradient(to bottom, #f5f5f5, #f9f9f9);
  background-repeat: repeat-x;
  border-radius: 0;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff5f5f5', endColorstr='#fff9f9f9', GradientType=0);
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}
.ui-progressbar .ui-progressbar-value {
  margin: 0;
  height: 100%;
  color: #fff;
  background-color: #428BCA;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: width .6s ease;
  transition: width .6s ease;
}
.ui-progressbar .ui-progressbar-overlay {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
  background-size: 40px 40px;
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -ms-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
}
.ui-progressbar-indeterminate .ui-progressbar-value {
  background-image: none;
}
/*
 * UI resizable
 */
.ui-resizable {
  position: relative;
}
.ui-resizable-handle {
  position: absolute;
  font-size: .1px;
  z-index: 99999;
  display: block;
}
.ui-resizable-autohide .ui-resizable-handle,
.ui-resizable-disabled .ui-resizable-handle {
  display: none;
}
.ui-resizable-n {
  cursor: n-resize;
  height: 7px;
  width: 100%;
  top: -5px;
  left: 0;
}
.ui-resizable-s {
  cursor: s-resize;
  height: 7px;
  width: 100%;
  bottom: -5px;
  left: 0;
}
.ui-resizable-e {
  cursor: e-resize;
  width: 7px;
  right: -5px;
  top: 0;
  height: 100%;
}
.ui-resizable-w {
  cursor: w-resize;
  width: 7px;
  left: -5px;
  top: 0;
  height: 100%;
}
.ui-resizable-se {
  cursor: se-resize;
  width: 12px;
  height: 12px;
  right: 1px;
  bottom: 1px;
}
.ui-resizable-sw {
  cursor: sw-resize;
  width: 9px;
  height: 9px;
  left: -5px;
  bottom: -5px;
}
.ui-resizable-nw {
  cursor: nw-resize;
  width: 9px;
  height: 9px;
  left: -5px;
  top: -5px;
}
.ui-resizable-ne {
  cursor: ne-resize;
  width: 9px;
  height: 9px;
  right: -5px;
  top: -5px;
}
/*
 * UI selectable
 */
.ui-selectable-helper {
  position: absolute;
  z-index: 100;
  border: 1px dotted #000;
}
/*
 * UI accordion
 */
.ui-accordion {
  width: 100%;
}
.ui-accordion .ui-accordion-li-fix {
  display: inline;
}
.ui-accordion .ui-accordion-header {
  display: block;
  position: relative;
  margin-top: -2px;
  border-color: #ddd!important;
  padding: 10px 15px 10px 36px!important;
  cursor: pointer;
  min-height: 0;
  background-color: #fbfbfb;
  border-radius: 0;
  font-size: 15px;
}
.ui-accordion .ui-accordion-header-active {
  border-bottom: 0!important;
}
.ui-accordion .ui-accordion-icons {
  padding-left: 2.2em;
}
.ui-accordion .ui-accordion-noicons {
  padding-left: .7em;
}
.ui-accordion .ui-accordion-icons .ui-accordion-icons {
  padding-left: 2.2em;
}
.ui-accordion .ui-accordion-header .ui-accordion-header-icon {
  position: absolute;
  left: .5em;
  top: 50%;
  margin-top: -8px;
  text-indent: 0!important;
  background-image: none!important;
  text-align: center;
  line-height: normal;
  left: 12px!important;
  margin-top: -6px !important;
  font-size: 14px!important;
}
.ui-accordion .ui-accordion-content {
  margin-top: -3px;
  border-radius: 0;
  border-top: 0 none;
  border-color: #ddd!important;
  padding: 15px;
  position: relative;
  top: 1px;
  margin-bottom: 2px;
  overflow: auto;
  display: none;
}
.ui-accordion .ui-accordion-content-active {
  display: block;
}
.ui-accordion-header-active + .ui-accordion-content {
  border-top: 1px solid #ddd;
}
.noUi-target * {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-touch-callout: none;
  -ms-touch-action: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  cursor: default;
}
.noUi-target *[disabled] .noUi-base {
  background: #999;
}
.noUi-target *[disabled] .noUi-connect {
  background: #BBB;
}
.noUi-base {
  width: 100%;
  height: 14px;
  position: relative;
  max-width: 100%;
  max-height: 100%;
  border: 1px solid #bfbfbf;
  z-index: 1;
}
.noUi-origin-lower {
  background: #72a8d7;
}
.noUi-handle {
  background: #858585;
  height: 30px;
  width: 16px;
  border: 1px solid #fff;
  margin: -8px 0 0 -8px;
  cursor: default;
}
.noUi-handle:hover {
  background: #6c6c6c;
}
.noUi-active {
  cursor: default;
  -webkit-box-shadow: rgba(0, 0, 0, 0.1) 1px 1px 1px 0;
  box-shadow: rgba(0, 0, 0, 0.1) 1px 1px 1px 0;
  background: #686868;
  height: 32px;
  width: 18px;
  margin: -9px 0 0 -8px;
  border: 0;
}
.noUi-active:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  content: "";
  display: block;
  height: 100%;
  border: 1px solid #ddd;
}
.noUi-connect {
  background: #3276b1;
}
.noUi-background {
  background: #eee;
  border: 0;
}
.noUi-origin {
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  z-index: 0;
}
.noUi-origin-upper {
  background: inherit!important;
}
.noUi-z-index {
  z-index: 10;
}
.noUi-vertical {
  width: 10px;
  height: 100%;
}
.noUi-vertical .noUi-origin {
  bottom: 0;
  left: 0;
}
.noUi-vertical .noUi-handle {
  margin: -8px 0 0 -3px;
}
.noUi-state-tap .noUi-origin {
  -webkit-transition: left .3s, top .3s;
  transition: left .3s, top .3s;
}
/**
 * UI modal dialog
 */
.modal-overflow .modal-body {
  overflow: hidden;
}
.ui-dialog {
  position: absolute;
  top: 0;
  left: 0;
  padding: 0;
  width: 300px;
  overflow: hidden;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #fff;
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
  box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
  border: 1px solid rgba(0, 0, 0, 0.2);
  outline: medium none;
  z-index: 1050;
}
.ui-dialog .ui-dialog-titlebar {
  position: relative;
  padding: 0 10px;
  background: #fff;
  border-color: #fff;
  font-size: 18px;
  text-decoration: none;
  border: 0 0 0 1px solid;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  border-bottom: 1px solid #ccc;
  border-bottom-color: #eee;
}
.ui-dialog .ui-dialog-title {
  float: left;
  margin: 0;
  color: #404040;
  font-weight: 700;
  padding: 5px;
  text-overflow: ellipsis;
  overflow: hidden;
}
.ui-dialog .ui-dialog-titlebar-close {
  position: absolute;
  right: .3em;
  top: 50%;
  width: 19px;
  margin: -16px 4px 0 0;
  padding: 1px;
  height: 18px;
  font-size: 20px;
  font-weight: 700;
  line-height: 13.5px;
  text-shadow: 0 1px 0 #fff;
  filter: alpha(opacity=25);
  -khtml-opacity: .25;
  -moz-opacity: .25;
  opacity: .25;
  background: 0 0;
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.ui-dialog .ui-dialog-titlebar-close:before {
  content: "\f00d";
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 13px;
}
.ui-dialog .ui-dialog-titlebar-close:focus,
.ui-dialog .ui-dialog-titlebar-close:hover {
  padding: 1px;
  filter: alpha(opacity=90);
  -moz-opacity: .9;
  opacity: .9;
}
.ui-dialog .ui-dialog-titlebar-close span {
  display: block;
  margin: 1px;
  text-indent: 9999px;
}
.ui-dialog .ui-dialog-content {
  position: relative;
  border: 0;
  padding: .5em 1em;
  background: 0 0;
  overflow: auto;
}
.ui-dialog .ui-dialog-buttonpane {
  margin: 13px 0 0;
  padding: 19px 15px 20px;
  border-top: 1px solid #eee;
  border-width: 1px 0 0;
  border-radius: 0 0 6px 6px;
  background-image: none;
  background-color: #fff;
  -webkit-box-shadow: inset 0 1px 0 #fff;
  box-shadow: inset 0 1px 0 #fff;
  text-align: right;
}
.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
  float: right;
}
.ui-dialog .ui-dialog-buttonpane button {
  margin: 0 .4em 0 0;
  cursor: pointer;
}
.ui-dialog .ui-resizable-se {
  width: 14px;
  height: 14px;
  right: 3px;
  bottom: 3px;
}
.ui-draggable .ui-dialog-titlebar {
  cursor: move;
}
.ui-dialog-buttonpane .ui-dialog-buttonset .ui-button {
  color: #fff;
  background-color: #428bca;
  border-color: #357ebd;
}
.ui-dialog-buttonpane .ui-dialog-buttonset .ui-button.ui-state-hover {
  color: #fff;
  background-color: #3276b1;
  border-color: #285e8e;
}
.ui-dialog-buttonset .ui-button:not(:first-child) {
  cursor: pointer;
  display: inline-block;
  color: #333;
  background-color: #fff;
  border: 1px solid #ccc;
  -webkit-transition: .1s linear all;
  transition: .1s linear all;
  overflow: visible;
}
.ui-dialog-buttonset .ui-button:not(:first-child) .ui-state-hover {
  color: #333;
  background-color: #ebebeb;
  border-color: #adadad;
  text-decoration: none;
}
.ui-dialog-buttonset .ui-button.ui-button-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.ui-dialog-buttonset .ui-button.ui-button-info.ui-state-hover {
  color: #fff;
  background-color: #39b3d7;
  border-color: #269abc;
}
.ui-dialog-buttonset .ui-button.ui-button-success {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.ui-dialog-buttonset .ui-button.ui-button-success.ui-state-hover {
  color: #fff;
  background-color: #47a447;
  border-color: #398439;
}
.ui-dialog-buttonset .ui-button.ui-button-warning {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.ui-dialog-buttonset .ui-button.ui-button-warning.ui-state-hover {
  color: #fff;
  background-color: #ed9c28;
  border-color: #d58512;
}
.ui-dialog-buttonset .ui-button.ui-button-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.ui-dialog-buttonset .ui-button.ui-button-danger.ui-state-hover {
  color: #fff;
  background-color: #d2322d;
  border-color: #ac2925;
}
.ui-dialog-buttonset .ui-button.ui-button-inverse {
  color: #fff;
  background-color: #222;
  border-color: #080808;
}
.ui-dialog-buttonset .ui-button.ui-button-inverse.ui-state-hover {
  color: #fff;
  background-color: #363636;
  border-color: #000;
}
.modal-overflow {
  position: relative;
}
.modal-overflow .scrollmarker {
  position: absolute;
  width: 100%;
  height: 20px;
}
.modal-overflow .scrollmarker.top {
  background: -moz-linear-gradient(top, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* FF3.6+ */
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #3276b1), color-stop(17%, rgba(50, 118, 177, 0.83)), color-stop(100%, rgba(50, 118, 177, 0)));
  /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(top, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(top, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* Opera 11.10+ */
  background: -ms-linear-gradient(top, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* IE10+ */
  background: linear-gradient(to bottom, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* W3C */
}
.modal-overflow .scrollmarker.bottom {
  background: -moz-linear-gradient(bottom, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* FF3.6+ */
  background: -webkit-gradient(linear, left bottom, left top, color-stop(0%, #3276b1), color-stop(17%, rgba(50, 118, 177, 0.83)), color-stop(100%, rgba(50, 118, 177, 0)));
  /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(bottom, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(bottom, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* Opera 11.10+ */
  background: -ms-linear-gradient(bottom, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* IE10+ */
  background: linear-gradient(to top, #3276b1 0%, rgba(50, 118, 177, 0.83) 17%, rgba(50, 118, 177, 0) 100%);
  /* W3C */
}
/*
 * Pricing-style component
 */
.pricing-big {
  border: 0!important;
}
.pricing-big .panel-heading {
  border-radius: 5px 5px 0 0;
}
.pricing-big .panel-title {
  text-transform: capitalize;
  font-size: 18px;
  padding: 20px 0;
  text-align: center;
  border-radius: 5px 5px 0 0;
  margin: 0;
  font-weight: 700;
}
.pricing-big .the-price {
  padding: 20px 0;
  background: #333;
  text-align: center;
  font-size: 24px;
  font-weight: 700;
  color: #FFF;
  -webkit-box-shadow: none!important;
  box-shadow: none!important;
}
.pricing-big .subscript {
  font-size: 18px;
  color: #999;
  margin-left: 5px;
}
.pricing-big .panel-footer {
  border-radius: 0 0 5px 5px;
  background-color: #F2F2F2!important;
}
.pricing-big .panel-footer > div {
  padding: 15px 0 10px;
  display: block;
  font-size: 13px;
}
.pricing-big .panel-footer .btn {
  padding: 15px 0;
  border-radius: 3px;
  font-weight: 700;
  font-size: 14px;
}
.pricing-big .panel-footer .btn span {
  font-weight: 400;
  font-style: italic;
}
.pricing-big table {
  background: #FAFAFA;
  padding: 20px 15px;
  height: 230px;
  text-align: left;
}
.price-features {
  background: #FAFAFA;
  padding: 20px 15px;
  min-height: 230px;
  font-size: 13.5px;
}
.price-features .price-features li + li {
  margin-top: 10px;
}
/*
 * Superbox component
 */
.superbox *,
.superbox :after,
.superbox :before {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-font-smoothing: antialiased;
  -moz-font-smoothing: antialiased;
  -o-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
}
.superbox-list {
  display: inline-block;
  *display: inline;
  zoom: 1;
  width: 12.5%;
  padding: 5px;
  position: relative;
}
.superbox-list.active:before {
  content: "\f0d8";
  font-family: FontAwesome;
  display: block;
  position: absolute;
  left: 43%;
  bottom: -34px;
  z-index: 2;
  text-align: center;
  font-size: 45px;
  color: #222;
}
@media only screen and (min-width: 320px) {
  .superbox-list {
    width: 50%;
  }
}
@media only screen and (min-width: 486px) {
  .superbox-list {
    width: 25%;
  }
}
@media only screen and (min-width: 768px) {
  .superbox-list {
    width: 16.66666667%;
  }
}
@media only screen and (min-width: 1025px) {
  .superbox-list {
    width: 12.5%;
  }
}
@media only screen and (min-width: 1824px) {
  .superbox-list {
    width: 12.5%;
  }
}
.superbox-img {
  max-width: 100%;
  width: 100%;
  cursor: pointer;
}
.superbox-show {
  text-align: left;
  position: relative;
  background-color: #222;
  width: 100%;
  float: left;
  padding: 25px 0 12px 25px;
  display: none;
  margin: 5px 0;
}
.superbox-current-img {
  max-width: 100%;
  float: left;
  padding-right: 25px;
  padding-bottom: 13px;
}
.superbox-img:hover {
  opacity: .8;
}
.superbox-float {
  float: left;
}
.superbox-close {
  opacity: .7;
  cursor: pointer;
  position: absolute;
  top: 15px;
  right: 15px;
  -webkit-transition: all .1s linear 0s;
  transition: all .1s linear 0s;
}
.superbox-close:hover {
  opacity: 1;
}
.superbox-imageinfo {
  display: inline-block;
  max-width: 500px;
  color: #fff;
  padding: 0 25px 0 0;
}
.superbox-imageinfo span {
  font-size: 13px;
  color: #a19994;
  margin-right: -2px;
  padding-top: 10px;
  display: inline-block;
  padding-bottom: 13px;
}
.superbox-imageinfo > :first-child {
  margin-bottom: 10px;
  font-weight: 700;
}
.superbox-imageinfo span p:last-child {
  margin-top: 30px;
}
/*
 * Bootstrap tags input
 */
.bootstrap-tagsinput {
  display: block;
  width: 100%;
  min-height: 32px;
  padding: 1px 3px;
  font-size: 13px;
  line-height: 1.428571429;
  color: #555;
  vertical-align: middle;
  background-color: #FFF;
  border: 1px solid #CCC;
  border-radius: 0;
}
.bootstrap-tagsinput > span {
  border-radius: 0!important;
  font-weight: 400;
  padding: 3px 28px 4px 8px;
  font-size: 13px;
  border: 1px solid #285E8E;
  background: #3276B1;
}
.bootstrap-tagsinput input {
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  outline: 0;
  background-color: transparent;
  padding: 0;
  margin: 0;
  width: auto!important;
  max-width: inherit;
}
.bootstrap-tagsinput input:focus {
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.bootstrap-tagsinput .tag {
  color: #FFF;
  position: relative;
  margin: 3px 0 3px 2px;
  display: inline-block;
}
.bootstrap-tagsinput .tag [data-role=remove] {
  display: block;
  top: -1px;
  right: 0;
  padding: 3px 4px 3px 5px;
  width: 23px;
  height: 22px;
  position: absolute;
  cursor: pointer;
}
.bootstrap-tagsinput .tag [data-role=remove]:after {
  content: "\f057";
  font-family: fontAwesome;
  padding: 2px 1px;
  line-height: 17px;
  font-size: 15px;
  text-align: center;
}
.bootstrap-tagsinput .tag [data-role=remove]:hover {
  background: rgba(0, 0, 0, 0.3);
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.bootstrap-tagsinput .tag [data-role=remove]:hover:active {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
/*
 * Bootstrap slider
 */
.slider {
  display: inline-block;
  vertical-align: middle;
  position: relative;
}
.slider.slider-horizontal {
  width: 100%!important;
  height: 20px;
}
.slider.slider-horizontal .slider-track {
  height: 10px;
  width: 100%;
  margin-top: -5px;
  top: 50%;
  left: 0;
}
.slider.slider-horizontal .slider-selection {
  height: 100%;
  top: 0;
  bottom: 0;
}
.slider.slider-horizontal .slider-selection + .slider-handle.triangle + .slider-handle.triangle:before {
  content: "\f0d9";
}
.slider.slider-horizontal .slider-handle {
  margin-left: -10px;
  margin-top: -5px;
}
.slider.slider-horizontal .slider-handle.triangle {
  width: 20px;
  height: 20px;
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(0deg);
  -ms-transform: rotate(0deg);
  transform: rotate(0deg);
  border: 0;
  line-height: 21px;
  color: #797777;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.8);
}
.slider.slider-horizontal .slider-handle.triangle:before {
  content: "\f0da";
  font-size: 34px;
}
.slider.slider-vertical {
  height: 210px;
  width: 20px;
}
.slider.slider-vertical .slider-track {
  width: 10px;
  height: 100%;
  margin-left: -5px;
  left: 50%;
  top: 0;
}
.slider.slider-vertical .slider-selection {
  width: 100%;
  left: 0;
  top: 0;
  bottom: 0;
}
.slider.slider-vertical .slider-selection + .slider-handle.triangle + .slider-handle.triangle:before {
  content: "\f0d8";
  text-shadow: 0 -1px 0 rgba(255, 255, 255, 0.8);
}
.slider.slider-vertical .slider-handle {
  margin-left: -5px;
  margin-top: -10px;
}
.slider.slider-vertical .slider-handle.triangle {
  width: 20px;
  height: 20px;
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(0deg);
  -ms-transform: rotate(0deg);
  transform: rotate(0deg);
  border: 0;
  line-height: 21px;
  color: #797777;
  text-shadow: 0 -1px 0 rgba(255, 255, 255, 0.8);
}
.slider.slider-vertical .slider-handle.triangle:before {
  content: "\f0d7";
  font-size: 32px;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.8);
}
.slider input {
  display: none;
}
.slider .tooltip-inner {
  white-space: nowrap;
}
.slider-track {
  position: absolute;
  cursor: pointer;
  background: #E5E5E5;
}
.slider-danger + .slider-track > .slider-selection {
  background: #a90329;
}
.slider-warning + .slider-track > .slider-selection {
  background: #c79121;
}
.slider-info + .slider-track > .slider-selection {
  background: #57889c;
}
.slider-success + .slider-track > .slider-selection {
  background: #739e73;
}
.slider-selection {
  position: absolute;
  background: #3276b1;
}
.slider-handle {
  position: absolute;
  width: 20px;
  height: 20px;
  border: 1px solid #FFF;
  background: #858585;
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: 400;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-align: center;
  line-height: 18px;
  font-size: 10px;
  color: #BDBDBD;
  text-shadow: 0 1px 0 rgba(77, 77, 77, 0.5);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.slider-handle:before {
  content: "\f0c9";
}
.slider-handle.round {
  border-radius: 20px;
  width: 20px;
  height: 20px;
}
.slider-handle.triangle {
  background: transparent none;
}
/*
 * fd-slider widget
 */
.fd-form-element-hidden {
  display: none;
}
.fd-slider {
  width: 100%;
  height: 20px;
  margin: 0;
}
.fd-slider-vertical {
  width: 20px;
  height: 100%;
  margin: 0 10px 10px 0;
}
.fd-slider,
.fd-slider-vertical {
  display: block;
  position: relative;
  text-decoration: none;
  border: 0 none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.fd-slider-inner {
  display: none;
}
.fd-slider-bar {
  position: absolute;
  display: block;
  z-index: 2;
  height: 6px;
  width: 100%;
  border: 1px solid #bbb;
  border-bottom: 1px solid #fff;
  border-right: 1px solid #fff;
  margin: 0;
  padding: 0;
  overflow: hidden;
  line-height: 4px;
  top: 8px;
  border-radius: 4px;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #333;
}
.fd-slider-range {
  position: absolute;
  display: block;
  z-index: 3;
  height: 6px;
  margin: 0;
  padding: 0 2px 0 0;
  overflow: hidden;
  top: 9px;
  border-radius: 2px;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #eee;
}
.fd-slider-handle {
  position: absolute;
  display: block;
  padding: 0;
  margin: 0 0 0 1px;
  z-index: 3;
  top: 5px;
  left: 0;
  width: 12px;
  height: 12px;
  line-height: 1px!important;
  outline: 0 none;
  background: #eee;
  border: 1px solid #aaa;
  border-radius: 12px;
  -webkit-user-select: none;
  -webkit-touch-callout: none;
  -moz-user-select: none;
  -moz-user-focus: none;
  -moz-outline: 0 none;
  -ms-user-select: none;
  user-select: none;
}
.fd-slider-handle:focus {
  outline: 0 none;
  border: 0 none;
  -moz-user-focus: normal;
}
.fd-slider-handle:before,
.fd-slider-handle:after {
  opacity: 0;
  -webkit-transition-property: opacity;
  -webkit-transition-duration: 1s;
  -webkit-transition-delay: 1s;
  transition-property: opacity;
  transition-duration: 1s;
  transition-delay: 1s;
}
button.fd-slider-handle:focus::-moz-focus-inner {
  border-color: transparent;
}
.oldie .fd-slider-handle:after,
.oldie .fd-slider-handle:before {
  display: none;
}
body.fd-slider-drag-horizontal,
body.fd-slider-drag-horizontal *,
body.fd-slider-drag-vertical,
body.fd-slider-drag-vertical * {
  -moz-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.fd-slider-active .fd-slider-handle :before,
.fd-slider-focused .fd-slider-handle :before,
.fd-slider-hover .fd-slider-handle :before {
  display: block;
  position: absolute;
  top: -21px;
  left: -8px;
  margin: 0;
  width: 20px;
  padding: 3px;
  height: 14px;
  line-height: 12px;
  text-align: center;
  font-size: 10px;
  font-weight: 700;
  color: #fff;
  text-shadow: 1px 1px 1px #1a3a95;
  background: #2f6ee0;
  z-index: 1;
  content: attr(aria-valuetext);
  border-radius: 3px;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-box-shadow: 0 0 4px #aaa;
  box-shadow: 0 0 4px #999;
  opacity: 1;
}
.fd-slider-active .fd-slider-handle:after,
.fd-slider-focused .fd-slider-handle:after,
.fd-slider-hover .fd-slider-handle:after {
  outline: 0;
  content: "";
  display: block;
  position: absolute;
  top: -9px;
  left: 50%;
  margin: 0 0 0 -5px;
  background: #2f6ee0;
  z-index: 2;
  width: 10px;
  height: 10px;
  overflow: hidden;
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  -webkit-box-shadow: 0 0 4px #aaa;
  box-shadow: 0 0 4px #aaa;
  clip: rect(4px, 14px, 14px, 4px);
  opacity: 1;
}
/*
 * Graphs
 */
.chart {
  height: 220px;
  margin: 20px 5px 10px 10px;
}
.chart-small {
  height: 100px;
  width: 100%;
}
.chart-large {
  height: 235px;
  width: 100%;
}
.chart-xl {
  height: 297px;
  width: 100%;
}
#flotTip {
  padding: 3px 5px;
  background-color: #fff;
  z-index: 9999;
  color: #333;
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
  font-size: 14px;
  border: 1px solid #C1C1C1;
  -khtml-border-radius: 4px;
  border-radius: 4px;
}
#flotTip span {
  color: #38812D;
  font-weight: 700;
}
.has-legend {
  margin-top: 30px!important;
}
.has-legend-unique {
  margin-top: 19px!important;
}
.legendLabel span {
  display: block;
  margin: 0 5px;
}
.legendColorBox {
  padding-left: 10px;
  vertical-align: top;
  padding-top: 5px;
}
.legendColorBox div > div {
  width: 4px;
  height: 4px;
  border-radius: 50%;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
.morris-hover {
  position: absolute;
  z-index: 1001;
}
.morris-hover.morris-default-style {
  border-radius: 10px;
  padding: 6px;
  color: #666;
  background: rgba(255, 255, 255, 0.8);
  border: solid 2px rgba(230, 230, 230, 0.8);
  font-family: Ubuntu, sans-serif;
  font-size: 12px;
  text-align: center;
}
.morris-hover.morris-default-style .morris-hover-row-label {
  font-weight: 700;
  margin: .25em 0;
}
.morris-hover.morris-default-style .morris-hover-point {
  white-space: nowrap;
  margin: .1em 0;
}
.easyPieChart {
  position: relative;
  text-align: center;
}
.easyPieChart canvas {
  position: absolute;
  top: 0;
  left: 0;
}
.easy-pie-chart {
  display: inline-block;
}
.easy-pie-chart .percent {
  color: #444;
  font-size: 12px;
  font-weight: 700;
}
.easy-pie-title {
  display: inline-block;
  margin: 10px 6px 0;
  font-size: 12px;
  font-weight: 400;
  text-transform: uppercase;
  width: 100px;
  height: 19px;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
.easy-pie-title .icon-color-bad,
.easy-pie-title .icon-color-good {
  font-size: 18px;
}
.show-stat-buttons {
  float: left;
  width: 100%;
}
@media (max-width: 767px) {
  .show-stat-buttons {
    padding-left: 10px!important;
    padding-right: 10px!important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .show-stat-buttons {
    padding-left: 10px!important;
    padding-right: 10px!important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .show-stat-buttons {
    padding-left: 10px!important;
    padding-right: 10px!important;
  }
}
.show-stats {
  padding-top: 6px!important;
}
.show-stats .progress {
  height: 7px;
  border-radius: 0;
  margin-top: 3px;
  margin-bottom: 15px;
}
.show-stats .show-stat-buttons > :first-child {
  padding-right: 5px;
}
@media (max-width: 979px) {
  .show-stats .show-stat-buttons > :first-child {
    padding-right: 13px;
  }
}
.show-stats .show-stat-buttons > :last-child {
  padding-left: 5px;
}
@media (max-width: 979px) {
  .show-stats .show-stat-buttons > :last-child {
    padding-left: 13px;
  }
}
.show-stat-microcharts {
  margin-left: -10px;
  margin-right: -10px;
}
.show-stat-microcharts > div {
  border-right: 1px solid #DADADA!important;
  border-top: 1px solid #DADADA!important;
  margin-top: 10px!important;
  height: 65px;
  overflow: hidden;
  padding: 7px 9px;
}
@media (max-width: 767px) {
  .show-stat-microcharts > div {
    margin-top: 0!important;
    border-right: 0!important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .show-stat-microcharts > div {
    margin-top: 0!important;
    border-right: 0!important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .show-stat-microcharts > div {
    margin-top: 0!important;
    border-right: 0!important;
  }
}
.show-stat-microcharts > :last-child {
  border-right: 0!important;
}
.show-stat-microcharts .sparkline {
  margin-top: 10px;
  margin-right: 8px;
  opacity: .7;
}
.show-stat-microcharts .sparkline:hover {
  opacity: 1;
}
.smaller-stat {
  margin: 0;
  padding: 0;
  list-style: none;
}
.smaller-stat li {
  margin-top: 3px;
  margin-right: 0;
}
.smaller-stat li:first-child {
  margin-top: 8px;
}
.smaller-stat span.label {
  width: 40px;
  display: block;
  text-align: left;
  opacity: .5;
  cursor: default;
}
.smaller-stat span.label:hover {
  opacity: 1;
}
.jvectormap-label {
  position: absolute;
  display: none;
  border: solid 1px #CDCDCD;
  border-radius: 3px;
  background: #292929;
  color: #fff;
  font-family: Ubuntu, sans-serif, Verdana;
  font-size: smaller;
  padding: 3px;
}
.jvectormap-zoomin {
  top: 0;
}
.jvectormap-zoomout {
  top: 24px;
}
.jvectormap-zoomin,
.jvectormap-zoomout {
  position: absolute;
  background: #292929;
  padding: 4px;
  width: 22px;
  height: 22px;
  cursor: pointer;
  line-height: 10px;
  text-align: center;
  font-size: 14px;
  border-radius: 2px;
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  background-color: #fff;
  border: 1px solid #bfbfbf;
}
.jvectormap-zoomin:hover,
.jvectormap-zoomout:hover {
  background: #eee;
  border-color: #d9d9d9;
}
.vector-map {
  height: 300px;
  width: 100%;
  padding: 10px;
}
/*
 * Chat application
 */
#chat-container {
  position: absolute;
  width: 250px;
  height: 270px;
  z-index: 2;
  border-left: 1px solid #CDCECF;
  right: -251px;
  top: 0;
  background: #fff;
  transition-duration: .25s;
  -webkit-transition-duration: .25s;
}
#chat-container:hover,
#chat-container:hover .chat-list-open-close {
  border-color: #A7A7A7;
}
#chat-container *,
#chat-container :after,
#chat-container :before {
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
#chat-container input[type=text] {
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
}
#chat-container.open {
  right: 0;
  top: 0;
}
#chat-container.open .chat-list-open-close i:before {
  content: "\f00d" !important;
}
#chat-container.open .chat-list-open-close b {
  display: none;
}
#chat-container .chat-list-open-close {
  display: block;
  width: 25px;
  height: 25px;
  border: 1px solid #CDCECF;
  border-right: 1px solid #f2f4f8!important;
  position: absolute;
  left: -32px;
  top: 7%;
  border-radius: 50% 0 0 50%;
  padding: 3px 1px 3px 5px;
  font-size: 21px;
  line-height: 22px;
  cursor: pointer;
  color: #868686;
  -webkit-box-shadow: inset 0 0.2em 0 rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 0.2em 0 rgba(0, 0, 0, 0.05);
  background: #f2f4f8;
  text-align: center;
}
#chat-container .chat-list-open-close b {
  position: absolute;
  right: 0;
  background: #ed1c24;
  line-height: 9px;
  height: 10px;
  width: 10px;
  top: 3px;
  border: 1px solid #FFF;
  border-radius: 3px;
  font-size: 9px;
  text-align: center;
  vertical-align: middle;
  color: #fff;
  font-weight: 400;
}
#chat-container .chat-list-body {
  height: 217px;
  overflow-y: scroll;
  overflow-x: hidden;
  display: block;
  padding: 0;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  background: #f2f4f8;
}
#chat-container #chat-users {
  list-style: none;
  margin: 10px 0;
  padding: 0;
}
#chat-container #chat-users li {
  margin-bottom: 3px;
  margin-left: 5px;
}
#chat-container #chat-users li a {
  display: block;
  font-size: 13px;
  color: #3d3d3d;
  text-decoration: none!important;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  padding: 3px 8px 3px 3px;
  line-height: 33px;
  vertical-align: middle;
}
#chat-container #chat-users li a:hover {
  background: #e0e4ee;
}
#chat-container #chat-users li a img {
  width: 33px;
  height: auto;
  margin-right: 10px;
}
#chat-container #chat-users li a i {
  color: #ACACAC;
  font-size: 8px;
  line-height: 34px;
  font-style: normal;
}
#chat-container #chat-users li a i.last-online {
  font-size: 12px;
  letter-spacing: -1px;
}
#chat-container .chat-list-footer {
  overflow: hidden;
  border-top: 1px solid #CCC;
  padding: 10px;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
}
#chat-container .chat-list-footer input[type=text] {
  border: 1px solid #bababa!important;
}
#chat-container .control-group {
  padding: 0;
}
.chat-body {
  background: #FAFAFA;
  background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodâ€¦EiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #fafafa), color-stop(100%, #ffffff));
  background: -webkit-linear-gradient(top, #fafafa 0, #ffffff 100%);
  background: -webkit-gradient(linear, top left, bottom left, from(#f5fcff), to(#ffffff));
  background: -webkit-linear-gradient(top, #f5fcff 0, #ffffff 100%);
  background: linear-gradient(to bottom, #f5fcff 0, #ffffff 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fafafa', endColorstr='#ffffff', GradientType=0);
  -webkit-box-shadow: inset 2px 2px 5px rgba(0, 0, 0, 0.04);
  box-shadow: inset 2px 2px 5px rgba(0, 0, 0, 0.04);
  display: block;
  height: 270px;
  overflow-y: scroll;
  overflow-x: hidden;
  padding: 10px;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  border: 1px solid #fff;
  border-top: 0;
}
.chat-body ul {
  margin: 0;
  padding: 0;
}
.chat-body li:first-child {
  margin-top: 10px;
}
.chat-body li.message {
  display: block;
  position: relative;
  margin: 20px 20px 0;
}
.chat-body li.message img {
  display: inline-block;
  border-left: 4px solid #fff;
  position: absolute;
}
.chat-body li.message img.online {
  border-left-color: #00a300;
}
.chat-body li.message img.offline {
  border-left-color: #ddd;
}
.chat-body li.message img.busy {
  border-left-color: #A90329;
}
.chat-body li.message img.away {
  border-left-color: #ffc40d;
}
.chat-body li.message .message-text {
  display: inline-block;
  vertical-align: top;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  padding: 0;
  margin-left: 65px;
  line-height: normal;
}
.chat-body li.message .message-text time {
  position: absolute;
  top: 1px;
  right: 0;
  font-size: 10px;
  line-height: 10px;
  color: #AFAFAF;
}
.chat-body li.message .message-text .chat-file {
  display: block;
  margin: 3px 0;
  padding: 4px;
  border: 1px dotted #ddd;
  background: rgba(0, 0, 0, 0.05);
  border-radius: 4px;
  text-align: right;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.chat-body li.message .message-text .chat-file:nth-child(3) {
  margin-top: 15px;
}
.chat-body li.message .message-text .chat-file.row-fluid [class*=span] {
  min-height: 10px!important;
}
.chat-body li.message .message-text .chat-file b {
  font-style: italic;
  white-space: nowrap;
  width: 250px;
  overflow: hidden;
  text-overflow: ellipsis;
  text-align: left;
}
@media (min-width: 768px) and (max-width: 880px) {
  .chat-body li.message .message-text .chat-file b {
    width: 150px;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .chat-body li.message .message-text .chat-file b {
    width: 150px;
  }
}
@media (max-width: 480px) {
  .chat-body li.message .message-text .chat-file b {
    width: 150px;
  }
}
.chat-body li.message .message-text a.username {
  display: block;
  font-weight: 700;
  margin-bottom: 4px;
  vertical-align: top;
  line-height: 14px;
  font-size: 14px;
  letter-spacing: -1px;
  text-decoration: none!important;
}
.chat-footer {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
  padding: 0 10px 15px;
  position: relative;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.profile-message {
  background: none!important;
  height: auto!important;
  box-shadow: none!important;
  -webkit-box-shadow: none!important;
  overflow: hidden;
}
.profile-message li.message.message-reply {
  margin-left: 85px!important;
  background: #F7F7F7;
  padding: 10px;
  margin: 3px 0 0 20px;
}
.profile-message li.message.message-reply img {
  width: 35px!important;
}
.profile-message li.message.message-reply .message-text {
  margin-left: 45px!important;
}
.profile-message .wall-comment-reply {
  margin-left: 85px;
  margin-bottom: 20px;
}
.cajita img {
  width: 23px;
  height: 23px;
  padding-left: 3px;
  padding-top: 3px;
}
#pageslide {
  display: none;
  position: absolute;
  position: fixed;
  top: 0;
  height: 100%;
  z-index: 999999;
  width: 305px;
  padding: 20px;
  background-color: #004d60;
  color: #FFF;
  -webkit-box-shadow: inset 0 0 5px 5px #222;
  -moz-shadow: inset 0 0 0 0 #222;
  box-shadow: inset 0 0 0 0 #222;
}
.purehtml {
  color: #fff;
  font-size: 16px;
}
/*
 *  Mail-style application
 */
#inbox-table {
  font-size: 13px;
  border-top: 0;
  border-left-color: transparent!important;
  border-right-color: transparent!important;
}
#inbox-table tbody tr:hover {
  cursor: pointer;
  background: #E4E4E4;
}
#inbox-table tr td {
  border-right: 0;
  border-left: 0;
  line-height: 26px;
  padding: 6px 4px 7px!important;
}
#inbox-table .inbox-table-icon {
  padding-left: 15px!important;
}
@media (max-width: 979px) {
  #inbox-table .inbox-table-icon {
    padding-left: 10px!important;
  }
}
#inbox-table tbody tr th {
  overflow: hidden;
}
#inbox-table.table tbody > tr > td {
  border-color: #fff!important;
}
#inbox-table .checkbox,
#inbox-table .radio {
  margin-top: -1px;
  margin-bottom: 0;
}
.minified .inbox-badge {
  border-radius: 50%;
  font-size: 9px;
  padding: 2px;
  position: absolute;
  top: 6px;
  right: 6px;
  background: #ED1C24;
  min-width: 13px;
}
.inbox-body {
  position: relative;
}
.inbox-body .table-wrap {
  background: #fff;
  padding: 10px 14px 7px;
  position: relative;
  margin-left: 200px;
}
@media (max-width: 1024px) {
  .inbox-body .table-wrap {
    margin-left: 0!important;
  }
}
@media (max-width: 979px) {
  .inbox-body .table-wrap {
    padding: 0!important;
  }
}
.inbox-body.no-content-padding {
  margin-top: 0;
  background: #fff;
}
.inbox-nav-bar {
  height: 70px;
  margin-bottom: 0;
  padding: 20px 14px;
  background: #fff;
}
@media (max-width: 979px) {
  .inbox-nav-bar {
    padding-left: 5px;
    padding-right: 5px;
  }
}
@media (min-width: 768px) and (max-width: 880px) {
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
}
@media (max-width: 767px) {
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
}
@media only screen and (min-width: 0) and (max-width: 679px) {
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
}
.inbox-nav-bar .page-title {
  display: inline-block;
  margin: 0;
  width: 196px;
  line-height: 33px;
  vertical-align: middle;
}
.inbox-footer {
  height: 52px;
  padding: 15px 14px 0;
  border-top: 1px solid #CECECE;
  background: #2a2725;
  position: absolute;
  bottom: -53px;
  width: 100%;
}
.inbox-footer .btn-group,
.inbox-paging {
  margin-left: 10px;
}
.inbox-data-attachment,
.inbox-table-icon {
  width: 28px;
  text-align: left;
  padding-left: 12px!important;
  padding-right: 0!important;
}
.inbox-data-from {
  width: 200px;
}
.inbox-data-from > :first-child {
  width: 200px;
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.inbox-data-date {
  width: 80px;
  padding-left: 7px!important;
  padding-right: 0!important;
}
.inbox-data-message > :first-child {
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 27px;
  color: #8A8A8A;
}
@media (max-width: 979px) {
  .inbox-data-message > :first-child {
    height: 50px;
    overflow: hidden;
  }
}
.inbox-data-message > :first-child span {
  color: #111;
}
.inbox-data-message > :first-child span.label {
  color: #fff;
}
@media (max-width: 979px) {
  .inbox-data-message > :first-child > :first-child {
    display: block!important;
    font-size: 14px;
  }
}
.inbox-data-message > :first-child > :first-child:after {
  content: " - ";
}
.inbox-checkbox-triggered {
  display: inline-block;
}
.inbox-checkbox-triggered > .btn-group {
  margin-right: 10px;
}
.inbox-checkbox-triggered > .btn-group .btn {
  padding-left: 14px;
  padding-right: 14px;
}
@media (max-width: 979px) {
  .inbox-checkbox-triggered > .btn-group .btn {
    padding-left: 10px;
    padding-right: 10px;
  }
}
.inbox-side-bar {
  height: 100%;
  position: absolute;
  background: #fff;
  display: block;
  width: 200px;
  padding: 10px 0 10px 14px;
}
@media (max-width: 1024px) {
  .inbox-side-bar {
    display: none!important;
  }
}
.inbox-side-bar h6 {
  font-weight: 400;
  font-size: 11px;
  display: block;
  padding: 0 15px;
  text-transform: uppercase;
  color: #838383;
}
.inbox-side-bar h6 a {
  font-size: 14px;
  margin-top: -2px;
}
.inbox-side-bar h6 .tooltip {
  text-transform: none!important;
}
.inbox-side-bar > .btn {
  margin-bottom: 35px;
}
.inbox-side-bar .input-group {
  margin-bottom: 25px;
}
.inbox-space {
  display: block;
  width: 185px;
}
.inbox-space > .progress {
  margin-top: 5px;
}
.inbox .inbox-menu-lg {
  list-style: none;
  padding: 0;
  margin: 0 0 20px;
}
.inbox .inbox-menu-lg .inbox-menu-lg li {
  display: block;
  width: 100%;
}
.inbox .inbox-menu-lg .inbox-menu-lg li a {
  display: block;
  padding: 6px 15px 7px;
  font-size: 13px;
  color: #333;
}
.inbox .inbox-menu-lg .inbox-menu-lg li a:hover {
  text-decoration: none;
  background: #f4f4f4;
}
.inbox .inbox-menu-lg .inbox-menu-lg li.active a {
  font-weight: 700;
  background: #F0F0F0;
  border-bottom: 1px solid #E7E7E7;
  color: #3276b1;
}
.inbox .inbox-menu-sm {
  list-style: none;
  padding: 0;
  margin: 0 0 20px;
}
.inbox .inbox-menu-sm .inbox-menu-sm li {
  display: block;
  width: 100%;
}
.inbox .inbox-menu-sm .inbox-menu-sm li a {
  display: block;
  padding: 8px 15px 10px;
  font-size: 13px;
  color: #333;
}
.inbox .inbox-menu-sm .inbox-menu-sm li a:hover {
  text-decoration: none;
  background: #f4f4f4;
}
.inbox .inbox-menu-sm .inbox-menu-sm li.active a {
  font-weight: 700;
  background: #F0F0F0;
  border-bottom: 1px solid #E7E7E7;
  color: #3276b1;
}
.inbox-info-bar {
  padding: 10px 0;
  border-bottom: 1px solid #bfbfbf;
}
.inbox-info-bar .form-group {
  margin: 0;
}
.inbox-info-bar .form-group input,
.inbox-info-bar .select2-container-multi .select2-choices {
  border-color: #fff!important;
}
.inbox-info-bar .select2-choices > div {
  display: none;
}
.inbox-info-bar .col-md-1,
.inbox-info-bar .col-md-11 {
  padding-left: 0;
  padding-right: 0;
}
@media (max-width: 1024px) {
  .inbox-info-bar .col-md-1,
  .inbox-info-bar .col-md-11 {
    padding-left: 26px;
    padding-right: 26px;
  }
}
.inbox-info-bar img {
  width: 35px;
  height: auto;
  display: inline-block;
  vertical-align: middle;
  margin-right: 7px;
  margin-left: 2px;
  border-left: 3px solid #fff;
}
.inbox-info-bar em {
  position: absolute;
  top: 6px;
  right: 20px;
  text-align: right;
  font-style: normal;
}
.inbox-download .inbox-message {
  padding: 15px 4px;
  border-bottom: 1px solid #bfbfbf;
}
.inbox-download-list {
  list-style: none;
  margin: 5px 0 0;
  padding: 0;
}
.inbox-download-list li {
  display: inline-block;
  margin: 0 5px 0 0;
  vertical-align: top;
}
.inbox-download-list li > :first-child {
  margin-bottom: 0;
  width: 150px;
  overflow: hidden;
}
.inbox-download-list li > :first-child:hover {
  background: #fff;
  border-color: silver;
}
.inbox-download-list li > :first-child > :first-child {
  text-align: center;
  display: block;
  color: #D6D6D6;
}
.inbox-download-list li > :first-child > :first-child > .fa {
  font-size: 150px;
}
.inbox-download-list li > :first-child > :first-child > img {
  max-width: 120px;
}
.inbox-compose-footer {
  padding: 10px;
  background: #F5F5F5;
  border-bottom: 1px solid #A9A9A9;
}
.inbox-compose-footer,
.inbox-download,
.inbox-info-bar,
.inbox-message {
  margin-right: 240px;
  position: relative;
}
@media (max-width: 1280px) {
  .inbox-compose-footer,
  .inbox-download,
  .inbox-info-bar,
  .inbox-message {
    margin-right: 0;
  }
}
@media (max-width: 979px) {
  .inbox-table-icon > :first-child {
    margin-top: 12px;
  }
}
.unread td {
  background: #fff;
}
.unread .inbox-data-date > :first-child,
.unread .inbox-data-from > :first-child,
.unread .inbox-data-message > :first-child > :first-child {
  font-weight: 700;
}
tr.highlight td,
tr.unread.highlight td {
  background: #ffc!important;
  color: #333;
}
#compose-mail-mini {
  margin-left: 4px;
}
.email-open-header {
  margin: -10px 0 0 0;
  font-size: 20px;
  border-bottom: 1px solid #bfbfbf;
  border-top: 1px solid #eee;
  padding: 15px 3px;
}
.email-open-header > span {
  font-size: 10px;
  font-weight: 400;
  padding: 3px 5px;
  letter-spacing: normal;
  text-transform: uppercase;
  vertical-align: middle;
  line-height: 33px;
  background: #ACACAC;
}
.email-infobox {
  display: block;
  width: 180px;
  border-bottom: 1px solid #bfbfbf;
  padding-bottom: 0;
  padding-top: 15px;
  position: absolute;
  top: 65px;
  right: 15px;
}
@media (max-width: 1280px) {
  .email-infobox .email-infobox {
    display: none;
  }
}
.email-reply-text > div {
  border-left: 1px solid #D6D6D6;
  padding-left: 10px;
  margin-left: 50px;
  color: #A9A9A9;
}
.email-reply-text > :first-child {
  padding-left: 45px;
}
.profile-pic {
  text-align: right;
}
.profile-pic > img {
  border-radius: 0;
  position: relative;
  border: 5px solid #fff;
  top: -30px;
  display: inline-block;
  text-align: right;
  z-index: 4;
  width: 120px;
  margin-bottom: -30px;
}
.profile-carousel .carousel-inner {
  max-height: 150px;
}
.friends-list li {
  margin-bottom: 10px;
}
.friends-list li img {
  width: 35px;
  border: 1px solid #fff;
  outline: 1px solid #bfbfbf;
}
.search-results {
  padding: 18px 5px;
}
.search-results + .search-results {
  border-top: 1px dashed #E3E3E3;
}
.search-results > :first-child {
  margin-bottom: 4px;
  font-weight: 400;
}
.search-results > :first-child a {
  text-decoration: underline;
}
.search-results .url {
  font-style: normal;
  font-size: 14px;
}
.search-results img {
  display: inline-block;
  margin-top: 4px;
  margin-right: 4px;
  width: 80px;
}
.search-results > div {
  display: inline-block;
  vertical-align: top;
}
.search-results .note {
  margin: 0;
  line-height: normal;
}
.search-results .note a {
  text-decoration: none!important;
  color: #333;
}
.search-results .note a:hover {
  color: #ed1c24;
}
/*
 * Todo-like application
 */
.todo {
  margin: 0;
  padding: 0;
  min-height: 5px;
  list-style: none;
}
.todo > li {
  display: block;
  position: relative;
  overflow: hidden;
  border-bottom: 1px solid #e7e7e7;
  margin: 0 5px;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAAQCAYAAADagWXwAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo0RkQ1OEY4NTM4NUIxMUUzQjdCMUMxQzJCQUE3MTMxOCIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDo0RkQ1OEY4NjM4NUIxMUUzQjdCMUMxQzJCQUE3MTMxOCI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjRGRDU4RjgzMzg1QjExRTNCN0IxQzFDMkJBQTcxMzE4IiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjRGRDU4Rjg0Mzg1QjExRTNCN0IxQzFDMkJBQTcxMzE4Ii8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+pTD+wgAAACtJREFUeNpimDBhwn8gYABhdDYjiIELMDHgAUwTJ06Ea0VnjxpLO2MBAgwAGYZLegQbQ3UAAAAASUVORK5CYII=) 1px 11px no-repeat;
}
.todo > li:last-child,
.todo > li:only-child {
  border-bottom: 0;
}
.todo > li > :first-child {
  display: block;
  border-right: 1px solid #FFE1EB;
  height: 100%;
  padding: 6px 11px 6px 18px;
  width: 20px;
  vertical-align: top;
  position: absolute;
}
.todo > li > :first-child:hover {
  cursor: move;
}
.todo > li.complete {
  background: 0 0;
}
.todo > li.complete.complete > :first-child:hover {
  cursor: default;
}
.todo > li.complete > * {
  text-decoration: line-through;
  font-style: italic;
}
.todo > li.ui-sortable-helper {
  border-top: 1px solid #eee;
  background: rgba(113, 132, 63, 0.1);
}
.todo > li > p {
  height: 100%;
  margin-left: 52px;
  border-left: 1px solid #FFE1EB;
  display: inline-block;
  padding: 8px 0 6px 7px;
  margin-bottom: 0;
  min-height: 37px;
  line-height: normal;
  font-size: 14px;
  font-weight: 500;
  color: #333;
}
.todo > li > p > span {
  display: block;
  line-height: 12px;
  font-size: 10px;
  font-weight: 400;
}
.todo > li > p > :first-child {
  margin-top: -5px;
  color: #999;
  margin-bottom: 4px;
}
.todo > li > p > .date {
  color: #bfbfbf;
}
.todo-group-title {
  margin: 0;
  line-height: 31px;
  padding: 0 0 0 10px;
  background: #fafafa;
  border-bottom: 1px solid #e7e7e7;
  border-top: 1px solid #f4f4f4;
  color: #999;
}
